@@ -233,7 +233,7 @@ Magick::Color::operator std::string() const
 
   pixel.colorspace=RGBColorspace;
   pixel.matte=_pixelType == RGBAPixel ? MagickTrue : MagickFalse;
-  pixel.depth=QuantumDepth;
+  pixel.depth=MAGICKCORE_QUANTUM_DEPTH;
   pixel.red=_pixel->red;
   pixel.green=_pixel->green;
   pixel.blue=_pixel->blue;
@@ -295,7 +295,7 @@ Magick::ColorHSL::ColorHSL ( double hue_,
 {
   Quantum red, green, blue;
 
-  HSLTransform ( hue_,
+  ConvertHSLToRGB ( hue_,
 		 saturation_,
 		 luminosity_,
 		 &red,
@@ -329,7 +329,7 @@ Magick::ColorHSL::~ColorHSL ( )
 void Magick::ColorHSL::hue ( double hue_ )
 {
   double hue_val, saturation_val, luminosity_val;
-  TransformHSL ( redQuantum(),
+  ConvertRGBToHSL ( redQuantum(),
 		 greenQuantum(),
 		 blueQuantum(),
 		 &hue_val,
@@ -339,7 +339,7 @@ void Magick::ColorHSL::hue ( double hue_ )
   hue_val = hue_;
 
   Quantum red, green, blue;
-  HSLTransform ( hue_val,
+  ConvertHSLToRGB ( hue_val,
 		 saturation_val,
 		 luminosity_val,
 		 &red,
@@ -355,7 +355,7 @@ void Magick::ColorHSL::hue ( double hue_ )
 double Magick::ColorHSL::hue ( void ) const
 {
   double hue_val, saturation_val, luminosity_val;
-  TransformHSL ( redQuantum(),
+  ConvertRGBToHSL ( redQuantum(),
 		 greenQuantum(),
 		 blueQuantum(),
 		 &hue_val,
@@ -367,7 +367,7 @@ double Magick::ColorHSL::hue ( void ) const
 void Magick::ColorHSL::saturation ( double saturation_ )
 {
   double hue_val, saturation_val, luminosity_val;
-  TransformHSL ( redQuantum(),
+  ConvertRGBToHSL ( redQuantum(),
 		 greenQuantum(),
 		 blueQuantum(),
 		 &hue_val,
@@ -377,7 +377,7 @@ void Magick::ColorHSL::saturation ( double saturation_ )
   saturation_val = saturation_;
   
   Quantum red, green, blue;
-  HSLTransform ( hue_val,
+  ConvertHSLToRGB ( hue_val,
 		 saturation_val,
 		 luminosity_val,
 		 &red,
@@ -393,7 +393,7 @@ void Magick::ColorHSL::saturation ( double saturation_ )
 double Magick::ColorHSL::saturation ( void ) const
 {
   double hue_val, saturation_val, luminosity_val;
-  TransformHSL ( redQuantum(),
+  ConvertRGBToHSL ( redQuantum(),
 		 greenQuantum(),
 		 blueQuantum(),
 		 &hue_val,
@@ -405,7 +405,7 @@ double Magick::ColorHSL::saturation ( void ) const
 void Magick::ColorHSL::luminosity ( double luminosity_ )
 {
   double hue_val, saturation_val, luminosity_val;
-  TransformHSL ( redQuantum(),
+  ConvertRGBToHSL ( redQuantum(),
 		 greenQuantum(),
 		 blueQuantum(),
 		 &hue_val,
@@ -415,7 +415,7 @@ void Magick::ColorHSL::luminosity ( double luminosity_ )
   luminosity_val = luminosity_;
   
   Quantum red, green, blue;
-  HSLTransform ( hue_val,
+  ConvertHSLToRGB ( hue_val,
 		 saturation_val,
 		 luminosity_val,
 		 &red,
@@ -431,7 +431,7 @@ void Magick::ColorHSL::luminosity ( double luminosity_ )
 double Magick::ColorHSL::luminosity ( void ) const
 {
   double hue_val, saturation_val, luminosity_val;
-  TransformHSL ( redQuantum(),
+  ConvertRGBToHSL ( redQuantum(),
 		 greenQuantum(),
 		 blueQuantum(),
 		 &hue_val,
