@@ -104,9 +104,9 @@ namespace Magick
   //
   // Base class for all drawable objects
   //
-  //struct MagickDLLDecl std::unary_function<MagickLib::DrawContext,void>;
+  //struct MagickDLLDecl std::unary_function<MagickLib::DrawingWand *,void>;
   class MagickDLLDecl DrawableBase:
-    public std::unary_function<MagickLib::DrawContext,void>
+    public std::unary_function<MagickLib::DrawingWand *,void>
   {
   public:
     // Constructor
@@ -117,7 +117,7 @@ namespace Magick
     virtual ~DrawableBase ( void );
 
     // Operator to invoke equivalent draw API call
-    virtual void operator()( MagickLib::DrawContext ) const = 0;
+    virtual void operator()( MagickLib::DrawingWand * ) const = 0;
 
     // Return polymorphic copy of object
     virtual DrawableBase* copy() const = 0;
@@ -149,7 +149,7 @@ namespace Magick
     Drawable& operator= (const Drawable& original_ );
 
     // Operator to invoke contained object
-    void operator()( MagickLib::DrawContext context_ ) const;
+    void operator()( MagickLib::DrawingWand * context_ ) const;
 
   private:
     DrawableBase* dp;
@@ -199,7 +199,7 @@ public:
   //    const VPathBase& operator= (const VPathBase& original_ );
 
   // Operator to invoke equivalent draw API call
-  virtual void operator()( MagickLib::DrawContext context_ ) const = 0;
+  virtual void operator()( MagickLib::DrawingWand * context_ ) const = 0;
 
   // Return polymorphic copy of object
   virtual VPathBase* copy() const = 0;
@@ -229,7 +229,7 @@ public:
   VPath& operator= (const VPath& original_ );
 
   // Operator to invoke contained object
-  void operator()( MagickLib::DrawContext context_ ) const;
+  void operator()( MagickLib::DrawingWand * context_ ) const;
 
 private:
   VPathBase* dp;
@@ -278,7 +278,7 @@ public:
   /*virtual*/ ~DrawableAffine( void );
 
   // Operator to invoke equivalent draw API call
-  /*virtual*/ void operator()( MagickLib::DrawContext context_ ) const;
+  /*virtual*/ void operator()( MagickLib::DrawingWand * context_ ) const;
 
   // Return polymorphic copy of object
   /*virtual*/
@@ -360,7 +360,7 @@ public:
   /*virtual*/ ~DrawableArc( void );
 
   // Operator to invoke equivalent draw API call
-  /*virtual*/ void operator()( MagickLib::DrawContext context_ ) const;
+  /*virtual*/ void operator()( MagickLib::DrawingWand * context_ ) const;
 
   // Return polymorphic copy of object
   /*virtual*/ DrawableBase* copy() const;
@@ -442,7 +442,7 @@ public:
   /*virtual*/ ~DrawableBezier ( void );
 
   // Operator to invoke equivalent draw API call
-  /*virtual*/ void operator()( MagickLib::DrawContext context_ ) const;
+  /*virtual*/ void operator()( MagickLib::DrawingWand * context_ ) const;
 
   // Return polymorphic copy of object
   /*virtual*/ DrawableBase* copy() const;
@@ -464,7 +464,7 @@ public:
   /*virtual*/ ~DrawablePopClipPath ( void );
 
   // Operator to invoke equivalent draw API call
-  /*virtual*/ void operator()( MagickLib::DrawContext context_ ) const;
+  /*virtual*/ void operator()( MagickLib::DrawingWand * context_ ) const;
 
   // Return polymorphic copy of object
   /*virtual*/ DrawableBase* copy() const;
@@ -484,7 +484,7 @@ public:
   /*virtual*/ ~DrawablePushClipPath ( void );
 
   // Operator to invoke equivalent draw API call
-  /*virtual*/ void operator()( MagickLib::DrawContext context_ ) const;
+  /*virtual*/ void operator()( MagickLib::DrawingWand * context_ ) const;
 
   // Return polymorphic copy of object
   /*virtual*/ DrawableBase* copy() const;
@@ -503,7 +503,7 @@ public:
   /*virtual*/ ~DrawableClipPath ( void );
 
   // Operator to invoke equivalent draw API call
-  /*virtual*/ void operator()( MagickLib::DrawContext context_ ) const;
+  /*virtual*/ void operator()( MagickLib::DrawingWand * context_ ) const;
 
   // Return polymorphic copy of object
   /*virtual*/ DrawableBase* copy() const;
@@ -537,7 +537,7 @@ public:
   /*virtual*/ ~DrawableCircle ( void );
     
   // Operator to invoke equivalent draw API call
-  /*virtual*/ void operator()( MagickLib::DrawContext context_ ) const;
+  /*virtual*/ void operator()( MagickLib::DrawingWand * context_ ) const;
 
   // Return polymorphic copy of object
   /*virtual*/ DrawableBase* copy() const;
@@ -599,7 +599,7 @@ public:
   /*virtual*/ ~DrawableColor ( void );
 
   // Operator to invoke equivalent draw API call
-  /*virtual*/ void operator()( MagickLib::DrawContext context_ ) const;
+  /*virtual*/ void operator()( MagickLib::DrawingWand * context_ ) const;
 
   // Return polymorphic copy of object
   /*virtual*/ DrawableBase* copy() const;
@@ -677,7 +677,7 @@ public:
   (const DrawableCompositeImage& original_ );
 
   // Operator to invoke equivalent draw API call
-  /*virtual*/ void operator()( MagickLib::DrawContext context_ ) const;
+  /*virtual*/ void operator()( MagickLib::DrawingWand * context_ ) const;
 
   // Return polymorphic copy of object
   /*virtual*/ DrawableBase* copy() const;
@@ -764,7 +764,7 @@ public:
   /*virtual*/ ~DrawableEllipse( void );
 
   // Operator to invoke equivalent draw API call
-  /*virtual*/ void operator()( MagickLib::DrawContext context_ ) const;
+  /*virtual*/ void operator()( MagickLib::DrawingWand * context_ ) const;
 
   // Return polymorphic copy of object
   /*virtual*/ DrawableBase* copy() const;
@@ -843,7 +843,7 @@ public:
   /*virtual*/ ~DrawableFillColor( void );
 
   // Operator to invoke equivalent draw API call
-  /*virtual*/ void operator()( MagickLib::DrawContext context_ ) const;
+  /*virtual*/ void operator()( MagickLib::DrawingWand * context_ ) const;
 
   // Return polymorphic copy of object
   /*virtual*/ DrawableBase* copy() const;
@@ -873,7 +873,7 @@ public:
   /*virtual*/ ~DrawableFillRule ( void );
 
   // Operator to invoke equivalent draw API call
-  /*virtual*/ void operator()( MagickLib::DrawContext context_ ) const;
+  /*virtual*/ void operator()( MagickLib::DrawingWand * context_ ) const;
 
   // Return polymorphic copy of object
   /*virtual*/ DrawableBase* copy() const;
@@ -903,7 +903,7 @@ public:
   /*virtual*/ ~DrawableFillOpacity ( void );
 
   // Operator to invoke equivalent draw API call
-  /*virtual*/ void operator()( MagickLib::DrawContext context_ ) const;
+  /*virtual*/ void operator()( MagickLib::DrawingWand * context_ ) const;
 
   // Return polymorphic copy of object
   /*virtual*/ DrawableBase* copy() const;
@@ -936,7 +936,7 @@ public:
   /*virtual*/ ~DrawableFont ( void );
 
   // Operator to invoke equivalent draw API call
-  /*virtual*/ void operator()( MagickLib::DrawContext context_ ) const;
+  /*virtual*/ void operator()( MagickLib::DrawingWand * context_ ) const;
 
   // Return polymorphic copy of object
   /*virtual*/ DrawableBase* copy() const;
@@ -970,7 +970,7 @@ public:
   /*virtual*/ ~DrawableGravity ( void );
 
   // Operator to invoke equivalent draw API call
-  /*virtual*/ void operator()( MagickLib::DrawContext context_ ) const;
+  /*virtual*/ void operator()( MagickLib::DrawingWand * context_ ) const;
 
   // Return polymorphic copy of object
   /*virtual*/ DrawableBase* copy() const;
@@ -1003,7 +1003,7 @@ public:
   /*virtual*/ ~DrawableLine ( void );
 
   // Operator to invoke equivalent draw API call
-  /*virtual*/ void operator()( MagickLib::DrawContext context_ ) const;
+  /*virtual*/ void operator()( MagickLib::DrawingWand * context_ ) const;
 
   // Return polymorphic copy of object
   /*virtual*/ DrawableBase* copy() const;
@@ -1065,7 +1065,7 @@ public:
   /*virtual*/ ~DrawableMatte ( void );
 
   // Operator to invoke equivalent draw API call
-  /*virtual*/ void operator()( MagickLib::DrawContext context_ ) const;
+  /*virtual*/ void operator()( MagickLib::DrawingWand * context_ ) const;
 
   // Return polymorphic copy of object
   /*virtual*/ DrawableBase* copy() const;
@@ -1114,7 +1114,7 @@ public:
   /*virtual*/ ~DrawablePath ( void );
 
   // Operator to invoke equivalent draw API call
-  /*virtual*/ void operator()( MagickLib::DrawContext context_ ) const;
+  /*virtual*/ void operator()( MagickLib::DrawingWand * context_ ) const;
 
   // Return polymorphic copy of object
   /*virtual*/ DrawableBase* copy() const;
@@ -1135,7 +1135,7 @@ public:
   /*virtual*/ ~DrawablePoint ( void );
 
   // Operator to invoke equivalent draw API call
-  /*virtual*/ void operator()( MagickLib::DrawContext context_ ) const;
+  /*virtual*/ void operator()( MagickLib::DrawingWand * context_ ) const;
 
   // Return polymorphic copy of object
   /*virtual*/ DrawableBase* copy() const;
@@ -1174,7 +1174,7 @@ public:
   /*virtual*/ ~DrawablePointSize ( void );
 
   // Operator to invoke equivalent draw API call
-  /*virtual*/ void operator()( MagickLib::DrawContext context_ ) const;
+  /*virtual*/ void operator()( MagickLib::DrawingWand * context_ ) const;
 
   // Return polymorphic copy of object
   /*virtual*/ DrawableBase* copy() const;
@@ -1203,7 +1203,7 @@ public:
   /*virtual*/ ~DrawablePolygon ( void );
 
   // Operator to invoke equivalent draw API call
-  /*virtual*/ void operator()( MagickLib::DrawContext context_ ) const;
+  /*virtual*/ void operator()( MagickLib::DrawingWand * context_ ) const;
 
   // Return polymorphic copy of object
   /*virtual*/ DrawableBase* copy() const;
@@ -1223,7 +1223,7 @@ public:
   /*virtual*/ ~DrawablePolyline ( void );
 
   // Operator to invoke equivalent draw API call
-  /*virtual*/ void operator()( MagickLib::DrawContext context_ ) const;
+  /*virtual*/ void operator()( MagickLib::DrawingWand * context_ ) const;
 
   // Return polymorphic copy of object
   /*virtual*/ DrawableBase* copy() const;
@@ -1244,7 +1244,7 @@ public:
   /*virtual*/ ~DrawablePopGraphicContext ( void );
 
   // Operator to invoke equivalent draw API call
-  /*virtual*/ void operator()( MagickLib::DrawContext context_ ) const;
+  /*virtual*/ void operator()( MagickLib::DrawingWand * context_ ) const;
 
   // Return polymorphic copy of object
   /*virtual*/ DrawableBase* copy() const;
@@ -1265,7 +1265,7 @@ public:
   /*virtual*/ ~DrawablePushGraphicContext ( void );
 
   // Operator to invoke equivalent draw API call
-  /*virtual*/ void operator()( MagickLib::DrawContext context_ ) const;
+  /*virtual*/ void operator()( MagickLib::DrawingWand * context_ ) const;
 
   // Return polymorphic copy of object
   /*virtual*/ DrawableBase* copy() const;
@@ -1286,7 +1286,7 @@ public:
   /*virtual*/ ~DrawablePopPattern ( void );
 
   // Operator to invoke equivalent draw API call
-  /*virtual*/ void operator()( MagickLib::DrawContext context_ ) const;
+  /*virtual*/ void operator()( MagickLib::DrawingWand * context_ ) const;
 
   // Return polymorphic copy of object
   /*virtual*/ DrawableBase* copy() const;
@@ -1307,7 +1307,7 @@ public:
   /*virtual*/ ~DrawablePushPattern ( void );
 
   // Operator to invoke equivalent draw API call
-  /*virtual*/ void operator()( MagickLib::DrawContext context_ ) const;
+  /*virtual*/ void operator()( MagickLib::DrawingWand * context_ ) const;
 
   // Return polymorphic copy of object
   /*virtual*/ DrawableBase* copy() const;
@@ -1335,7 +1335,7 @@ public:
   /*virtual*/ ~DrawableRectangle ( void );
 
   // Operator to invoke equivalent draw API call
-  /*virtual*/ void operator()( MagickLib::DrawContext context_ ) const;
+  /*virtual*/ void operator()( MagickLib::DrawingWand * context_ ) const;
 
   // Return polymorphic copy of object
   /*virtual*/ DrawableBase* copy() const;
@@ -1394,7 +1394,7 @@ public:
   /*virtual*/ ~DrawableRotation ( void );
 
   // Operator to invoke equivalent draw API call
-  /*virtual*/ void operator()( MagickLib::DrawContext context_ ) const;
+  /*virtual*/ void operator()( MagickLib::DrawingWand * context_ ) const;
 
   // Return polymorphic copy of object
   /*virtual*/ DrawableBase* copy() const;
@@ -1430,7 +1430,7 @@ public:
   /*virtual*/ ~DrawableRoundRectangle ( void );
 
   // Operator to invoke equivalent draw API call
-  /*virtual*/ void operator()( MagickLib::DrawContext context_ ) const;
+  /*virtual*/ void operator()( MagickLib::DrawingWand * context_ ) const;
 
   // Return polymorphic copy of object
   /*virtual*/ DrawableBase* copy() const;
@@ -1510,7 +1510,7 @@ public:
   /*virtual*/ ~DrawableScaling ( void );
 
   // Operator to invoke equivalent draw API call
-  /*virtual*/ void operator()( MagickLib::DrawContext context_ ) const;
+  /*virtual*/ void operator()( MagickLib::DrawingWand * context_ ) const;
 
   // Return polymorphic copy of object
   /*virtual*/ DrawableBase* copy() const;
@@ -1549,7 +1549,7 @@ public:
   /*virtual*/ ~DrawableSkewX ( void );
 
   // Operator to invoke equivalent draw API call
-  /*virtual*/ void operator()( MagickLib::DrawContext context_ ) const;
+  /*virtual*/ void operator()( MagickLib::DrawingWand * context_ ) const;
 
   // Return polymorphic copy of object
   /*virtual*/ DrawableBase* copy() const;
@@ -1578,7 +1578,7 @@ public:
   /*virtual*/ ~DrawableSkewY ( void );
 
   // Operator to invoke equivalent draw API call
-  /*virtual*/ void operator()( MagickLib::DrawContext context_ ) const;
+  /*virtual*/ void operator()( MagickLib::DrawingWand * context_ ) const;
 
   // Return polymorphic copy of object
   /*virtual*/ DrawableBase* copy() const;
@@ -1607,7 +1607,7 @@ public:
   /*virtual*/ ~DrawableDashArray( void );
 
   // Operator to invoke equivalent draw API call
-  /*virtual*/ void operator()( MagickLib::DrawContext context_ ) const;
+  /*virtual*/ void operator()( MagickLib::DrawingWand * context_ ) const;
 
   // Return polymorphic copy of object
   /*virtual*/ DrawableBase* copy() const;
@@ -1638,7 +1638,7 @@ public:
   /*virtual*/ ~DrawableDashOffset ( void );
 
   // Operator to invoke equivalent draw API call
-  /*virtual*/ void operator()( MagickLib::DrawContext context_ ) const;
+  /*virtual*/ void operator()( MagickLib::DrawingWand * context_ ) const;
 
   // Return polymorphic copy of object
   /*virtual*/ DrawableBase* copy() const;
@@ -1667,7 +1667,7 @@ public:
   /*virtual*/ ~DrawableStrokeLineCap ( void );
 
   // Operator to invoke equivalent draw API call
-  /*virtual*/ void operator()( MagickLib::DrawContext context_ ) const;
+  /*virtual*/ void operator()( MagickLib::DrawingWand * context_ ) const;
 
   // Return polymorphic copy of object
   /*virtual*/ DrawableBase* copy() const;
@@ -1696,7 +1696,7 @@ public:
   /*virtual*/ ~DrawableStrokeLineJoin ( void );
 
   // Operator to invoke equivalent draw API call
-  /*virtual*/ void operator()( MagickLib::DrawContext context_ ) const;
+  /*virtual*/ void operator()( MagickLib::DrawingWand * context_ ) const;
 
   // Return polymorphic copy of object
   /*virtual*/ DrawableBase* copy() const;
@@ -1725,7 +1725,7 @@ public:
   /*virtual*/ ~DrawableMiterLimit ( void );
 
   // Operator to invoke equivalent draw API call
-  /*virtual*/ void operator()( MagickLib::DrawContext context_ ) const;
+  /*virtual*/ void operator()( MagickLib::DrawingWand * context_ ) const;
 
   // Return polymorphic copy of object
   /*virtual*/ DrawableBase* copy() const;
@@ -1755,7 +1755,7 @@ public:
   /*virtual*/ ~DrawableStrokeAntialias ( void );
 
   // Operator to invoke equivalent draw API call
-  /*virtual*/ void operator()( MagickLib::DrawContext context_ ) const;
+  /*virtual*/ void operator()( MagickLib::DrawingWand * context_ ) const;
 
   // Return polymorphic copy of object
   /*virtual*/ DrawableBase* copy() const;
@@ -1784,7 +1784,7 @@ public:
   /*virtual*/ ~DrawableStrokeColor ( void );
 
   // Operator to invoke equivalent draw API call
-  /*virtual*/ void operator()( MagickLib::DrawContext context_ ) const;
+  /*virtual*/ void operator()( MagickLib::DrawingWand * context_ ) const;
 
   // Return polymorphic copy of object
   /*virtual*/ DrawableBase* copy() const;
@@ -1814,7 +1814,7 @@ public:
   /*virtual*/ ~DrawableStrokeOpacity ( void );
 
   // Operator to invoke equivalent draw API call
-  /*virtual*/ void operator()( MagickLib::DrawContext context_ ) const;
+  /*virtual*/ void operator()( MagickLib::DrawingWand * context_ ) const;
 
   // Return polymorphic copy of object
   /*virtual*/ DrawableBase* copy() const;
@@ -1843,7 +1843,7 @@ public:
   /*virtual*/ ~DrawableStrokeWidth ( void );
 
   // Operator to invoke equivalent draw API call
-  /*virtual*/ void operator()( MagickLib::DrawContext context_ ) const;
+  /*virtual*/ void operator()( MagickLib::DrawingWand * context_ ) const;
 
   // Return polymorphic copy of object
   /*virtual*/ DrawableBase* copy() const;
@@ -1875,7 +1875,7 @@ public:
   /*virtual*/ ~DrawableText ( void );
 
   // Operator to invoke equivalent draw API call
-  /*virtual*/ void operator()( MagickLib::DrawContext context_ ) const;
+  /*virtual*/ void operator()( MagickLib::DrawingWand * context_ ) const;
 
   // Return polymorphic copy of object
   /*virtual*/ DrawableBase* copy() const;
@@ -1930,7 +1930,7 @@ public:
   /*virtual*/ ~DrawableTextAntialias ( void );
 
   // Operator to invoke equivalent draw API call
-  /*virtual*/ void operator()( MagickLib::DrawContext context_ ) const;
+  /*virtual*/ void operator()( MagickLib::DrawingWand * context_ ) const;
 
   // Return polymorphic copy of object
   /*virtual*/ DrawableBase* copy() const;
@@ -1959,7 +1959,7 @@ public:
   /*virtual*/ ~DrawableTextDecoration( void );
 
   // Operator to invoke equivalent draw API call
-  /*virtual*/  void operator()( MagickLib::DrawContext context_ ) const;
+  /*virtual*/  void operator()( MagickLib::DrawingWand * context_ ) const;
 
   // Return polymorphic copy of object
   /*virtual*/ DrawableBase* copy() const;
@@ -1988,7 +1988,7 @@ public:
   /*virtual*/ ~DrawableTextUnderColor ( void );
 
   // Operator to invoke equivalent draw API call
-  /*virtual*/ void operator()( MagickLib::DrawContext context_ ) const;
+  /*virtual*/ void operator()( MagickLib::DrawingWand * context_ ) const;
 
   // Return polymorphic copy of object
   /*virtual*/ DrawableBase* copy() const;
@@ -2018,7 +2018,7 @@ public:
   /*virtual*/ ~DrawableTranslation ( void );
 
   // Operator to invoke equivalent draw API call
-  /*virtual*/ void operator()( MagickLib::DrawContext context_ ) const;
+  /*virtual*/ void operator()( MagickLib::DrawingWand * context_ ) const;
 
   // Return polymorphic copy of object
   /*virtual*/ DrawableBase* copy() const;
@@ -2060,7 +2060,7 @@ public:
   /*virtual*/ ~DrawableViewbox ( void );
 
   // Operator to invoke equivalent draw API call
-  /*virtual*/ void operator()( MagickLib::DrawContext context_ ) const;
+  /*virtual*/ void operator()( MagickLib::DrawingWand * context_ ) const;
 
   // Return polymorphic copy of object
   /*virtual*/
@@ -2241,7 +2241,7 @@ public:
   /*virtual*/ ~PathArcAbs ( void );
 
   // Operator to invoke equivalent draw API call
-  /*virtual*/ void operator()( MagickLib::DrawContext context_ ) const;
+  /*virtual*/ void operator()( MagickLib::DrawingWand * context_ ) const;
 
   // Return polymorphic copy of object
   /*virtual*/ VPathBase* copy() const;
@@ -2263,7 +2263,7 @@ public:
   /*virtual*/ ~PathArcRel ( void );
 
   // Operator to invoke equivalent draw API call
-  /*virtual*/ void operator()( MagickLib::DrawContext context_ ) const;
+  /*virtual*/ void operator()( MagickLib::DrawingWand * context_ ) const;
 
   // Return polymorphic copy of object
   /*virtual*/ VPathBase* copy() const;
@@ -2284,7 +2284,7 @@ public:
   /*virtual*/ ~PathClosePath ( void );
 
   // Operator to invoke equivalent draw API call
-  /*virtual*/ void operator()( MagickLib::DrawContext context_ ) const;
+  /*virtual*/ void operator()( MagickLib::DrawingWand * context_ ) const;
 
   // Return polymorphic copy of object
   /*virtual*/ VPathBase* copy() const;
@@ -2414,7 +2414,7 @@ public:
   /*virtual*/ ~PathCurvetoAbs ( void );
 
   // Operator to invoke equivalent draw API call
-  /*virtual*/ void operator()( MagickLib::DrawContext context_ ) const;
+  /*virtual*/ void operator()( MagickLib::DrawingWand * context_ ) const;
 
   // Return polymorphic copy of object
   /*virtual*/ VPathBase* copy() const;
@@ -2437,7 +2437,7 @@ public:
   /*virtual*/ ~PathCurvetoRel ( void );
 
   // Operator to invoke equivalent draw API call
-  /*virtual*/ void operator()( MagickLib::DrawContext context_ ) const;
+  /*virtual*/ void operator()( MagickLib::DrawingWand * context_ ) const;
 
   // Return polymorphic copy of object
   /*virtual*/ VPathBase* copy() const;
@@ -2460,7 +2460,7 @@ public:
   /*virtual*/ ~PathSmoothCurvetoAbs ( void );
 
   // Operator to invoke equivalent draw API call
-  /*virtual*/ void operator()( MagickLib::DrawContext context_ ) const;
+  /*virtual*/ void operator()( MagickLib::DrawingWand * context_ ) const;
 
   // Return polymorphic copy of object
   /*virtual*/ 
@@ -2485,7 +2485,7 @@ public:
   /*virtual*/ ~PathSmoothCurvetoRel ( void );
 
   // Operator to invoke equivalent draw API call
-  /*virtual*/ void operator()( MagickLib::DrawContext context_ ) const;
+  /*virtual*/ void operator()( MagickLib::DrawingWand * context_ ) const;
 
   // Return polymorphic copy of object
   /*virtual*/ 
@@ -2595,7 +2595,7 @@ public:
   /*virtual*/ ~PathQuadraticCurvetoAbs ( void );
 
   // Operator to invoke equivalent draw API call
-  /*virtual*/ void operator()( MagickLib::DrawContext context_ ) const;
+  /*virtual*/ void operator()( MagickLib::DrawingWand * context_ ) const;
 
   // Return polymorphic copy of object
   /*virtual*/ VPathBase* copy() const;
@@ -2619,7 +2619,7 @@ public:
   /*virtual*/ ~PathQuadraticCurvetoRel ( void );
 
   // Operator to invoke equivalent draw API call
-  /*virtual*/ void operator()( MagickLib::DrawContext context_ ) const;
+  /*virtual*/ void operator()( MagickLib::DrawingWand * context_ ) const;
 
   // Return polymorphic copy of object
   /*virtual*/ VPathBase* copy() const;
@@ -2643,7 +2643,7 @@ public:
   /*virtual*/ ~PathSmoothQuadraticCurvetoAbs ( void );
 
   // Operator to invoke equivalent draw API call
-  /*virtual*/ void operator()( MagickLib::DrawContext context_ ) const;
+  /*virtual*/ void operator()( MagickLib::DrawingWand * context_ ) const;
 
   // Return polymorphic copy of object
   /*virtual*/ VPathBase* copy() const;
@@ -2667,7 +2667,7 @@ public:
   /*virtual*/ ~PathSmoothQuadraticCurvetoRel ( void );
 
   // Operator to invoke equivalent draw API call
-  /*virtual*/ void operator()( MagickLib::DrawContext context_ ) const;
+  /*virtual*/ void operator()( MagickLib::DrawingWand * context_ ) const;
 
   // Return polymorphic copy of object
   /*virtual*/ VPathBase* copy() const;
@@ -2695,7 +2695,7 @@ public:
   /*virtual*/ ~PathLinetoAbs ( void );
 
   // Operator to invoke equivalent draw API call
-  /*virtual*/ void operator()( MagickLib::DrawContext context_ ) const;
+  /*virtual*/ void operator()( MagickLib::DrawingWand * context_ ) const;
 
   // Return polymorphic copy of object
   /*virtual*/ VPathBase* copy() const;
@@ -2719,7 +2719,7 @@ public:
   /*virtual*/ ~PathLinetoRel ( void );
 
   // Operator to invoke equivalent draw API call
-  /*virtual*/ void operator()( MagickLib::DrawContext context_ ) const;
+  /*virtual*/ void operator()( MagickLib::DrawingWand * context_ ) const;
 
   // Return polymorphic copy of object
   /*virtual*/ VPathBase* copy() const;
@@ -2740,7 +2740,7 @@ public:
   /*virtual*/ ~PathLinetoHorizontalAbs ( void );
 
   // Operator to invoke equivalent draw API call
-  /*virtual*/ void operator()( MagickLib::DrawContext context_ ) const;
+  /*virtual*/ void operator()( MagickLib::DrawingWand * context_ ) const;
 
   // Return polymorphic copy of object
   /*virtual*/ VPathBase* copy() const;
@@ -2768,7 +2768,7 @@ public:
   /*virtual*/ ~PathLinetoHorizontalRel ( void );
 
   // Operator to invoke equivalent draw API call
-  /*virtual*/ void operator()( MagickLib::DrawContext context_ ) const;
+  /*virtual*/ void operator()( MagickLib::DrawingWand * context_ ) const;
 
   // Return polymorphic copy of object
   /*virtual*/ VPathBase* copy() const;
@@ -2798,7 +2798,7 @@ public:
   /*virtual*/ ~PathLinetoVerticalAbs ( void );
 
   // Operator to invoke equivalent draw API call
-  /*virtual*/ void operator()( MagickLib::DrawContext context_ ) const;
+  /*virtual*/ void operator()( MagickLib::DrawingWand * context_ ) const;
 
   // Return polymorphic copy of object
   /*virtual*/ VPathBase* copy() const;
@@ -2826,7 +2826,7 @@ public:
   /*virtual*/ ~PathLinetoVerticalRel ( void );
 
   // Operator to invoke equivalent draw API call
-  /*virtual*/ void operator()( MagickLib::DrawContext context_ ) const;
+  /*virtual*/ void operator()( MagickLib::DrawingWand * context_ ) const;
 
   // Return polymorphic copy of object
   /*virtual*/ VPathBase* copy() const;
@@ -2861,7 +2861,7 @@ public:
   /*virtual*/ ~PathMovetoAbs ( void );
 
   // Operator to invoke equivalent draw API call
-  /*virtual*/ void operator()( MagickLib::DrawContext context_ ) const;
+  /*virtual*/ void operator()( MagickLib::DrawingWand * context_ ) const;
 
   // Return polymorphic copy of object
   /*virtual*/ VPathBase* copy() const;
@@ -2885,7 +2885,7 @@ public:
   /*virtual*/ ~PathMovetoRel ( void );
 
   // Operator to invoke equivalent draw API call
-  /*virtual*/ void operator()( MagickLib::DrawContext context_ ) const;
+  /*virtual*/ void operator()( MagickLib::DrawingWand * context_ ) const;
 
   // Return polymorphic copy of object
   /*virtual*/ VPathBase* copy() const;
