@@ -17,7 +17,7 @@
 %                                 July 1992                                   %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2007 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2008 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -51,9 +51,10 @@
 #include "magick/magick.h"
 #include "magick/memory_.h"
 #include "magick/monitor.h"
-#include "magick/quantum.h"
+#include "magick/quantum-private.h"
 #include "magick/static.h"
 #include "magick/string_.h"
+#include "magick/module.h"
 
 /*
   Forward declarations.
@@ -82,22 +83,11 @@ static MagickBooleanType
 %
 %  A description of each parameter follows:
 %
-%    o image_info: The image info.
+%    o image_info: the image info.
 %
 %    o exception: return any errors or warnings in this structure.
 %
-%
 */
-
-static inline size_t CheckOverflowException(const Image *image,
-  const size_t extend)
-{
-  if ((extend*image->columns) < (size_t) image->columns)
-    ThrowMagickFatalException(ResourceLimitFatalError,"MemoryAllocationFailed",
-      image->filename);
-  return(extend*image->columns);
-}
-
 static Image *ReadAVSImage(const ImageInfo *image_info,ExceptionInfo *exception)
 {
   Image
@@ -141,7 +131,7 @@ static Image *ReadAVSImage(const ImageInfo *image_info,ExceptionInfo *exception)
       image_info->filename);
   assert(exception != (ExceptionInfo *) NULL);
   assert(exception->signature == MagickSignature);
-  image=AllocateImage(image_info);
+  image=AcquireImage(image_info);
   status=OpenBlob(image_info,image,ReadBinaryBlobMode,exception);
   if (status == MagickFalse)
     {
@@ -153,7 +143,9 @@ static Image *ReadAVSImage(const ImageInfo *image_info,ExceptionInfo *exception)
   */
   width=ReadBlobMSBLong(image);
   height=ReadBlobMSBLong(image);
-  if ((width == ~0UL) || (height == ~0UL))
+  if (EOFBlob(image) != MagickFalse)
+    ThrowReaderException(CorruptImageError,"ImproperImageHeader");
+  if ((width == 0UL) || (height == 0UL))
     ThrowReaderException(CorruptImageError,"ImproperImageHeader");
   do
   {
@@ -166,10 +158,16 @@ static Image *ReadAVSImage(const ImageInfo *image_info,ExceptionInfo *exception)
     if ((image_info->ping != MagickFalse) && (image_info->number_scenes != 0))
       if (image->scene >= (image_info->scene+image_info->number_scenes-1))
         break;
-    length=CheckOverflowException(image,4);
-    pixels=(unsigned char *) AcquireMagickMemory(length);
+    if (SetImageExtent(image,0,0) == MagickFalse)
+      {
+        InheritException(exception,&image->exception);
+        return(DestroyImageList(image));
+      }
+    length=(size_t) image->columns;
+    pixels=(unsigned char *) AcquireQuantumMemory(length,4*sizeof(*pixels));
     if (pixels == (unsigned char *) NULL) 
       ThrowReaderException(ResourceLimitError,"MemoryAllocationFailed");
+    length*=4*sizeof(*pixels);
     for (y=0; y < (long) image->rows; y++)
     {
       count=ReadBlob(image,length,pixels);
@@ -216,12 +214,12 @@ static Image *ReadAVSImage(const ImageInfo *image_info,ExceptionInfo *exception)
         break;
     width=ReadBlobMSBLong(image);
     height=ReadBlobMSBLong(image);
-    if ((width != ~0UL) && (height != ~0UL))
+    if ((width != 0UL) && (height != 0UL))
       {
         /*
           Allocate next image structure.
         */
-        AllocateNextImage(image_info,image);
+        AcquireNextImage(image_info,image);
         if (GetNextImageInList(image) == (Image *) NULL)
           {
             image=DestroyImageList(image);
@@ -236,8 +234,8 @@ static Image *ReadAVSImage(const ImageInfo *image_info,ExceptionInfo *exception)
               break;
           }
       }
-  } while ((width != ~0UL) && (height != ~0UL));
-  CloseBlob(image);
+  } while ((width != 0UL) && (height != 0UL));
+  (void) CloseBlob(image);
   return(GetFirstImageInList(image));
 }
 
@@ -260,20 +258,21 @@ static Image *ReadAVSImage(const ImageInfo *image_info,ExceptionInfo *exception)
 %
 %  The format of the RegisterAVSImage method is:
 %
-%      RegisterAVSImage(void)
+%      unsigned long RegisterAVSImage(void)
 %
 */
-ModuleExport void RegisterAVSImage(void)
+ModuleExport unsigned long RegisterAVSImage(void)
 {
   MagickInfo
     *entry;
 
   entry=SetMagickInfo("AVS");
-  entry->decoder=(DecoderHandler *) ReadAVSImage;
-  entry->encoder=(EncoderHandler *) WriteAVSImage;
+  entry->decoder=(DecodeImageHandler *) ReadAVSImage;
+  entry->encoder=(EncodeImageHandler *) WriteAVSImage;
   entry->description=ConstantString("AVS X image");
   entry->module=ConstantString("AVS");
   (void) RegisterMagickInfo(entry);
+  return(MagickImageCoderSignature);
 }
 
 /*
@@ -319,11 +318,10 @@ ModuleExport void UnregisterAVSImage(void)
 %
 %  A description of each parameter follows.
 %
-%    o image_info: The image info.
+%    o image_info: the image info.
 %
 %    o image:  The image.
 %
-%
 */
 static MagickBooleanType WriteAVSImage(const ImageInfo *image_info,Image *image)
 {
@@ -364,7 +362,7 @@ static MagickBooleanType WriteAVSImage(const ImageInfo *image_info,Image *image)
     /*
       Write AVS header.
     */
-    if (image_info->colorspace == UndefinedColorspace)
+    if (image->colorspace != RGBColorspace)
       (void) SetImageColorspace(image,RGBColorspace);
     (void) WriteBlobMSBLong(image,image->columns);
     (void) WriteBlobMSBLong(image,image->rows);
@@ -372,7 +370,7 @@ static MagickBooleanType WriteAVSImage(const ImageInfo *image_info,Image *image)
       Allocate memory for pixels.
     */
     pixels=(unsigned char *) AcquireMagickMemory((size_t) image->columns*
-      sizeof(PixelPacket));
+      4*sizeof(*pixels));
     if (pixels == (unsigned char *) NULL)
       ThrowWriterException(ResourceLimitError,"MemoryAllocationFailed");
     /*
@@ -417,6 +415,6 @@ static MagickBooleanType WriteAVSImage(const ImageInfo *image_info,Image *image)
       }
     scene++;
   } while (image_info->adjoin != MagickFalse);
-  CloseBlob(image);
+  (void) CloseBlob(image);
   return(MagickTrue);
 }
