@@ -823,7 +823,7 @@ static MagickBooleanType WriteCMYKImage(const ImageInfo *image_info,
       (void) SetImageColorspace(image,CMYKColorspace);
     if ((LocaleCompare(image_info->magick,"CMYKA") == 0) &&
         (image->matte == MagickFalse))
-      (void) SetImageOpacity(image,OpaqueOpacity);
+      (void) SetImageAlphaChannel(image,ResetAlphaChannel);
     quantum_info=AcquireQuantumInfo(image_info,image);
     pixels=GetQuantumPixels(quantum_info);
     switch (image_info->interlace)
