@@ -421,7 +421,7 @@ static MagickBooleanType ReadDDSInfo(Image *image, DDSInfo *dds_info)
 	dds_info->flags = ReadBlobLSBLong(image);
   
 	/* Check required flags */
-	required = (unsigned long) (DDSD_CAPS | DDSD_WIDTH | DDSD_HEIGHT | DDSD_PIXELFORMAT);
+	required=(unsigned long) (DDSD_WIDTH | DDSD_HEIGHT | DDSD_PIXELFORMAT);
   if ((dds_info->flags & required) != required)
 		return MagickFalse;
   
