@@ -167,7 +167,7 @@ pump_data_until_message(LoadContext *lc,Image *image) /* ddjvu_context_t *contex
         unsigned char data[BLOCKSIZE];
         unsigned long size;
         ddjvu_message_t *message;
-                
+
         /* i might check for a condition! */
         while (!(message = ddjvu_message_peek(lc->context))
                && (size = (unsigned long) ReadBlob(image,(size_t) blocksize,data)) == blocksize) {
@@ -215,10 +215,10 @@ void
 process_message(ddjvu_message_t *message)
 {
 
-#if 0        
+#if 0
    ddjvu_context_t* context= message->m_any.context;
 #endif
-   
+
    if (! message)
       return;
 #if DEBUG
@@ -245,11 +245,11 @@ process_message(ddjvu_message_t *message)
 #endif
            break;
 
-   
+
    case DDJVU_RELAYOUT:
    case DDJVU_PAGEINFO:
    {
-#if 0      
+#if 0
       ddjvu_page_t* page = message->m_any.page;
       page_info* info = ddjvu_page_get_user_data(page);
 
@@ -280,12 +280,12 @@ process_message(ddjvu_message_t *message)
 
       printf("the page can/should be REDISPLAYED\n");
       info->display = 1;
-#endif 
+#endif
       break;
    }
 
    case DDJVU_PROGRESS:
-#if DEBUG 
+#if DEBUG
            printf("PROGRESS:\n");
 #endif
            break;
@@ -321,6 +321,9 @@ process_message(ddjvu_message_t *message)
 static void
 get_page_image(LoadContext *lc, ddjvu_page_t *page, int x, int y, int w, int h, QuantumInfo* quantum_info)
 {
+  int
+    ret;
+
         ddjvu_rect_t rect;
         rect.x = x;
         rect.y = y;
@@ -336,7 +339,7 @@ get_page_image(LoadContext *lc, ddjvu_page_t *page, int x, int y, int w, int h,
                 lc->image->columns *3;
 
         unsigned char* q = malloc(lc->image->rows *  stride);
-        
+
 
         ddjvu_format_t *format = ddjvu_format_create(
                 (type == DDJVU_PAGETYPE_BITONAL)?DDJVU_FORMAT_LSBTOMSB : DDJVU_FORMAT_RGB24,
@@ -352,12 +355,12 @@ get_page_image(LoadContext *lc, ddjvu_page_t *page, int x, int y, int w, int h,
                         abort();
                         /* ThrowReaderException(ResourceLimitError,"MemoryAllocationFailed"); */
                 }
-        
-#endif   
+
+#endif
         ddjvu_format_set_row_order(format, 1);
         ddjvu_format_set_y_direction(format, 1);
 
-        int ret = ddjvu_page_render(page,
+        ret = ddjvu_page_render(page,
                                     DDJVU_RENDER_COLOR, /* ddjvu_render_mode_t */
                                     &rect,
                                     &rect,     /* mmc: ?? */
@@ -411,12 +414,12 @@ get_page_image(LoadContext *lc, ddjvu_page_t *page, int x, int y, int w, int h,
 #else
                 register PixelPacket *r;
 #endif
-                
+
                 for (i = 0;i< (long) lc->image->rows; i++)
                         {
-#if DEBUG 
+#if DEBUG
                                if (i % 1000 == 0) printf("%d\n",i);
-#endif 
+#endif
                                r = SetImagePixels(lc->image,0,i,lc->image->columns,1);
 
                                 ImportQuantumPixels(lc->image,
@@ -436,7 +439,6 @@ get_page_line(PixelPacket *q, LoadContext *lc, int row)
         ddjvu_rect_t rect, pagerect;
         rect.x = 0;
         rect.y = row;
-        rect.w = lc->image->columns;             /* /10 */
         rect.h = 1;             /* /10 */
 
         pagerect.x = 0;
@@ -501,9 +503,9 @@ get_page_line_new(LoadContext *lc, int row, QuantumInfo* quantum_info)
         unsigned char* q = malloc(lc->image->columns
 #if RGB
                          * 3
-#endif                         
+#endif
                 );
-        
+
         int ret = ddjvu_page_render(lc->page,
                                     DDJVU_RENDER_COLOR, /* ddjvu_render_mode_t */
                                     &pagerect,
@@ -518,7 +520,7 @@ get_page_line_new(LoadContext *lc, int row, QuantumInfo* quantum_info)
                             RGBQuantum
 #else
                             GrayQuantum
-#endif 
+#endif
                             ,q);
         free(q);
         ddjvu_format_release(format);
@@ -526,11 +528,11 @@ get_page_line_new(LoadContext *lc, int row, QuantumInfo* quantum_info)
 }
 
 /*
-p%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %                                                                             %
 %                                                                             %
 %                                                                             %
-%   read_one_djvu_image                                                       %
+%   R e a d O n e D J V U I m a g e                                           %
 %                                                                             %
 %                                                                             %
 %                                                                             %
@@ -564,7 +566,7 @@ ReadOneDJVUImage(LoadContext* lc, const int pagenum, const ImageInfo *image_info
         Image *image = lc->image;
         int logging;
         /* register PixelPacket *q; */
-        
+
         QuantumInfo *quantum_info;
 
         ddjvu_message_t *message;
@@ -584,7 +586,7 @@ ReadOneDJVUImage(LoadContext* lc, const int pagenum, const ImageInfo *image_info
                         }
                 /* fixme: maybe exit? */
                 /* if (lc->error) break; */
-                
+
                 message = pump_data_until_message(lc,image);
                 if (message)
                         do {
@@ -597,15 +599,14 @@ ReadOneDJVUImage(LoadContext* lc, const int pagenum, const ImageInfo *image_info
         ddjvu_document_get_pageinfo(lc->document, pagenum, &info);
 
         ddjvu_page_type_t type = ddjvu_page_get_type(lc->page);
-        
+
         /* double -> float! */
         /* image->gamma = (float)ddjvu_page_get_gamma(lc->page); */
 
         /* mmc:  set  image->depth  */
-        /* mmc:  This is from the type */
-        
-        image->columns = info.width;
-        image->rows    = info.height;
+        /* mmc:  This from the type */
+
+        SetImageExtent(image,info.width,info.height);
 
         image->x_resolution = (float) info.dpi;
         image->y_resolution =(float) info.dpi;
@@ -628,17 +629,17 @@ ReadOneDJVUImage(LoadContext* lc, const int pagenum, const ImageInfo *image_info
                 image->matte = MagickTrue;
                 /* is this useful? */
         }
-#if DEBUG        
+#if DEBUG
         printf("now filling %ld x %ld\n", image->columns,image->rows);
 #endif
 
 
 #if 1                           /* per_line */
         quantum_info=AcquireQuantumInfo(image_info,image);
-        
+
         /* q = SetImagePixels(image,0,0,image->columns,image->rows); */
         get_page_image(lc, lc->page, 0, 0, info.width, info.height, quantum_info);
-#else                                        
+#else
         int i;
         for (i = 0;i< image->rows; i++)
                 {
@@ -656,10 +657,10 @@ ReadOneDJVUImage(LoadContext* lc, const int pagenum, const ImageInfo *image_info
 
 #endif /* per_line */
 
-                
+
 #if DEBUG
         printf("END: finished filling %ld x %ld\n", image->columns,image->rows);
-#endif 
+#endif
 
         SyncImage(image);
         quantum_info=DestroyQuantumInfo(quantum_info);
@@ -673,7 +674,7 @@ ReadOneDJVUImage(LoadContext* lc, const int pagenum, const ImageInfo *image_info
                 ddjvu_page_release(lc->page);
                 lc->page = NULL;
         }
-        
+
         /* image->page.y=mng_info->y_off[mng_info->object_id]; */
         return image;
         /* end of reading one DJVU page/image */
@@ -686,7 +687,7 @@ ReadOneDJVUImage(LoadContext* lc, const int pagenum, const ImageInfo *image_info
   if (AcquireImageColormap(image,2) == MagickFalse)
     ThrowReaderException(ResourceLimitError,"MemoryAllocationFailed");
   /*
-    Monochrome colormap.   mmc: this is the default!
+    Monochrome colormap.   mmc: this the default!
   */
   image->colormap[0].red=QuantumRange;
   image->colormap[0].green=QuantumRange;
@@ -711,13 +712,24 @@ djvu_close_lc(LoadContext* lc)
 }
 
 
-static Image *ReadDJVUImage(const ImageInfo *image_info,ExceptionInfo *exception)
+static Image *ReadDJVUImage(const ImageInfo *image_info,
+  ExceptionInfo *exception)
 {
-  Image *image;
+  Image
+    *image,
+    *images;
 
-  MagickBooleanType status;
-  int logging;
-  LoadContext *lc;
+  int
+    logging;
+
+  LoadContext
+    *lc;
+
+  MagickBooleanType
+    status;
+
+  register long
+    i;
 
   /*
    * Open image file.
@@ -736,7 +748,7 @@ static Image *ReadDJVUImage(const ImageInfo *image_info,ExceptionInfo *exception
   logging = LogMagickEvent(CoderEvent,GetMagickModule(),"enter ReadDJVUImage()");
 
   image = AcquireImage(image_info); /* mmc: ?? */
-  
+
 
   lc = (LoadContext *) NULL;
   status = OpenBlob(image_info,image,ReadBinaryBlobMode,exception);
@@ -745,7 +757,7 @@ static Image *ReadDJVUImage(const ImageInfo *image_info,ExceptionInfo *exception
   /*
     Verify DJVU signature.
   */
-#if 0  
+#if 0
   count = ReadBlob(image,8,(unsigned char *) magic_number);
 
   /* IsDJVU(const unsigned char *magick,const size_t length) */
@@ -779,8 +791,8 @@ static Image *ReadDJVUImage(const ImageInfo *image_info,ExceptionInfo *exception
   lc->document = ddjvu_document_create(lc->context, url, use_cache); /* don't cache */
   ddjvu_document_set_user_data(lc->document, lc);
 
-  
-  /* now we wait the the message-request for data: */
+
+  /* now we wait the message-request for data: */
   message = ddjvu_message_wait(lc->context);
 
   if (message->m_any.tag != DDJVU_NEWSTREAM) {
@@ -788,9 +800,9 @@ static Image *ReadDJVUImage(const ImageInfo *image_info,ExceptionInfo *exception
 
           ddjvu_document_release(lc->document);
           ddjvu_context_release(lc->context);
-          
+
           RelinquishMagickMemory(lc);
-                
+
           ThrowReaderException(ResourceLimitError,"Djvu initial message: unexpected type");
           return NULL;    /* error! */
   };
@@ -815,16 +827,18 @@ static Image *ReadDJVUImage(const ImageInfo *image_info,ExceptionInfo *exception
           ddjvu_message_pop(lc->context);
   }
 
-  /* by now we should now the DOCINFO! */
-  assert (lc->pages > 0);
-
-  image = ReadOneDJVUImage(lc,0,image_info,exception);
-  
+  images=NewImageList();
+  for (i=0; i < (long) lc->pages; i++)
+  {
+    image=ReadOneDJVUImage(lc,i,image_info,exception);
+    AppendImageToList(&images,CloneImageList(image,exception));
+  }
 
   djvu_close_lc(lc);
   (void) CloseBlob(image);
+  image=DestroyImageList(image);
 
-#if 0  
+#if 0
   if ((image->page.width == 0) && (image->page.height == 0))
     {
       image->page.width = image->columns+image->page.x;
@@ -843,7 +857,7 @@ static Image *ReadDJVUImage(const ImageInfo *image_info,ExceptionInfo *exception
 #endif
 
 
-  return(GetFirstImageInList(image));
+  return(GetFirstImageInList(images));
 }
 #endif
 
@@ -852,7 +866,7 @@ static Image *ReadDJVUImage(const ImageInfo *image_info,ExceptionInfo *exception
 %                                                                             %
 %                                                                             %
 %                                                                             %
-%   R e g i s t e r P N G I m a g e                                           %
+%   R e g i s t e r D J V U I m a g e                                         %
 %                                                                             %
 %                                                                             %
 %                                                                             %
@@ -885,7 +899,7 @@ ModuleExport unsigned long RegisterDJVUImage(void)
       "DJVU 1.2 specification is available there and at\n"
       "ftp://swrinde.nde.swri.edu/pub/djvu/documents/."
     };
-  
+
   *version='\0';
 #if defined(DJVU_LIBDJVU_VER_STRING)
   (void) ConcatenateMagickString(version,"libdjvu ",MaxTextExtent);
@@ -913,7 +927,7 @@ ModuleExport unsigned long RegisterDJVUImage(void)
 %                                                                             %
 %                                                                             %
 %                                                                             %
-%   U n r e g i s t e r P N G I m a g e                                       %
+%   U n r e g i s t e r D J V U I m a g e                                     %
 %                                                                             %
 %                                                                             %
 %                                                                             %
