@@ -17,7 +17,7 @@
 %                                 July 1992                                   %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2007 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2008 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -57,9 +57,10 @@
 #include "magick/monitor.h"
 #include "magick/quantize.h"
 #include "magick/resource_.h"
-#include "magick/quantum.h"
+#include "magick/quantum-private.h"
 #include "magick/static.h"
 #include "magick/string_.h"
+#include "magick/module.h"
 #include "magick/transform.h"
 #include "magick/utility.h"
 
@@ -147,7 +148,7 @@ static MagickBooleanType IsEPT(const unsigned char *magick,const size_t length)
 %
 %  A description of each parameter follows:
 %
-%    o image_info: The image info.
+%    o image_info: the image info.
 %
 %    o exception: return any errors or warnings in this structure.
 %
@@ -182,7 +183,7 @@ static Image *ReadEPTImage(const ImageInfo *image_info,ExceptionInfo *exception)
       image_info->filename);
   assert(exception != (ExceptionInfo *) NULL);
   assert(exception->signature == MagickSignature);
-  image=AllocateImage(image_info);
+  image=AcquireImage(image_info);
   status=OpenBlob(image_info,image,ReadBinaryBlobMode,exception);
   if (status == MagickFalse)
     {
@@ -201,10 +202,11 @@ static Image *ReadEPTImage(const ImageInfo *image_info,ExceptionInfo *exception)
   (void) ReadBlobLSBShort(image);
   ept_info.postscript=(unsigned char *) AcquireQuantumMemory(
     ept_info.postscript_length,sizeof(*ept_info.postscript));
+  if (ept_info.postscript == (unsigned char *) NULL)
+    ThrowReaderException(ResourceLimitError,"MemoryAllocationFailed");
   ept_info.tiff=(unsigned char *) AcquireQuantumMemory(ept_info.tiff_length,
     sizeof(*ept_info.tiff));
-  if ((ept_info.postscript == (unsigned char *) NULL) ||
-      (ept_info.tiff == (unsigned char *) NULL))
+  if ((ept_info.tiff_length != 0) && (ept_info.tiff == (unsigned char *) NULL))
     ThrowReaderException(ResourceLimitError,"MemoryAllocationFailed");
   offset=SeekBlob(image,ept_info.tiff_offset,SEEK_SET);
   if (offset < 0)
@@ -218,7 +220,7 @@ static Image *ReadEPTImage(const ImageInfo *image_info,ExceptionInfo *exception)
   count=ReadBlob(image,ept_info.postscript_length,ept_info.postscript);
   if (count != (ssize_t) (ept_info.postscript_length))
     ThrowReaderException(CorruptImageError,"InsufficientImageDataInFile");
-  CloseBlob(image);
+  (void) CloseBlob(image);
   image=DestroyImage(image);
   read_info=CloneImageInfo(image_info);
   (void) CopyMagickString(read_info->magick,"EPS",MaxTextExtent);
@@ -258,18 +260,18 @@ static Image *ReadEPTImage(const ImageInfo *image_info,ExceptionInfo *exception)
 %
 %  The format of the RegisterEPTImage method is:
 %
-%      RegisterEPTImage(void)
+%      unsigned long RegisterEPTImage(void)
 %
 */
-ModuleExport void RegisterEPTImage(void)
+ModuleExport unsigned long RegisterEPTImage(void)
 {
   MagickInfo
     *entry;
 
   entry=SetMagickInfo("EPT");
-  entry->decoder=(DecoderHandler *) ReadEPTImage;
-  entry->encoder=(EncoderHandler *) WriteEPTImage;
-  entry->magick=(MagickHandler *) IsEPT;
+  entry->decoder=(DecodeImageHandler *) ReadEPTImage;
+  entry->encoder=(EncodeImageHandler *) WriteEPTImage;
+  entry->magick=(IsImageFormatHandler *) IsEPT;
   entry->adjoin=MagickFalse;
   entry->blob_support=MagickFalse;
   entry->description=ConstantString(
@@ -277,9 +279,9 @@ ModuleExport void RegisterEPTImage(void)
   entry->module=ConstantString("EPT");
   (void) RegisterMagickInfo(entry);
   entry=SetMagickInfo("EPT2");
-  entry->decoder=(DecoderHandler *) ReadEPTImage;
-  entry->encoder=(EncoderHandler *) WriteEPTImage;
-  entry->magick=(MagickHandler *) IsEPT;
+  entry->decoder=(DecodeImageHandler *) ReadEPTImage;
+  entry->encoder=(EncodeImageHandler *) WriteEPTImage;
+  entry->magick=(IsImageFormatHandler *) IsEPT;
   entry->adjoin=MagickFalse;
   entry->blob_support=MagickFalse;
   entry->description=ConstantString(
@@ -287,14 +289,15 @@ ModuleExport void RegisterEPTImage(void)
   entry->module=ConstantString("EPT");
   (void) RegisterMagickInfo(entry);
   entry=SetMagickInfo("EPT3");
-  entry->decoder=(DecoderHandler *) ReadEPTImage;
-  entry->encoder=(EncoderHandler *) WriteEPTImage;
-  entry->magick=(MagickHandler *) IsEPT;
+  entry->decoder=(DecodeImageHandler *) ReadEPTImage;
+  entry->encoder=(EncodeImageHandler *) WriteEPTImage;
+  entry->magick=(IsImageFormatHandler *) IsEPT;
   entry->blob_support=MagickFalse;
   entry->description=ConstantString(
     "Encapsulated PostScript Level III with TIFF preview");
   entry->module=ConstantString("EPT");
   (void) RegisterMagickInfo(entry);
+  return(MagickImageCoderSignature);
 }
 
 /*
@@ -341,7 +344,7 @@ ModuleExport void UnregisterEPTImage(void)
 %
 %  A description of each parameter follows.
 %
-%    o image_info: The image info.
+%    o image_info: the image info.
 %
 %    o image:  The image.
 %
@@ -445,6 +448,6 @@ static MagickBooleanType WriteEPTImage(const ImageInfo *image_info,Image *image)
   ept_info.postscript=(unsigned char *) RelinquishMagickMemory(
     ept_info.postscript);
   ept_info.tiff=(unsigned char *) RelinquishMagickMemory(ept_info.tiff);
-  CloseBlob(image);
+  (void) CloseBlob(image);
   return(MagickTrue);
 }
