@@ -17,7 +17,7 @@
 %                                 July 1992                                   %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2007 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2008 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -57,10 +57,11 @@
 #include "magick/memory_.h"
 #include "magick/monitor.h"
 #include "magick/pixel.h"
-#include "magick/quantum.h"
+#include "magick/quantum-private.h"
 #include "magick/static.h"
 #include "magick/string_.h"
-#if defined(HasFPX)
+#include "magick/module.h"
+#if defined(MAGICKCORE_FPX_DELEGATE)
 #if !defined(vms) && !defined(macintosh) && !defined(__WINDOWS__)
 #include <fpxlib.h>
 #else
@@ -68,7 +69,7 @@
 #endif
 #endif
 
-#if defined(HasFPX)
+#if defined(MAGICKCORE_FPX_DELEGATE)
 /*
   Forward declarations.
 */
@@ -111,7 +112,7 @@ static MagickBooleanType IsFPX(const unsigned char *magick,const size_t length)
   return(MagickFalse);
 }
 
-#if defined(HasFPX)
+#if defined(MAGICKCORE_FPX_DELEGATE)
 /*
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %                                                                             %
@@ -133,7 +134,7 @@ static MagickBooleanType IsFPX(const unsigned char *magick,const size_t length)
 %
 %  A description of each parameter follows:
 %
-%    o image_info: The image info.
+%    o image_info: the image info.
 %
 %    o exception: return any errors or warnings in this structure.
 %
@@ -189,17 +190,21 @@ static Image *ReadFPXImage(const ImageInfo *image_info,ExceptionInfo *exception)
     *g,
     *r;
 
-  unsigned char
-    *scanline;
+  size_t
+    memory_limit;
 
-  unsigned long
+  unsigned char
+    *pixels;
+
+  unsigned int
     height,
-    memory_limit,
-    scene,
     tile_width,
     tile_height,
     width;
 
+  unsigned long
+    scene;
+
   /*
     Open image.
   */
@@ -210,14 +215,14 @@ static Image *ReadFPXImage(const ImageInfo *image_info,ExceptionInfo *exception)
       image_info->filename);
   assert(exception != (ExceptionInfo *) NULL);
   assert(exception->signature == MagickSignature);
-  image=AllocateImage(image_info);
+  image=AcquireImage(image_info);
   status=OpenBlob(image_info,image,ReadBinaryBlobMode,exception);
   if (status == MagickFalse)
     {
       image=DestroyImageList(image);
       return((Image *) NULL);
     }
-  CloseBlob(image);
+  (void) CloseBlob(image);
   /*
     Initialize FPX toolkit.
   */
@@ -295,8 +300,10 @@ static Image *ReadFPXImage(const ImageInfo *image_info,ExceptionInfo *exception)
         /*
           Note image label.
         */
-        label=(char *) AcquireMagickMemory(summary_info.title.length+
-          MaxTextExtent);
+        label=(char *) NULL;
+        if (~summary_info.title.length >= MaxTextExtent)
+          label=(char *) AcquireQuantumMemory(summary_info.title.length+
+            MaxTextExtent,sizeof(*label));
         if (label == (char *) NULL)
           {
             FPX_ClearSystem();
@@ -317,8 +324,10 @@ static Image *ReadFPXImage(const ImageInfo *image_info,ExceptionInfo *exception)
         /*
           Note image comment.
         */
-        comments=(char *) AcquireMagickMemory(summary_info.comments.length+
-          MaxTextExtent);
+        comments=(char *) NULL;
+        if (~summary_info.comments.length >= MaxTextExtent)
+          comments=(char *) AcquireQuantumMemory(summary_info.comments.length+
+            MaxTextExtent,sizeof(*comments));
         if (comments == (char *) NULL)
           {
             FPX_ClearSystem();
@@ -326,7 +335,7 @@ static Image *ReadFPXImage(const ImageInfo *image_info,ExceptionInfo *exception)
           }
         (void) CopyMagickString(comments,(char *) summary_info.comments.ptr,
           summary_info.comments.length+1);
-        (void) SetImageProperty(image,"Comment",comments);
+        (void) SetImageProperty(image,"comment",comments);
         comments=DestroyString(comments);
       }
   /*
@@ -360,7 +369,7 @@ static Image *ReadFPXImage(const ImageInfo *image_info,ExceptionInfo *exception)
       /*
         Create linear colormap.
       */
-      if (AllocateImageColormap(image,MaxColormapSize) == MagickFalse)
+      if (AcquireImageColormap(image,MaxColormapSize) == MagickFalse)
         {
           FPX_ClearSystem();
           ThrowReaderException(ResourceLimitError,"MemoryAllocationFailed");
@@ -372,12 +381,19 @@ static Image *ReadFPXImage(const ImageInfo *image_info,ExceptionInfo *exception)
       FPX_ClearSystem();
       return(GetFirstImageInList(image));
     }
+  if (SetImageExtent(image,0,0) == MagickFalse)
+    {
+      (void) FPX_CloseImage(flashpix);
+      FPX_ClearSystem();
+      InheritException(exception,&image->exception);
+      return(DestroyImageList(image));
+    }
   /*
     Allocate memory for the image and pixel buffer.
   */
-  scanline=(unsigned char *) AcquireMagickMemory(colorspace.numberOfComponents*
-    image->columns*(tile_height+1));
-  if (scanline == (unsigned char *) NULL)
+  pixels=(unsigned char *) AcquireQuantumMemory(image->columns,(tile_height+
+    1UL)*colorspace.numberOfComponents*sizeof(*pixels));
+  if (pixels == (unsigned char *) NULL)
     {
       FPX_ClearSystem();
       (void) FPX_CloseImage(flashpix);
@@ -393,15 +409,15 @@ static Image *ReadFPXImage(const ImageInfo *image_info,ExceptionInfo *exception)
     fpx_info.components[i].horzSubSampFactor=1;
     fpx_info.components[i].vertSubSampFactor=1;
     fpx_info.components[i].columnStride=fpx_info.numberOfComponents;
-    fpx_info.components[i].lineStride=
-      image->columns*fpx_info.components[i].columnStride;
-    fpx_info.components[i].theData=scanline+i;
+    fpx_info.components[i].lineStride=image->columns*
+      fpx_info.components[i].columnStride;
+    fpx_info.components[i].theData=pixels+i;
   }
-  fpx_info.components[0].myColorType.myColor=
-    fpx_info.numberOfComponents > 2 ? NIFRGB_R : MONOCHROME;
+  fpx_info.components[0].myColorType.myColor=fpx_info.numberOfComponents > 2 ?
+    NIFRGB_R : MONOCHROME;
   red_component=(&fpx_info.components[0]);
-  fpx_info.components[1].myColorType.myColor=
-    fpx_info.numberOfComponents > 2 ? NIFRGB_G : ALPHA;
+  fpx_info.components[1].myColorType.myColor=fpx_info.numberOfComponents > 2 ?
+    NIFRGB_G : ALPHA;
   green_component=(&fpx_info.components[1]);
   fpx_info.components[2].myColorType.myColor=NIFRGB_B;
   blue_component=(&fpx_info.components[2]);
@@ -432,14 +448,14 @@ static Image *ReadFPXImage(const ImageInfo *image_info,ExceptionInfo *exception)
             (long) tile_height,&fpx_info);
         if (fpx_status == FPX_LOW_MEMORY_ERROR)
           {
-            scanline=(unsigned char *) RelinquishMagickMemory(scanline);
+            pixels=(unsigned char *) RelinquishMagickMemory(pixels);
             (void) FPX_CloseImage(flashpix);
             FPX_ClearSystem();
             ThrowReaderException(ResourceLimitError,"MemoryAllocationFailed");
           }
       }
     /*
-      Transfer a FPX scanline.
+      Transfer a FPX pixels.
     */
     r=red_component->theData+(y % tile_height)*red_component->lineStride;
     g=green_component->theData+(y % tile_height)*green_component->lineStride;
@@ -480,7 +496,7 @@ static Image *ReadFPXImage(const ImageInfo *image_info,ExceptionInfo *exception)
           break;
       }
   }
-  scanline=(unsigned char *) RelinquishMagickMemory(scanline);
+  pixels=(unsigned char *) RelinquishMagickMemory(pixels);
   (void) FPX_CloseImage(flashpix);
   FPX_ClearSystem();
   return(GetFirstImageInList(image));
@@ -507,26 +523,27 @@ static Image *ReadFPXImage(const ImageInfo *image_info,ExceptionInfo *exception)
 %
 %  The format of the RegisterFPXImage method is:
 %
-%      RegisterFPXImage(void)
+%      unsigned long RegisterFPXImage(void)
 %
 */
-ModuleExport void RegisterFPXImage(void)
+ModuleExport unsigned long RegisterFPXImage(void)
 {
   MagickInfo
     *entry;
 
   entry=SetMagickInfo("FPX");
-#if defined(HasFPX)
-  entry->decoder=(DecoderHandler *) ReadFPXImage;
-  entry->encoder=(EncoderHandler *) WriteFPXImage;
+#if defined(MAGICKCORE_FPX_DELEGATE)
+  entry->decoder=(DecodeImageHandler *) ReadFPXImage;
+  entry->encoder=(EncodeImageHandler *) WriteFPXImage;
 #endif
   entry->adjoin=MagickFalse;
   entry->seekable_stream=MagickTrue;
   entry->blob_support=MagickFalse;
-  entry->magick=(MagickHandler *) IsFPX;
+  entry->magick=(IsImageFormatHandler *) IsFPX;
   entry->description=ConstantString("FlashPix Format");
   entry->module=ConstantString("FPX");
   (void) RegisterMagickInfo(entry);
+  return(MagickImageCoderSignature);
 }
 
 /*
@@ -553,7 +570,7 @@ ModuleExport void UnregisterFPXImage(void)
   (void) UnregisterMagickInfo("FPX");
 }
 
-#if defined(HasFPX)
+#if defined(MAGICKCORE_FPX_DELEGATE)
 /*
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %                                                                             %
@@ -574,7 +591,7 @@ ModuleExport void UnregisterFPXImage(void)
 %
 %  A description of each parameter follows.
 %
-%    o image_info: The image info.
+%    o image_info: the image info.
 %
 %    o image:  The image.
 %
@@ -804,7 +821,10 @@ static MagickBooleanType WriteFPXImage(const ImageInfo *image_info,Image *image)
     status;
 
   QuantumInfo
-    quantum_info;
+    *quantum_info;
+
+  QuantumType
+    quantum_type;
 
   register const PixelPacket
     *p;
@@ -812,11 +832,14 @@ static MagickBooleanType WriteFPXImage(const ImageInfo *image_info,Image *image)
   register long
     i;
 
+  size_t
+    length,
+    memory_limit;
+
   unsigned char
     *pixels;
 
-  unsigned long
-    memory_limit,
+  unsigned int
     tile_height,
     tile_width;
 
@@ -832,12 +855,12 @@ static MagickBooleanType WriteFPXImage(const ImageInfo *image_info,Image *image)
   status=OpenBlob(image_info,image,WriteBinaryBlobMode,&image->exception);
   if (status == MagickFalse)
     return(status);
-  CloseBlob(image);
+  (void) CloseBlob(image);
   /*
     Initialize FPX toolkit.
   */
   image->depth=8;
-  if (image_info->colorspace == UndefinedColorspace)
+  if (image->colorspace != RGBColorspace)
     (void) SetImageColorspace(image,RGBColorspace);
   memory_limit=20000000;
   fpx_status=FPX_SetToolkitMemoryLimit(&memory_limit);
@@ -907,22 +930,27 @@ static MagickBooleanType WriteFPXImage(const ImageInfo *image_info,Image *image)
   summary_info.thumbnail_valid=MagickFalse;
   summary_info.appname_valid=MagickFalse;
   summary_info.security_valid=MagickFalse;
-  label=GetImageProperty(image,"Label");
+  label=GetImageProperty(image,"label");
   if (label != (const char *) NULL)
     {
+      size_t
+        length;
+
       /*
         Note image label.
       */
       summary_info.title_valid=MagickTrue;
-      summary_info.title.length=strlen(label);
-      summary_info.title.ptr=(unsigned char *)
-        AcquireMagickMemory(strlen(label)+MaxTextExtent);
+      length=strlen(label);
+      summary_info.title.length=length;
+      if (~length >= MaxTextExtent)
+        summary_info.title.ptr=(unsigned char *) AcquireQuantumMemory(
+          length+MaxTextExtent,sizeof(*summary_info.title.ptr));
       if (summary_info.title.ptr == (unsigned char *) NULL)
         ThrowWriterException(DelegateError,"UnableToSetImageTitle");
       (void) CopyMagickString((char *) summary_info.title.ptr,label,
         MaxTextExtent);
     }
-  comment=GetImageProperty(image,"Comment");
+  comment=GetImageProperty(image,"comment");
   if (comment != (const char *) NULL)
     {
       /*
@@ -935,20 +963,11 @@ static MagickBooleanType WriteFPXImage(const ImageInfo *image_info,Image *image)
   fpx_status=FPX_SetSummaryInformation(flashpix,&summary_info);
   if (fpx_status != FPX_OK)
     ThrowWriterException(DelegateError,"UnableToSetSummaryInfo");
-  /*
-    Allocate pixels.
-  */
-  pixels=(unsigned char *) AcquireMagickMemory((colorspace.numberOfComponents*
-    image->columns)*sizeof(*pixels));
-  if (pixels == (unsigned char *) NULL)
-    {
-      (void) FPX_CloseImage(flashpix);
-      FPX_ClearSystem();
-      ThrowWriterException(ResourceLimitError,"MemoryAllocationFailed");
-    }
   /*
     Initialize FlashPix image description.
   */
+  quantum_info=AcquireQuantumInfo(image_info,image);
+  pixels=GetQuantumPixels(quantum_info);
   fpx_info.numberOfComponents=colorspace.numberOfComponents;
   for (i=0; i < (long) fpx_info.numberOfComponents; i++)
   {
@@ -960,27 +979,25 @@ static MagickBooleanType WriteFPXImage(const ImageInfo *image_info,Image *image)
       image->columns*fpx_info.components[i].columnStride;
     fpx_info.components[i].theData=pixels+i;
   }
-  fpx_info.components[0].myColorType.myColor=
-    fpx_info.numberOfComponents != 1 ? NIFRGB_R : MONOCHROME;
+  fpx_info.components[0].myColorType.myColor=fpx_info.numberOfComponents != 1
+    ? NIFRGB_R : MONOCHROME;
   fpx_info.components[1].myColorType.myColor=NIFRGB_G;
   fpx_info.components[2].myColorType.myColor=NIFRGB_B;
   fpx_info.components[3].myColorType.myColor=ALPHA;
   /*
-    Write image scanlines.
+    Write image pixelss.
   */
-  GetQuantumInfo(image_info,&quantum_info);
+  quantum_type=RGBQuantum;
+  if (image->matte != MagickFalse)
+    quantum_type=RGBAQuantum;
+  if (fpx_info.numberOfComponents == 1)
+    quantum_type=GrayQuantum;
   for (y=0; y < (long) image->rows; y++)
   {
     p=AcquireImagePixels(image,0,y,image->columns,1,&image->exception);
     if (p == (const PixelPacket *) NULL)
       break;
-    if (fpx_info.numberOfComponents == 1)
-      (void) ImportQuantumPixels(image,&quantum_info,GrayQuantum,pixels);
-    else
-      if (image->matte == MagickFalse)
-        (void) ImportQuantumPixels(image,&quantum_info,RGBQuantum,pixels);
-      else
-        (void) ImportQuantumPixels(image,&quantum_info,RGBAQuantum,pixels);
+    length=ExportQuantumPixels(image,quantum_info,quantum_type,pixels);
     fpx_status=FPX_WriteImageLine(flashpix,&fpx_info);
     if (fpx_status != FPX_OK)
       break;
@@ -993,6 +1010,7 @@ static MagickBooleanType WriteFPXImage(const ImageInfo *image_info,Image *image)
           break;
       }
   }
+  quantum_info=DestroyQuantumInfo(quantum_info);
   if (image_info->view != (char *) NULL)
     {
       FPXAffineMatrix
@@ -1118,7 +1136,6 @@ static MagickBooleanType WriteFPXImage(const ImageInfo *image_info,Image *image)
     }
   (void) FPX_CloseImage(flashpix);
   FPX_ClearSystem();
-  pixels=(unsigned char *) RelinquishMagickMemory(pixels);
   return(MagickTrue);
 }
 #endif
