@@ -262,7 +262,7 @@ static inline int GetNextLZWCode(LZWInfo *lzw_info,const unsigned long bits)
     lzw_info->code_info.count=2;
     count=ReadBlobBlock(lzw_info->image,&lzw_info->code_info.buffer[
       lzw_info->code_info.count]);
-    if (count >= 0)
+    if (count > 0)
       lzw_info->code_info.count+=count;
     else
       lzw_info->code_info.eof=MagickTrue;
@@ -1023,7 +1023,7 @@ static Image *ReadGIFImage(const ImageInfo *image_info,ExceptionInfo *exception)
       return((Image *) NULL);
     }
   /*
-    Determine if this is a GIF file.
+    Determine if this a GIF file.
   */
   count=ReadBlob(image,6,magick);
   if ((count != 6) || ((LocaleNCompare((char *) magick,"GIF87",5) != 0) &&
