@@ -97,6 +97,7 @@ ModuleExport unsigned long RegisterHISTOGRAMImage(void)
   entry=SetMagickInfo("HISTOGRAM");
   entry->encoder=(EncodeImageHandler *) WriteHISTOGRAMImage;
   entry->adjoin=MagickFalse;
+  entry->format_type=ImplicitFormatType;
   entry->description=ConstantString("Histogram of the image");
   entry->module=ConstantString("HISTOGRAM");
   (void) RegisterMagickInfo(entry);
@@ -230,7 +231,6 @@ static MagickBooleanType WriteHISTOGRAMImage(const ImageInfo *image_info,
   if (image->debug != MagickFalse)
     (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",
       image_info->filename);
-  (void) SetImageDepth(image,image->depth);
   SetGeometry(image,&geometry);
   if (image_info->density == (char *) NULL)
     (void) ParseAbsoluteGeometry(HistogramDensity,&geometry);
@@ -240,7 +240,7 @@ static MagickBooleanType WriteHISTOGRAMImage(const ImageInfo *image_info,
     &image->exception);
   if (histogram_image == (Image *) NULL)
     ThrowWriterException(ResourceLimitError,"MemoryAllocationFailed");
-  histogram_image->storage_class=DirectClass;
+  (void) SetImageStorageClass(histogram_image,DirectClass);
   /*
     Allocate histogram count arrays.
   */
