@@ -160,7 +160,7 @@ static MagickBooleanType
 %
 %  A description of each parameter follows:
 %
-%    o image_info: The image info.
+%    o image_info: the image info.
 %
 %    o exception: return any errors or warnings in this structure.
 %
@@ -216,7 +216,7 @@ static Image *ReadICONImage(const ImageInfo *image_info,
   (void) LogMagickEvent(CoderEvent,GetMagickModule(),"%s",image_info->filename);
   assert(exception != (ExceptionInfo *) NULL);
   assert(exception->signature == MagickSignature);
-  image=AllocateImage(image_info);
+  image=AcquireImage(image_info);
   status=OpenBlob(image_info,image,ReadBinaryBlobMode,exception);
   if (status == MagickFalse)
     {
@@ -266,7 +266,11 @@ static Image *ReadICONImage(const ImageInfo *image_info,
     icon_info.colors_important=ReadBlobLSBLong(image);
     image->matte=MagickTrue;
     image->columns=(unsigned long) icon_file.directory[i].width;
+    if (image->columns == 0)
+      image->columns=256;
     image->rows=(unsigned long) icon_file.directory[i].height;
+    if (image->rows == 0)
+      image->rows=256;
     image->depth=8;
     if (image->debug != MagickFalse)
       {
@@ -306,7 +310,7 @@ static Image *ReadICONImage(const ImageInfo *image_info,
         Read Icon raster colormap.
       */
       number_colors=1UL << icon_info.bits_per_pixel;
-      if (AllocateImageColormap(image,number_colors) == MagickFalse)
+      if (AcquireImageColormap(image,number_colors) == MagickFalse)
         ThrowReaderException(ResourceLimitError,"MemoryAllocationFailed");
       icon_colormap=(unsigned char *) AcquireQuantumMemory((size_t)
         image->colors,4UL*sizeof(*icon_colormap));
@@ -501,7 +505,7 @@ static Image *ReadICONImage(const ImageInfo *image_info,
             q->blue=ScaleCharToQuantum((unsigned char) ReadBlobByte(image));
             q->green=ScaleCharToQuantum((unsigned char) ReadBlobByte(image));
             q->red=ScaleCharToQuantum((unsigned char) ReadBlobByte(image));
-            if (image->matte != MagickFalse)
+            if (icon_info.bits_per_pixel == 32)
               q->opacity=(Quantum) QuantumRange-ScaleCharToQuantum(
                 (unsigned char) ReadBlobByte(image));
             q++;
@@ -527,7 +531,7 @@ static Image *ReadICONImage(const ImageInfo *image_info,
         ThrowReaderException(CorruptImageError,"ImproperImageHeader");
     }
     (void) SyncImage(image);
-    if (icon_info.bits_per_pixel <= 16)
+    if (icon_info.bits_per_pixel != 32)
       {
         /*
           Read the ICON alpha mask.
@@ -576,7 +580,7 @@ static Image *ReadICONImage(const ImageInfo *image_info,
         /*
           Allocate next image structure.
         */
-        AllocateNextImage(image_info,image);
+        AcquireNextImage(image_info,image);
         if (GetNextImageInList(image) == (Image *) NULL)
           {
             image=DestroyImageList(image);
@@ -592,7 +596,7 @@ static Image *ReadICONImage(const ImageInfo *image_info,
           }
       }
   }
-  CloseBlob(image);
+  (void) CloseBlob(image);
   return(GetFirstImageInList(image));
 }
 
@@ -699,7 +703,7 @@ ModuleExport void UnregisterICONImage(void)
 %
 %  A description of each parameter follows.
 %
-%    o image_info: The image info.
+%    o image_info: the image info.
 %
 %    o image:  The image.
 %
@@ -790,15 +794,14 @@ static MagickBooleanType WriteICONImage(const ImageInfo *image_info,
     scene++;
     next=SyncNextImageInList(next);
   } while ((next != (Image *) NULL) && (image_info->adjoin != MagickFalse));
-
   scene=0;
-  next = image;
+  next=image;
   do
   {
     /*
       Initialize ICON raster file header.
     */
-    if (image_info->colorspace == UndefinedColorspace)
+    if (image->colorspace != RGBColorspace)
       (void) SetImageColorspace(next,RGBColorspace);
     icon_info.file_size=14+12+28;
     icon_info.offset_bits=icon_info.file_size;
@@ -811,7 +814,7 @@ static MagickBooleanType WriteICONImage(const ImageInfo *image_info,
           Full color ICON raster.
         */
         icon_info.number_colors=0;
-        icon_info.bits_per_pixel=(unsigned short) 24;
+        icon_info.bits_per_pixel=32;
         icon_info.compression=(unsigned long) BI_RGB;
       }
     else
@@ -875,8 +878,8 @@ static MagickBooleanType WriteICONImage(const ImageInfo *image_info,
     /*
       Convert MIFF to ICON raster pixels.
     */
-    pixels=(unsigned char *) AcquireQuantumMemory((size_t)
-      icon_info.image_size,sizeof(*pixels));
+    pixels=(unsigned char *) AcquireQuantumMemory((size_t) icon_info.image_size,
+      sizeof(*pixels));
     if (pixels == (unsigned char *) NULL)
       ThrowWriterException(ResourceLimitError,"MemoryAllocationFailed");
     (void) ResetMagickMemory(pixels,0,(size_t) icon_info.image_size);
@@ -1013,7 +1016,9 @@ static MagickBooleanType WriteICONImage(const ImageInfo *image_info,
             *q++=ScaleQuantumToChar(p->blue);
             *q++=ScaleQuantumToChar(p->green);
             *q++=ScaleQuantumToChar(p->red);
-            if (icon_info.bits_per_pixel == 32)
+            if (next->matte == MagickFalse)
+              *q++=ScaleQuantumToChar(255);
+            else
               *q++=ScaleQuantumToChar(p->opacity);
             p++;
           }
@@ -1046,7 +1051,7 @@ static MagickBooleanType WriteICONImage(const ImageInfo *image_info,
     icon_file.directory[scene].offset=(unsigned long) TellBlob(image);
     (void) WriteBlobLSBLong(image,(unsigned long) 40);
     (void) WriteBlobLSBLong(image,(unsigned long) icon_info.width);
-    (void) WriteBlobLSBLong(image,(unsigned long) icon_info.height * 2);
+    (void) WriteBlobLSBLong(image,(unsigned long) icon_info.height*2);
     (void) WriteBlobLSBShort(image,icon_info.planes);
     (void) WriteBlobLSBShort(image,icon_info.bits_per_pixel);
     (void) WriteBlobLSBLong(image,icon_info.compression);
@@ -1149,7 +1154,7 @@ static MagickBooleanType WriteICONImage(const ImageInfo *image_info,
     (void) WriteBlobLSBLong(image,icon_file.directory[scene].offset);
     scene++;
     next=SyncNextImageInList(next);
-  } while (next && (image_info->adjoin != MagickFalse));
-  CloseBlob(image);
+  } while ((next != (Image *) NULL) && (image_info->adjoin != MagickFalse));
+  (void) CloseBlob(image);
   return(MagickTrue);
 }
