@@ -189,7 +189,7 @@ static MagickBooleanType IsJPC(const unsigned char *magick,const size_t length)
 %
 %  A description of each parameter follows:
 %
-%    o image_info: The image info.
+%    o image_info: the image info.
 %
 %    o exception: return any errors or warnings in this structure.
 %
@@ -246,7 +246,7 @@ static int BlobClose(jas_stream_obj_t *object)
     *source;
 
   source=(StreamManager *) object;
-  CloseBlob(source->image);
+  (void) CloseBlob(source->image);
   return(0);
 }
 
@@ -318,6 +318,7 @@ static Image *ReadJP2Image(const ImageInfo *image_info,ExceptionInfo *exception)
     *image;
 
   long
+    components[4],
     y;
 
   jas_cmprof_t
@@ -345,18 +346,13 @@ static Image *ReadJP2Image(const ImageInfo *image_info,ExceptionInfo *exception)
   register PixelPacket
     *q;
 
-  int
-    components[4];
-
-  unsigned int
+  unsigned long
     maximum_component_depth,
+    number_components,
     scale[4],
     x_step[4],
     y_step[4];
 
-  unsigned long
-    number_components;
-
   /*
     Open image file.
   */
@@ -367,7 +363,7 @@ static Image *ReadJP2Image(const ImageInfo *image_info,ExceptionInfo *exception)
       image_info->filename);
   assert(exception != (ExceptionInfo *) NULL);
   assert(exception->signature == MagickSignature);
-  image=AllocateImage(image_info);
+  image=AcquireImage(image_info);
   status=OpenBlob(image_info,image,ReadBinaryBlobMode,exception);
   if (status == MagickFalse)
     {
@@ -489,7 +485,7 @@ static Image *ReadJP2Image(const ImageInfo *image_info,ExceptionInfo *exception)
     maximum_component_depth=(unsigned int) MagickMax((size_t)
       jas_image_cmptprec(jp2_image,components[i]),(size_t)
       maximum_component_depth);
-    pixels[i]=jas_matrix_create(1,(int) image->columns/x_step[i]);
+    pixels[i]=jas_matrix_create(1,(int) (image->columns/x_step[i]));
     if (pixels[i] == (jas_matrix_t *) NULL)
       {
         jas_image_destroy(jp2_image);
@@ -504,13 +500,12 @@ static Image *ReadJP2Image(const ImageInfo *image_info,ExceptionInfo *exception)
   {
     scale[i]=1;
     if (jas_image_cmptprec(jp2_image,components[i]) < 16)
-      scale[i]=(1U << (16-jas_image_cmptprec(jp2_image,components[i])));
+      scale[i]=(1U << (16-jas_image_cmptprec(jp2_image,components[i])))+1;
   }
   if (number_components == 1)
     {
-      image->storage_class=PseudoClass;
       image->colors=(image->depth == 8 ? 256UL : MaxColormapSize);
-      if (AllocateImageColormap(image,image->colors) == MagickFalse)
+      if (AcquireImageColormap(image,image->colors) == MagickFalse)
         ThrowReaderException(ResourceLimitError,"MemoryAllocationFailed");
     }
   for (y=0; y < (long) image->rows; y++)
@@ -542,16 +537,16 @@ static Image *ReadJP2Image(const ImageInfo *image_info,ExceptionInfo *exception)
             index=ScaleQuantumToChar(ScaleShortToQuantum((unsigned short)
               (scale[0]*jas_matrix_getv(pixels[0],x))));
             index=ConstrainColormapIndex(image,index);
-            *indexes++=index;
+            indexes[x]=index;
             *q++=image->colormap[(long) index];
           }
         else
           for (x=0; x < (long) image->columns; x++)
           {
-            index=(unsigned short) (scale[0]*
-              jas_matrix_getv(pixels[0],x/x_step[0]));
+            index=(unsigned short) (scale[0]*jas_matrix_getv(pixels[0],x/
+              x_step[0]));
             index=ConstrainColormapIndex(image,index);
-            *indexes++=index;
+            indexes[x]=index;
             *q++=image->colormap[(long) index];
           }
         break;
@@ -783,7 +778,7 @@ ModuleExport void UnregisterJP2Image(void)
 %
 %  A description of each parameter follows.
 %
-%    o image_info: The image info.
+%    o image_info: the image info.
 %
 %    o image:  The image.
 %
@@ -798,10 +793,8 @@ static MagickBooleanType WriteJP2Image(const ImageInfo *image_info,Image *image)
   const char
     *option;
 
-  int
-    format;
-
   long
+    format,
     y;
 
   jas_image_cmptparm_t
@@ -844,7 +837,7 @@ static MagickBooleanType WriteJP2Image(const ImageInfo *image_info,Image *image)
   /*
     Intialize JPEG 2000 API.
   */
-  if (image_info->colorspace == UndefinedColorspace)
+  if (image->colorspace != RGBColorspace)
     (void) SetImageColorspace(image,RGBColorspace);
   jp2_stream=JP2StreamManager(image);
   if (jp2_stream == (jas_stream_t *) NULL)
@@ -957,8 +950,11 @@ static MagickBooleanType WriteJP2Image(const ImageInfo *image_info,Image *image)
         if (LocaleNCompare(key,"jp2:",4) == 0)
           {
             (void) ConcatenateString(&options,key+4);
-            (void) ConcatenateString(&options,"=");
-            (void) ConcatenateString(&options,option);
+            if (*option != '\0')
+              {
+                (void) ConcatenateString(&options,"=");
+                (void) ConcatenateString(&options,option);
+              }
             (void) ConcatenateString(&options," ");
           }
        }
