@@ -197,7 +197,7 @@ static MagickBooleanType IsJPEG(const unsigned char *magick,const size_t length)
 %
 %  A description of each parameter follows:
 %
-%    o image_info: The image info.
+%    o image_info: the image info.
 %
 %    o exception: return any errors or warnings in this structure.
 %
@@ -669,6 +669,7 @@ static Image *ReadJPEGImage(const ImageInfo *image_info,
     *q;
 
   unsigned long
+    precision,
     units;
 
   /*
@@ -682,7 +683,7 @@ static Image *ReadJPEGImage(const ImageInfo *image_info,
   assert(exception != (ExceptionInfo *) NULL);
   assert(exception->signature == MagickSignature);
   debug=IsEventLogging();
-  image=AllocateImage(image_info);
+  image=AcquireImage(image_info);
   status=OpenBlob(image_info,image,ReadBinaryBlobMode,exception);
   if (status == MagickFalse)
     {
@@ -703,7 +704,7 @@ static Image *ReadJPEGImage(const ImageInfo *image_info,
     {
       jpeg_destroy_decompress(&jpeg_info);
       InheritException(exception,&image->exception);
-      CloseBlob(image);
+      (void) CloseBlob(image);
       number_pixels=(MagickSizeType) image->columns*image->rows;
       if (number_pixels != 0)
         return(GetFirstImageInList(image));
@@ -720,9 +721,9 @@ static Image *ReadJPEGImage(const ImageInfo *image_info,
     if ((i != 2) && (i != 13) && (i != 14))
       jpeg_set_marker_processor(&jpeg_info,(int) (JPEG_APP0+i),ReadProfile);
   i=jpeg_read_header(&jpeg_info,MagickTrue);
-  if ((image_info->colorspace == YCbCrColorspace) ||
-      (image_info->colorspace == Rec601YCbCrColorspace) ||
-      (image_info->colorspace == Rec709YCbCrColorspace))
+  if ((image->colorspace == YCbCrColorspace) ||
+      (image->colorspace == Rec601YCbCrColorspace) ||
+      (image->colorspace == Rec709YCbCrColorspace))
     {
       jpeg_info.out_color_space=JCS_YCbCr;
       image->colorspace=YCbCrColorspace;
@@ -770,6 +771,7 @@ static Image *ReadJPEGImage(const ImageInfo *image_info,
       jpeg_info.scale_denom=(unsigned int) image_info->subrange;
       jpeg_calc_output_dimensions(&jpeg_info);
     }
+  precision=jpeg_info.data_precision;
 #if (JPEG_LIB_VERSION >= 61) && defined(D_PROGRESSIVE_SUPPORTED)
 #if defined(D_LOSSLESS_SUPPORTED)
   image->interlace=jpeg_info.process == JPROC_PROGRESSIVE ?
@@ -780,9 +782,11 @@ static Image *ReadJPEGImage(const ImageInfo *image_info,
     (void) ThrowMagickException(exception,GetMagickModule(),OptionError,
       "12-bit JPEG not supported. Reducing pixel data to 8 bits","`%s'",
       image->filename);
+  if (jpeg_info.data_precision == 16)
+    jpeg_info.data_precision=12;
 #else
-  image->interlace=jpeg_info.progressive_mode != 0 ?
-    JPEGInterlace : NoInterlace;
+  image->interlace=jpeg_info.progressive_mode != 0 ? JPEGInterlace :
+    NoInterlace;
   image->compression=JPEGCompression;
 #endif
 #else
@@ -802,12 +806,16 @@ static Image *ReadJPEGImage(const ImageInfo *image_info,
   image->rows=jpeg_info.output_height;
   image->depth=(unsigned long) jpeg_info.data_precision;
   if ((image_info->colors != 0) && (image_info->colors <= 256))
-    if (AllocateImageColormap(image,image_info->colors) == MagickFalse)
+    if (AcquireImageColormap(image,image_info->colors) == MagickFalse)
       ThrowReaderException(ResourceLimitError,"MemoryAllocationFailed");
   if ((jpeg_info.output_components == 1) &&
       (jpeg_info.quantize_colors == MagickFalse))
     {
-      if (AllocateImageColormap(image,1UL << image->depth) == MagickFalse)
+      unsigned long
+        colors;
+
+      colors=(unsigned long) GetQuantumRange(image->depth)+1;
+      if (AcquireImageColormap(image,colors) == MagickFalse)
         ThrowReaderException(ResourceLimitError,"MemoryAllocationFailed");
     }
   if (image->debug != MagickFalse)
@@ -1025,7 +1033,7 @@ static Image *ReadJPEGImage(const ImageInfo *image_info,
   if (image_info->ping != MagickFalse)
     {
       jpeg_destroy_decompress(&jpeg_info);
-      CloseBlob(image);
+      (void) CloseBlob(image);
       return(GetFirstImageInList(image));
     }
   if (SetImageExtent(image,0,0) == MagickFalse)
@@ -1046,7 +1054,7 @@ static Image *ReadJPEGImage(const ImageInfo *image_info,
       jpeg_pixels=(unsigned char *) RelinquishMagickMemory(jpeg_pixels);
       jpeg_destroy_decompress(&jpeg_info);
       InheritException(exception,&image->exception);
-      CloseBlob(image);
+      (void) CloseBlob(image);
       number_pixels=(MagickSizeType) image->columns*image->rows;
       if (number_pixels != 0)
         return(GetFirstImageInList(image));
@@ -1090,7 +1098,14 @@ static Image *ReadJPEGImage(const ImageInfo *image_info,
         if (jpeg_info.output_components == 1)
           for (x=0; x < (long) image->columns; x++)
           {
-            index=ConstrainColormapIndex(image,(unsigned long) GETJSAMPLE(*p));
+            unsigned long
+              pixel;
+
+            if (precision != 16)
+              pixel=(unsigned long) GETJSAMPLE(*p);
+            else
+              pixel=(unsigned long) ((GETJSAMPLE(*p) ^ 0x80) << 4);
+            index=ConstrainColormapIndex(image,pixel);
             indexes[x]=index;
             *q++=image->colormap[(int) index];
             p++;
@@ -1169,7 +1184,7 @@ static Image *ReadJPEGImage(const ImageInfo *image_info,
   (void) jpeg_finish_decompress(&jpeg_info);
   jpeg_destroy_decompress(&jpeg_info);
   jpeg_pixels=(unsigned char *) RelinquishMagickMemory(jpeg_pixels);
-  CloseBlob(image);
+  (void) CloseBlob(image);
   InheritException(exception,&image->exception);
   return(GetFirstImageInList(image));
 }
@@ -1297,7 +1312,7 @@ ModuleExport void UnregisterJPEGImage(void)
 %
 %  A description of each parameter follows:
 %
-%    o image_info: The image info.
+%    o image_info: the image info.
 %
 %    o jpeg_image:  The image.
 %
@@ -1587,7 +1602,7 @@ static MagickBooleanType WriteJPEGImage(const ImageInfo *image_info,
       jpeg_destroy_compress(&jpeg_info);
       if (jpeg_pixels != (unsigned char *) NULL)
         jpeg_pixels=(unsigned char *) RelinquishMagickMemory(jpeg_pixels);
-      CloseBlob(image);
+      (void) CloseBlob(image);
       return(MagickFalse);
     }
   jpeg_info.client_data=(void *) &error_manager;
@@ -1598,13 +1613,12 @@ static MagickBooleanType WriteJPEGImage(const ImageInfo *image_info,
   jpeg_info.input_components=3;
   jpeg_info.data_precision=8;
   jpeg_info.in_color_space=JCS_RGB;
-  switch (image_info->colorspace)
+  switch (image->colorspace)
   {
     case CMYKColorspace:
     {
       jpeg_info.input_components=4;
       jpeg_info.in_color_space=JCS_CMYK;
-      (void) SetImageColorspace(image,CMYKColorspace);
       break;
     }
     case YCbCrColorspace:
@@ -1612,7 +1626,6 @@ static MagickBooleanType WriteJPEGImage(const ImageInfo *image_info,
     case Rec709YCbCrColorspace:
     {
       jpeg_info.in_color_space=JCS_YCbCr;
-      (void) SetImageColorspace(image,YCbCrColorspace);
       break;
     }
     case GRAYColorspace:
@@ -1621,28 +1634,10 @@ static MagickBooleanType WriteJPEGImage(const ImageInfo *image_info,
     {
       jpeg_info.input_components=1;
       jpeg_info.in_color_space=JCS_GRAYSCALE;
-      (void) SetImageColorspace(image,GRAYColorspace);
       break;
     }
     default:
-    {
-      if (image->colorspace == CMYKColorspace)
-        {
-          jpeg_info.input_components=4;
-          jpeg_info.in_color_space=JCS_CMYK;
-          break;
-        }
-      if ((image->colorspace == YCbCrColorspace) ||
-          (image->colorspace == Rec601YCbCrColorspace) ||
-          (image->colorspace == Rec709YCbCrColorspace))
-        {
-          jpeg_info.in_color_space=JCS_YCbCr;
-          break;
-        }
-      if (image_info->colorspace == UndefinedColorspace)
-        (void) SetImageColorspace(image,RGBColorspace);
       break;
-    }
   }
   if ((image_info->type != TrueColorType) &&
       (IsGrayImage(image,&image->exception) != MagickFalse))
@@ -1835,7 +1830,7 @@ static MagickBooleanType WriteJPEGImage(const ImageInfo *image_info,
           "Number of colors: unspecified");
       (void) LogMagickEvent(CoderEvent,GetMagickModule(),
         "JPEG data precision: %d",(int) jpeg_info.data_precision);
-      switch (image_info->colorspace)
+      switch (image->colorspace)
       {
         case CMYKColorspace:
         {
@@ -1962,8 +1957,8 @@ static MagickBooleanType WriteJPEGImage(const ImageInfo *image_info,
           q=jpeg_pixels;
           for (x=0; x < (long) image->columns; x++)
           {
-            *q++=(JSAMPLE)
-              (ScaleQuantumToShort(PixelIntensityToQuantum(p)) >> 4);
+            *q++=(JSAMPLE) (ScaleQuantumToShort(PixelIntensityToQuantum(p)) >>
+              4);
             p++;
           }
           (void) jpeg_write_scanlines(&jpeg_info,scanline,1);
@@ -2094,14 +2089,14 @@ static MagickBooleanType WriteJPEGImage(const ImageInfo *image_info,
             /*
               Convert DirectClass packets to contiguous CMYK scanlines.
             */
-            *q++=(JSAMPLE) (ScaleQuantumToChar((Quantum)
-              (QuantumRange-p->red)));
-            *q++=(JSAMPLE) (ScaleQuantumToChar((Quantum)
-              (QuantumRange-p->green)));
-            *q++=(JSAMPLE) (ScaleQuantumToChar((Quantum)
-              (QuantumRange-p->blue)));
-            *q++=(JSAMPLE) (ScaleQuantumToChar((Quantum)
-              (QuantumRange-indexes[x])));
+            *q++=(JSAMPLE) (ScaleQuantumToChar((Quantum) (QuantumRange-
+              p->red)));
+            *q++=(JSAMPLE) (ScaleQuantumToChar((Quantum) (QuantumRange-
+              p->green)));
+            *q++=(JSAMPLE) (ScaleQuantumToChar((Quantum) (QuantumRange-
+              p->blue)));
+            *q++=(JSAMPLE) (ScaleQuantumToChar((Quantum) (QuantumRange-
+              indexes[x])));
             p++;
           }
           (void) jpeg_write_scanlines(&jpeg_info,scanline,1);
@@ -2117,11 +2112,11 @@ static MagickBooleanType WriteJPEGImage(const ImageInfo *image_info,
   if (y == (long) image->rows)
     jpeg_finish_compress(&jpeg_info);
   /*
-    Free resources.
+    Relinquish resources.
   */
   jpeg_destroy_compress(&jpeg_info);
   jpeg_pixels=(unsigned char *) RelinquishMagickMemory(jpeg_pixels);
-  CloseBlob(image);
+  (void) CloseBlob(image);
   return(MagickTrue);
 }
 #endif
