@@ -58,20 +58,25 @@
 #include "magick/list.h"
 #include "magick/magick.h"
 #include "magick/memory_.h"
-#include "magick/option.h"
-#include "magick/shear.h"
 #include "magick/quantum-private.h"
+#include "magick/option.h"
+#include "magick/resource_.h"
+#include "magick/shear.h"
 #include "magick/static.h"
 #include "magick/string_.h"
 #include "magick/module.h"
 #include "magick/transform.h"
+#if defined(MAGICKCORE_ZLIB_DELEGATE)
+ #include "zlib.h"
+#endif
 
 /*
   Forward declaration.
 */
 static MagickBooleanType
   WriteMATImage(const ImageInfo *,Image *);
-
+
+
 /* Auto coloring method, sorry this creates some artefact inside data
 MinReal+j*MaxComplex = red  MaxReal+j*MaxComplex = black
 MinReal+j*0 = white          MaxReal+j*0 = black
@@ -161,7 +166,7 @@ typedef enum
 #define FLAG_GLOBAL  0x4
 #define FLAG_LOGICAL 0x2
 
-static const QuantumType z2qtype[4] = {GrayQuantum, BlueQuantum, GreenQuantum, RedQuantum};
+static const QuantumType z2qtype[4] = {IndexQuantum, BlueQuantum, GreenQuantum, RedQuantum};
 
 
 static void InsertComplexDoubleRow(double *p, int y, Image * image, double MinVal,
@@ -183,27 +188,27 @@ static void InsertComplexDoubleRow(double *p, int y, Image * image, double MinVa
   {
     if (*p > 0)
     {
-      f = (double) (*p / MaxVal) * (QuantumRange - q->red);
+      f = (*p / MaxVal) * (QuantumRange - q->red);
       if (f + q->red > QuantumRange)
-        q->red = (Quantum) QuantumRange;
+        q->red = QuantumRange;
       else
         q->red += (int) f;
-      if ((f / 2.0) > (double) q->green)
-        q->green = q->blue = (Quantum) 0;
+      if ((int) f / 2.0 > q->green)
+        q->green = q->blue = 0;
       else
-        q->green = q->blue -= (Quantum) (f / 2.0);
+        q->green = q->blue -= (int) (f / 2.0);
     }
     if (*p < 0)
     {
-      f = (double) (*p / MaxVal) * (QuantumRange - q->blue);
+      f = (*p / MaxVal) * (QuantumRange - q->blue);
       if (f + q->blue > QuantumRange)
-        q->blue = (Quantum) QuantumRange;
+        q->blue = QuantumRange;
       else
         q->blue += (int) f;
-      if ((f / 2.0) > (double) q->green)
-        q->green = q->red = (Quantum) 0;
+      if ((int) f / 2.0 > q->green)
+        q->green = q->red = 0;
       else
-        q->green = q->red -= (Quantum) (f / 2.0);
+        q->green = q->red -= (int) (f / 2.0);
     }
     p++;
     q++;
@@ -236,27 +241,27 @@ static void InsertComplexFloatRow(float *p, int y, Image * image, double MinVal,
   {
     if (*p > 0)
     {
-      f = (double) (*p / MaxVal) * (QuantumRange - q->red);
+      f = (*p / MaxVal) * (QuantumRange - q->red);
       if (f + q->red > QuantumRange)
-        q->red = (Quantum) QuantumRange;
+        q->red = QuantumRange;
       else
         q->red += (int) f;
-      if ((f / 2.0) > (double) q->green)
-        q->green = q->blue = (Quantum) 0;
+      if ((int) f / 2.0 > q->green)
+        q->green = q->blue = 0;
       else
-        q->green = q->blue -= (Quantum) (f / 2.0);
+        q->green = q->blue -= (int) (f / 2.0);
     }
     if (*p < 0)
     {
-      f = (double) (*p / MaxVal) * (QuantumRange - q->blue);
+      f = (*p / MaxVal) * (QuantumRange - q->blue);
       if (f + q->blue > QuantumRange)
-        q->blue = (Quantum) QuantumRange;
+        q->blue = QuantumRange;
       else
         q->blue += (int) f;
-      if ((f / 2.0) > 1.0*q->green)
-        q->green = q->red = (Quantum) 0;
+      if ((int) f / 2.0 > q->green)
+        q->green = q->red = 0;
       else
-        q->green = q->red -= (Quantum) (f / 2.0);
+        q->green = q->red -= (int) (f / 2.0);
     }
     p++;
     q++;
@@ -281,7 +286,7 @@ static void ReadBlobFloatsLSB(Image * image, size_t len, float *data)
     len -= sizeof(float);
   }
   if (len > 0)
-    (void) SeekBlob(image, (MagickOffsetType) len, SEEK_CUR);
+    (void) SeekBlob(image, len, SEEK_CUR);
 }
 
 static void ReadBlobFloatsMSB(Image * image, size_t len, float *data)
@@ -292,7 +297,7 @@ static void ReadBlobFloatsMSB(Image * image, size_t len, float *data)
     len -= sizeof(float);
   }
   if (len > 0)
-    (void) SeekBlob(image, (MagickOffsetType) len, SEEK_CUR);
+    (void) SeekBlob(image, len, SEEK_CUR);
 }
 
 /* This function reads one block of doubles*/
@@ -304,7 +309,7 @@ static void ReadBlobDoublesLSB(Image * image, size_t len, double *data)
     len -= sizeof(double);
   }
   if (len > 0)
-    (void) SeekBlob(image, (MagickOffsetType) len, SEEK_CUR);
+    (void) SeekBlob(image, len, SEEK_CUR);
 }
 
 static void ReadBlobDoublesMSB(Image * image, size_t len, double *data)
@@ -315,10 +320,9 @@ static void ReadBlobDoublesMSB(Image * image, size_t len, double *data)
     len -= sizeof(double);
   }
   if (len > 0)
-    (void) SeekBlob(image, (MagickOffsetType) len, SEEK_CUR);
+    (void) SeekBlob(image, len, SEEK_CUR);
 }
 
-
 /* Calculate minimum and maximum from a given block of data */
 static void CalcMinMax(Image *image, MATHeader *MATLAB_HDR, unsigned long CellType, unsigned ldblk, void *BImgBuff, double *Min, double *Max)
 {
@@ -382,7 +386,7 @@ float *fltrow;
 }
 
 
-static void FixSignedValues(PixelPacket *q, long y)
+static void FixSignedValues(PixelPacket *q, int y)
 {
   while(y-->0)
   {
@@ -396,6 +400,121 @@ static void FixSignedValues(PixelPacket *q, long y)
   }
 }
 
+
+/** Fix whole row of logical/binary data. It means pack it. */
+static void FixLogical(unsigned char *Buff,int ldblk)
+{
+unsigned char mask=128;
+unsigned char *BuffL = Buff;
+unsigned char val = 0;
+
+  while(ldblk-->0)
+  {
+    if(*Buff++ != 0)
+      val |= mask;    
+
+    mask >>= 1;
+    if(mask==0)
+    {
+      *BuffL++ = val;
+      val = 0;
+      mask = 128;
+    }   
+      
+  }
+  *BuffL = val;
+}
+
+
+/** This procedure decompreses an image block for a new MATLAB format. */
+static Image *DecompressBlock(Image *orig, MagickOffsetType Size, ImageInfo *clone_info, ExceptionInfo *exception)
+{
+#if defined(MAGICKCORE_ZLIB_DELEGATE)
+
+Image *image2;
+void *CacheBlock, *DecompressBlock;
+z_stream zip_info;
+FILE *mat_file;
+size_t magick_size;
+int status;
+
+  if(clone_info==NULL) return NULL;
+  if(clone_info->file)		/* Close file opened from previous transaction. */
+  {
+    fclose(clone_info->file);
+    clone_info->file = NULL;
+    (void) unlink(clone_info->filename);
+  }
+
+  CacheBlock = AcquireQuantumMemory((size_t)((Size<16384)?Size:16384),sizeof(unsigned char *));
+  if(CacheBlock==NULL) return NULL;
+  DecompressBlock = AcquireQuantumMemory((size_t)(4096),sizeof(unsigned char *));
+  if(DecompressBlock==NULL) 
+  {
+    RelinquishMagickMemory(CacheBlock);    
+    return NULL;
+  }
+
+  mat_file = fdopen(AcquireUniqueFileResource(clone_info->filename),"w");
+  if(!mat_file)
+  {
+    RelinquishMagickMemory(CacheBlock);
+    RelinquishMagickMemory(DecompressBlock);
+    (void) LogMagickEvent(CoderEvent,GetMagickModule(),"Gannot create file stream for PS image");
+    return NULL;
+  }
+
+  zip_info.zalloc = (alloc_func) NULL;
+  zip_info.zfree = (free_func) NULL;
+  zip_info.opaque = (voidpf) NULL;
+  inflateInit(&zip_info);
+  /* zip_info.next_out = 8*4;*/
+
+  zip_info.avail_in = 0;
+  zip_info.total_out = 0;
+  while(Size>0 && !EOFBlob(orig))
+  {    
+    magick_size = ReadBlob(orig, (Size<16384)?Size:16384, CacheBlock);
+    zip_info.next_in = CacheBlock;
+    zip_info.avail_in = magick_size;    
+
+    while(zip_info.avail_in>0)
+    {
+      zip_info.avail_out = 4096;    
+      zip_info.next_out = DecompressBlock;
+      status = inflate(&zip_info,Z_NO_FLUSH);      
+      fwrite(DecompressBlock, 4096-zip_info.avail_out, 1, mat_file);
+
+      if(status == Z_STREAM_END) goto DblBreak;
+    }
+
+    Size -= magick_size;
+  }
+DblBreak:
+ 
+  (void)fclose(mat_file);
+  RelinquishMagickMemory(CacheBlock);
+  RelinquishMagickMemory(DecompressBlock);
+
+  if((clone_info->file=fopen(clone_info->filename,"rb"))==NULL) goto UnlinkFile;
+  if( (image2 = AcquireImage(clone_info))==NULL ) goto EraseFile;  
+  status = OpenBlob(clone_info,image2,ReadBinaryBlobMode,exception);
+  if (status == MagickFalse)
+  {
+    DeleteImageFromList(&image2);    
+EraseFile:
+    fclose(clone_info->file);
+    clone_info->file = NULL;
+UnlinkFile:
+    (void) unlink(clone_info->filename);
+    return NULL; 
+  }
+
+  return image2;
+#else
+  return NULL;
+#endif
+}
 
 /*
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
@@ -408,9 +527,9 @@ static void FixSignedValues(PixelPacket *q, long y)
 %                                                                             %
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
-%  ReadMATImage() reads an MAT X image file and returns it.  It allocates
-%  the memory necessary for the new Image structure and returns a pointer to
-%  the new image.
+%  ReadMATImage() reads an MAT X image file and returns it.  It
+%  allocates the memory necessary for the new Image structure and returns a
+%  pointer to the new image.
 %
 %  The format of the ReadMATImage method is:
 %
@@ -418,6 +537,10 @@ static void FixSignedValues(PixelPacket *q, long y)
 %
 %  A description of each parameter follows:
 %
+%    o image:  Method ReadMATImage returns a pointer to the image after
+%      reading. A null image is returned if there is a memory shortage or if
+%      the image cannot be read.
+%
 %    o image_info: Specifies a pointer to a ImageInfo structure.
 %
 %    o exception: return any errors or warnings in this structure.
@@ -433,7 +556,7 @@ static inline size_t MagickMin(const size_t x,const size_t y)
 
 static Image *ReadMATImage(const ImageInfo *image_info,ExceptionInfo *exception)
 {
-  Image *image,
+  Image *image, *image2=NULL,
    *rotated_image;
   PixelPacket *q;
   unsigned int status;
@@ -441,18 +564,18 @@ static Image *ReadMATImage(const ImageInfo *image_info,ExceptionInfo *exception)
   unsigned long size;  
   unsigned long CellType;
   QuantumInfo *quantum_info;
-  long i;
+  ImageInfo *clone_info;
+  int i;
   long ldblk;
   unsigned char *BImgBuff = NULL;
   double MinVal, MaxVal;
   unsigned long Unknown6;
-  ImageInfo *clone_info;
   unsigned z;
   int logging;
-  ssize_t count;
+  int sample_size;
   MagickOffsetType filepos=0x80;
   BlobInfo *blob;
-
+  
   unsigned long (*ReadBlobXXXLong)(Image *image);
   unsigned short (*ReadBlobXXXShort)(Image *image);
   void (*ReadBlobDoublesXXX)(Image * image, size_t len, double *data);
@@ -463,12 +586,13 @@ static Image *ReadMATImage(const ImageInfo *image_info,ExceptionInfo *exception)
   assert(image_info->signature == MagickSignature);
   assert(exception != (ExceptionInfo *) NULL);
   assert(exception->signature == MagickSignature);
-  logging=LogMagickEvent(CoderEvent,GetMagickModule(),"enter"); 
+  logging = LogMagickEvent(CoderEvent,GetMagickModule(),"enter"); 
 
   /*
      Open image file.
    */
   image = AcquireImage(image_info);
+
   status = OpenBlob(image_info, image, ReadBinaryBlobMode, exception);
   if (status == MagickFalse)
     {
@@ -478,12 +602,11 @@ static Image *ReadMATImage(const ImageInfo *image_info,ExceptionInfo *exception)
   /*
      Read MATLAB image.
    */
-  count=ReadBlob(image, 124, (unsigned char *) &MATLAB_HDR.identific);
-  if (count == 0)
+  clone_info=CloneImageInfo(image_info);
+  if(ReadBlob(image,124,(unsigned char *) &MATLAB_HDR.identific) != 124)
     ThrowReaderException(CorruptImageError,"ImproperImageHeader");
   MATLAB_HDR.Version = ReadBlobLSBShort(image);
-  count=ReadBlob(image, 2, (unsigned char *) &MATLAB_HDR.EndianIndicator);
-  if (count == 0)
+  if(ReadBlob(image,2,(unsigned char *) &MATLAB_HDR.EndianIndicator) != 2)
     ThrowReaderException(CorruptImageError,"ImproperImageHeader");
 
   if (logging) (void)LogMagickEvent(CoderEvent,GetMagickModule(),"  Endian %c%c",
@@ -510,117 +633,143 @@ static Image *ReadMATImage(const ImageInfo *image_info,ExceptionInfo *exception)
   if (strncmp(MATLAB_HDR.identific, "MATLAB", 6))
 MATLAB_KO: ThrowReaderException(CorruptImageError,"ImproperImageHeader");
 
-  filepos=TellBlob(image);
-  while (EOFBlob(image) == MagickFalse) /* object parser loop */
+  filepos = TellBlob(image);
+  while(!EOFBlob(image)) /* object parser loop */
   {
     (void) SeekBlob(image,filepos,SEEK_SET);
-    MATLAB_HDR.DataType=ReadBlobXXXLong(image);
-    if (EOFBlob(image) != MagickFalse)
-      break;
+    /* printf("pos=%X\n",TellBlob(image)); */
+
+    MATLAB_HDR.DataType = ReadBlobXXXLong(image);
+    if(EOFBlob(image)) break;
     MATLAB_HDR.ObjectSize = ReadBlobXXXLong(image);
-    if (EOFBlob(image) != MagickFalse)
-      break;
-    filepos+=MATLAB_HDR.ObjectSize+4+4;
-    if (MATLAB_HDR.DataType == miCOMPRESSED)
-      continue;
-    if (MATLAB_HDR.DataType != miMATRIX)
-      continue;  /* skip another objects. */    
-    MATLAB_HDR.unknown1=ReadBlobXXXLong(image);
-    MATLAB_HDR.unknown2=ReadBlobXXXLong(image);  
-    MATLAB_HDR.unknown5=(unsigned short) ReadBlobXXXLong(image);
-    MATLAB_HDR.StructureClass=(unsigned char) (MATLAB_HDR.unknown5 & 0xFF);
-    MATLAB_HDR.StructureFlag=(unsigned char) ((MATLAB_HDR.unknown5 >> 8) & 0xFF);  
-    MATLAB_HDR.unknown3=ReadBlobXXXLong(image);
-    MATLAB_HDR.unknown4=ReadBlobXXXLong(image);
-    MATLAB_HDR.DimFlag=ReadBlobXXXLong(image);
-    MATLAB_HDR.SizeX=ReadBlobXXXLong(image);
-    MATLAB_HDR.SizeY = ReadBlobXXXLong(image);  
-    switch (MATLAB_HDR.DimFlag)
+    if(EOFBlob(image)) break;
+    filepos += MATLAB_HDR.ObjectSize + 4 + 4;
+
+    image2 = image;
+#if defined(MAGICKCORE_ZLIB_DELEGATE)
+    if(MATLAB_HDR.DataType == miCOMPRESSED)
     {
-      case  8: z=1; break;	       /* 2D matrix*/
-      case 12: z=(unsigned int) ReadBlobXXXLong(image); /* 3D matrix RGB*/
-  	       Unknown6 = ReadBlobXXXLong(image);
+      image2 = DecompressBlock(image,MATLAB_HDR.ObjectSize,clone_info,exception);
+      if(image2==NULL) continue;
+      MATLAB_HDR.DataType = ReadBlobXXXLong(image2); /* replace compressed object type. */
+    }
+#endif    
+
+    if(MATLAB_HDR.DataType!=miMATRIX) continue;  /* skip another objects. */
+ 
+    MATLAB_HDR.unknown1 = ReadBlobXXXLong(image2);
+    MATLAB_HDR.unknown2 = ReadBlobXXXLong(image2);  
+
+    MATLAB_HDR.unknown5 = ReadBlobXXXLong(image2);
+    MATLAB_HDR.StructureClass = MATLAB_HDR.unknown5 & 0xFF;
+    MATLAB_HDR.StructureFlag = (MATLAB_HDR.unknown5>>8) & 0xFF;  
+
+    MATLAB_HDR.unknown3 = ReadBlobXXXLong(image2);
+    if(image!=image2)
+      MATLAB_HDR.unknown4 = ReadBlobXXXLong(image2);	/* ??? don't understand why ?? */
+    MATLAB_HDR.unknown4 = ReadBlobXXXLong(image2);
+    MATLAB_HDR.DimFlag = ReadBlobXXXLong(image2);
+    MATLAB_HDR.SizeX = ReadBlobXXXLong(image2);
+    MATLAB_HDR.SizeY = ReadBlobXXXLong(image2);  
+   
+
+    switch(MATLAB_HDR.DimFlag)
+    {     
+      case  8: z=1; break;			/* 2D matrix*/
+      case 12: z = ReadBlobXXXLong(image2);	/* 3D matrix RGB*/
+  	       Unknown6 = ReadBlobXXXLong(image2);
 	       if(z!=3) ThrowReaderException(CoderError, "MultidimensionalMatricesAreNotSupported");
 	       break;
       default: ThrowReaderException(CoderError, "MultidimensionalMatricesAreNotSupported");
     }  
 
-    MATLAB_HDR.Flag1 = ReadBlobXXXShort(image);
-    MATLAB_HDR.NameFlag = ReadBlobXXXShort(image);
+    MATLAB_HDR.Flag1 = ReadBlobXXXShort(image2);
+    MATLAB_HDR.NameFlag = ReadBlobXXXShort(image2);
 
     if (logging) (void)LogMagickEvent(CoderEvent,GetMagickModule(),
           "MATLAB_HDR.StructureClass %d",MATLAB_HDR.StructureClass);
     if (MATLAB_HDR.StructureClass != mxCHAR_CLASS && 
-        MATLAB_HDR.StructureClass != mxSINGLE_CLASS &&	     /* float + complex float */
-        MATLAB_HDR.StructureClass != mxDOUBLE_CLASS &&	     /* double + complex double */
+        MATLAB_HDR.StructureClass != mxSINGLE_CLASS &&		/* float + complex float */
+        MATLAB_HDR.StructureClass != mxDOUBLE_CLASS &&		/* double + complex double */
         MATLAB_HDR.StructureClass != mxINT8_CLASS &&
-        MATLAB_HDR.StructureClass != mxUINT8_CLASS &&          /* uint8 + uint8 3D */
+        MATLAB_HDR.StructureClass != mxUINT8_CLASS &&		/* uint8 + uint8 3D */
         MATLAB_HDR.StructureClass != mxINT16_CLASS &&
-        MATLAB_HDR.StructureClass != mxUINT16_CLASS &&	     /* uint16 + uint16 3D */
+        MATLAB_HDR.StructureClass != mxUINT16_CLASS &&		/* uint16 + uint16 3D */
         MATLAB_HDR.StructureClass != mxINT32_CLASS &&
-        MATLAB_HDR.StructureClass != mxUINT32_CLASS &&	     /* uint32 + uint32 3D */
+        MATLAB_HDR.StructureClass != mxUINT32_CLASS &&		/* uint32 + uint32 3D */
         MATLAB_HDR.StructureClass != mxINT64_CLASS &&
-        MATLAB_HDR.StructureClass != mxUINT64_CLASS)	     /* uint64 + uint64 3D */
+        MATLAB_HDR.StructureClass != mxUINT64_CLASS)		/* uint64 + uint64 3D */
       ThrowReaderException(CoderError,"UnsupportedCellTypeInTheMatrix");
 
     switch (MATLAB_HDR.NameFlag)
     {
       case 0:
-        size = ReadBlobXXXLong(image);	/* Object name string size */
-        size = 4UL * (long) ((size + 3 + 1) / 4);
-        (void) SeekBlob(image, (MagickOffsetType) size, SEEK_CUR);
+        size = ReadBlobXXXLong(image2);	/* Object name string size */
+        size = 4 * (long) ((size + 3 + 1) / 4);
+        (void) SeekBlob(image2, size, SEEK_CUR);
         break;
       case 1:
       case 2:
       case 3:
       case 4:
-        (void) ReadBlob(image, 4, (unsigned char *) &size); /* Object name string */
+        (void) ReadBlob(image2, 4, (unsigned char *) &size); /* Object name string */
         break;
       default:
         goto MATLAB_KO;
     }
 
-    CellType = ReadBlobXXXLong(image);    /* Additional object type */
+    CellType = ReadBlobXXXLong(image2);    /* Additional object type */
     if (logging) (void)LogMagickEvent(CoderEvent,GetMagickModule(),
           "MATLAB_HDR.CellType: %ld",CellType);
   
-    (void) ReadBlob(image, 4, (unsigned char *) &size);     /* data size */
+    (void) ReadBlob(image2, 4, (unsigned char *) &size);     /* data size */
+
+      /* Image is gray when no complex flag is set and 2D Matrix */
+    if ((MATLAB_HDR.DimFlag == 8) &&
+        ((MATLAB_HDR.StructureFlag & FLAG_COMPLEX) == 0))
+      image->type=GrayscaleType;
 
-    image->columns = MATLAB_HDR.SizeX;
-    image->rows = MATLAB_HDR.SizeY;
-    clone_info=CloneImageInfo(image_info);
     switch (CellType)
     {
       case miINT8:
       case miUINT8:
-        image->depth= 8;
+        sample_size = 8;
+        if(MATLAB_HDR.StructureFlag & FLAG_LOGICAL) 
+          image->depth = 1;
+        else
+          image->depth = 8;         /* Byte type cell */
         ldblk = (long) MATLAB_HDR.SizeX;      
         break;
       case miINT16:
       case miUINT16:
-        image->depth= 16;
+        sample_size = 16;
+        image->depth = 16;        /* Word type cell */
         ldblk = (long) (2 * MATLAB_HDR.SizeX);
         break;
       case miINT32:
       case miUINT32:
-        image->depth= 32;
+        sample_size = 32;
+        image->depth = 32;        /* Dword type cell */
         ldblk = (long) (4 * MATLAB_HDR.SizeX);      
         break;
       case miINT64:
       case miUINT64:
-        image->depth= 64;
+        sample_size = 64;
+        image->depth = 64;        /* Qword type cell */
         ldblk = (long) (8 * MATLAB_HDR.SizeX);      
         break;   
       case miSINGLE:
-        image->depth= 32;
+        sample_size = 32;
+        image->depth = 32;        /* double type cell */
         (void) SetImageOption(clone_info,"quantum:format","floating-point");
         if (MATLAB_HDR.StructureFlag & FLAG_COMPLEX)
-	{                         /* complex float type cell */
+	{					    /* complex float type cell */
 	}
         ldblk = (long) (4 * MATLAB_HDR.SizeX);
         break;
       case miDOUBLE:
-        image->depth= 64; 
+        sample_size = 64; 
+        image->depth = 64;        /* double type cell */
         (void) SetImageOption(clone_info,"quantum:format","floating-point");
         if (sizeof(double) != 8)
           ThrowReaderException(CoderError, "IncompatibleSizeOfDouble");
@@ -632,13 +781,24 @@ MATLAB_KO: ThrowReaderException(CorruptImageError,"ImproperImageHeader");
       default:
         ThrowReaderException(CoderError, "UnsupportedCellTypeInTheMatrix");
     }
+    image->columns = MATLAB_HDR.SizeX;
+    image->rows = MATLAB_HDR.SizeY;    
     quantum_info=AcquireQuantumInfo(clone_info,image);
-    clone_info=DestroyImageInfo(clone_info);
-
-    image->colors = 1UL >> 8;
+    image->colors = 1l << image->depth;
     if (image->columns == 0 || image->rows == 0)
       goto MATLAB_KO;
 
+    /* ----- Create gray palette ----- */
+
+    if (CellType==miUINT8 && z!=3)
+    {
+      if(image->colors>256) image->colors = 256;
+
+      if (!AcquireImageColormap(image, image->colors))
+      {
+ NoMemory:ThrowReaderException(ResourceLimitError,"MemoryAllocationFailed");}
+    }
+
     /*
       If ping is true, then only set image size and colors without
       reading any image data.
@@ -648,19 +808,19 @@ MATLAB_KO: ThrowReaderException(CorruptImageError,"ImproperImageHeader");
       unsigned long temp = image->columns;
       image->columns = image->rows;
       image->rows = temp;
-      goto done_reading; 
+      goto done_reading; /* !!!!!! BAD  !!!! */
     }  
 
   /* ----- Load raster data ----- */
-    BImgBuff = (unsigned char *) AcquireQuantumMemory((size_t) ldblk,sizeof(*BImgBuff));
+    BImgBuff = AcquireQuantumMemory((size_t) (ldblk),sizeof(unsigned char *));    /* Ldblk was set in the check phase */
     if (BImgBuff == NULL)
-      ThrowReaderException(ResourceLimitError,"MemoryAllocationFailed");
+      goto NoMemory;
 
     MinVal = 0;
     MaxVal = 0;
     if (CellType==miDOUBLE || CellType==miSINGLE)        /* Find Min and Max Values for floats */
     {
-      CalcMinMax(image, &MATLAB_HDR, CellType, (unsigned int) ldblk, BImgBuff, &quantum_info->minimum, &quantum_info->maximum);
+      CalcMinMax(image2, &MATLAB_HDR, CellType, ldblk, BImgBuff, &quantum_info->minimum, &quantum_info->maximum);
     }
 
     /* Main loop for reading all scanlines */
@@ -670,14 +830,47 @@ MATLAB_KO: ThrowReaderException(CorruptImageError,"ImproperImageHeader");
     {
       for (i = 0; i < (long) MATLAB_HDR.SizeY; i++)
       {
-        q=SetImagePixels(image,0,(long) MATLAB_HDR.SizeY-i-1,image->columns,1);
-        if (q == (PixelPacket *)NULL) goto done_reading;
-        (void) ReadBlob(image, (size_t) ldblk, (unsigned char *)BImgBuff);	  
-        (void) ImportQuantumPixels(image,quantum_info,z2qtype[z],BImgBuff);
-        if (z<=1 &&
+        q=SetImagePixels(image,0,MATLAB_HDR.SizeY-i-1,image->columns,1);
+        if (q == (PixelPacket *)NULL)
+	{
+	  if (logging) (void)LogMagickEvent(CoderEvent,GetMagickModule(),
+              "  MAT set image pixels returns unexpected NULL on a row %u.", (unsigned)(MATLAB_HDR.SizeY-i-1));
+	  goto done_reading;		/* Skip image rotation, when cannot set image pixels	  */
+	}
+        if(ReadBlob(image2,ldblk,(unsigned char *)BImgBuff) != (ssize_t) ldblk)
+	{
+	  if (logging) (void)LogMagickEvent(CoderEvent,GetMagickModule(),
+             "  MAT cannot read scanrow %u from a file.", (unsigned)(MATLAB_HDR.SizeY-i-1));
+	  goto ExitLoop;
+	}
+        if((CellType==miINT8 || CellType==miUINT8) && (MATLAB_HDR.StructureFlag & FLAG_LOGICAL))
+        {
+          FixLogical((unsigned char *)BImgBuff,ldblk);
+          if(ImportQuantumPixels(image,quantum_info,z2qtype[z],BImgBuff) <= 0)
+	  {
+ImportQuantumPixelsFailed:
+	    if (logging) (void)LogMagickEvent(CoderEvent,GetMagickModule(),
+              "  MAT failed to ImportQuantumPixels for a row %u", (unsigned)(MATLAB_HDR.SizeY-i-1));
+	    break;
+	  }
+        }
+        else
+        {
+          if(ImportQuantumPixels(image,quantum_info,z2qtype[z],BImgBuff) <= 0)
+	    goto ImportQuantumPixelsFailed;
+
+
+          if (z<=1 &&			 /* fix only during a last pass z==0 || z==1 */
 	        (CellType==miINT8 || CellType==miINT16 || CellType==miINT32 || CellType==miINT64))
-	  FixSignedValues(q,(long) MATLAB_HDR.SizeX);
-        if (!SyncImagePixels(image)) goto ExitLoop;
+	    FixSignedValues(q,MATLAB_HDR.SizeX);
+        }
+
+        if (!SyncImagePixels(image))
+	{
+	  if (logging) (void)LogMagickEvent(CoderEvent,GetMagickModule(),
+            "  MAT failed to sync image pixels for a row %u", (unsigned)(MATLAB_HDR.SizeY-i-1));
+	  goto ExitLoop;
+	}
       }
     } while(z-- >= 2);
 ExitLoop:
@@ -686,35 +879,39 @@ ExitLoop:
     /* Read complex part of numbers here */
     if (MATLAB_HDR.StructureFlag & FLAG_COMPLEX)
     {        /* Find Min and Max Values for complex parts of floats */
-      CellType = ReadBlobXXXLong(image);    /* Additional object type */
-      i = (long) ReadBlobXXXLong(image);           /* size of a complex part - toss away*/
+      CellType = ReadBlobXXXLong(image2);    /* Additional object type */
+      i = ReadBlobXXXLong(image2);           /* size of a complex part - toss away*/
 
       if (CellType==miDOUBLE || CellType==miSINGLE)
       {
-        CalcMinMax(image, &MATLAB_HDR, CellType, (unsigned int) ldblk, BImgBuff, &MinVal, &MaxVal);      
+        CalcMinMax(image2, &MATLAB_HDR, CellType, ldblk, BImgBuff, &MinVal, &MaxVal);      
       }
 
       if (CellType==miDOUBLE)
         for (i = 0; i < (long) MATLAB_HDR.SizeY; i++)
 	{
-          ReadBlobDoublesXXX(image, (size_t) ldblk, (double *)BImgBuff);
+          ReadBlobDoublesXXX(image2, ldblk, (double *)BImgBuff);
           InsertComplexDoubleRow((double *)BImgBuff, i, image, MinVal, MaxVal);
 	}
 
       if (CellType==miSINGLE)
         for (i = 0; i < (long) MATLAB_HDR.SizeY; i++)
 	{
-          ReadBlobFloatsXXX(image, (size_t) ldblk, (float *)BImgBuff);
+          ReadBlobFloatsXXX(image2, ldblk, (float *)BImgBuff);
           InsertComplexFloatRow((float *)BImgBuff, i, image, MinVal, MaxVal);
 	}    
     }
+
+      /* Image is gray when no complex flag is set and 2D Matrix AGAIN!!! */
     if ((MATLAB_HDR.DimFlag == 8) &&
         ((MATLAB_HDR.StructureFlag & FLAG_COMPLEX) == 0))
       image->type=GrayscaleType;
     if (image->depth == 1)
       image->type=BilevelType;
 
-      /* Image is gray when no complex flag is set and 2D Matrix AGAIN!!! */
+    if(image2==image)
+        image2 = NULL;    /* Remove shadow copy to an image before rotation. */
+
       /*  Rotate image. */
     rotated_image = RotateImage(image, 90.0, exception);
     if (rotated_image != (Image *) NULL)
@@ -725,6 +922,7 @@ ExitLoop:
 
       blob = rotated_image->blob;
       rotated_image->blob = image->blob;
+      rotated_image->colors = image->colors;
       image->blob = blob;
       AppendImageToList(&image,rotated_image);      
       DeleteImageFromList(&image);      
@@ -732,21 +930,36 @@ ExitLoop:
 
 done_reading:
 
+    if(image2!=NULL)
+      if(image2!=image)
+      {
+        DeleteImageFromList(&image2); 
+	if(clone_info)
+	{
+          if(clone_info->file)
+	  {
+            fclose(clone_info->file);
+            clone_info->file = NULL;
+            (void) unlink(clone_info->filename);
+	  }
+        }    
+      }
+
       /* Allocate next image structure. */    
-    AcquireNextImage(image_info,image);   
+    AcquireNextImage(image_info,image);
     if (image->next == (Image *) NULL) break;                
     image=SyncNextImageInList(image);
     image->columns=image->rows=0;
     image->colors=0;    
 
       /* row scan buffer is no longer needed */
-    BImgBuff=(unsigned char *) RelinquishMagickMemory(BImgBuff);
-    quantum_info=DestroyQuantumInfo(quantum_info);
+    RelinquishMagickMemory(BImgBuff);
+    BImgBuff = NULL;
   }
+    clone_info=DestroyImageInfo(clone_info);
 
-
-  BImgBuff=(unsigned char *) RelinquishMagickMemory(BImgBuff);
-  (void) CloseBlob(image);
+  RelinquishMagickMemory(BImgBuff);
+  CloseBlob(image);
 
 
   {
@@ -758,7 +971,7 @@ done_reading:
     */
     p=image;
     image=NULL;
-    while (p != (Image *) NULL)
+    while (p != (Image *)NULL)
       {
         Image *tmp=p;
         if ((p->rows == 0) || (p->columns == 0)) {
@@ -774,10 +987,23 @@ done_reading:
       Fix scene numbers
     */
     for (p=image; p != (Image *) NULL; p=p->next)
-      p->scene=(unsigned long) scene++;
+      p->scene=scene++;
   }
 
-  if (logging) (void) LogMagickEvent(CoderEvent,GetMagickModule(),"return");
+  if(clone_info != NULL)	/* cleanup garbage file from compression */
+  {
+    if(clone_info->file)
+    {
+      fclose(clone_info->file);
+      clone_info->file = NULL;
+      (void) unlink(clone_info->filename);
+    }
+    DestroyImageInfo(clone_info);
+    clone_info = NULL;
+  }
+  if (logging) (void)LogMagickEvent(CoderEvent,GetMagickModule(),"return");
+  if(image==NULL)
+    ThrowReaderException(CorruptImageError,"ImproperImageHeader");
   return (image);
 }
 
@@ -909,7 +1135,7 @@ static MagickBooleanType WriteMATImage(const ImageInfo *image_info,Image *image)
   current_time=time((time_t *) NULL);
   t=localtime(&current_time);
   (void) memset(MATLAB_HDR,' ',MagickMin(sizeof(MATLAB_HDR),124));
-  (void) FormatMagickString(MATLAB_HDR,MaxTextExtent,"MATLAB 5.0 MAT-file, Platform: %s, Created on: %s %s %2d %2d:%2d:%2d %d",
+  FormatMagickString(MATLAB_HDR,MaxTextExtent,"MATLAB 5.0 MAT-file, Platform: %s, Created on: %s %s %2d %2d:%2d:%2d %d",
     OsDesc,
     DayOfWTab[t->tm_wday],
     MonthsTab[t->tm_mon],
@@ -928,14 +1154,14 @@ static MagickBooleanType WriteMATImage(const ImageInfo *image_info,Image *image)
       (void) SetImageColorspace(image,RGBColorspace);
 
     is_gray = IsGrayImage(image,&image->exception);
-    z = is_gray ? 0U : 3U;
+    z = is_gray ? 0 : 3;
 
     /*
       Store MAT header.
     */
     DataSize = image->rows /*Y*/ * image->columns /*X*/;
     if(!is_gray) DataSize *= 3 /*Z*/;
-    padding=(char) (((unsigned char)(DataSize-1) & 0x7) ^ 0x7);
+    padding=((unsigned char)(DataSize-1) & 0x7) ^ 0x7;
 
     (void) WriteBlobLSBLong(image, miMATRIX);
     (void) WriteBlobLSBLong(image, DataSize+padding+(is_gray ? 48l : 56l));
@@ -944,7 +1170,7 @@ static MagickBooleanType WriteMATImage(const ImageInfo *image_info,Image *image)
     (void) WriteBlobLSBLong(image, 0x6); /* 0x90 */  
     (void) WriteBlobLSBLong(image, 0);   
     (void) WriteBlobLSBLong(image, 0x5); /* 0x98 */
-    (void) WriteBlobLSBLong(image, (unsigned long) (is_gray ? 0x8 : 0xC)); /* 0x9C - DimFlag */
+    (void) WriteBlobLSBLong(image, is_gray ? 0x8 : 0xC); /* 0x9C - DimFlag */
     (void) WriteBlobLSBLong(image, image->rows);    /* x: 0xA0 */  
     (void) WriteBlobLSBLong(image, image->columns); /* y: 0xA4 */  
     if(!is_gray)
