@@ -137,11 +137,7 @@ static MagickBooleanType IsMIFF(const unsigned char *magick,const size_t length)
 %
 %  A description of each parameter follows:
 %
-%    o image: Method ReadMIFFImage returns a pointer to the image after
-%      reading.  A null image is returned if there is a memory shortage or
-%      if the image cannot be read.
-%
-%    o image_info: The image info.
+%    o image_info: the image info.
 %
 %    o exception: return any errors or warnings in this structure.
 %
@@ -178,9 +174,8 @@ static inline size_t MagickMin(const size_t x,const size_t y)
   return(y);
 }
 
-static void PushRunlengthPacket(Image *image,const QuantumState *quantum_state,
-  const unsigned char *pixels,size_t *length,PixelPacket *pixel,
-  IndexPacket *index)
+static void PushRunlengthPacket(Image *image,const unsigned char *pixels,
+  size_t *length,PixelPacket *pixel,IndexPacket *index)
 {
   const unsigned char
     *p;
@@ -224,7 +219,7 @@ static void PushRunlengthPacket(Image *image,const QuantumState *quantum_state,
 
           if (image->matte != MagickFalse)
             {
-              quantum=PushCharPixel(&p);
+              p=PushCharPixel(p,&quantum);
               pixel->opacity=ScaleCharToQuantum(quantum);
             }
           break;
@@ -236,7 +231,7 @@ static void PushRunlengthPacket(Image *image,const QuantumState *quantum_state,
 
           if (image->matte != MagickFalse)
             {
-              quantum=PushShortPixel(quantum_state,&p);
+              p=PushShortPixel(MSBEndian,p,&quantum);
               pixel->opacity=(Quantum) (quantum >> (image->depth-
                 MAGICKCORE_QUANTUM_DEPTH));
             }
@@ -249,7 +244,7 @@ static void PushRunlengthPacket(Image *image,const QuantumState *quantum_state,
 
           if (image->matte != MagickFalse)
             {
-              quantum=PushLongPixel(quantum_state,&p);
+              p=PushLongPixel(MSBEndian,p,&quantum);
               pixel->opacity=(Quantum) (quantum >> (image->depth-
                 MAGICKCORE_QUANTUM_DEPTH));
             }
@@ -269,20 +264,20 @@ static void PushRunlengthPacket(Image *image,const QuantumState *quantum_state,
       unsigned char
         quantum;
 
-      quantum=PushCharPixel(&p);
+      p=PushCharPixel(p,&quantum);
       pixel->red=ScaleCharToQuantum(quantum);
-      quantum=PushCharPixel(&p);
+      p=PushCharPixel(p,&quantum);
       pixel->green=ScaleCharToQuantum(quantum);
-      quantum=PushCharPixel(&p);
+      p=PushCharPixel(p,&quantum);
       pixel->blue=ScaleCharToQuantum(quantum);
       if (image->matte != MagickFalse)
         {
-          quantum=PushCharPixel(&p);
+          p=PushCharPixel(p,&quantum);
           pixel->opacity=ScaleCharToQuantum(quantum);
         }
       if (image->colorspace == CMYKColorspace)
         {
-          quantum=PushCharPixel(&p);
+          p=PushCharPixel(p,&quantum);
           *index=ScaleCharToQuantum(quantum);
         }
       break;
@@ -292,23 +287,23 @@ static void PushRunlengthPacket(Image *image,const QuantumState *quantum_state,
       unsigned short
         quantum;
 
-      quantum=PushShortPixel(quantum_state,&p);
+      p=PushShortPixel(MSBEndian,p,&quantum);
       pixel->red=(Quantum) (quantum >> (image->depth-MAGICKCORE_QUANTUM_DEPTH));
-      quantum=PushShortPixel(quantum_state,&p);
+      p=PushShortPixel(MSBEndian,p,&quantum);
       pixel->green=(Quantum) (quantum >> (image->depth-
         MAGICKCORE_QUANTUM_DEPTH));
-      quantum=PushShortPixel(quantum_state,&p);
+      p=PushShortPixel(MSBEndian,p,&quantum);
       pixel->blue=(Quantum) (quantum >> (image->depth-
         MAGICKCORE_QUANTUM_DEPTH));
       if (image->matte != MagickFalse)
         {
-          quantum=PushShortPixel(quantum_state,&p);
+          p=PushShortPixel(MSBEndian,p,&quantum);
           pixel->opacity=(Quantum) (quantum >> (image->depth-
             MAGICKCORE_QUANTUM_DEPTH));
         }
       if (image->colorspace == CMYKColorspace)
         {
-          quantum=PushShortPixel(quantum_state,&p);
+          p=PushShortPixel(MSBEndian,p,&quantum);
           *index=(IndexPacket) (quantum >> (image->depth-
             MAGICKCORE_QUANTUM_DEPTH));
         }
@@ -319,23 +314,23 @@ static void PushRunlengthPacket(Image *image,const QuantumState *quantum_state,
       unsigned long
         quantum;
 
-      quantum=PushLongPixel(quantum_state,&p);
+      p=PushLongPixel(MSBEndian,p,&quantum);
       pixel->red=(Quantum) (quantum >> (image->depth-MAGICKCORE_QUANTUM_DEPTH));
-      quantum=PushLongPixel(quantum_state,&p);
+      p=PushLongPixel(MSBEndian,p,&quantum);
       pixel->green=(Quantum) (quantum >> (image->depth-
         MAGICKCORE_QUANTUM_DEPTH));
-      quantum=PushLongPixel(quantum_state,&p);
+      p=PushLongPixel(MSBEndian,p,&quantum);
       pixel->blue=(Quantum) (quantum >> (image->depth-
         MAGICKCORE_QUANTUM_DEPTH));
       if (image->matte != MagickFalse)
         {
-          quantum=PushLongPixel(quantum_state,&p);
+          p=PushLongPixel(MSBEndian,p,&quantum);
           pixel->opacity=(Quantum) (quantum >> (image->depth-
             MAGICKCORE_QUANTUM_DEPTH));
         }
       if (image->colorspace == CMYKColorspace)
         {
-          quantum=PushLongPixel(quantum_state,&p);
+          p=PushLongPixel(MSBEndian,p,&quantum);
           *index=(IndexPacket) (quantum >> (image->depth-
             MAGICKCORE_QUANTUM_DEPTH));
         }
@@ -417,11 +412,11 @@ static Image *ReadMIFFImage(const ImageInfo *image_info,
   PixelPacket
     pixel;
 
-  QuantumInfo
-    quantum_info;
+  QuantumFormatType
+    quantum_format;
 
-  QuantumState
-    quantum_state;
+  QuantumInfo
+    *quantum_info;
 
   QuantumType
     quantum_type;
@@ -465,7 +460,7 @@ static Image *ReadMIFFImage(const ImageInfo *image_info,
       image_info->filename);
   assert(exception != (ExceptionInfo *) NULL);
   assert(exception->signature == MagickSignature);
-  image=AllocateImage(image_info);
+  image=AcquireImage(image_info);
   status=OpenBlob(image_info,image,ReadBinaryBlobMode,exception);
   if (status == MagickFalse)
     {
@@ -489,12 +484,11 @@ static Image *ReadMIFFImage(const ImageInfo *image_info,
     */
     length=MaxTextExtent;
     options=AcquireString((char *) NULL);
+    quantum_format=UndefinedQuantumFormat;
     profiles=(LinkedListInfo *) NULL;
     colors=0;
     image->depth=8UL;
     image->compression=NoCompression;
-    GetQuantumInfo(image_info,&quantum_info);
-    InitializeQuantumState(&quantum_info,MSBEndian,&quantum_state);
     while ((isgraph(c) != MagickFalse) && (c != (int) ':'))
     {
       register char
@@ -805,10 +799,8 @@ static Image *ReadMIFFImage(const ImageInfo *image_info,
                   }
                 if (LocaleCompare(keyword,"quantum-format") == 0)
                   {
-                    quantum_info.format=(QuantumFormatType) ParseMagickOption(
+                    quantum_format=(QuantumFormatType) ParseMagickOption(
                       MagickQuantumFormatOptions,MagickFalse,options);
-                    if (quantum_info.format == FloatingPointQuantumFormat)
-                      quantum_info.scale=QuantumRange;
                     break;
                   }
                 (void) SetImageProperty(image,keyword,options);
@@ -1006,7 +998,7 @@ static Image *ReadMIFFImage(const ImageInfo *image_info,
         /*
           Create image colormap.
         */
-        status=AllocateImageColormap(image,colors != 0 ? colors : 256);
+        status=AcquireImageColormap(image,colors != 0 ? colors : 256);
         if (status == MagickFalse)
           ThrowReaderException(ResourceLimitError,"MemoryAllocationFailed");
         if (colors != 0)
@@ -1039,11 +1031,11 @@ static Image *ReadMIFFImage(const ImageInfo *image_info,
 
                 for (i=0; i < (long) image->colors; i++)
                 {
-                  pixel=PushCharPixel(&p);
+                  p=PushCharPixel(p,&pixel);
                   image->colormap[i].red=ScaleCharToQuantum(pixel);
-                  pixel=PushCharPixel(&p);
+                  p=PushCharPixel(p,&pixel);
                   image->colormap[i].green=ScaleCharToQuantum(pixel);
-                  pixel=PushCharPixel(&p);
+                  p=PushCharPixel(p,&pixel);
                   image->colormap[i].blue=ScaleCharToQuantum(pixel);
                 }
                 break;
@@ -1055,11 +1047,11 @@ static Image *ReadMIFFImage(const ImageInfo *image_info,
 
                 for (i=0; i < (long) image->colors; i++)
                 {
-                  pixel=PushShortPixel(&quantum_state,&p);
+                  p=PushShortPixel(MSBEndian,p,&pixel);
                   image->colormap[i].red=ScaleShortToQuantum(pixel);
-                  pixel=PushShortPixel(&quantum_state,&p);
+                  p=PushShortPixel(MSBEndian,p,&pixel);
                   image->colormap[i].green=ScaleShortToQuantum(pixel);
-                  pixel=PushShortPixel(&quantum_state,&p);
+                  p=PushShortPixel(MSBEndian,p,&pixel);
                   image->colormap[i].blue=ScaleShortToQuantum(pixel);
                 }
                 break;
@@ -1071,11 +1063,11 @@ static Image *ReadMIFFImage(const ImageInfo *image_info,
 
                 for (i=0; i < (long) image->colors; i++)
                 {
-                  pixel=PushLongPixel(&quantum_state,&p);
+                  p=PushLongPixel(MSBEndian,p,&pixel);
                   image->colormap[i].red=ScaleLongToQuantum(pixel);
-                  pixel=PushLongPixel(&quantum_state,&p);
+                  p=PushLongPixel(MSBEndian,p,&pixel);
                   image->colormap[i].green=ScaleLongToQuantum(pixel);
-                  pixel=PushLongPixel(&quantum_state,&p);
+                  p=PushLongPixel(MSBEndian,p,&pixel);
                   image->colormap[i].blue=ScaleLongToQuantum(pixel);
                 }
                 break;
@@ -1095,37 +1087,50 @@ static Image *ReadMIFFImage(const ImageInfo *image_info,
         InheritException(exception,&image->exception);
         return(DestroyImageList(image));
       }
-    packet_size=(size_t) (image->depth/8);
+    quantum_info=AcquireQuantumInfo(image_info,image);
+    if (quantum_format != UndefinedQuantumFormat)
+      (void) SetQuantumFormat(image,quantum_format,quantum_info);
+    packet_size=(size_t) (quantum_info->depth/8);
     if (image->storage_class == DirectClass)
-      packet_size=(size_t) (3*image->depth/8);
+      packet_size=(size_t) (3*quantum_info->depth/8);
     if (image->matte != MagickFalse)
-      packet_size+=image->depth/8;
+      packet_size+=quantum_info->depth/8;
     if (image->colorspace == CMYKColorspace)
-      packet_size+=image->depth/8;
+      packet_size+=quantum_info->depth/8;
     if (image->compression == RLECompression)
       packet_size++;
     length=image->columns;
-    pixels=(unsigned char *) AcquireQuantumMemory(length,packet_size*
-      sizeof(*pixels));
     length=MagickMax(BZipMaxExtent(packet_size*image->columns),ZipMaxExtent(
       packet_size*image->columns));
     compress_pixels=(unsigned char *) AcquireQuantumMemory(length,
       sizeof(*compress_pixels));
-    if ((pixels == (unsigned char *) NULL) ||
-        (compress_pixels == (unsigned char *) NULL))
+    if (compress_pixels == (unsigned char *) NULL)
       ThrowReaderException(ResourceLimitError,"MemoryAllocationFailed");
     /*
       Read image pixels.
     */
     quantum_type=RGBQuantum;
+    if (image->matte != MagickFalse)
+      quantum_type=RGBAQuantum;
+    if (image->colorspace == CMYKColorspace)
+      {
+        quantum_type=CMYKQuantum;
+        if (image->matte != MagickFalse)
+          quantum_type=CMYKAQuantum;
+      }
     if (image->storage_class == PseudoClass)
-      quantum_type=image->matte != MagickFalse ? IndexAlphaQuantum :
-        IndexQuantum;
-    else
-      if (image->colorspace == CMYKColorspace)
-        quantum_type=image->matte != MagickFalse ? CMYKAQuantum : CMYKQuantum;
-      else
-        quantum_type=image->matte != MagickFalse ? RGBAQuantum : RGBQuantum;
+      {
+        quantum_type=IndexQuantum;
+        if (image->matte != MagickFalse)
+          quantum_type=IndexAlphaQuantum;
+      }
+    if (image->colorspace == GRAYColorspace)
+      {
+        quantum_type=GrayQuantum;
+        if (image->matte != MagickFalse)
+          quantum_type=GrayAlphaQuantum;
+      }
+    pixels=GetQuantumPixels(quantum_info);
     index=(IndexPacket) 0;
     length=0;
     for (y=0; y < (long) image->rows; y++)
@@ -1180,7 +1185,7 @@ static Image *ReadMIFFImage(const ImageInfo *image_info,
               if (code >= 0)
                 status=MagickTrue;
             }
-          status=ExportQuantumPixels(image,&quantum_info,quantum_type,pixels);
+          (void) ImportQuantumPixels(image,quantum_info,quantum_type,pixels);
           break;
         }
 #endif
@@ -1228,7 +1233,7 @@ static Image *ReadMIFFImage(const ImageInfo *image_info,
               if (code >= 0)
                 status=MagickTrue;
             }
-          status=ExportQuantumPixels(image,&quantum_info,quantum_type,pixels);
+          (void) ImportQuantumPixels(image,quantum_info,quantum_type,pixels);
           break;
         }
 #endif
@@ -1245,8 +1250,7 @@ static Image *ReadMIFFImage(const ImageInfo *image_info,
             if (length == 0)
               {
                 count=ReadBlob(image,packet_size,pixels);
-                PushRunlengthPacket(image,&quantum_state,pixels,&length,&pixel,
-                  &index);
+                PushRunlengthPacket(image,pixels,&length,&pixel,&index);
               }
             length--;
             if ((image->storage_class == PseudoClass) ||
@@ -1259,14 +1263,15 @@ static Image *ReadMIFFImage(const ImageInfo *image_info,
         default:
         {
           count=ReadBlob(image,packet_size*image->columns,pixels);
-          status=ExportQuantumPixels(image,&quantum_info,quantum_type,pixels);
+          (void) ImportQuantumPixels(image,quantum_info,quantum_type,pixels);
           break;
         }
       }
       if (SyncImagePixels(image) == MagickFalse)
         break;
     }
-    pixels=(unsigned char *) RelinquishMagickMemory(pixels);
+    SetQuantumImageType(image,quantum_type);
+    quantum_info=DestroyQuantumInfo(quantum_info);
     compress_pixels=(unsigned char *) RelinquishMagickMemory(compress_pixels);
     if (((y != (long) image->rows)) || (status == MagickFalse))
       {
@@ -1294,7 +1299,7 @@ static Image *ReadMIFFImage(const ImageInfo *image_info,
         /*
           Allocate next image structure.
         */
-        AllocateNextImage(image_info,image);
+        AcquireNextImage(image_info,image);
         if (GetNextImageInList(image) == (Image *) NULL)
           {
             image=DestroyImageList(image);
@@ -1310,7 +1315,7 @@ static Image *ReadMIFFImage(const ImageInfo *image_info,
           }
       }
   } while (c != EOF);
-  CloseBlob(image);
+  (void) CloseBlob(image);
   return(GetFirstImageInList(image));
 }
 
@@ -1413,33 +1418,29 @@ ModuleExport void UnregisterMIFFImage(void)
 %
 %  A description of each parameter follows:
 %
-%    o image_info: The image info.
+%    o image_info: the image info.
 %
-%    o image: The image.
+%    o image: the image.
 %
 */
 
-static size_t PopRunlengthPacket(Image *image,const QuantumState *quantum_state,
-  unsigned char *pixels,size_t length,PixelPacket pixel,IndexPacket index)
+static unsigned char *PopRunlengthPacket(Image *image,unsigned char *pixels,
+  size_t length,PixelPacket pixel,IndexPacket index)
 {
-  unsigned char
-    *q;
-
-  q=pixels;
   if (image->storage_class != DirectClass)
     {
       switch (image->depth)
       {
         case 32:
         {
-          *q++=(unsigned char) ((unsigned long) index >> 24);
-          *q++=(unsigned char) ((unsigned long) index >> 16);
+          *pixels++=(unsigned char) ((unsigned long) index >> 24);
+          *pixels++=(unsigned char) ((unsigned long) index >> 16);
         }
         case 16:
-          *q++=(unsigned char) ((unsigned long) index >> 8);
+          *pixels++=(unsigned char) ((unsigned long) index >> 8);
         case 8:
         {
-          *q++=(unsigned char) index;
+          *pixels++=(unsigned char) index;
           break;
         }
         default:
@@ -1456,7 +1457,7 @@ static size_t PopRunlengthPacket(Image *image,const QuantumState *quantum_state,
           if (image->matte != MagickFalse)
             {
               value=ScaleQuantumToLong(pixel.opacity);
-              PopLongPixel(quantum_state,value,&q);
+              pixels=PopLongPixel(MSBEndian,value,pixels);
             }
           break;
         }
@@ -1468,7 +1469,7 @@ static size_t PopRunlengthPacket(Image *image,const QuantumState *quantum_state,
           if (image->matte != MagickFalse)
             {
               value=ScaleQuantumToShort(pixel.opacity);
-              PopShortPixel(quantum_state,value,&q);
+              pixels=PopShortPixel(MSBEndian,value,pixels);
             }
           break;
         }
@@ -1480,7 +1481,7 @@ static size_t PopRunlengthPacket(Image *image,const QuantumState *quantum_state,
           if (image->matte != MagickFalse)
             {
               value=(unsigned char) ScaleQuantumToChar(pixel.opacity);
-              PopCharPixel(value,&q);
+              pixels=PopCharPixel(value,pixels);
             }
           break;
         }
@@ -1488,8 +1489,8 @@ static size_t PopRunlengthPacket(Image *image,const QuantumState *quantum_state,
           (void) ThrowMagickException(&image->exception,GetMagickModule(),
             CorruptImageError,"ImageDepthNotSupported","`%s'",image->filename);
       }
-      *q++=(unsigned char) length;
-      return((size_t) (q-pixels));
+      *pixels++=(unsigned char) length;
+      return(pixels);
     }
   switch (image->depth)
   {
@@ -1499,20 +1500,20 @@ static size_t PopRunlengthPacket(Image *image,const QuantumState *quantum_state,
         value;
 
       value=ScaleQuantumToLong(pixel.red);
-      PopLongPixel(quantum_state,value,&q);
+      pixels=PopLongPixel(MSBEndian,value,pixels);
       value=ScaleQuantumToLong(pixel.green);
-      PopLongPixel(quantum_state,value,&q);
+      pixels=PopLongPixel(MSBEndian,value,pixels);
       value=ScaleQuantumToLong(pixel.blue);
-      PopLongPixel(quantum_state,value,&q);
+      pixels=PopLongPixel(MSBEndian,value,pixels);
       if (image->matte != MagickFalse)
         {
           value=ScaleQuantumToLong(pixel.opacity);
-          PopLongPixel(quantum_state,value,&q);
+          pixels=PopLongPixel(MSBEndian,value,pixels);
         }
       if (image->colorspace == CMYKColorspace)
         {
           value=ScaleQuantumToLong(index);
-          PopLongPixel(quantum_state,value,&q);
+          pixels=PopLongPixel(MSBEndian,value,pixels);
         }
       break;
     }
@@ -1522,20 +1523,20 @@ static size_t PopRunlengthPacket(Image *image,const QuantumState *quantum_state,
         value;
 
       value=ScaleQuantumToShort(pixel.red);
-      PopShortPixel(quantum_state,value,&q);
+      pixels=PopShortPixel(MSBEndian,value,pixels);
       value=ScaleQuantumToShort(pixel.green);
-      PopShortPixel(quantum_state,value,&q);
+      pixels=PopShortPixel(MSBEndian,value,pixels);
       value=ScaleQuantumToShort(pixel.blue);
-      PopShortPixel(quantum_state,value,&q);
+      pixels=PopShortPixel(MSBEndian,value,pixels);
       if (image->matte != MagickFalse)
         {
           value=ScaleQuantumToShort(pixel.opacity);
-          PopShortPixel(quantum_state,value,&q);
+          pixels=PopShortPixel(MSBEndian,value,pixels);
         }
       if (image->colorspace == CMYKColorspace)
         {
           value=ScaleQuantumToShort(index);
-          PopShortPixel(quantum_state,value,&q);
+          pixels=PopShortPixel(MSBEndian,value,pixels);
         }
       break;
     }
@@ -1545,20 +1546,20 @@ static size_t PopRunlengthPacket(Image *image,const QuantumState *quantum_state,
         value;
 
       value=(unsigned char) ScaleQuantumToChar(pixel.red);
-      PopCharPixel(value,&q);
+      pixels=PopCharPixel(value,pixels);
       value=(unsigned char) ScaleQuantumToChar(pixel.green);
-      PopCharPixel(value,&q);
+      pixels=PopCharPixel(value,pixels);
       value=(unsigned char) ScaleQuantumToChar(pixel.blue);
-      PopCharPixel(value,&q);
+      pixels=PopCharPixel(value,pixels);
       if (image->matte != MagickFalse)
         {
           value=(unsigned char) ScaleQuantumToChar(pixel.opacity);
-          PopCharPixel(value,&q);
+          pixels=PopCharPixel(value,pixels);
         }
       if (image->colorspace == CMYKColorspace)
         {
           value=(unsigned char) ScaleQuantumToChar(index);
-          PopCharPixel(value,&q);
+          pixels=PopCharPixel(value,pixels);
         }
       break;
     }
@@ -1566,8 +1567,8 @@ static size_t PopRunlengthPacket(Image *image,const QuantumState *quantum_state,
       (void) ThrowMagickException(&image->exception,GetMagickModule(),
         CorruptImageError,"ImageDepthNotSupported","`%s'",image->filename);
   }
-  *q++=(unsigned char) length;
-  return((size_t) (q-pixels));
+  *pixels++=(unsigned char) length;
+  return(pixels);
 }
 
 static MagickBooleanType WriteMIFFImage(const ImageInfo *image_info,
@@ -1607,10 +1608,7 @@ static MagickBooleanType WriteMIFFImage(const ImageInfo *image_info,
     pixel;
 
   QuantumInfo
-    quantum_info;
-
-  QuantumState
-    quantum_state;
+    *quantum_info;
 
   QuantumType
     quantum_type;
@@ -1658,10 +1656,20 @@ static MagickBooleanType WriteMIFFImage(const ImageInfo *image_info,
     /*
       Allocate image pixels.
     */
-    image->depth=image->depth <= 8 ? 8UL : image->depth <= 16 ? 16UL : 32UL;
+    image->depth=image->depth <= 8 ? 8UL : image->depth <= 16 ? 16UL :
+      image->depth <= 32 ? 32UL : 64UL;
+    quantum_info=AcquireQuantumInfo(image_info,image);
+    if ((quantum_info->format == UndefinedQuantumFormat) &&
+        (IsHighDynamicRangeImage(image,&image->exception) != MagickFalse))
+      (void) SetQuantumFormat(image,FloatingPointQuantumFormat,quantum_info);
     if ((image->storage_class == PseudoClass) &&
-        (image->colors > (1UL << image->depth)))
+        (image->colors > (unsigned long) (GetQuantumRange(image->depth)+1)))
       (void) SetImageStorageClass(image,DirectClass);
+    if (IsGrayImage(image,&image->exception) != MagickFalse)
+      {
+        image->storage_class=DirectClass;
+        image->colorspace=GRAYColorspace;
+      }
     compression=NoCompression;
     switch (image->compression)
     {
@@ -1672,22 +1680,25 @@ static MagickBooleanType WriteMIFFImage(const ImageInfo *image_info,
 #if defined(MAGICKCORE_BZLIB_DELEGATE)
       case BZipCompression: compression=BZipCompression; break;
 #endif
-      case RLECompression: compression=RLECompression; break;
+      case RLECompression:
+      {
+        if (quantum_info->format != FloatingPointQuantumFormat)
+          compression=RLECompression;
+        break;
+      }
       default:
         break;
     }
-    packet_size=(size_t) (image->depth/8);
+    packet_size=(size_t) (quantum_info->depth/8);
     if (image->storage_class == DirectClass)
-      packet_size=(size_t) (3*image->depth/8);
+      packet_size=(size_t) (3*quantum_info->depth/8);
     if (image->matte != MagickFalse)
-      packet_size+=image->depth/8;
+      packet_size+=quantum_info->depth/8;
     if (image->colorspace == CMYKColorspace)
-      packet_size+=image->depth/8;
+      packet_size+=quantum_info->depth/8;
     if (compression == RLECompression)
-      packet_size+=image->depth/8;
+      packet_size++;
     length=image->columns;
-    pixels=(unsigned char *) AcquireQuantumMemory(length,packet_size*
-      sizeof(*pixels));
     length=MagickMax(BZipMaxExtent(packet_size*image->columns),ZipMaxExtent(
       packet_size*image->columns));
     if ((compression == BZipCompression) || (compression == ZipCompression))
@@ -1695,8 +1706,7 @@ static MagickBooleanType WriteMIFFImage(const ImageInfo *image_info,
         compression=NoCompression;
     compress_pixels=(unsigned char *) AcquireQuantumMemory(length,
       sizeof(*compress_pixels));
-    if ((pixels == (unsigned char *) NULL) ||
-        (compress_pixels == (unsigned char *) NULL))
+    if (compress_pixels == (unsigned char *) NULL)
       ThrowWriterException(ResourceLimitError,"MemoryAllocationFailed");
     /*
       Write MIFF header.
@@ -1707,9 +1717,8 @@ static MagickBooleanType WriteMIFFImage(const ImageInfo *image_info,
       MagickClassOptions,image->storage_class),image->colors,
       MagickOptionToMnemonic(MagickBooleanOptions,(long) image->matte));
     (void) WriteBlobString(image,buffer);
-    (void) FormatMagickString(buffer,MaxTextExtent,
-      "columns=%lu  rows=%lu  depth=%lu\n",image->columns,image->rows,
-      image->depth);
+    (void) FormatMagickString(buffer,MaxTextExtent,"columns=%lu  rows=%lu  "
+      "depth=%lu\n",image->columns,image->rows,image->depth);
     (void) WriteBlobString(image,buffer);
     if (image->colorspace != UndefinedColorspace)
       {
@@ -1719,9 +1728,9 @@ static MagickBooleanType WriteMIFFImage(const ImageInfo *image_info,
       }
     if (image->compression != UndefinedCompression)
       {
-        (void) FormatMagickString(buffer,MaxTextExtent,
-          "compression=%s  quality=%lu\n",MagickOptionToMnemonic(
-          MagickCompressOptions,image->compression),image->quality);
+        (void) FormatMagickString(buffer,MaxTextExtent,"compression=%s  "
+          "quality=%lu\n",MagickOptionToMnemonic(MagickCompressOptions,
+          compression),image->quality);
         (void) WriteBlobString(image,buffer);
       }
     if (image->units != UndefinedResolution)
@@ -1759,14 +1768,13 @@ static MagickBooleanType WriteMIFFImage(const ImageInfo *image_info,
         (GetPreviousImageInList(image) != (Image *) NULL))
       {
         if (image->scene == 0)
-          (void) FormatMagickString(buffer,MaxTextExtent,
-            "iterations=%lu  delay=%lu  ticks-per-second=%lu\n",
-            image->iterations,image->delay,image->ticks_per_second);
+          (void) FormatMagickString(buffer,MaxTextExtent,"iterations=%lu  "
+            "delay=%lu  ticks-per-second=%lu\n",image->iterations,image->delay,
+             image->ticks_per_second);
         else
-          (void) FormatMagickString(buffer,MaxTextExtent,
-            "scene=%lu  iterations=%lu  delay=%lu  ticks-per-second=%lu\n",
-            image->scene,image->iterations,image->delay,
-            image->ticks_per_second);
+          (void) FormatMagickString(buffer,MaxTextExtent,"scene=%lu  "
+            "iterations=%lu  delay=%lu  ticks-per-second=%lu\n",image->scene,
+            image->iterations,image->delay,image->ticks_per_second);
         (void) WriteBlobString(image,buffer);
       }
     else
@@ -1820,8 +1828,8 @@ static MagickBooleanType WriteMIFFImage(const ImageInfo *image_info,
         /*
           Note chomaticity points.
         */
-        (void) FormatMagickString(buffer,MaxTextExtent,
-          "red-primary=%g,%g  green-primary=%g,%g  blue-primary=%g,%g\n",
+        (void) FormatMagickString(buffer,MaxTextExtent,"red-primary=%g,%g  "
+          "green-primary=%g,%g  blue-primary=%g,%g\n",
           image->chromaticity.red_primary.x,image->chromaticity.red_primary.y,
           image->chromaticity.green_primary.x,
           image->chromaticity.green_primary.y,
@@ -1834,9 +1842,8 @@ static MagickBooleanType WriteMIFFImage(const ImageInfo *image_info,
       }
     if (image->orientation != UndefinedOrientation)
       {
-        (void) FormatMagickString(buffer,MaxTextExtent,
-          "orientation=%s\n",MagickOptionToMnemonic(MagickOrientationOptions,
-          image->orientation));
+        (void) FormatMagickString(buffer,MaxTextExtent,"orientation=%s\n",
+          MagickOptionToMnemonic(MagickOrientationOptions,image->orientation));
         (void) WriteBlobString(image,buffer);
       }
     if (image->profiles != (void *) NULL)
@@ -1857,9 +1864,8 @@ static MagickBooleanType WriteMIFFImage(const ImageInfo *image_info,
           profile=GetImageProfile(image,name);
           if (profile != (StringInfo *) NULL)
             {
-              (void) FormatMagickString(buffer,MaxTextExtent,
-                "profile-%s=%lu\n",name,(unsigned long)
-                GetStringInfoLength(profile));
+              (void) FormatMagickString(buffer,MaxTextExtent,"profile-%s=%lu\n",
+                name,(unsigned long) GetStringInfoLength(profile));
               (void) WriteBlobString(image,buffer);
             }
           name=GetNextImageProfile(image);
@@ -1871,13 +1877,8 @@ static MagickBooleanType WriteMIFFImage(const ImageInfo *image_info,
           image->montage);
         (void) WriteBlobString(image,buffer);
       }
-    GetQuantumInfo(image_info,&quantum_info);
-    if (quantum_info.format == FloatingPointQuantumFormat)
-      {
-        (void) WriteBlobString(image,"quantum-format=floating-point\n");
-        quantum_info.scale=1.0/QuantumRange;
-      }
-    InitializeQuantumState(&quantum_info,MSBEndian,&quantum_state);
+    if (quantum_info->format == FloatingPointQuantumFormat)
+      (void) WriteBlobString(image,"quantum-format=floating-point\n");
     ResetImagePropertyIterator(image);
     property=GetNextImageProperty(image);
     while (property != (const char *) NULL)
@@ -1906,8 +1907,8 @@ static MagickBooleanType WriteMIFFImage(const ImageInfo *image_info,
           Write montage tile directory.
         */
         if (image->directory != (char *) NULL)
-          (void) WriteBlob(image,strlen(image->directory),
-            (unsigned char *) image->directory);
+          (void) WriteBlob(image,strlen(image->directory),(unsigned char *)
+            image->directory);
         (void) WriteBlobByte(image,'\0');
       }
     if (image->profiles != (void *) NULL)
@@ -1943,7 +1944,7 @@ static MagickBooleanType WriteMIFFImage(const ImageInfo *image_info,
         /*
           Allocate colormap.
         */
-        packet_size=(size_t) (3*image->depth/8);
+        packet_size=(size_t) (3*quantum_info->depth/8);
         colormap=(unsigned char *) AcquireQuantumMemory(image->colors,
           packet_size*sizeof(*colormap));
         if (colormap == (unsigned char *) NULL)
@@ -1954,7 +1955,7 @@ static MagickBooleanType WriteMIFFImage(const ImageInfo *image_info,
         q=colormap;
         for (i=0; i < (long) image->colors; i++)
         {
-          switch (image->depth)
+          switch (quantum_info->depth)
           {
             default:
               ThrowWriterException(CorruptImageError,"ImageDepthNotSupported");
@@ -1964,11 +1965,11 @@ static MagickBooleanType WriteMIFFImage(const ImageInfo *image_info,
                 pixel;
 
               pixel=ScaleQuantumToLong(image->colormap[i].red);
-              PopLongPixel(&quantum_state,pixel,&q);
+              q=PopLongPixel(MSBEndian,pixel,q);
               pixel=ScaleQuantumToLong(image->colormap[i].green);
-              PopLongPixel(&quantum_state,pixel,&q);
+              q=PopLongPixel(MSBEndian,pixel,q);
               pixel=ScaleQuantumToLong(image->colormap[i].blue);
-              PopLongPixel(&quantum_state,pixel,&q);
+              q=PopLongPixel(MSBEndian,pixel,q);
               break;
             }
             case 16:
@@ -1977,11 +1978,11 @@ static MagickBooleanType WriteMIFFImage(const ImageInfo *image_info,
                 pixel;
 
               pixel=ScaleQuantumToShort(image->colormap[i].red);
-              PopShortPixel(&quantum_state,pixel,&q);
+              q=PopShortPixel(MSBEndian,pixel,q);
               pixel=ScaleQuantumToShort(image->colormap[i].green);
-              PopShortPixel(&quantum_state,pixel,&q);
+              q=PopShortPixel(MSBEndian,pixel,q);
               pixel=ScaleQuantumToShort(image->colormap[i].blue);
-              PopShortPixel(&quantum_state,pixel,&q);
+              q=PopShortPixel(MSBEndian,pixel,q);
               break;
             }
             case 8:
@@ -1990,12 +1991,12 @@ static MagickBooleanType WriteMIFFImage(const ImageInfo *image_info,
                 pixel;
 
               pixel=(unsigned char) ScaleQuantumToChar(image->colormap[i].red);
-              PopCharPixel(pixel,&q);
+              q=PopCharPixel(pixel,q);
               pixel=(unsigned char) ScaleQuantumToChar(
                 image->colormap[i].green);
-              PopCharPixel(pixel,&q);
+              q=PopCharPixel(pixel,q);
               pixel=(unsigned char) ScaleQuantumToChar(image->colormap[i].blue);
-              PopCharPixel(pixel,&q);
+              q=PopCharPixel(pixel,q);
               break;
             }
           }
@@ -2006,15 +2007,8 @@ static MagickBooleanType WriteMIFFImage(const ImageInfo *image_info,
     /*
       Write image pixels to file.
     */
-    quantum_type=RGBQuantum;
-    if (image->storage_class == PseudoClass)
-      quantum_type=image->matte != MagickFalse ? IndexAlphaQuantum :
-        IndexQuantum;
-    else
-      if (image->colorspace == CMYKColorspace)
-        quantum_type=image->matte != MagickFalse ? CMYKAQuantum : CMYKQuantum;
-      else
-        quantum_type=image->matte != MagickFalse ? RGBAQuantum : RGBQuantum;
+    quantum_type=GetQuantumType(image,&image->exception);
+    pixels=GetQuantumPixels(quantum_info);
     status=MagickTrue;
     for (y=0; y < (long) image->rows; y++)
     {
@@ -2042,7 +2036,7 @@ static MagickBooleanType WriteMIFFImage(const ImageInfo *image_info,
             }
           zip_info.next_in=pixels;
           zip_info.avail_in=(uInt) (packet_size*image->columns);
-          (void) ImportQuantumPixels(image,&quantum_info,quantum_type,pixels);
+          (void) ExportQuantumPixels(image,quantum_info,quantum_type,pixels);
           do
           {
             zip_info.next_out=compress_pixels;
@@ -2062,8 +2056,8 @@ static MagickBooleanType WriteMIFFImage(const ImageInfo *image_info,
               for ( ; ; )
               {
                 zip_info.next_out=compress_pixels;
-                zip_info.avail_out=(uInt)
-                  ZipMaxExtent(packet_size*image->columns);
+                zip_info.avail_out=(uInt) ZipMaxExtent(packet_size*
+                  image->columns);
                 code=deflate(&zip_info,Z_FINISH);
                 length=(size_t) (zip_info.next_out-compress_pixels);
                 if (length > 6)
@@ -2096,7 +2090,7 @@ static MagickBooleanType WriteMIFFImage(const ImageInfo *image_info,
             }
           bzip_info.next_in=(char *) pixels;
           bzip_info.avail_in=(unsigned int) (packet_size*image->columns);
-          (void) ImportQuantumPixels(image,&quantum_info,quantum_type,pixels);
+          (void) ExportQuantumPixels(image,quantum_info,quantum_type,pixels);
           do
           {
             bzip_info.next_out=(char *) compress_pixels;
@@ -2117,8 +2111,8 @@ static MagickBooleanType WriteMIFFImage(const ImageInfo *image_info,
               for ( ; ; )
               {
                 bzip_info.next_out=(char *) compress_pixels;
-                bzip_info.avail_out=(unsigned int)
-                  BZipMaxExtent(packet_size*image->columns);
+                bzip_info.avail_out=(unsigned int) BZipMaxExtent(packet_size*
+                  image->columns);
                 code=BZ2_bzCompress(&bzip_info,BZ_FINISH);
                 length=(size_t) (bzip_info.next_out-(char *) compress_pixels);
                 if (length != 0)
@@ -2153,8 +2147,7 @@ static MagickBooleanType WriteMIFFImage(const ImageInfo *image_info,
             else
               {
                 if (x > 0)
-                  q+=PopRunlengthPacket(image,&quantum_state,q,length,pixel,
-                    index);
+                  q=PopRunlengthPacket(image,q,length,pixel,index);
                 length=0;
               }
             pixel=(*p);
@@ -2162,13 +2155,13 @@ static MagickBooleanType WriteMIFFImage(const ImageInfo *image_info,
               index=indexes[x];
             p++;
           }
-          q+=PopRunlengthPacket(image,&quantum_state,q,length,pixel,index);
+          q=PopRunlengthPacket(image,q,length,pixel,index);
           (void) WriteBlob(image,(size_t) (q-pixels),pixels);
           break;
         }
         default:
         {
-          (void) ImportQuantumPixels(image,&quantum_info,quantum_type,pixels);
+          (void) ExportQuantumPixels(image,quantum_info,quantum_type,pixels);
           (void) WriteBlob(image,packet_size*image->columns,pixels);
           break;
         }
@@ -2183,7 +2176,7 @@ static MagickBooleanType WriteMIFFImage(const ImageInfo *image_info,
               break;
           }
     }
-    pixels=(unsigned char *) RelinquishMagickMemory(pixels);
+    quantum_info=DestroyQuantumInfo(quantum_info);
     compress_pixels=(unsigned char *) RelinquishMagickMemory(compress_pixels);
     if (GetNextImageInList(image) == (Image *) NULL)
       break;
@@ -2197,6 +2190,6 @@ static MagickBooleanType WriteMIFFImage(const ImageInfo *image_info,
       }
     scene++;
   } while (image_info->adjoin != MagickFalse);
-  CloseBlob(image);
+  (void) CloseBlob(image);
   return(status);
 }
