@@ -133,7 +133,7 @@ static MagickBooleanType IsPCL(const unsigned char *magick,const size_t length)
 %
 %  A description of each parameter follows:
 %
-%    o image_info: The image info.
+%    o image_info: the image info.
 %
 %    o exception: return any errors or warnings in this structure.
 %
@@ -201,7 +201,7 @@ static Image *ReadPCLImage(const ImageInfo *image_info,ExceptionInfo *exception)
   /*
     Open image file.
   */
-  image=AllocateImage(image_info);
+  image=AcquireImage(image_info);
   status=OpenBlob(image_info,image,ReadBinaryBlobMode,exception);
   if (status == MagickFalse)
     {
@@ -240,7 +240,7 @@ static Image *ReadPCLImage(const ImageInfo *image_info,ExceptionInfo *exception)
   /*
     Determine page geometry from the PCL media box.
   */
-  cmyk=image_info->colorspace == CMYKColorspace ? MagickTrue : MagickFalse;
+  cmyk=image->colorspace == CMYKColorspace ? MagickTrue : MagickFalse;
   count=0;
   (void) ResetMagickMemory(&bounding_box,0,sizeof(bounding_box));
   (void) ResetMagickMemory(&bounds,0,sizeof(bounds));
@@ -299,7 +299,7 @@ static Image *ReadPCLImage(const ImageInfo *image_info,ExceptionInfo *exception)
     if (height > page.height)
       page.height=height;
   }
-  CloseBlob(image);
+  (void) CloseBlob(image);
   /*
     Render PCL with the GhostPCL delegate.
   */
@@ -307,11 +307,6 @@ static Image *ReadPCLImage(const ImageInfo *image_info,ExceptionInfo *exception)
     (void) ParseAbsoluteGeometry(PSPageGeometry,&page);
   if (image_info->page != (char *) NULL)
     (void) ParseAbsoluteGeometry(image_info->page,&page);
-  page.width=(unsigned long)
-    (page.width*image->x_resolution/delta.x+0.5);
-  page.height=(unsigned long)
-    (page.height*image->y_resolution/delta.y+0.5);
-  image=DestroyImage(image);
   (void) FormatMagickString(geometry,MaxTextExtent,"%lux%lu",
     page.width,page.height);
   if (image_info->monochrome != MagickFalse)
@@ -324,6 +319,15 @@ static Image *ReadPCLImage(const ImageInfo *image_info,ExceptionInfo *exception)
   if (delegate_info == (const DelegateInfo *) NULL)
     return((Image *) NULL);
   *options='\0';
+  if ((page.width == 0) || (page.height == 0))
+    (void) ParseAbsoluteGeometry(PSPageGeometry,&page);
+  if (image_info->page != (char *) NULL)
+    (void) ParseAbsoluteGeometry(image_info->page,&page);
+  page.width=(unsigned long) (page.width*image->y_resolution/delta.x+0.5);
+  page.height=(unsigned long) (page.height*image->y_resolution/delta.y+0.5);
+  (void) FormatMagickString(options,MaxTextExtent,"-g%lux%lu ",
+    page.width,page.height);
+  image=DestroyImage(image);
   read_info=CloneImageInfo(image_info);
   *read_info->magick='\0';
   if (read_info->number_scenes != 0)
@@ -347,7 +351,7 @@ static Image *ReadPCLImage(const ImageInfo *image_info,ExceptionInfo *exception)
   (void) FormatMagickString(command,MaxTextExtent,
     GetDelegateCommands(delegate_info),
     read_info->antialias != MagickFalse ? 4 : 1,
-    read_info->antialias != MagickFalse ? 4 : 1,geometry,density,options,
+    read_info->antialias != MagickFalse ? 4 : 1,density,options,
     read_info->filename,input_filename);
   status=SystemCommand(read_info->verbose,command) != 0 ? MagickTrue :
     MagickFalse;
@@ -466,7 +470,7 @@ ModuleExport void UnregisterPCLImage(void)
 %
 %  A description of each parameter follows.
 %
-%    o image_info: The image info.
+%    o image_info: the image info.
 %
 %    o image:  The image.
 %
@@ -511,7 +515,7 @@ static MagickBooleanType WritePCLImage(const ImageInfo *image_info,Image *image)
   status=OpenBlob(image_info,image,WriteBinaryBlobMode,&image->exception);
   if (status == MagickFalse)
     return(status);
-  if (image_info->colorspace == UndefinedColorspace)
+  if (image->colorspace != RGBColorspace)
     (void) SetImageColorspace(image,RGBColorspace);
   /*
     Initialize the printer.
@@ -645,6 +649,6 @@ static MagickBooleanType WritePCLImage(const ImageInfo *image_info,Image *image)
       pixels=(unsigned char *) RelinquishMagickMemory(pixels);
     }
   (void) WriteBlobString(image,"\033E");
-  CloseBlob(image);
+  (void) CloseBlob(image);
   return(MagickTrue);
 }
