@@ -363,7 +363,7 @@ static Image *ReadPDFImage(const ImageInfo *image_info,ExceptionInfo *exception)
   /*
     Determine page geometry from the PDF media box.
   */
-  cmyk=image->colorspace == CMYKColorspace ? MagickTrue : MagickFalse;
+  cmyk=image_info->colorspace == CMYKColorspace ? MagickTrue : MagickFalse;
   cropbox=MagickFalse;
   option=GetImageOption(image_info,"pdf:use-cropbox");
   if (option != (const char *) NULL)
@@ -502,7 +502,7 @@ static Image *ReadPDFImage(const ImageInfo *image_info,ExceptionInfo *exception)
       page.width=page.height;
       page.height=swap;
     }
-  if (image->colorspace == RGBColorspace)
+  if (image_info->colorspace == RGBColorspace)
     cmyk=MagickFalse;
   /*
     Create Ghostscript control file.
