@@ -17,7 +17,7 @@
 %                                 July 1992                                   %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2007 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2008 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -57,9 +57,10 @@
 #include "magick/monitor.h"
 #include "magick/profile.h"
 #include "magick/resource_.h"
-#include "magick/quantum.h"
+#include "magick/quantum-private.h"
 #include "magick/static.h"
 #include "magick/string_.h"
+#include "magick/module.h"
 #include "magick/transform.h"
 #include "magick/utility.h"
 
@@ -101,13 +102,13 @@
 
 typedef struct _PICTCode
 {
-  char
+  const char
     *name;
 
   long
     length;
 
-  char
+  const char
     *description;
 } PICTCode;
 
@@ -332,22 +333,22 @@ static MagickBooleanType
 %
 %  The format of the DecodeImage method is:
 %
-%      unsigned char* DecodeImage(const ImageInfo *image_info,Image *blob,
-%        Image *image,unsigned long bytes_per_line,const int bits_per_pixel,
-%        unsigned long *extent)
+%      unsigned char *DecodeImage(Image *blob,Image *image,
+%        unsigned long bytes_per_line,const int bits_per_pixel,
+%        unsigned size_t extent)
 %
 %  A description of each parameter follows:
 %
-%    o image_info: The image info.
+%    o image_info: the image info.
 %
-%    o blob,image: The address of a structure of type Image.
+%    o blob,image: the address of a structure of type Image.
 %
 %    o bytes_per_line: This integer identifies the number of bytes in a
 %      scanline.
 %
-%    o bits_per_pixel: The number of bits in a pixel.
+%    o bits_per_pixel: the number of bits in a pixel.
 %
-%    o extent: The number of pixels allocated.
+%    o extent: the number of pixels allocated.
 %
 */
 
@@ -419,9 +420,8 @@ static unsigned char *ExpandBuffer(unsigned char *pixels,
   return(scanline);
 }
 
-static unsigned char *DecodeImage(const ImageInfo *image_info,Image *blob,
-  Image *image,unsigned long bytes_per_line,const unsigned int bits_per_pixel,
-  unsigned long *extent)
+static unsigned char *DecodeImage(Image *blob,Image *image,
+  unsigned long bytes_per_line,const unsigned int bits_per_pixel,size_t *extent)
 {
   long
     j,
@@ -438,7 +438,8 @@ static unsigned char *DecodeImage(const ImageInfo *image_info,Image *blob,
     *q;
 
   size_t
-    length;
+    length,
+    row_bytes;
 
   ssize_t
     count;
@@ -447,9 +448,6 @@ static unsigned char *DecodeImage(const ImageInfo *image_info,Image *blob,
     *pixels,
     *scanline;
 
-  unsigned short
-    row_bytes;
-
   unsigned long
     bytes_per_pixel,
     scanline_length,
@@ -472,9 +470,9 @@ static unsigned char *DecodeImage(const ImageInfo *image_info,Image *blob,
       width*=image->matte ? 4 : 3;
   if (bytes_per_line == 0)
     bytes_per_line=width;
-  row_bytes=(unsigned short) (image->columns | 0x8000);
+  row_bytes=(size_t) (image->columns | 0x8000);
   if (image->storage_class == DirectClass)
-    row_bytes=(unsigned short) ((4*image->columns) | 0x8000);
+    row_bytes=(size_t) ((4*image->columns) | 0x8000);
   /*
     Allocate pixel and scanline buffer.
   */
@@ -498,6 +496,13 @@ static unsigned char *DecodeImage(const ImageInfo *image_info,Image *blob,
         number_pixels=bytes_per_line;
         count=ReadBlob(blob,(size_t) number_pixels,scanline);
         p=ExpandBuffer(scanline,&number_pixels,bits_per_pixel);
+        if ((q+number_pixels) > (pixels+(*extent)))
+          {
+            (void) ThrowMagickException(&image->exception,GetMagickModule(),
+              CorruptImageError,"UnableToUncompressImage","`%s'",
+              image->filename);
+            break;
+          }
         (void) CopyMagickMemory(q,p,(size_t) number_pixels);
       }
       scanline=(unsigned char *) RelinquishMagickMemory(scanline);
@@ -516,7 +521,7 @@ static unsigned char *DecodeImage(const ImageInfo *image_info,Image *blob,
     if (scanline_length >= row_bytes)
       {
         (void) ThrowMagickException(&image->exception,GetMagickModule(),
-           CorruptImageError,"UnableToUncompressImage","`%s'",image->filename);
+          CorruptImageError,"UnableToUncompressImage","`%s'",image->filename);
         break;
       }
     count=ReadBlob(blob,scanline_length,scanline);
@@ -526,7 +531,8 @@ static unsigned char *DecodeImage(const ImageInfo *image_info,Image *blob,
           length=(size_t) ((scanline[j] & 0xff)+1);
           number_pixels=length*bytes_per_pixel;
           p=ExpandBuffer(scanline+j+1,&number_pixels,bits_per_pixel);
-          (void) CopyMagickMemory(q,p,(size_t) number_pixels);
+          if ((q-pixels+number_pixels) <= *extent)
+            (void) CopyMagickMemory(q,p,(size_t) number_pixels);
           q+=number_pixels;
           j+=(long) (length*bytes_per_pixel+1);
         }
@@ -537,7 +543,8 @@ static unsigned char *DecodeImage(const ImageInfo *image_info,Image *blob,
           p=ExpandBuffer(scanline+j+1,&number_pixels,bits_per_pixel);
           for (i=0; i < (long) length; i++)
           {
-            (void) CopyMagickMemory(q,p,(size_t) number_pixels);
+            if ((q-pixels+number_pixels) <= *extent)
+              (void) CopyMagickMemory(q,p,(size_t) number_pixels);
             q+=number_pixels;
           }
           j+=bytes_per_pixel+1;
@@ -568,11 +575,11 @@ static unsigned char *DecodeImage(const ImageInfo *image_info,Image *blob,
 %
 %  A description of each parameter follows:
 %
-%    o image: The address of a structure of type Image.
+%    o image: the address of a structure of type Image.
 %
 %    o scanline: A pointer to an array of characters to pack.
 %
-%    o bytes_per_line: The number of bytes in a scanline.
+%    o bytes_per_line: the number of bytes in a scanline.
 %
 %    o pixels: A pointer to an array of characters where the packed
 %      characters are stored.
@@ -767,7 +774,7 @@ static MagickBooleanType IsPICT(const unsigned char *magick,const size_t length)
 %
 %  A description of each parameter follows:
 %
-%    o image_info: The image info.
+%    o image_info: the image info.
 %
 %    o exception: return any errors or warnings in this structure.
 %
@@ -826,6 +833,7 @@ static Image *ReadPICTImage(const ImageInfo *image_info,
     i;
 
   size_t
+    extent,
     length;
 
   ssize_t
@@ -834,9 +842,6 @@ static Image *ReadPICTImage(const ImageInfo *image_info,
   StringInfo
     *profile;
 
-  unsigned long
-    extent;
-
   /*
     Open image file.
   */
@@ -847,7 +852,7 @@ static Image *ReadPICTImage(const ImageInfo *image_info,
       image_info->filename);
   assert(exception != (ExceptionInfo *) NULL);
   assert(exception->signature == MagickSignature);
-  image=AllocateImage(image_info);
+  image=AcquireImage(image_info);
   image->depth=8;
   status=OpenBlob(image_info,image,ReadBinaryBlobMode,exception);
   if (status == MagickFalse)
@@ -864,7 +869,7 @@ static Image *ReadPICTImage(const ImageInfo *image_info,
     (void) ReadBlobByte(image);  /* skip header */
   (void) ReadBlobMSBShort(image);  /* skip picture size */
   ReadRectangle(image,frame);
-  while ((c=ReadBlobByte(image)) == 0);
+  while ((c=ReadBlobByte(image)) == 0) ;
   if (c != 0x11)
     ThrowReaderException(CorruptImageError,"ImproperImageHeader");
   version=ReadBlobByte(image);
@@ -877,6 +882,10 @@ static Image *ReadPICTImage(const ImageInfo *image_info,
   else
     if (version != 1)
       ThrowReaderException(CorruptImageError,"ImproperImageHeader");
+  if ((frame.left < 0) || (frame.right < 0) || (frame.top < 0) ||
+      (frame.bottom < 0) || (frame.left >= frame.right) ||
+      (frame.top >= frame.bottom))
+    ThrowReaderException(CorruptImageError,"ImproperImageHeader");
   /*
     Create black canvas.
   */
@@ -1099,7 +1108,7 @@ static Image *ReadPICTImage(const ImageInfo *image_info,
                     flags=1L*ReadBlobMSBShort(image);
                     tile_image->colors=1UL*ReadBlobMSBShort(image)+1;
                   }
-                status=AllocateImageColormap(tile_image,tile_image->colors);
+                status=AcquireImageColormap(tile_image,tile_image->colors);
                 if (status == MagickFalse)
                   {
                     tile_image=DestroyImage(tile_image);
@@ -1148,11 +1157,10 @@ static Image *ReadPICTImage(const ImageInfo *image_info,
               }
             if ((code != 0x9a) && (code != 0x9b) &&
                 (bytes_per_line & 0x8000) == 0)
-              pixels=DecodeImage(image_info,image,tile_image,1UL*
-                bytes_per_line,1,&extent);
+              pixels=DecodeImage(image,tile_image,1UL*bytes_per_line,1,&extent);
             else
-              pixels=DecodeImage(image_info,image,tile_image,1UL*bytes_per_line,
-                1U*pixmap.bits_per_pixel,&extent);
+              pixels=DecodeImage(image,tile_image,1UL*bytes_per_line,1U*
+                pixmap.bits_per_pixel,&extent);
             if (pixels == (unsigned char *) NULL)
               {
                 tile_image=DestroyImage(tile_image);
@@ -1394,7 +1402,7 @@ static Image *ReadPICTImage(const ImageInfo *image_info,
           MagickMax(image->columns,tile_image->columns),
           MagickMax(image->rows,tile_image->rows));
         (void) TransformImage(&image,(char *) NULL,geometry);
-        if (image_info->colorspace == UndefinedColorspace)
+        if (image->colorspace != RGBColorspace)
           (void) SetImageColorspace(image,tile_image->colorspace);
         (void) CompositeImage(image,CopyCompositeOp,tile_image,frame.left,
           frame.right);
@@ -1426,7 +1434,7 @@ static Image *ReadPICTImage(const ImageInfo *image_info,
         continue;
       }
   }
-  CloseBlob(image);
+  (void) CloseBlob(image);
   return(GetFirstImageInList(image));
 }
 #endif
@@ -1451,30 +1459,31 @@ static Image *ReadPICTImage(const ImageInfo *image_info,
 %
 %  The format of the RegisterPICTImage method is:
 %
-%      RegisterPICTImage(void)
+%      unsigned long RegisterPICTImage(void)
 %
 */
-ModuleExport void RegisterPICTImage(void)
+ModuleExport unsigned long RegisterPICTImage(void)
 {
   MagickInfo
     *entry;
 
   entry=SetMagickInfo("PCT");
-  entry->decoder=(DecoderHandler *) ReadPICTImage;
-  entry->encoder=(EncoderHandler *) WritePICTImage;
+  entry->decoder=(DecodeImageHandler *) ReadPICTImage;
+  entry->encoder=(EncodeImageHandler *) WritePICTImage;
   entry->adjoin=MagickFalse;
   entry->description=ConstantString("Apple Macintosh QuickDraw/PICT");
-  entry->magick=(MagickHandler *) IsPICT;
+  entry->magick=(IsImageFormatHandler *) IsPICT;
   entry->module=ConstantString("PICT");
   (void) RegisterMagickInfo(entry);
   entry=SetMagickInfo("PICT");
-  entry->decoder=(DecoderHandler *) ReadPICTImage;
-  entry->encoder=(EncoderHandler *) WritePICTImage;
+  entry->decoder=(DecodeImageHandler *) ReadPICTImage;
+  entry->encoder=(EncodeImageHandler *) WritePICTImage;
   entry->adjoin=MagickFalse;
   entry->description=ConstantString("Apple Macintosh QuickDraw/PICT");
-  entry->magick=(MagickHandler *) IsPICT;
+  entry->magick=(IsImageFormatHandler *) IsPICT;
   entry->module=ConstantString("PICT");
   (void) RegisterMagickInfo(entry);
+  return(MagickImageCoderSignature);
 }
 
 /*
@@ -1522,7 +1531,7 @@ ModuleExport void UnregisterPICTImage(void)
 %
 %  A description of each parameter follows.
 %
-%    o image_info: The image info.
+%    o image_info: the image info.
 %
 %    o image:  The image.
 %
@@ -1609,7 +1618,7 @@ static MagickBooleanType WritePICTImage(const ImageInfo *image_info,
   status=OpenBlob(image_info,image,WriteBinaryBlobMode,&image->exception);
   if (status == MagickFalse)
     return(status);
-  if (image_info->colorspace == UndefinedColorspace)
+  if (image->colorspace != RGBColorspace)
     (void) SetImageColorspace(image,RGBColorspace);
   /*
     Initialize image info.
@@ -1745,7 +1754,7 @@ static MagickBooleanType WritePICTImage(const ImageInfo *image_info,
       jpeg_image=CloneImage(image,0,0,MagickTrue,&image->exception);
       if (jpeg_image == (Image *) NULL)
         {
-          CloseBlob(image);
+          (void) CloseBlob(image);
           return(MagickFalse);
         }
       DestroyBlob(jpeg_image);
@@ -1967,6 +1976,6 @@ static MagickBooleanType WritePICTImage(const ImageInfo *image_info,
   scanline=(unsigned char *) RelinquishMagickMemory(scanline);
   packed_scanline=(unsigned char *) RelinquishMagickMemory(packed_scanline);
   buffer=(unsigned char *) RelinquishMagickMemory(buffer);
-  CloseBlob(image);
+  (void) CloseBlob(image);
   return(MagickTrue);
 }
