@@ -1462,10 +1462,7 @@ static MagickBooleanType WritePNMImage(const ImageInfo *image_info,Image *image)
           indexes=GetIndexes(image);
           for (x=0; x < (long) image->columns; x++)
           {
-            if (IsGrayPixel(p) != MagickFalse)
-              pixel=p->red;
-            else
-              pixel=PixelIntensityToQuantum(p);
+            pixel=PixelIntensityToQuantum(p);
             *q++=(unsigned char) (pixel >= (Quantum) (QuantumRange/2) ?
               '0' : '1');
             *q++=' ';
@@ -1835,11 +1832,8 @@ static MagickBooleanType WritePNMImage(const ImageInfo *image_info,Image *image)
                   if (image->depth <= 8)
                     for (x=0; x < (long) image->columns; x++)
                     {
-                      if (IsGrayPixel(p) != MagickFalse)
-                        pixel=ScaleQuantumToAny(p->red,image->depth,scale);
-                      else
-                        pixel=ScaleQuantumToAny(PixelIntensityToQuantum(p),
-                          image->depth,scale);
+                      pixel=ScaleQuantumToAny(PixelIntensityToQuantum(p),
+                        image->depth,scale);
                       q=PopCharPixel((unsigned char) pixel,q);
                       if (image->matte != MagickFalse)
                         {
@@ -1852,11 +1846,8 @@ static MagickBooleanType WritePNMImage(const ImageInfo *image_info,Image *image)
                   else
                     for (x=0; x < (long) image->columns; x++)
                     {
-                      if (IsGrayPixel(p) != MagickFalse)
-                        pixel=ScaleQuantumToAny(p->red,image->depth,scale);
-                      else
-                        pixel=ScaleQuantumToAny(PixelIntensityToQuantum(p),
-                          image->depth,scale);
+                      pixel=ScaleQuantumToAny(PixelIntensityToQuantum(p),
+                        image->depth,scale);
                       q=PopShortPixel(MSBEndian,(unsigned short) pixel,q);
                       if (image->matte != MagickFalse)
                         {
