@@ -451,7 +451,7 @@ static Image *ReadPSImage(const ImageInfo *image_info,ExceptionInfo *exception)
   spotcolor=0;
   language_level=1;
   skip=MagickFalse;
-  cmyk=image->colorspace == CMYKColorspace ? MagickTrue : MagickFalse;
+  cmyk=image_info->colorspace == CMYKColorspace ? MagickTrue : MagickFalse;
   pages=(~0UL);
   p=command;
   for (c=ReadBlobByte(image); c != EOF; c=ReadBlobByte(image))
@@ -623,7 +623,7 @@ static Image *ReadPSImage(const ImageInfo *image_info,ExceptionInfo *exception)
       }
   }
   (void) CloseBlob(image);
-  if (image->colorspace == RGBColorspace)
+  if (image_info->colorspace == RGBColorspace)
     cmyk=MagickFalse;
   /*
     Create Ghostscript control file.
@@ -1330,7 +1330,8 @@ static MagickBooleanType WritePSImage(const ImageInfo *image_info,Image *image)
     /*
       Scale relative to dots-per-inch.
     */
-    if (image->colorspace != RGBColorspace)
+    if ((image->colorspace != RGBColorspace) &&
+        (image->colorspace != CMYKColorspace))
       (void) SetImageColorspace(image,RGBColorspace);
     delta.x=DefaultResolution;
     delta.y=DefaultResolution;
@@ -1528,10 +1529,7 @@ static MagickBooleanType WritePSImage(const ImageInfo *image_info,Image *image)
               for (x=0; x < (long) preview_image->columns; x++)
               {
                 byte<<=1;
-                if (IsGrayPixel(p) != MagickFalse)
-                  pixel=p->red;
-                else
-                  pixel=PixelIntensityToQuantum(p);
+                pixel=PixelIntensityToQuantum(p);
                 if (pixel >= (Quantum) (QuantumRange/2))
                   byte|=0x01;
                 bit++;
@@ -1666,10 +1664,7 @@ static MagickBooleanType WritePSImage(const ImageInfo *image_info,Image *image)
                 break;
               for (x=0; x < (long) image->columns; x++)
               {
-                if (IsGrayPixel(p) != MagickFalse)
-                  pixel=ScaleQuantumToChar(p->red);
-                else
-                  pixel=ScaleQuantumToChar(PixelIntensityToQuantum(p));
+                pixel=ScaleQuantumToChar(PixelIntensityToQuantum(p));
                 q=PopHexPixel(hex_digits,pixel,q);
                 i++;
                 if ((q-pixels+8) >= 80)
@@ -1723,10 +1718,7 @@ static MagickBooleanType WritePSImage(const ImageInfo *image_info,Image *image)
               for (x=0; x < (long) image->columns; x++)
               {
                 byte<<=1;
-                if (IsGrayPixel(p) != MagickFalse)
-                  pixel=p->red;
-                else
-                  pixel=PixelIntensityToQuantum(p);
+                pixel=PixelIntensityToQuantum(p);
                 if (pixel >= (Quantum) (QuantumRange/2))
                   byte|=0x01;
                 bit++;
