@@ -763,7 +763,7 @@ static MagickBooleanType WriteRGBImage(const ImageInfo *image_info,Image *image)
       (void) SetImageColorspace(image,RGBColorspace);
     if ((LocaleCompare(image_info->magick,"RGBA") == 0) &&
         (image->matte == MagickFalse))
-      (void) SetImageOpacity(image,OpaqueOpacity);
+      (void) SetImageAlphaChannel(image,ResetAlphaChannel);
     quantum_info=AcquireQuantumInfo(image_info,image);
     pixels=GetQuantumPixels(quantum_info);
     switch (image_info->interlace)
