@@ -17,7 +17,7 @@
 %                                 July 1992                                   %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2007 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2008 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -50,9 +50,10 @@
 #include "magick/magick.h"
 #include "magick/memory_.h"
 #include "magick/monitor.h"
-#include "magick/quantum.h"
+#include "magick/quantum-private.h"
 #include "magick/static.h"
 #include "magick/string_.h"
+#include "magick/module.h"
 
 /*
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
@@ -79,7 +80,6 @@
 %
 %    o length: Specifies the length of the magick string.
 %
-%
 */
 static MagickBooleanType IsSCT(const unsigned char *magick,const size_t length)
 {
@@ -111,7 +111,7 @@ static MagickBooleanType IsSCT(const unsigned char *magick,const size_t length)
 %
 %  A description of each parameter follows:
 %
-%    o image_info: The image info.
+%    o image_info: the image info.
 %
 %    o exception: return any errors or warnings in this structure.
 %
@@ -134,10 +134,14 @@ static Image *ReadSCTImage(const ImageInfo *image_info,ExceptionInfo *exception)
     height,
     width;
 
+  Quantum
+    pixel;
+
   register IndexPacket
     *indexes;
 
   register long
+    i,
     x;
 
   register PixelPacket
@@ -164,7 +168,7 @@ static Image *ReadSCTImage(const ImageInfo *image_info,ExceptionInfo *exception)
       image_info->filename);
   assert(exception != (ExceptionInfo *) NULL);
   assert(exception->signature == MagickSignature);
-  image=AllocateImage(image_info);
+  image=AcquireImage(image_info);
   status=OpenBlob(image_info,image,ReadBinaryBlobMode,exception);
   if (status == MagickFalse)
     {
@@ -215,71 +219,63 @@ static Image *ReadSCTImage(const ImageInfo *image_info,ExceptionInfo *exception)
   image->y_resolution=1.0*image->rows/height;
   if (image_info->ping != MagickFalse)
     {
-      CloseBlob(image);
+      (void) CloseBlob(image);
       return(GetFirstImageInList(image));
     }
+  if (SetImageExtent(image,0,0) == MagickFalse)
+    {
+      InheritException(exception,&image->exception);
+      return(DestroyImageList(image));
+    }
   /*
     Convert SCT raster image to pixel packets.
   */
   for (y=0; y < (long) image->rows; y++)
   {
-    q=GetImagePixels(image,0,y,image->columns,1);
-    if (q == (PixelPacket *) NULL)
-      break;
-    for (x=0; x < (long) image->columns; x++)
+    for (i=0; i < (long) separations; i++)
     {
-      q->red=(Quantum) ScaleCharToQuantum((unsigned char) ReadBlobByte(image));
-      q++;
-    }
-    if (SyncImagePixels(image) == MagickFalse)
-      break;
-    if ((image->columns % 2) != 0)
-      (void) ReadBlobByte(image);  /* pad */
-    q=GetImagePixels(image,0,y,image->columns,1);
-    if (q == (PixelPacket *) NULL)
-      break;
-    for (x=0; x < (long) image->columns; x++)
-    {
-      q->green=(Quantum) ScaleCharToQuantum((unsigned char)
-        ReadBlobByte(image));
-      q++;
-    }
-    if (SyncImagePixels(image) == MagickFalse)
-      break;
-    if ((image->columns % 2) != 0)
-      (void) ReadBlobByte(image);  /* pad */
-    q=GetImagePixels(image,0,y,image->columns,1);
-    if (q == (PixelPacket *) NULL)
-      break;
-    for (x=0; x < (long) image->columns; x++)
-    {
-      q->blue=(Quantum) ScaleCharToQuantum((unsigned char) ReadBlobByte(image));
-      q++;
-    }
-    if (SyncImagePixels(image) == MagickFalse)
-      break;
-    if ((image->columns % 2) != 0)
-      (void) ReadBlobByte(image);  /* pad */
-    if (image->colorspace == CMYKColorspace)
+      q=GetImagePixels(image,0,y,image->columns,1);
+      if (q == (PixelPacket *) NULL)
+        break;
+      indexes=GetIndexes(image);
+      for (x=0; x < (long) image->columns; x++)
       {
-        q=GetImagePixels(image,0,y,image->columns,1);
-        if (q == (PixelPacket *) NULL)
-          break;
-        indexes=GetIndexes(image);
-        for (x=0; x < (long) image->columns; x++)
+        pixel=(Quantum) ScaleCharToQuantum((unsigned char) ReadBlobByte(image));
+        if (image->colorspace == CMYKColorspace)
+          pixel=(Quantum) (QuantumRange-pixel);
+        switch (i)
         {
-          q->red=QuantumRange-q->red;
-          q->green=QuantumRange-q->green;
-          q->blue=QuantumRange-q->blue;
-          indexes[x]=(IndexPacket) (QuantumRange-ScaleCharToQuantum(
-            (unsigned char) ReadBlobByte(image)));
-          q++;
+          case 0:
+          {
+            q->red=pixel;
+            q->green=pixel;
+            q->blue=pixel;
+            break;
+          }
+          case 1:
+          {
+            q->green=pixel;
+            break;
+          }
+          case 2:
+          {
+            q->blue=pixel; break;
+            break;
+          }
+          case 3: 
+          {
+            if (image->colorspace == CMYKColorspace)
+              indexes[x]=(IndexPacket) pixel;
+            break;
+          }
         }
-        if (SyncImagePixels(image) == MagickFalse)
-          break;
-        if ((image->columns % 2) != 0)
-          (void) ReadBlobByte(image);  /* pad */
+        q++;
       }
+      if (SyncImagePixels(image) == MagickFalse)
+        break;
+      if ((image->columns % 2) != 0)
+        (void) ReadBlobByte(image);  /* pad */
+    }
     if ((image->progress_monitor != (MagickProgressMonitor) NULL) &&
         (QuantumTick(y,image->rows) != MagickFalse))
       {
@@ -292,7 +288,7 @@ static Image *ReadSCTImage(const ImageInfo *image_info,ExceptionInfo *exception)
   if (EOFBlob(image) != MagickFalse)
     ThrowFileException(exception,CorruptImageError,"UnexpectedEndOfFile",
       image->filename);
-  CloseBlob(image);
+  (void) CloseBlob(image);
   return(GetFirstImageInList(image));
 }
 
@@ -316,21 +312,22 @@ static Image *ReadSCTImage(const ImageInfo *image_info,ExceptionInfo *exception)
 %
 %  The format of the RegisterSCTImage method is:
 %
-%      RegisterSCTImage(void)
+%      unsigned long RegisterSCTImage(void)
 %
 */
-ModuleExport void RegisterSCTImage(void)
+ModuleExport unsigned long RegisterSCTImage(void)
 {
   MagickInfo
     *entry;
 
   entry=SetMagickInfo("SCT");
-  entry->decoder=(DecoderHandler *) ReadSCTImage;
-  entry->magick=(MagickHandler *) IsSCT;
+  entry->decoder=(DecodeImageHandler *) ReadSCTImage;
+  entry->magick=(IsImageFormatHandler *) IsSCT;
   entry->adjoin=MagickFalse;
   entry->description=ConstantString("Scitex HandShake");
   entry->module=ConstantString("SCT");
   (void) RegisterMagickInfo(entry);
+  return(MagickImageCoderSignature);
 }
 
 /*
