@@ -17,7 +17,7 @@
 %                                 July 1992                                   %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2007 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2008 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -50,9 +50,10 @@
 #include "magick/monitor.h"
 #include "magick/profile.h"
 #include "magick/property.h"
-#include "magick/quantum.h"
+#include "magick/quantum-private.h"
 #include "magick/static.h"
 #include "magick/string_.h"
+#include "magick/module.h"
 
 /*
   Forward declarations.
@@ -80,19 +81,20 @@ static MagickBooleanType
 %
 %  The format of the RegisterTHUMBNAILImage method is:
 %
-%      RegisterTHUMBNAILImage(void)
+%      unsigned long RegisterTHUMBNAILImage(void)
 %
 */
-ModuleExport void RegisterTHUMBNAILImage(void)
+ModuleExport unsigned long RegisterTHUMBNAILImage(void)
 {
   MagickInfo
     *entry;
 
   entry=SetMagickInfo("THUMBNAIL");
-  entry->encoder=(EncoderHandler *) WriteTHUMBNAILImage;
+  entry->encoder=(EncodeImageHandler *) WriteTHUMBNAILImage;
   entry->description=ConstantString("EXIF Profile Thumbnail");
   entry->module=ConstantString("THUMBNAIL");
   (void) RegisterMagickInfo(entry);
+  return(MagickImageCoderSignature);
 }
 
 /*
@@ -130,8 +132,7 @@ ModuleExport void UnregisterTHUMBNAILImage(void)
 %                                                                             %
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
-%  WriteTHUMBNAILImage() writes an image of clip bytes to a file.  It
-%  consists of data from the clip component of the image [0..255].
+%  WriteTHUMBNAILImage() extracts the EXIF thumbnail image and writes it.
 %
 %  The format of the WriteTHUMBNAILImage method is:
 %
@@ -140,7 +141,7 @@ ModuleExport void UnregisterTHUMBNAILImage(void)
 %
 %  A description of each parameter follows.
 %
-%    o image_info: The image info.
+%    o image_info: the image info.
 %
 %    o image:  The image.
 %
