@@ -789,24 +789,12 @@ static Image *ReadTIFFImage(const ImageInfo *image_info,
     /*
       Allocate memory for the image and pixel buffer.
     */
-#if defined(MAGICKCORE_HAVE_TIFFGETCONFIGUREDCODECS) || (TIFFLIB_VERSION > 20040919)
-    if (compress_tag != COMPRESSION_NONE)
+#if defined(MAGICKCORE_HAVE_TIFFISCODECCONFIGURED) || (TIFFLIB_VERSION > 20040919)
+    if ((compress_tag != COMPRESSION_NONE) &&
+        (TIFFIsCODECConfigured(compress_tag) == 0))
       {
-        TIFFCodec
-          *codec;
-
-        codec=TIFFGetConfiguredCODECs();
-        while ((codec != (TIFFCodec *) NULL) && (codec->name != (char *) NULL))
-        {
-          if (codec->scheme == compress_tag)
-            break;
-          codec++;
-        }
-        if (((codec == (TIFFCodec *) NULL)) || (codec->scheme != compress_tag))
-          {
-            TIFFClose(tiff);
-            ThrowReaderException(CoderError,"CompressionNotSupported");
-          }
+        TIFFClose(tiff);
+        ThrowReaderException(CoderError,"CompressNotSupported");
       }
 #endif
     switch (compress_tag)
@@ -954,6 +942,7 @@ static Image *ReadTIFFImage(const ImageInfo *image_info,
     if ((samples_per_pixel >= 2) && (interlace == PLANARCONFIG_SEPARATE))
       method=ReadCMYKAMethod;
     if ((photometric != PHOTOMETRIC_RGB) &&
+        (photometric != PHOTOMETRIC_CIELAB) &&
         (photometric != PHOTOMETRIC_SEPARATED))
       method=ReadGenericMethod;
     if (image->storage_class == PseudoClass)
@@ -1947,7 +1936,7 @@ static MagickBooleanType WriteTIFFImage(const ImageInfo *image_info,
   Image *image)
 {
 #if !defined(TIFFDefaultStripSize)
-#define TIFFDefaultStripSize(tiff,request)  ((8*1024)/TIFFScanlineSize(tiff))
+#define TIFFDefaultStripSize(tiff,request)  (8192UL/TIFFScanlineSize(tiff))
 #endif
 
   const char
@@ -2055,52 +2044,7 @@ static MagickBooleanType WriteTIFFImage(const ImageInfo *image_info,
       (void) TIFFSetField(tiff,TIFFTAG_SUBFILETYPE,FILETYPE_REDUCEDIMAGE);
     (void) TIFFSetField(tiff,TIFFTAG_IMAGELENGTH,(uint32) image->rows);
     (void) TIFFSetField(tiff,TIFFTAG_IMAGEWIDTH,(uint32) image->columns);
-    compression=image_info->compression;
-    switch (compression)
-    {
-      case FaxCompression:
-      case Group4Compression:
-      {
-        if (IsMonochromeImage(image,&image->exception) == MagickFalse)
-          compression=RLECompression;
-        if (IsOpaqueImage(image,&image->exception) == MagickFalse)
-          compression=RLECompression;
-#if !defined(CCITT_SUPPORT)
-        compression=RLECompression;
-#endif
-        break;
-      }
-      case JPEGCompression:
-      {
-#if !defined(MAGICKCORE_JPEG_DELEGATE) || !defined(YCBCR_SUPPORT)
-        compression=RLECompression;
-#else
-        (void) SetImageStorageClass(image,DirectClass);
-        (void) SetImageDepth(image,8);
-#endif
-        break;
-      }
-      case LZWCompression:
-      {
-#if !defined(LZW_SUPPORT)
-        compression=RLECompression;
-#endif
-        break;
-      }
-      case ZipCompression:
-      {
-#if !defined(ZIP_SUPPORT)
-        compression=RLECompression;
-#endif
-        break;
-      }
-      default:
-        break;
-    }
-#if !defined(PACKBITS_SUPPORT)
-    if (compression == RLECompression)
-      compression=NoCompression;
-#endif
+    compression=image->compression;
     switch (compression)
     {
       case FaxCompression:
@@ -2154,13 +2098,65 @@ static MagickBooleanType WriteTIFFImage(const ImageInfo *image_info,
           codec++;
         }
         if (((codec == (TIFFCodec *) NULL)) || (codec->scheme != compress_tag))
+          {
+            (void) ThrowMagickException(&image->exception,GetMagickModule(),
+              CoderError,"CompressionNotSupported","`%s'",
+              MagickOptionToMnemonic(MagickCompressOptions,(long) compression));
+            compress_tag=COMPRESSION_NONE;
+            compression=NoCompression;
+          }
+      }
+#else
+      switch (compress_tag)
+      {
+#if defined(CCITT_SUPPORT)
+        case COMPRESSION_CCITTFAX3:
+        case COMPRESSION_CCITTFAX4:
+#endif
+#if defined(YCBCR_SUPPORT) && defined(JPEG_SUPPORT)
+        case COMPRESSION_JPEG:
+#endif
+#if defined(LZW_SUPPORT)
+        case COMPRESSION_LZW:
+#endif
+#if defined(PACKBITS_SUPPORT)
+        case COMPRESSION_PACKBITS:
+#endif
+#if defined(ZIP_SUPPORT)
+        case COMPRESSION_ADOBE_DEFLATE:
+#endif
+        case COMPRESSION_NONE:
+          break;
+        default:
+        {
+          (void) ThrowMagickException(&image->exception,GetMagickModule(),
+            CoderError,"CompressionNotSupported","`%s'",MagickOptionToMnemonic(
+              MagickCompressOptions,(long) compression));
           compress_tag=COMPRESSION_NONE;
+          compression=NoCompression;
+          break;
+        }
       }
 #endif
+    switch (compression)
+    {
+      case FaxCompression:
+      case Group4Compression:
+      {
+        (void) SetImageType(image,BilevelType);
+        break;
+      }
+      case JPEGCompression:
+      {
+        (void) SetImageStorageClass(image,DirectClass);
+        (void) SetImageDepth(image,8);
+        break;
+      }
+      default:
+        break;
+    }
     (void) TIFFSetField(tiff,TIFFTAG_COMPRESSION,compress_tag);
-    if (((image->colorspace != RGBColorspace) &&
-         (image->colorspace == CMYKColorspace)) ||
-         (image->colorspace == CMYKColorspace))
+    if (image->colorspace == CMYKColorspace)
       {
         photometric=PHOTOMETRIC_SEPARATED;
         (void) TIFFSetField(tiff,TIFFTAG_SAMPLESPERPIXEL,4);
