@@ -85,7 +85,7 @@ static MagickBooleanType
 %  IsTXT() returns MagickTrue if the image format type, identified by the magick
 %  string, is TXT.
 %
-%  The colorspace of the IsTXT method is:
+%  The format of the IsTXT method is:
 %
 %      MagickBooleanType IsTXT(const unsigned char *magick,const size_t length)
 %
@@ -138,7 +138,7 @@ static MagickBooleanType IsTXT(const unsigned char *magick,const size_t length)
 %  allocates the memory necessary for the new Image structure and returns a
 %  pointer to the new image.
 %
-%  The colorspace of the ReadTEXTImage method is:
+%  The format of the ReadTEXTImage method is:
 %
 %      Image *ReadTEXTImage(const ImageInfo *image_info,
 %        ExceptionInfo *exception)
@@ -358,7 +358,7 @@ static Image *ReadTEXTImage(const ImageInfo *image_info,
 %  the memory necessary for the new Image structure and returns a pointer to
 %  the new image.
 %
-%  The colorspace of the ReadTXTImage method is:
+%  The format of the ReadTXTImage method is:
 %
 %      Image *ReadTXTImage(const ImageInfo *image_info,ExceptionInfo *exception)
 %
@@ -425,6 +425,7 @@ static Image *ReadTXTImage(const ImageInfo *image_info,ExceptionInfo *exception)
       image=DestroyImageList(image);
       return((Image *) NULL);
     }
+  (void) ResetMagickMemory(text,0,sizeof(text));
   (void) ReadBlobString(image,text);
   if (LocaleNCompare((char *) text,MagickID,strlen(MagickID)) != 0)
     ThrowReaderException(CorruptImageError,"ImproperImageHeader");
@@ -482,7 +483,8 @@ static Image *ReadTXTImage(const ImageInfo *image_info,ExceptionInfo *exception)
         *indexes=ScaleAnyToQuantum(pixel.index,image->depth,scale);
       }
     if (image->matte != MagickFalse)
-      q->opacity=(Quantum) ScaleAnyToQuantum(pixel.opacity,image->depth,scale);
+      q->opacity=(Quantum) (QuantumRange-ScaleAnyToQuantum(pixel.opacity,
+        image->depth,scale));
     if (SyncImagePixels(image) == MagickFalse)
       break;
   }
@@ -502,12 +504,12 @@ static Image *ReadTXTImage(const ImageInfo *image_info,ExceptionInfo *exception)
 %
 %  RegisterTXTImage() adds attributes for the TXT image format to the
 %  list of supported formats.  The attributes include the image format
-%  tag, a method to read and/or write the colorspace, whether the format
+%  tag, a method to read and/or write the format, whether the format
 %  supports the saving of more than one frame to the same file or blob,
 %  whether the format supports native in-memory I/O, and a brief
 %  description of the format.
 %
-%  The colorspace of the RegisterTXTImage method is:
+%  The format of the RegisterTXTImage method is:
 %
 %      unsigned long RegisterTXTImage(void)
 %
@@ -548,10 +550,10 @@ ModuleExport unsigned long RegisterTXTImage(void)
 %                                                                             %
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
-%  UnregisterTXTImage() removes colorspace registrations made by the
-%  TXT module from the list of supported colorspaces.
+%  UnregisterTXTImage() removes format registrations made by the
+%  TXT module from the list of supported format.
 %
-%  The colorspace of the UnregisterTXTImage method is:
+%  The format of the UnregisterTXTImage method is:
 %
 %      UnregisterTXTImage(void)
 %
@@ -575,7 +577,7 @@ ModuleExport void UnregisterTXTImage(void)
 %
 %  WriteTXTImage writes the pixel values as text numbers.
 %
-%  The colorspace of the WriteTXTImage method is:
+%  The format of the WriteTXTImage method is:
 %
 %      MagickBooleanType WriteTXTImage(const ImageInfo *image_info,Image *image)
 %
