@@ -17,7 +17,7 @@
 %                                 July 1992                                   %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2007 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2008 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -52,10 +52,11 @@
 #include "magick/magick.h"
 #include "magick/memory_.h"
 #include "magick/monitor.h"
-#include "magick/quantum.h"
-#include "magick/quantum.h"
+#include "magick/quantum-private.h"
+#include "magick/quantum-private.h"
 #include "magick/static.h"
 #include "magick/string_.h"
+#include "magick/module.h"
 
 /*
   Forward declarations.
@@ -89,7 +90,6 @@ static MagickBooleanType
 %
 %    o length: Specifies the length of the magick string.
 %
-%
 */
 static MagickBooleanType IsVICAR(const unsigned char *magick,
   const size_t length)
@@ -131,7 +131,7 @@ static MagickBooleanType IsVICAR(const unsigned char *magick,
 %      reading.  A null image is returned if there is a memory shortage or if
 %      the image cannot be read.
 %
-%    o image_info: The image info.
+%    o image_info: the image info.
 %
 %    o exception: return any errors or warnings in this structure.
 %
@@ -158,7 +158,10 @@ static Image *ReadVICARImage(const ImageInfo *image_info,
     value_expected;
 
   QuantumInfo
-    quantum_info;
+    *quantum_info;
+
+  QuantumType
+    quantum_type;
 
   register PixelPacket
     *q;
@@ -166,11 +169,11 @@ static Image *ReadVICARImage(const ImageInfo *image_info,
   ssize_t
     count;
 
-  ssize_t
+  size_t
     length;
 
   unsigned char
-    *scanline;
+    *pixels;
 
   /*
     Open image file.
@@ -182,7 +185,7 @@ static Image *ReadVICARImage(const ImageInfo *image_info,
       image_info->filename);
   assert(exception != (ExceptionInfo *) NULL);
   assert(exception->signature == MagickSignature);
-  image=AllocateImage(image_info);
+  image=AcquireImage(image_info);
   status=OpenBlob(image_info,image,ReadBinaryBlobMode,exception);
   if (status == MagickFalse)
     {
@@ -220,7 +223,7 @@ static Image *ReadVICARImage(const ImageInfo *image_info,
         p=keyword;
         do
         {
-          if ((size_t) (p-keyword) < (MaxTextExtent/2))
+          if ((size_t) (p-keyword) < MaxTextExtent)
             *p++=c;
           c=ReadBlobByte(image);
           count++;
@@ -239,7 +242,7 @@ static Image *ReadVICARImage(const ImageInfo *image_info,
         p=value;
         while (isalnum(c))
         {
-          if ((size_t) (p-value) < (MaxTextExtent/2))
+          if ((size_t) (p-value) < MaxTextExtent)
             *p++=c;
           c=ReadBlobByte(image);
           count++;
@@ -275,27 +278,32 @@ static Image *ReadVICARImage(const ImageInfo *image_info,
   if ((image->columns == 0) || (image->rows == 0))
     ThrowReaderException(CorruptImageError,"NegativeOrZeroImageSize");
   image->depth=8;
-  if (AllocateImageColormap(image,256) == MagickFalse)
+  if (AcquireImageColormap(image,256) == MagickFalse)
     ThrowReaderException(ResourceLimitError,"MemoryAllocationFailed");
   if (image_info->ping != MagickFalse)
     {
-      CloseBlob(image);
+      (void) CloseBlob(image);
       return(GetFirstImageInList(image));
     }
   /*
     Read VICAR pixels.
   */
-  GetQuantumInfo(image_info,&quantum_info);
-  scanline=(unsigned char *) AcquireMagickMemory(image->columns);
-  if (scanline == (unsigned char *) NULL)
-    ThrowReaderException(CorruptImageError,"UnableToReadImageData");
+  if (SetImageExtent(image,0,0) == MagickFalse)
+    {
+      InheritException(exception,&image->exception);
+      return(DestroyImageList(image));
+    }
+  quantum_type=IndexQuantum;
+  quantum_info=AcquireQuantumInfo(image_info,image);
+  pixels=GetQuantumPixels(quantum_info);
+  length=GetQuantumExtent(image,quantum_info,IndexQuantum);
   for (y=0; y < (long) image->rows; y++)
   {
     q=SetImagePixels(image,0,y,image->columns,1);
     if (q == (PixelPacket *) NULL)
       break;
-    count=ReadBlob(image,image->columns,scanline);
-    (void) ExportQuantumPixels(image,&quantum_info,GrayQuantum,scanline);
+    count=ReadBlob(image,length,pixels);
+    (void) ImportQuantumPixels(image,quantum_info,quantum_type,pixels);
     if (SyncImagePixels(image) == MagickFalse)
       break;
     if ((image->progress_monitor != (MagickProgressMonitor) NULL) &&
@@ -307,11 +315,12 @@ static Image *ReadVICARImage(const ImageInfo *image_info,
           break;
       }
   }
-  scanline=(unsigned char *) RelinquishMagickMemory(scanline);
+  SetQuantumImageType(image,quantum_type);
+  quantum_info=DestroyQuantumInfo(quantum_info);
   if (EOFBlob(image) != MagickFalse)
     ThrowFileException(exception,CorruptImageError,"UnexpectedEndOfFile",
       image->filename);
-  CloseBlob(image);
+  (void) CloseBlob(image);
   return(GetFirstImageInList(image));
 }
 
@@ -335,22 +344,23 @@ static Image *ReadVICARImage(const ImageInfo *image_info,
 %
 %  The format of the RegisterVICARImage method is:
 %
-%      RegisterVICARImage(void)
+%      unsigned long RegisterVICARImage(void)
 %
 */
-ModuleExport void RegisterVICARImage(void)
+ModuleExport unsigned long RegisterVICARImage(void)
 {
   MagickInfo
     *entry;
 
   entry=SetMagickInfo("VICAR");
-  entry->decoder=(DecoderHandler *) ReadVICARImage;
-  entry->encoder=(EncoderHandler *) WriteVICARImage;
-  entry->magick=(MagickHandler *) IsVICAR;
+  entry->decoder=(DecodeImageHandler *) ReadVICARImage;
+  entry->encoder=(EncodeImageHandler *) WriteVICARImage;
+  entry->magick=(IsImageFormatHandler *) IsVICAR;
   entry->adjoin=MagickFalse;
   entry->description=ConstantString("VICAR rasterfile format");
   entry->module=ConstantString("VICAR");
   (void) RegisterMagickInfo(entry);
+  return(MagickImageCoderSignature);
 }
 
 /*
@@ -404,11 +414,10 @@ ModuleExport void UnregisterVICARImage(void)
 %
 %  A description of each parameter follows.
 %
-%    o image_info: The image info.
+%    o image_info: the image info.
 %
 %    o image:  The image.
 %
-%
 */
 static MagickBooleanType WriteVICARImage(const ImageInfo *image_info,
   Image *image)
@@ -423,13 +432,19 @@ static MagickBooleanType WriteVICARImage(const ImageInfo *image_info,
     status;
 
   QuantumInfo
-    quantum_info;
+    *quantum_info;
 
   register const PixelPacket
     *p;
 
+  ssize_t
+    count;
+
+  size_t
+    length;
+
   unsigned char
-    *scanline;
+    *pixels;
 
   /*
     Open output image file.
@@ -443,7 +458,7 @@ static MagickBooleanType WriteVICARImage(const ImageInfo *image_info,
   status=OpenBlob(image_info,image,WriteBinaryBlobMode,&image->exception);
   if (status == MagickFalse)
     return(status);
-  if (image_info->colorspace == UndefinedColorspace)
+  if (image->colorspace != RGBColorspace)
     (void) SetImageColorspace(image,RGBColorspace);
   /*
     Write header.
@@ -456,23 +471,20 @@ static MagickBooleanType WriteVICARImage(const ImageInfo *image_info,
     image->rows,image->columns);
   (void) WriteBlob(image,MaxTextExtent,(unsigned char *) header);
   /*
-    Allocate memory for scanline.
+    Write VICAR pixels.
   */
-  scanline=(unsigned char *) AcquireMagickMemory(image->columns);
-  if (scanline == (unsigned char *) NULL)
-    ThrowWriterException(ResourceLimitError,"MemoryAllocationFailed");
-  /*
-    Write VICAR scanline.
-  */
-  GetQuantumInfo(image_info,&quantum_info);
   image->depth=8;
+  quantum_info=AcquireQuantumInfo(image_info,image);
+  pixels=GetQuantumPixels(quantum_info);
   for (y=0; y < (long) image->rows; y++)
   {
     p=AcquireImagePixels(image,0,y,image->columns,1,&image->exception);
     if (p == (const PixelPacket *) NULL)
       break;
-    (void) ImportQuantumPixels(image,&quantum_info,GrayQuantum,scanline);
-    (void) WriteBlob(image,image->columns,scanline);
+    length=ExportQuantumPixels(image,quantum_info,GrayQuantum,pixels);
+    count=WriteBlob(image,length,pixels);
+    if (count != (ssize_t) length)
+      break;
     if (image->previous == (Image *) NULL)
       if ((image->progress_monitor != (MagickProgressMonitor) NULL) &&
           (QuantumTick(y,image->rows) != MagickFalse))
@@ -483,7 +495,7 @@ static MagickBooleanType WriteVICARImage(const ImageInfo *image_info,
             break;
         }
   }
-  scanline=(unsigned char *) RelinquishMagickMemory(scanline);
-  CloseBlob(image);
+  quantum_info=DestroyQuantumInfo(quantum_info);
+  (void) CloseBlob(image);
   return(MagickTrue);
 }
