@@ -634,7 +634,7 @@ static void ipa_bmp_free(wmfAPI * API, wmfBMP * bmp)
 }
 
 /*
-  This is called by wmf_play() the *first* time the meta file is played
+  This called by wmf_play() the *first* time the meta file is played
  */
 static void ipa_device_open(wmfAPI * API)
 {
@@ -657,7 +657,7 @@ static void ipa_device_open(wmfAPI * API)
 }
 
 /*
-  This is called by wmf_api_destroy()
+  This called by wmf_api_destroy()
  */
 static void ipa_device_close(wmfAPI * API)
 {
@@ -667,7 +667,7 @@ static void ipa_device_close(wmfAPI * API)
 }
 
 /*
-  This is called from the beginning of each play for initial page setup
+  This called from the beginning of each play for initial page setup
  */
 static void ipa_device_begin(wmfAPI * API)
 {
@@ -775,7 +775,7 @@ static void ipa_device_begin(wmfAPI * API)
 }
 
 /*
-  This is called from the end of each play for page termination
+  This called from the end of each play for page termination
  */
 static void ipa_device_end(wmfAPI * API)
 {
@@ -2093,7 +2093,7 @@ static int util_font_weight( const char* font )
  * Returns width of string in points, assuming (unstretched) font size of 1pt
  * (similar to wmf_ipa_font_stringwidth)
  *
- * This is extremely odd at best, particularly since player/meta.h has access
+ * This extremely odd at best, particularly since player/meta.h has access
  * to the corrected font_height (as drawtext.font_height) when it invokes the
  * stringwidth callback.  It should be possible to compute the real stringwidth!
  */
@@ -2555,7 +2555,7 @@ static Image *ReadWMFImage(const ImageInfo * image_info, ExceptionInfo * excepti
 
   /* Compute bounding box scale factors and origin translations
    *
-   * This is all just a hack since libwmf does not currently seem to
+   * This all just a hack since libwmf does not currently seem to
    * provide the mapping between LOGICAL coordinates and DEVICE
    * coordinates. This mapping is necessary in order to know
    * where to place the logical bounding box within the image.
