@@ -16,7 +16,7 @@
 %                                 June 2000                                   %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2007 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2008 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -53,10 +53,11 @@
 #include "magick/magick.h"
 #include "magick/memory_.h"
 #include "magick/resource_.h"
-#include "magick/quantum.h"
+#include "magick/quantum-private.h"
 #include "magick/shear.h"
 #include "magick/static.h"
 #include "magick/string_.h"
+#include "magick/module.h"
 #include "magick/transform.h"
 #include "magick/utility.h"
 
@@ -69,134 +70,134 @@ typedef struct
 
 /* Default palette for WPG level 1 */
 const RGB_Record WPG1_Palette[256]={
-{  0,  0,  0},		{  0,  0,168},
-{  0,168,  0},		{  0,168,168},
-{168,  0,  0},		{168,  0,168},
-{168, 84,  0},		{168,168,168},
-{ 84, 84, 84},		{ 84, 84,252},
-{ 84,252, 84},		{ 84,252,252},
-{252, 84, 84},		{252, 84,252},
-{252,252, 84},		{252,252,252},  /*16*/
-{  0,  0,  0},		{ 20, 20, 20},
-{ 32, 32, 32},		{ 44, 44, 44},
-{ 56, 56, 56},		{ 68, 68, 68},
-{ 80, 80, 80},		{ 96, 96, 96},
-{112,112,112},		{128,128,128},
-{144,144,144},		{160,160,160},
-{180,180,180},		{200,200,200},
-{224,224,224},		{252,252,252},  /*32*/
-{  0,  0,252},		{ 64,  0,252},
-{124,  0,252},		{188,  0,252},
-{252,  0,252},		{252,  0,188},
-{252,  0,124},		{252,  0, 64},
-{252,  0,  0},		{252, 64,  0},
-{252,124,  0},		{252,188,  0},
-{252,252,  0},		{188,252,  0},
-{124,252,  0},		{ 64,252,  0},	/*48*/
-{  0,252,  0},		{  0,252, 64},
-{  0,252,124},		{  0,252,188},
-{  0,252,252},		{  0,188,252},
-{  0,124,252},		{  0, 64,252},
-{124,124,252},		{156,124,252},
-{188,124,252},		{220,124,252},
-{252,124,252},		{252,124,220},
-{252,124,188},		{252,124,156},	/*64*/
-{252,124,124},		{252,156,124},
-{252,188,124},		{252,220,124},
-{252,252,124},		{220,252,124},
-{188,252,124},		{156,252,124},
-{124,252,124},		{124,252,156},
-{124,252,188},		{124,252,220},
-{124,252,252},		{124,220,252},
-{124,188,252},		{124,156,252},	/*80*/
-{180,180,252},		{196,180,252},
-{216,180,252},		{232,180,252},
-{252,180,252},		{252,180,232},
-{252,180,216},		{252,180,196},
-{252,180,180},		{252,196,180},
-{252,216,180},		{252,232,180},
-{252,252,180},		{232,252,180},
-{216,252,180},		{196,252,180},	/*96*/
-{180,220,180},		{180,252,196},
-{180,252,216},		{180,252,232},
-{180,252,252},		{180,232,252},
-{180,216,252},		{180,196,252},
-{0,0,112},		{28,0,112},
-{56,0,112},		{84,0,112},
-{112,0,112},		{112,0,84},
-{112,0,56},		{112,0,28},	/*112*/
-{112,0,0},		{112,28,0},
-{112,56,0},		{112,84,0},
-{112,112,0},		{84,112,0},
-{56,112,0},		{28,112,0},
-{0,112,0},		{0,112,28},
-{0,112,56},		{0,112,84},
-{0,112,112},		{0,84,112},
-{0,56,112},		{0,28,112}, 	/*128*/
-{56,56,112},		{68,56,112},
-{84,56,112},		{96,56,112},
-{112,56,112},		{112,56,96},
-{112,56,84},		{112,56,68},
-{112,56,56},		{112,68,56},
-{112,84,56},		{112,96,56},
-{112,112,56},		{96,112,56},
-{84,112,56},		{68,112,56},	/*144*/
-{56,112,56},		{56,112,69},
-{56,112,84},		{56,112,96},
-{56,112,112},		{56,96,112},
-{56,84,112},		{56,68,112},
-{80,80,112},		{88,80,112},
-{96,80,112},		{104,80,112},
-{112,80,112},		{112,80,104},
-{112,80,96},		{112,80,88},	/*160*/
-{112,80,80},		{112,88,80},
-{112,96,80},		{112,104,80},
-{112,112,80},		{104,112,80},
-{96,112,80},		{88,112,80},
-{80,112,80},		{80,112,88},
-{80,112,96},		{80,112,104},
-{80,112,112},		{80,114,112},
-{80,96,112},		{80,88,112},	/*176*/
-{0,0,64},		{16,0,64},
-{32,0,64},		{48,0,64},
-{64,0,64},		{64,0,48},
-{64,0,32},		{64,0,16},
-{64,0,0},		{64,16,0},
-{64,32,0},		{64,48,0},
-{64,64,0},		{48,64,0},
-{32,64,0},		{16,64,0},	/*192*/
-{0,64,0},		{0,64,16},
-{0,64,32},		{0,64,48},
-{0,64,64},		{0,48,64},
-{0,32,64},		{0,16,64},
-{32,32,64},		{40,32,64},
-{48,32,64},		{56,32,64},
-{64,32,64},		{64,32,56},
-{64,32,48},		{64,32,40},	/*208*/
-{64,32,32},		{64,40,32},
-{64,48,32},		{64,56,32},
-{64,64,32},		{56,64,32},
-{48,64,32},		{40,64,32},
-{32,64,32},		{32,64,40},
-{32,64,48},		{32,64,56},
-{32,64,64},		{32,56,64},
-{32,48,64},		{32,40,64},	/*224*/
-{44,44,64},		{48,44,64},
-{52,44,64},		{60,44,64},
-{64,44,64},		{64,44,60},
-{64,44,52},		{64,44,48},
-{64,44,44},		{64,48,44},
-{64,52,44},		{64,60,44},
-{64,64,44},		{60,64,44},
-{52,64,44},		{48,64,44},	/*240*/
-{44,64,44},		{44,64,48},
-{44,64,52},		{44,64,60},
-{44,64,64},		{44,60,64},
-{44,55,64},		{44,48,64},
-{0,0,0},		{0,0,0},
-{0,0,0},		{0,0,0},
-{0,0,0},		{0,0,0},
-{0,0,0},		{0,0,0}		/*256*/
+{  0,  0,  0},    {  0,  0,168},
+{  0,168,  0},    {  0,168,168},
+{168,  0,  0},    {168,  0,168},
+{168, 84,  0},    {168,168,168},
+{ 84, 84, 84},    { 84, 84,252},
+{ 84,252, 84},    { 84,252,252},
+{252, 84, 84},    {252, 84,252},
+{252,252, 84},    {252,252,252},  /*16*/
+{  0,  0,  0},    { 20, 20, 20},
+{ 32, 32, 32},    { 44, 44, 44},
+{ 56, 56, 56},    { 68, 68, 68},
+{ 80, 80, 80},    { 96, 96, 96},
+{112,112,112},    {128,128,128},
+{144,144,144},    {160,160,160},
+{180,180,180},    {200,200,200},
+{224,224,224},    {252,252,252},  /*32*/
+{  0,  0,252},    { 64,  0,252},
+{124,  0,252},    {188,  0,252},
+{252,  0,252},    {252,  0,188},
+{252,  0,124},    {252,  0, 64},
+{252,  0,  0},    {252, 64,  0},
+{252,124,  0},    {252,188,  0},
+{252,252,  0},    {188,252,  0},
+{124,252,  0},    { 64,252,  0},  /*48*/
+{  0,252,  0},    {  0,252, 64},
+{  0,252,124},    {  0,252,188},
+{  0,252,252},    {  0,188,252},
+{  0,124,252},    {  0, 64,252},
+{124,124,252},    {156,124,252},
+{188,124,252},    {220,124,252},
+{252,124,252},    {252,124,220},
+{252,124,188},    {252,124,156},  /*64*/
+{252,124,124},    {252,156,124},
+{252,188,124},    {252,220,124},
+{252,252,124},    {220,252,124},
+{188,252,124},    {156,252,124},
+{124,252,124},    {124,252,156},
+{124,252,188},    {124,252,220},
+{124,252,252},    {124,220,252},
+{124,188,252},    {124,156,252},  /*80*/
+{180,180,252},    {196,180,252},
+{216,180,252},    {232,180,252},
+{252,180,252},    {252,180,232},
+{252,180,216},    {252,180,196},
+{252,180,180},    {252,196,180},
+{252,216,180},    {252,232,180},
+{252,252,180},    {232,252,180},
+{216,252,180},    {196,252,180},  /*96*/
+{180,220,180},    {180,252,196},
+{180,252,216},    {180,252,232},
+{180,252,252},    {180,232,252},
+{180,216,252},    {180,196,252},
+{0,0,112},    {28,0,112},
+{56,0,112},    {84,0,112},
+{112,0,112},    {112,0,84},
+{112,0,56},    {112,0,28},  /*112*/
+{112,0,0},    {112,28,0},
+{112,56,0},    {112,84,0},
+{112,112,0},    {84,112,0},
+{56,112,0},    {28,112,0},
+{0,112,0},    {0,112,28},
+{0,112,56},    {0,112,84},
+{0,112,112},    {0,84,112},
+{0,56,112},    {0,28,112},   /*128*/
+{56,56,112},    {68,56,112},
+{84,56,112},    {96,56,112},
+{112,56,112},    {112,56,96},
+{112,56,84},    {112,56,68},
+{112,56,56},    {112,68,56},
+{112,84,56},    {112,96,56},
+{112,112,56},    {96,112,56},
+{84,112,56},    {68,112,56},  /*144*/
+{56,112,56},    {56,112,69},
+{56,112,84},    {56,112,96},
+{56,112,112},    {56,96,112},
+{56,84,112},    {56,68,112},
+{80,80,112},    {88,80,112},
+{96,80,112},    {104,80,112},
+{112,80,112},    {112,80,104},
+{112,80,96},    {112,80,88},  /*160*/
+{112,80,80},    {112,88,80},
+{112,96,80},    {112,104,80},
+{112,112,80},    {104,112,80},
+{96,112,80},    {88,112,80},
+{80,112,80},    {80,112,88},
+{80,112,96},    {80,112,104},
+{80,112,112},    {80,114,112},
+{80,96,112},    {80,88,112},  /*176*/
+{0,0,64},    {16,0,64},
+{32,0,64},    {48,0,64},
+{64,0,64},    {64,0,48},
+{64,0,32},    {64,0,16},
+{64,0,0},    {64,16,0},
+{64,32,0},    {64,48,0},
+{64,64,0},    {48,64,0},
+{32,64,0},    {16,64,0},  /*192*/
+{0,64,0},    {0,64,16},
+{0,64,32},    {0,64,48},
+{0,64,64},    {0,48,64},
+{0,32,64},    {0,16,64},
+{32,32,64},    {40,32,64},
+{48,32,64},    {56,32,64},
+{64,32,64},    {64,32,56},
+{64,32,48},    {64,32,40},  /*208*/
+{64,32,32},    {64,40,32},
+{64,48,32},    {64,56,32},
+{64,64,32},    {56,64,32},
+{48,64,32},    {40,64,32},
+{32,64,32},    {32,64,40},
+{32,64,48},    {32,64,56},
+{32,64,64},    {32,56,64},
+{32,48,64},    {32,40,64},  /*224*/
+{44,44,64},    {48,44,64},
+{52,44,64},    {60,44,64},
+{64,44,64},    {64,44,60},
+{64,44,52},    {64,44,48},
+{64,44,44},    {64,48,44},
+{64,52,44},    {64,60,44},
+{64,64,44},    {60,64,44},
+{52,64,44},    {48,64,44},  /*240*/
+{44,64,44},    {44,64,48},
+{44,64,52},    {44,64,60},
+{44,64,64},    {44,60,64},
+{44,55,64},    {44,48,64},
+{0,0,0},    {0,0,0},
+{0,0,0},    {0,0,0},
+{0,0,0},    {0,0,0},
+{0,0,0},    {0,0,0}    /*256*/
 };
 
 /*
@@ -357,7 +358,7 @@ static void InsertRow(unsigned char *p,long y,Image *image, int bpp)
           break;
         break;
       }
-      
+ 
     case 4:  /* Convert PseudoColor scanline. */
       {
         q=SetImagePixels(image,0,y,image->columns,1);
@@ -453,7 +454,8 @@ static int UnpackWPGRaster(Image *image,int bpp)
   y=0;
 
   ldblk=(long) ((bpp*image->columns+7)/8);
-  BImgBuff=(unsigned char *) AcquireMagickMemory((size_t) ldblk);
+  BImgBuff=(unsigned char *) AcquireQuantumMemory((size_t) ldblk,
+    sizeof(*BImgBuff));
   if(BImgBuff==NULL) return(-2);
 
   while(y<(long) image->rows)
@@ -551,7 +553,8 @@ static int UnpackWPG2Raster(Image *image,int bpp)
   x=0;
   y=0;
   ldblk=(long) ((bpp*image->columns+7)/8);
-  BImgBuff=(unsigned char *) AcquireMagickMemory((size_t) ldblk);
+  BImgBuff=(unsigned char *) AcquireQuantumMemory((size_t) ldblk,
+    sizeof(*BImgBuff));
   if(BImgBuff==NULL)
     return(-2);
 
@@ -570,7 +573,7 @@ static int UnpackWPG2Raster(Image *image,int bpp)
           break;
         case 0x7E:
           (void) fprintf(stderr,"\nUnsupported WPG token XOR, please report!");
-	  XorMe=!XorMe;
+    XorMe=!XorMe;
           break;
         case 0x7F:
           RunCount=ReadBlobByte(image);   /* BLK */
@@ -580,8 +583,8 @@ static int UnpackWPG2Raster(Image *image,int bpp)
             }
           break;
         case 0xFD:
-	  RunCount=ReadBlobByte(image);   /* EXT */
-	  for(i=0; i<= RunCount;i++)
+    RunCount=ReadBlobByte(image);   /* EXT */
+    for(i=0; i<= RunCount;i++)
             for(bbuf=0; bbuf < SampleSize; bbuf++)
               InsertByte6(SampleBuffer[bbuf]);          
           break;
@@ -605,7 +608,7 @@ static int UnpackWPG2Raster(Image *image,int bpp)
           }
           break;
         case 0xFF:
-          RunCount=ReadBlobByte(image);	 /* WHT */
+          RunCount=ReadBlobByte(image);   /* WHT */
           for(i=0; i < SampleSize*(RunCount+1); i++)
             {
               InsertByte6(0xFF);
@@ -614,7 +617,7 @@ static int UnpackWPG2Raster(Image *image,int bpp)
         default:
           RunCount=bbuf & 0x7F;
 
-          if(bbuf & 0x80)		 /* REP */
+          if(bbuf & 0x80)     /* REP */
             {  
               for(i=0; i < SampleSize; i++)
                 SampleBuffer[i]=ReadBlobByte(image);
@@ -622,7 +625,7 @@ static int UnpackWPG2Raster(Image *image,int bpp)
                 for(bbuf=0;bbuf<SampleSize;bbuf++)
                   InsertByte6(SampleBuffer[bbuf]);
             }
-          else {			/* NRP */
+          else {      /* NRP */
             for(i=0; i< SampleSize*(RunCount+1);i++)
               {
                 bbuf=ReadBlobByte(image);
@@ -645,56 +648,56 @@ long x;
 unsigned DenX;
 unsigned Flags;
 
- memset(*CTM,0,sizeof(*CTM));     /*CTM.erase();CTM.resize(3,3);*/
+ (void) memset(*CTM,0,sizeof(*CTM));     /*CTM.erase();CTM.resize(3,3);*/
  (*CTM)[0][0]=1;
  (*CTM)[1][1]=1;
  (*CTM)[2][2]=1;
 
  Flags=ReadBlobLSBShort(image);
- if(Flags & LCK) x=ReadBlobLSBLong(image);	/*Edit lock*/
+ if(Flags & LCK) x=ReadBlobLSBLong(image);  /*Edit lock*/
  if(Flags & OID)
-	{
-	if(Precision==0)
-	  {x=ReadBlobLSBShort(image);}	/*ObjectID*/
-	else
-	  {x=ReadBlobLSBLong(image);}	/*ObjectID (Double precision)*/
-	}
+  {
+  if(Precision==0)
+    {x=ReadBlobLSBShort(image);}  /*ObjectID*/
+  else
+    {x=ReadBlobLSBLong(image);}  /*ObjectID (Double precision)*/
+  }
  if(Flags & ROT)
-	{
-	x=ReadBlobLSBLong(image);	/*Rot Angle*/
-	if(Angle) *Angle=x/65536.0;
-	}
+  {
+  x=ReadBlobLSBLong(image);  /*Rot Angle*/
+  if(Angle) *Angle=x/65536.0;
+  }
  if(Flags & (ROT|SCL))
-	{
-	x=ReadBlobLSBLong(image);	/*Sx*cos()*/
-	(*CTM)[0][0] = (float)x/0x10000;
-	x=ReadBlobLSBLong(image);	/*Sy*cos()*/
-	(*CTM)[1][1] = (float)x/0x10000;
-	}
+  {
+  x=ReadBlobLSBLong(image);  /*Sx*cos()*/
+  (*CTM)[0][0] = (float)x/0x10000;
+  x=ReadBlobLSBLong(image);  /*Sy*cos()*/
+  (*CTM)[1][1] = (float)x/0x10000;
+  }
  if(Flags & (ROT|SKW))
-	{
-	x=ReadBlobLSBLong(image);       /*Kx*sin()*/
-	(*CTM)[1][0] = (float)x/0x10000;
-	x=ReadBlobLSBLong(image);       /*Ky*sin()*/
-	(*CTM)[0][1] = (float)x/0x10000;
-	}
+  {
+  x=ReadBlobLSBLong(image);       /*Kx*sin()*/
+  (*CTM)[1][0] = (float)x/0x10000;
+  x=ReadBlobLSBLong(image);       /*Ky*sin()*/
+  (*CTM)[0][1] = (float)x/0x10000;
+  }
  if(Flags & TRN)
-	{
-	x=ReadBlobLSBLong(image); DenX=ReadBlobLSBShort(image);  /*Tx*/
+  {
+  x=ReadBlobLSBLong(image); DenX=ReadBlobLSBShort(image);  /*Tx*/
         if(x>=0) (*CTM)[0][2] = (float)x+(float)DenX/0x10000;
             else (*CTM)[0][2] = (float)x-(float)DenX/0x10000;
-	x=ReadBlobLSBLong(image); DenX=ReadBlobLSBShort(image);  /*Ty*/
-	(*CTM)[1][2]=(float)x + ((x>=0)?1:-1)*(float)DenX/0x10000;
+  x=ReadBlobLSBLong(image); DenX=ReadBlobLSBShort(image);  /*Ty*/
+  (*CTM)[1][2]=(float)x + ((x>=0)?1:-1)*(float)DenX/0x10000;
         if(x>=0) (*CTM)[1][2] = (float)x+(float)DenX/0x10000;
             else (*CTM)[1][2] = (float)x-(float)DenX/0x10000;
-	}
+  }
  if(Flags & TPR)
-	{
-	x=ReadBlobLSBShort(image); DenX=ReadBlobLSBShort(image);  /*Px*/
-	(*CTM)[2][0] = x + (float)DenX/0x10000;;
-	x=ReadBlobLSBShort(image);  DenX=ReadBlobLSBShort(image); /*Py*/
-	(*CTM)[2][1] = x + (float)DenX/0x10000;
-	}
+  {
+  x=ReadBlobLSBShort(image); DenX=ReadBlobLSBShort(image);  /*Px*/
+  (*CTM)[2][0] = x + (float)DenX/0x10000;;
+  x=ReadBlobLSBShort(image);  DenX=ReadBlobLSBShort(image); /*Py*/
+  (*CTM)[2][1] = x + (float)DenX/0x10000;
+  }
  return(Flags);
 }
 
@@ -728,8 +731,8 @@ static Image *ExtractPostscript(Image *image,const ImageInfo *image_info,
 
   /* Obtain temporary file */
   AcquireUniqueFilename(postscript_file);
-  ps_file=fopen(postscript_file,"wb");
-  if (!ps_file)
+  ps_file=MagickOpenStream(postscript_file,"wb");
+  if (ps_file == (FILE *) NULL)
     goto FINISH;
 
   /* Copy postscript to temporary file */
@@ -812,7 +815,6 @@ static Image *ExtractPostscript(Image *image,const ImageInfo *image_info,
 %
 %    o exception: return any errors or warnings in this structure.
 %
-%
 */
 static Image *ReadWPGImage(const ImageInfo *image_info,
   ExceptionInfo *exception)
@@ -845,8 +847,8 @@ static Image *ReadWPGImage(const ImageInfo *image_info,
 
   typedef struct
   {
-    unsigned	HorizontalUnits;
-    unsigned	VerticalUnits;
+    unsigned  HorizontalUnits;
+    unsigned  VerticalUnits;
     unsigned char PosSizePrecision;
   } WPG2Start;
 
@@ -943,7 +945,7 @@ static Image *ReadWPGImage(const ImageInfo *image_info,
   assert(image_info->signature == MagickSignature);
   assert(exception != (ExceptionInfo *) NULL);
   assert(exception->signature == MagickSignature);
-  image=AllocateImage(image_info);
+  image=AcquireImage(image_info);
   image->depth=8;
   status=OpenBlob(image_info,image,ReadBinaryBlobMode,exception);
   if (status == MagickFalse)
@@ -1016,17 +1018,17 @@ static Image *ReadWPGImage(const ImageInfo *image_info,
               WPG_Palette.NumOfEntries=ReadBlobLSBShort(image);
 
               image->colors=WPG_Palette.NumOfEntries;
-              if (!AllocateImageColormap(image,image->colors))
+              if (!AcquireImageColormap(image,image->colors))
                 goto NoMemory;
               for (i=WPG_Palette.StartIndex;
                    i < (int)WPG_Palette.NumOfEntries; i++)
                 {
-                  image->colormap[i].red=
-                    ScaleCharToQuantum(ReadBlobByte(image));
-                  image->colormap[i].green=
-                    ScaleCharToQuantum(ReadBlobByte(image));
-                  image->colormap[i].blue=
-                    ScaleCharToQuantum(ReadBlobByte(image));
+                  image->colormap[i].red=ScaleCharToQuantum((unsigned char)
+                    ReadBlobByte(image));
+                  image->colormap[i].green=ScaleCharToQuantum((unsigned char)
+                    ReadBlobByte(image));
+                  image->colormap[i].blue=ScaleCharToQuantum((unsigned char)
+                    ReadBlobByte(image));
                 }
               break;
      
@@ -1065,11 +1067,11 @@ static Image *ReadWPGImage(const ImageInfo *image_info,
               image->rows=BitmapHeader2.Heigth;
               bpp=BitmapHeader2.Depth;
 
-            UnpackRaster:	    
+            UnpackRaster:      
               if ((image->colors == 0) && (bpp != 24))
                 {
                   image->colors=1 << bpp;
-                  if (!AllocateImageColormap(image,image->colors))
+                  if (!AcquireImageColormap(image,image->colors))
                     {
                     NoMemory:
                       ThrowReaderException(ResourceLimitError,
@@ -1087,8 +1089,9 @@ static Image *ReadWPGImage(const ImageInfo *image_info,
                 {
                   if (bpp < 24)
                     if ( (image->colors < (1UL<<bpp)) && (bpp != 24) )
-                      image->colormap=(PixelPacket *) ResizeMagickMemory(
-                        image->colormap,(size_t) ((1UL<<bpp)*sizeof(PixelPacket)));
+                      image->colormap=(PixelPacket *) ResizeQuantumMemory(
+                        image->colormap,(size_t) (1UL << bpp),
+                        sizeof(*image->colormap));
                 }
           
               if (bpp == 1)
@@ -1115,38 +1118,38 @@ static Image *ReadWPGImage(const ImageInfo *image_info,
 
               if(Rec.RecType==0x14 && BitmapHeader2.RotAngle!=0 && !image_info->ping)
                 {  
-                  // flop command                
+                  /* flop command */
                   if(BitmapHeader2.RotAngle & 0x8000)
                     {
                       rotated_image = FlopImage(image, exception);
                       rotated_image->blob = image->blob;
                       image->blob = NULL;
-                      RemoveLastImageFromList(&image);
+                      (void) RemoveLastImageFromList(&image);
                       AppendImageToList(&image,rotated_image);
                     }
-                  // flip command
+                  /* flip command */
                   if(BitmapHeader2.RotAngle & 0x2000)
                     {
                       rotated_image = FlipImage(image, exception);
                       rotated_image->blob = image->blob;
                       image->blob = NULL;
-                      RemoveLastImageFromList(&image);
-                      AppendImageToList(&image,rotated_image);		
+                      (void) RemoveLastImageFromList(&image);
+                      AppendImageToList(&image,rotated_image);    
                     }
-		
-		  // rotate command
+    
+      /* rotate command */
                   if(BitmapHeader2.RotAngle & 0x0FFF)
                     {
                       rotated_image = RotateImage(image, (BitmapHeader2.RotAngle & 0x0FFF), exception);
                       rotated_image->blob = image->blob;
                       image->blob = NULL;
-                      RemoveLastImageFromList(&image);
-                      AppendImageToList(&image,rotated_image);		
+                      (void) RemoveLastImageFromList(&image);
+                      AppendImageToList(&image,rotated_image);    
                     }                
                 }
 
               /* Allocate next image structure. */
-              AllocateNextImage(image_info,image);
+              AcquireNextImage(image_info,image);
               image->depth=8;
               if (image->next == (Image *) NULL)
                 goto Finish;
@@ -1166,7 +1169,7 @@ static Image *ReadWPGImage(const ImageInfo *image_info,
       break;
 
     case 2:  /* WPG level 2 */
-      memset(CTM,0,sizeof(CTM));
+      (void) memset(CTM,0,sizeof(CTM));
       StartWPG.PosSizePrecision = 0;
       while(!EOFBlob(image)) /* object parser loop */
         {
@@ -1189,7 +1192,7 @@ static Image *ReadWPGImage(const ImageInfo *image_info,
 
           switch(Rec2.RecType)
             {
-	    case 1:
+      case 1:
               StartWPG.HorizontalUnits=ReadBlobLSBShort(image);
               StartWPG.VerticalUnits=ReadBlobLSBShort(image);
               StartWPG.PosSizePrecision=ReadBlobByte(image);
@@ -1199,18 +1202,18 @@ static Image *ReadWPGImage(const ImageInfo *image_info,
               WPG_Palette.NumOfEntries=ReadBlobLSBShort(image);
 
               image->colors=WPG_Palette.NumOfEntries;
-              if (AllocateImageColormap(image,image->colors) == MagickFalse)
+              if (AcquireImageColormap(image,image->colors) == MagickFalse)
                 ThrowReaderException(ResourceLimitError,
                   "MemoryAllocationFailed");
               for (i=WPG_Palette.StartIndex;
                    i < (int)WPG_Palette.NumOfEntries; i++)
                 {
-                  image->colormap[i].red=
-                    ScaleCharToQuantum(ReadBlobByte(image));
-                  image->colormap[i].green=
-                    ScaleCharToQuantum(ReadBlobByte(image));
-                  image->colormap[i].blue=
-                    ScaleCharToQuantum(ReadBlobByte(image));
+                  image->colormap[i].red=ScaleCharToQuantum((char)
+                    ReadBlobByte(image));
+                  image->colormap[i].green=ScaleCharToQuantum((char)
+                    ReadBlobByte(image));
+                  image->colormap[i].blue=ScaleCharToQuantum((char)
+                    ReadBlobByte(image));
                   (void) ReadBlobByte(image);   /*Opacity??*/
                 }
               break;
@@ -1248,15 +1251,16 @@ static Image *ReadWPGImage(const ImageInfo *image_info,
               if ((image->colors == 0) && (bpp != 24))
                 {
                   image->colors=1 << bpp;
-                  if (!AllocateImageColormap(image,image->colors))
+                  if (!AcquireImageColormap(image,image->colors))
                     goto NoMemory;
                 }
               else
                 {
                   if(bpp < 24)
                     if( image->colors<(1UL<<bpp) && bpp!=24 )
-                      image->colormap=(PixelPacket *) ResizeMagickMemory(
-                       image->colormap,(size_t) ((1UL<<bpp)*sizeof(PixelPacket)));
+                      image->colormap=(PixelPacket *) ResizeQuantumMemory(
+                       image->colormap,(size_t) (1UL << bpp),
+                       sizeof(*image->colormap));
                 }
 
 
@@ -1265,7 +1269,8 @@ static Image *ReadWPGImage(const ImageInfo *image_info,
                 case 0:    /*Uncompressed raster*/
                   {
                     ldblk=(long) ((bpp*image->columns+7)/8);
-                    BImgBuff=(unsigned char *) AcquireMagickMemory((size_t) ldblk);
+                    BImgBuff=(unsigned char *) AcquireQuantumMemory((size_t)
+                      ldblk,sizeof(*BImgBuff));
                     if (BImgBuff == (unsigned char *) NULL)
                       goto NoMemory;
 
@@ -1288,36 +1293,36 @@ static Image *ReadWPGImage(const ImageInfo *image_info,
                 }
 
               if(CTM[0][0]<0 && !image_info->ping)
-		{		/*?? RotAngle=360-RotAngle;*/
-		  rotated_image = FlopImage(image, exception);
-		  rotated_image->blob = image->blob;
-		  image->blob = NULL;
-		  RemoveLastImageFromList(&image);
-		  AppendImageToList(&image,rotated_image);
-                  /* Try to change CTM according to Flip - I am not sure, must be checked.		  
+    {    /*?? RotAngle=360-RotAngle;*/
+      rotated_image = FlopImage(image, exception);
+      rotated_image->blob = image->blob;
+      image->blob = NULL;
+      (void) RemoveLastImageFromList(&image);
+      AppendImageToList(&image,rotated_image);
+                  /* Try to change CTM according to Flip - I am not sure, must be checked.      
                      Tx(0,0)=-1;      Tx(1,0)=0;   Tx(2,0)=0;
                      Tx(0,1)= 0;      Tx(1,1)=1;   Tx(2,1)=0;
                      Tx(0,2)=(WPG._2Rect.X_ur+WPG._2Rect.X_ll);
                      Tx(1,2)=0;   Tx(2,2)=1; */                  
                 }
               if(CTM[1][1]<0 && !image_info->ping)
-		{		/*?? RotAngle=360-RotAngle;*/
-		  rotated_image = FlipImage(image, exception);
-		  rotated_image->blob = image->blob;
-		  image->blob = NULL;
-		  RemoveLastImageFromList(&image);
-		  AppendImageToList(&image,rotated_image);
+    {    /*?? RotAngle=360-RotAngle;*/
+      rotated_image = FlipImage(image, exception);
+      rotated_image->blob = image->blob;
+      image->blob = NULL;
+      (void) RemoveLastImageFromList(&image);
+      AppendImageToList(&image,rotated_image);
                   /* Try to change CTM according to Flip - I am not sure, must be checked.
                      float_matrix Tx(3,3);
                      Tx(0,0)= 1;   Tx(1,0)= 0;   Tx(2,0)=0;
                      Tx(0,1)= 0;   Tx(1,1)=-1;   Tx(2,1)=0;
                      Tx(0,2)= 0;   Tx(1,2)=(WPG._2Rect.Y_ur+WPG._2Rect.Y_ll);
-                     Tx(2,2)=1; */		  
-		}		
-		
+                     Tx(2,2)=1; */      
+    }    
+    
 
               /* Allocate next image structure. */
-              AllocateNextImage(image_info,image);
+              AcquireNextImage(image_info,image);
               image->depth=8;
               if (image->next == (Image *) NULL)
                 goto Finish;
@@ -1327,14 +1332,14 @@ static Image *ReadWPGImage(const ImageInfo *image_info,
               break;
 
             case 0x12:  /* Postscript WPG2*/
-	      i=ReadBlobLSBShort(image);
+        i=ReadBlobLSBShort(image);
               if(Rec2.RecordLength > (unsigned int) i)
                 image=ExtractPostscript(image,image_info,
-                  TellBlob(image)+i,		/*skip PS header in the wpg2*/
+                  TellBlob(image)+i,    /*skip PS header in the wpg2*/
                   (long) (Rec2.RecordLength-i-2),exception);
               break;
 
-	    case 0x1B:          /*bitmap rectangle*/
+      case 0x1B:          /*bitmap rectangle*/
               WPG2Flags = LoadWPG2Flags(image,StartWPG.PosSizePrecision,NULL,&CTM);
               break;
             }
@@ -1349,7 +1354,7 @@ static Image *ReadWPGImage(const ImageInfo *image_info,
    }
 
  Finish:
-  CloseBlob(image);
+  (void) CloseBlob(image);
 
   {
     Image
@@ -1378,9 +1383,12 @@ static Image *ReadWPGImage(const ImageInfo *image_info,
       Fix scene numbers.
     */
     for (p=image; p != (Image *) NULL; p=p->next)
-      p->scene=scene++;
+      p->scene=(unsigned long) scene++;
   }
-  return(image);       
+  if (image == (Image *) NULL)
+    ThrowReaderException(CorruptImageError,
+      "ImageFileDoesNotContainAnyImageData");
+  return(image);
 }
 
 /*
@@ -1403,21 +1411,22 @@ static Image *ReadWPGImage(const ImageInfo *image_info,
 %
 %  The format of the RegisterWPGImage method is:
 %
-%      RegisterWPGImage(void)
+%      unsigned long RegisterWPGImage(void)
 %
 */
-ModuleExport void RegisterWPGImage(void)
+ModuleExport unsigned long RegisterWPGImage(void)
 {
   MagickInfo
     *entry;
 
   entry=SetMagickInfo("WPG");
-  entry->decoder=(DecoderHandler *) ReadWPGImage;
-  entry->magick=(MagickHandler *) IsWPG;
+  entry->decoder=(DecodeImageHandler *) ReadWPGImage;
+  entry->magick=(IsImageFormatHandler *) IsWPG;
   entry->description=AcquireString("Word Perfect Graphics");
   entry->module=ConstantString("WPG");
   entry->seekable_stream=MagickTrue;
   (void) RegisterMagickInfo(entry);
+  return(MagickImageCoderSignature);
 }
 
 /*
