@@ -17,7 +17,7 @@
 %                                 July 1992                                   %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2007 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2008 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -56,12 +56,13 @@
 #include "magick/monitor.h"
 #include "magick/pixel-private.h"
 #include "magick/quantize.h"
-#include "magick/quantum.h"
+#include "magick/quantum-private.h"
 #include "magick/resize.h"
 #include "magick/resource_.h"
 #include "magick/splay-tree.h"
 #include "magick/static.h"
 #include "magick/string_.h"
+#include "magick/module.h"
 #include "magick/threshold.h"
 #include "magick/utility.h"
 
@@ -128,7 +129,7 @@ static MagickBooleanType IsXPM(const unsigned char *magick,const size_t length)
 %
 %  A description of each parameter follows:
 %
-%    o image_info: The image info.
+%    o image_info: the image info.
 %
 %    o exception: return any errors or warnings in this structure.
 %
@@ -266,7 +267,7 @@ static Image *ReadXPMImage(const ImageInfo *image_info,ExceptionInfo *exception)
       image_info->filename);
   assert(exception != (ExceptionInfo *) NULL);
   assert(exception->signature == MagickSignature);
-  image=AllocateImage(image_info);
+  image=AcquireImage(image_info);
   status=OpenBlob(image_info,image,ReadBinaryBlobMode,exception);
   if (status == MagickFalse)
     {
@@ -277,7 +278,7 @@ static Image *ReadXPMImage(const ImageInfo *image_info,ExceptionInfo *exception)
     Read XPM file.
   */
   length=MaxTextExtent;
-  xpm_buffer=(char *) AcquireMagickMemory((size_t) length);
+  xpm_buffer=(char *) AcquireQuantumMemory((size_t) length,sizeof(*xpm_buffer));
   p=xpm_buffer;
   if (xpm_buffer != (char *) NULL)
     while (ReadBlobString(image,p) != (char *) NULL)
@@ -290,7 +291,7 @@ static Image *ReadXPMImage(const ImageInfo *image_info,ExceptionInfo *exception)
       if ((size_t) (p-xpm_buffer+MaxTextExtent) < length)
         continue;
       length<<=1;
-      xpm_buffer=(char *) ResizeMagickMemory(xpm_buffer,(length+MaxTextExtent)*
+      xpm_buffer=(char *) ResizeQuantumMemory(xpm_buffer,length+MaxTextExtent,
         sizeof(*xpm_buffer));
       if (xpm_buffer == (char *) NULL)
         break;
@@ -338,7 +339,7 @@ static Image *ReadXPMImage(const ImageInfo *image_info,ExceptionInfo *exception)
   */
   xpm_colors=NewSplayTree(CompareXPMColor,RelinquishMagickMemory,
     (void *(*)(void *)) NULL);
-  if (AllocateImageColormap(image,image->colors) == MagickFalse)
+  if (AcquireImageColormap(image,image->colors) == MagickFalse)
     ThrowReaderException(ResourceLimitError,"MemoryAllocationFailed");
   /*
     Read image colormap.
@@ -386,6 +387,11 @@ static Image *ReadXPMImage(const ImageInfo *image_info,ExceptionInfo *exception)
       /*
         Read image pixels.
       */
+      if (SetImageExtent(image,0,0) == MagickFalse)
+        {
+          InheritException(exception,&image->exception);
+          return(DestroyImageList(image));
+        }
       for (y=0; y < (long) image->rows; y++)
       {
         p=NextXPMLine(p);
@@ -412,10 +418,10 @@ static Image *ReadXPMImage(const ImageInfo *image_info,ExceptionInfo *exception)
         ThrowReaderException(CorruptImageError,"NotEnoughPixelData");
     }
   /*
-    Free resources.
+    Relinquish resources.
   */
   xpm_colors=DestroySplayTree(xpm_colors);
-  CloseBlob(image);
+  (void) CloseBlob(image);
   return(GetFirstImageInList(image));
 }
 
@@ -439,37 +445,38 @@ static Image *ReadXPMImage(const ImageInfo *image_info,ExceptionInfo *exception)
 %
 %  The format of the RegisterXPMImage method is:
 %
-%      RegisterXPMImage(void)
+%      unsigned long RegisterXPMImage(void)
 %
 */
-ModuleExport void RegisterXPMImage(void)
+ModuleExport unsigned long RegisterXPMImage(void)
 {
   MagickInfo
     *entry;
 
   entry=SetMagickInfo("PICON");
-  entry->decoder=(DecoderHandler *) ReadXPMImage;
-  entry->encoder=(EncoderHandler *) WritePICONImage;
+  entry->decoder=(DecodeImageHandler *) ReadXPMImage;
+  entry->encoder=(EncodeImageHandler *) WritePICONImage;
   entry->adjoin=MagickFalse;
   entry->description=ConstantString("Personal Icon");
   entry->module=ConstantString("XPM");
   (void) RegisterMagickInfo(entry);
   entry=SetMagickInfo("PM");
-  entry->decoder=(DecoderHandler *) ReadXPMImage;
-  entry->encoder=(EncoderHandler *) WriteXPMImage;
+  entry->decoder=(DecodeImageHandler *) ReadXPMImage;
+  entry->encoder=(EncodeImageHandler *) WriteXPMImage;
   entry->adjoin=MagickFalse;
   entry->stealth=MagickTrue;
   entry->description=ConstantString("X Windows system pixmap (color)");
   entry->module=ConstantString("XPM");
   (void) RegisterMagickInfo(entry);
   entry=SetMagickInfo("XPM");
-  entry->decoder=(DecoderHandler *) ReadXPMImage;
-  entry->encoder=(EncoderHandler *) WriteXPMImage;
-  entry->magick=(MagickHandler *) IsXPM;
+  entry->decoder=(DecodeImageHandler *) ReadXPMImage;
+  entry->encoder=(EncodeImageHandler *) WriteXPMImage;
+  entry->magick=(IsImageFormatHandler *) IsXPM;
   entry->adjoin=MagickFalse;
   entry->description=ConstantString("X Windows system pixmap (color)");
   entry->module=ConstantString("XPM");
   (void) RegisterMagickInfo(entry);
+  return(MagickImageCoderSignature);
 }
 
 /*
@@ -519,7 +526,7 @@ ModuleExport void UnregisterXPMImage(void)
 %
 %  A description of each parameter follows.
 %
-%    o image_info: The image info.
+%    o image_info: the image info.
 %
 %    o image:  The image.
 %
@@ -623,7 +630,7 @@ static MagickBooleanType WritePICONImage(const ImageInfo *image_info,
   status=OpenBlob(image_info,image,WriteBinaryBlobMode,&image->exception);
   if (status == MagickFalse)
     return(status);
-  if (image_info->colorspace == UndefinedColorspace)
+  if (image->colorspace != RGBColorspace)
     (void) SetImageColorspace(image,RGBColorspace);
   SetGeometry(image,&geometry);
   (void) ParseMetaGeometry(PiconGeometry,&geometry.x,&geometry.y,
@@ -667,7 +674,7 @@ static MagickBooleanType WritePICONImage(const ImageInfo *image_info,
               break;
             for (x=0; x < (long) picon->columns; x++)
             {
-              if (q->opacity == TransparentOpacity)
+              if (q->opacity == (Quantum) TransparentOpacity)
                 transparent=MagickTrue;
               else
                 q->opacity=OpaqueOpacity;
@@ -683,8 +690,8 @@ static MagickBooleanType WritePICONImage(const ImageInfo *image_info,
   if (transparent != MagickFalse)
     {
       colors++;
-      picon->colormap=(PixelPacket *) ResizeMagickMemory((void **)
-        picon->colormap,(size_t) colors*sizeof(*picon->colormap));
+      picon->colormap=(PixelPacket *) ResizeQuantumMemory((void **)
+        picon->colormap,(size_t) colors,sizeof(*picon->colormap));
       if (picon->colormap == (PixelPacket *) NULL)
         ThrowWriterException(ResourceLimitError,"MemoryAllocationError");
       for (y=0; y < (long) picon->rows; y++)
@@ -695,7 +702,7 @@ static MagickBooleanType WritePICONImage(const ImageInfo *image_info,
         indexes=GetIndexes(picon);
         for (x=0; x < (long) picon->columns; x++)
         {
-          if (q->opacity == TransparentOpacity)
+          if (q->opacity == (Quantum) TransparentOpacity)
             indexes[x]=(IndexPacket) picon->colors;
           q++;
         }
@@ -731,11 +738,8 @@ static MagickBooleanType WritePICONImage(const ImageInfo *image_info,
     pixel.colorspace=RGBColorspace;
     pixel.depth=8;
     pixel.opacity=(MagickRealType) OpaqueOpacity;
-    (void) QueryMagickColorname(image,&pixel,XPMCompliance,MagickFalse,name,
+    (void) QueryMagickColorname(image,&pixel,XPMCompliance,name,
       &image->exception);
-    if (LocaleNCompare(name,"rgb",3) == 0)
-      (void) QueryMagickColorname(image,&pixel,XPMCompliance,MagickTrue,name,
-        &image->exception);
     if (transparent != MagickFalse)
       {
         if (i == (long) (colors-1))
@@ -795,7 +799,7 @@ static MagickBooleanType WritePICONImage(const ImageInfo *image_info,
   }
   picon=DestroyImage(picon);
   (void) WriteBlobString(image,"};\n");
-  CloseBlob(image);
+  (void) CloseBlob(image);
   return(MagickTrue);
 }
 
@@ -818,7 +822,7 @@ static MagickBooleanType WritePICONImage(const ImageInfo *image_info,
 %
 %  A description of each parameter follows.
 %
-%    o image_info: The image info.
+%    o image_info: the image info.
 %
 %    o image:  The image.
 %
@@ -875,7 +879,7 @@ static MagickBooleanType WriteXPMImage(const ImageInfo *image_info,Image *image)
   status=OpenBlob(image_info,image,WriteBinaryBlobMode,&image->exception);
   if (status == MagickFalse)
     return(status);
-  if (image_info->colorspace == UndefinedColorspace)
+  if (image->colorspace != RGBColorspace)
     (void) SetImageColorspace(image,RGBColorspace);
   opacity=(-1);
   if (image->matte == MagickFalse)
@@ -902,9 +906,9 @@ static MagickBooleanType WriteXPMImage(const ImageInfo *image_info,Image *image)
                 opacity=i;
                 continue;
               }
-            alpha=TransparentOpacity-(MagickRealType)
+            alpha=(Quantum) TransparentOpacity-(MagickRealType)
               image->colormap[i].opacity;
-            beta=TransparentOpacity-(MagickRealType)
+            beta=(Quantum) TransparentOpacity-(MagickRealType)
               image->colormap[opacity].opacity;
             if (alpha < beta)
               opacity=i;
@@ -920,9 +924,9 @@ static MagickBooleanType WriteXPMImage(const ImageInfo *image_info,Image *image)
                     opacity=i;
                     continue;
                   }
-                alpha=TransparentOpacity-(MagickRealType)
+                alpha=(Quantum) TransparentOpacity-(MagickRealType)
                   image->colormap[i].opacity;
-                beta=TransparentOpacity-(MagickRealType)
+                beta=(Quantum) TransparentOpacity-(MagickRealType)
                   image->colormap[opacity].opacity;
                 if (alpha < beta)
                   opacity=i;
@@ -971,11 +975,8 @@ static MagickBooleanType WriteXPMImage(const ImageInfo *image_info,Image *image)
     pixel.colorspace=RGBColorspace;
     pixel.depth=8;
     pixel.opacity=(MagickRealType) OpaqueOpacity;
-    (void) QueryMagickColorname(image,&pixel,XPMCompliance,MagickFalse,name,
+    (void) QueryMagickColorname(image,&pixel,XPMCompliance,name,
       &image->exception);
-    if (LocaleNCompare(name,"rgb",3) == 0)
-      (void) QueryMagickColorname(image,&pixel,XPMCompliance,MagickTrue,name,
-        &image->exception);
     if (i == opacity)
       (void) CopyMagickString(name,"None",MaxTextExtent);
     /*
@@ -1031,6 +1032,6 @@ static MagickBooleanType WriteXPMImage(const ImageInfo *image_info,Image *image)
         }
   }
   (void) WriteBlobString(image,"};\n");
-  CloseBlob(image);
+  (void) CloseBlob(image);
   return(MagickTrue);
 }
