@@ -754,7 +754,7 @@ static MagickBooleanType WriteYCBCRImage(const ImageInfo *image_info,
       (void) SetImageColorspace(image,YCbCrColorspace);
     if ((LocaleCompare(image_info->magick,"YCbCrA") == 0) &&
         (image->matte == MagickFalse))
-      (void) SetImageOpacity(image,OpaqueOpacity);
+      (void) SetImageAlphaChannel(image,ResetAlphaChannel);
     quantum_info=AcquireQuantumInfo(image_info,image);
     pixels=GetQuantumPixels(quantum_info);
     switch (image_info->interlace)
