@@ -17,7 +17,7 @@
 %                                 July 1992                                   %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2007 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2008 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -54,9 +54,10 @@
 #include "magick/memory_.h"
 #include "magick/monitor.h"
 #include "magick/resize.h"
-#include "magick/quantum.h"
+#include "magick/quantum-private.h"
 #include "magick/static.h"
 #include "magick/string_.h"
+#include "magick/module.h"
 #include "magick/utility.h"
 
 /*
@@ -87,11 +88,10 @@ static MagickBooleanType
 %
 %  A description of each parameter follows:
 %
-%    o image_info: The image info.
+%    o image_info: the image info.
 %
 %    o exception: return any errors or warnings in this structure.
 %
-%
 */
 static Image *ReadYUVImage(const ImageInfo *image_info,ExceptionInfo *exception)
 {
@@ -142,7 +142,7 @@ static Image *ReadYUVImage(const ImageInfo *image_info,ExceptionInfo *exception)
       image_info->filename);
   assert(exception != (ExceptionInfo *) NULL);
   assert(exception->signature == MagickSignature);
-  image=AllocateImage(image_info);
+  image=AcquireImage(image_info);
   if ((image->columns == 0) || (image->rows == 0))
     ThrowReaderException(OptionError,"MustSpecifyImageSize");
   image->depth=8;
@@ -185,16 +185,22 @@ static Image *ReadYUVImage(const ImageInfo *image_info,ExceptionInfo *exception)
           return((Image *) NULL);
         }
       for (i=0; i < image->offset; i++)
-        (void) ReadBlobByte(image);
+        if (ReadBlobByte(image) == EOF)
+          {
+            ThrowFileException(exception,CorruptImageError,
+              "UnexpectedEndOfFile",image->filename);
+            break;
+          }
     }
   /*
     Allocate memory for a scanline.
   */
   if (interlace == NoInterlace)
-    scanline=(unsigned char *)
-      AcquireMagickMemory((size_t) (2*image->columns+2));
+    scanline=(unsigned char *) AcquireQuantumMemory((size_t) 2UL*
+      image->columns+2UL,sizeof(*scanline));
   else
-    scanline=(unsigned char *) AcquireMagickMemory((size_t) image->columns);
+    scanline=(unsigned char *) AcquireQuantumMemory((size_t) image->columns,
+      sizeof(*scanline));
   if (scanline == (unsigned char *) NULL)
     ThrowReaderException(ResourceLimitError,"MemoryAllocationFailed");
   do
@@ -209,6 +215,11 @@ static Image *ReadYUVImage(const ImageInfo *image_info,ExceptionInfo *exception)
     if ((image_info->ping != MagickFalse) && (image_info->number_scenes != 0))
       if (image->scene >= (image_info->scene+image_info->number_scenes-1))
         break;
+    if (SetImageExtent(image,0,0) == MagickFalse)
+      {
+        InheritException(exception,&image->exception);
+        return(DestroyImageList(image));
+      }
     if (interlace == PartitionInterlace)
       {
         AppendImageFormat("Y",image->filename);
@@ -284,7 +295,7 @@ static Image *ReadYUVImage(const ImageInfo *image_info,ExceptionInfo *exception)
     }
     if (interlace == PartitionInterlace)
       {
-        CloseBlob(image);
+        (void) CloseBlob(image);
         AppendImageFormat("U",image->filename);
         status=OpenBlob(image_info,image,ReadBinaryBlobMode,exception);
         if (status == MagickFalse)
@@ -314,7 +325,7 @@ static Image *ReadYUVImage(const ImageInfo *image_info,ExceptionInfo *exception)
         }
       if (interlace == PartitionInterlace)
         {
-          CloseBlob(image);
+          (void) CloseBlob(image);
           AppendImageFormat("V",image->filename);
           status=OpenBlob(image_info,image,ReadBinaryBlobMode,exception);
           if (status == MagickFalse)
@@ -367,8 +378,6 @@ static Image *ReadYUVImage(const ImageInfo *image_info,ExceptionInfo *exception)
     }
     resize_image=DestroyImage(resize_image);
     image->colorspace=YCbCrColorspace;
-    if (image_info->colorspace == UndefinedColorspace)
-      (void) SetImageColorspace(image,RGBColorspace);
     if (interlace == PartitionInterlace)
       (void) CopyMagickString(image->filename,image_info->filename,
         MaxTextExtent);
@@ -393,7 +402,7 @@ static Image *ReadYUVImage(const ImageInfo *image_info,ExceptionInfo *exception)
         /*
           Allocate next image structure.
         */
-        AllocateNextImage(image_info,image);
+        AcquireNextImage(image_info,image);
         if (GetNextImageInList(image) == (Image *) NULL)
           {
             image=DestroyImageList(image);
@@ -410,7 +419,7 @@ static Image *ReadYUVImage(const ImageInfo *image_info,ExceptionInfo *exception)
       }
   } while (count != 0);
   scanline=(unsigned char *) RelinquishMagickMemory(scanline);
-  CloseBlob(image);
+  (void) CloseBlob(image);
   return(GetFirstImageInList(image));
 }
 
@@ -434,22 +443,23 @@ static Image *ReadYUVImage(const ImageInfo *image_info,ExceptionInfo *exception)
 %
 %  The format of the RegisterYUVImage method is:
 %
-%      RegisterYUVImage(void)
+%      unsigned long RegisterYUVImage(void)
 %
 */
-ModuleExport void RegisterYUVImage(void)
+ModuleExport unsigned long RegisterYUVImage(void)
 {
   MagickInfo
     *entry;
 
   entry=SetMagickInfo("YUV");
-  entry->decoder=(DecoderHandler *) ReadYUVImage;
-  entry->encoder=(EncoderHandler *) WriteYUVImage;
+  entry->decoder=(DecodeImageHandler *) ReadYUVImage;
+  entry->encoder=(EncodeImageHandler *) WriteYUVImage;
   entry->adjoin=MagickFalse;
   entry->raw=MagickTrue;
   entry->description=ConstantString("CCIR 601 4:1:1 or 4:2:2");
   entry->module=ConstantString("YUV");
   (void) RegisterMagickInfo(entry);
+  return(MagickImageCoderSignature);
 }
 
 /*
@@ -497,7 +507,7 @@ ModuleExport void UnregisterYUVImage(void)
 %
 %  A description of each parameter follows.
 %
-%    o image_info: The image info.
+%    o image_info: the image info.
 %
 %    o image:  The image.
 %
@@ -590,16 +600,13 @@ static MagickBooleanType WriteYUVImage(const ImageInfo *image_info,Image *image)
       Sample image to an even width and height, if necessary.
     */
     image->depth=8;
-    if (image_info->colorspace == UndefinedColorspace)
-      (void) SetImageColorspace(image,RGBColorspace);
     width=image->columns+(image->columns & (horizontal_factor-1));
     height=image->rows+(image->rows & (vertical_factor-1));
     yuv_image=ResizeImage(image,width,height,TriangleFilter,1.0,
       &image->exception);
     if (yuv_image == (Image *) NULL)
       ThrowWriterException(ResourceLimitError,image->exception.reason);
-    if (image_info->colorspace == UndefinedColorspace)
-      (void) SetImageColorspace(yuv_image,YCbCrColorspace);
+    (void) SetImageColorspace(yuv_image,YCbCrColorspace);
     /*
       Downsample image.
     */
@@ -607,8 +614,7 @@ static MagickBooleanType WriteYUVImage(const ImageInfo *image_info,Image *image)
       height/vertical_factor,TriangleFilter,1.0,&image->exception);
     if (chroma_image == (Image *) NULL)
       ThrowWriterException(ResourceLimitError,image->exception.reason);
-    if (image_info->colorspace == UndefinedColorspace)
-      (void) SetImageColorspace(chroma_image,YCbCrColorspace);
+    (void) SetImageColorspace(chroma_image,YCbCrColorspace);
     if (interlace == NoInterlace)
       {
         /*
@@ -679,7 +685,7 @@ static MagickBooleanType WriteYUVImage(const ImageInfo *image_info,Image *image)
         */
         if (interlace == PartitionInterlace)
           {
-            CloseBlob(image);
+            (void) CloseBlob(image);
             AppendImageFormat("U",image->filename);
             status=OpenBlob(image_info,image,WriteBinaryBlobMode,
               &image->exception);
@@ -703,7 +709,7 @@ static MagickBooleanType WriteYUVImage(const ImageInfo *image_info,Image *image)
         */
         if (interlace == PartitionInterlace)
           {
-            CloseBlob(image);
+            (void) CloseBlob(image);
             AppendImageFormat("V",image->filename);
             status=OpenBlob(image_info,image,WriteBinaryBlobMode,
               &image->exception);
@@ -739,6 +745,6 @@ static MagickBooleanType WriteYUVImage(const ImageInfo *image_info,Image *image)
       }
     scene++;
   } while (image_info->adjoin != MagickFalse);
-  CloseBlob(image);
+  (void) CloseBlob(image);
   return(MagickTrue);
 }
