@@ -1240,25 +1240,12 @@ static MagickBooleanType RenderFreetype(Image *image,const DrawInfo *draw_info,
   long
     y;
 
-  MagickBooleanType
-    active;
-
-  MagickRealType
-    fill_opacity;
-
-  PixelPacket
-    fill_color;
-
   PointInfo
     point,
     resolution;
 
   register long
-    i,
-    x;
-
-  register PixelPacket
-    *q;
+    i;
 
   size_t
     length;
@@ -1473,7 +1460,7 @@ static MagickBooleanType RenderFreetype(Image *image,const DrawInfo *draw_info,
       if (image->storage_class != DirectClass)
         (void) SetImageStorageClass(image,DirectClass);
       if (image->matte == MagickFalse)
-        (void) SetImageOpacity(image,OpaqueOpacity);
+        (void) SetImageAlphaChannel(image,ResetAlphaChannel);
     }
   point.x=0.0;
   point.y=0.0;
@@ -1534,36 +1521,57 @@ static MagickBooleanType RenderFreetype(Image *image,const DrawInfo *draw_info,
     point.y=offset->y-bitmap->top;
     if (draw_info->render != MagickFalse)
       {
-        long
-          x_offset,
-          y_offset;
-
-        register unsigned char
-          *p;
+        MagickBooleanType
+          status;
 
         ViewInfo
-          *image_view;
+          **image_view;
 
         /*
           Rasterize the glyph.
         */
-        p=bitmap->bitmap.buffer;
-        image_view=AcquireCacheView(image);
+        status=MagickTrue;
+        image_view=AcquireCacheViewThreadSet(image);
+        #pragma omp parallel for
         for (y=0; y < (long) bitmap->bitmap.rows; y++)
         {
+          long
+            x_offset,
+            y_offset;
+
+          MagickBooleanType
+            active;
+
+          MagickRealType
+            fill_opacity;
+
+          PixelPacket
+            fill_color;
+
+          register long
+            id,
+            x;
+
+          register PixelPacket
+            *q;
+
+          register unsigned char
+            *p;
+
+          if (status == MagickFalse)
+            continue;
           x_offset=(long) (point.x+0.5);
           y_offset=(long) (point.y+y+0.5);
           if ((y_offset < 0) || (y_offset >= (long) image->rows))
-            {
-              p+=bitmap->bitmap.width;
-              continue;
-            }
-          q=GetCacheViewPixels(image_view,x_offset,y_offset,
+            continue;
+          id=GetCacheViewThreadId();
+          q=GetCacheViewPixels(image_view[id],x_offset,y_offset,
             bitmap->bitmap.width,1);
           active=q != (PixelPacket *) NULL ? MagickTrue : MagickFalse;
+          p=bitmap->bitmap.buffer+y*bitmap->bitmap.width;
           for (x=0; x < (long) bitmap->bitmap.width; x++)
           {
-            x_offset=(long) (point.x+x+0.5);
+            x_offset++;
             if ((*p == 0) || (x_offset < 0) ||
                 (x_offset >= (long) image->columns))
               {
@@ -1575,7 +1583,7 @@ static MagickBooleanType RenderFreetype(Image *image,const DrawInfo *draw_info,
             if (draw_info->text_antialias == MagickFalse)
               fill_opacity=fill_opacity > 0.5 ? 1.0 : 0.0;
             if (active == MagickFalse)
-              q=GetCacheViewPixels(image_view,x_offset,y_offset,1,1);
+              q=GetCacheViewPixels(image_view[id],x_offset,y_offset,1,1);
             if (q == (PixelPacket *) NULL)
               {
                 p++;
@@ -1586,15 +1594,16 @@ static MagickBooleanType RenderFreetype(Image *image,const DrawInfo *draw_info,
             fill_opacity=QuantumRange-fill_opacity*(QuantumRange-
               fill_color.opacity);
             MagickCompositeOver(&fill_color,fill_opacity,q,q->opacity,q);
-            if (active == MagickFalse)
-              (void) SyncCacheView(image_view);
+            if ((active == MagickFalse) &&
+                (SyncCacheView(image_view[id]) == MagickFalse))
+              status=MagickFalse;
             p++;
             q++;
           }
-          if (SyncCacheView(image_view) == MagickFalse)
-            break;
+          if (SyncCacheView(image_view[id]) == MagickFalse)
+            status=MagickFalse;
         }
-        image_view=DestroyCacheView(image_view);
+        image_view=DestroyCacheViewThreadSet(image_view);
       }
     if ((bitmap->left+bitmap->bitmap.width) > metrics->width)
       metrics->width=bitmap->left+bitmap->bitmap.width;
@@ -1925,9 +1934,9 @@ static MagickBooleanType RenderPostscript(Image *image,
         Render fill color.
       */
       if (image->matte == MagickFalse)
-        (void) SetImageOpacity(image,OpaqueOpacity);
+        (void) SetImageAlphaChannel(image,ResetAlphaChannel);
       if (annotate_image->matte == MagickFalse)
-        (void) SetImageOpacity(annotate_image,OpaqueOpacity);
+        (void) SetImageAlphaChannel(annotate_image,ResetAlphaChannel);
       fill_color=draw_info->fill;
       annotate_view=AcquireCacheView(annotate_image);
       for (y=0; y < (long) annotate_image->rows; y++)
