@@ -81,6 +81,50 @@ struct _ViewInfo
 %                                                                             %
 %                                                                             %
 %                                                                             %
+%   A c q u i r e C a c h e V i e w                                           %
+%                                                                             %
+%                                                                             %
+%                                                                             %
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%
+%  AcquireCacheView() acquires a view into the pixel cache, using the
+%  VirtualPixelMethod that is defined within the given image itself.
+%
+%  The format of the AcquireCacheView method is:
+%
+%      ViewInfo *AcquireCacheView(const Image *image)
+%
+%  A description of each parameter follows:
+%
+%    o image: the image.
+%
+*/
+MagickExport ViewInfo *AcquireCacheView(const Image *image)
+{
+  ViewInfo
+    *cache_view;
+
+  assert(image != (Image *) NULL);
+  assert(image->signature == MagickSignature);
+  if (image->debug != MagickFalse)
+    (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",image->filename);
+  cache_view=(ViewInfo *) AcquireMagickMemory(sizeof(*cache_view));
+  if (cache_view == (ViewInfo *) NULL)
+    ThrowFatalException(ResourceLimitFatalError,"MemoryAllocationFailed");
+  (void) ResetMagickMemory(cache_view,0,sizeof(*cache_view));
+  cache_view->image=ReferenceImage((Image *) image);
+  cache_view->id=GetNexus(cache_view->image->cache);
+  cache_view->virtual_pixel_method=GetImageVirtualPixelMethod(image);
+  cache_view->debug=IsEventLogging();
+  cache_view->signature=MagickSignature;
+  return(cache_view);
+}
+
+/*
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%                                                                             %
+%                                                                             %
+%                                                                             %
 %   A c q u i r e C a c h e V i e w I n d e x e s                             %
 %                                                                             %
 %                                                                             %
@@ -92,23 +136,23 @@ struct _ViewInfo
 %
 %  The format of the AcquireCacheViewIndexes method is:
 %
-%      const IndexPacket *AcquireCacheViewIndexes(const ViewInfo *view_info)
+%      const IndexPacket *AcquireCacheViewIndexes(const ViewInfo *cache_view)
 %
 %  A description of each parameter follows:
 %
-%    o view_info: The address of a structure of type ViewInfo.
+%    o cache_view: the cache view.
 %
 */
 MagickExport const IndexPacket *AcquireCacheViewIndexes(
-  const ViewInfo *view_info)
+  const ViewInfo *cache_view)
 {
-  assert(view_info != (ViewInfo *) NULL);
-  assert(view_info->signature == MagickSignature);
-  assert(view_info->image != (Image *) NULL);
-  if (view_info->debug != MagickFalse)
+  assert(cache_view != (ViewInfo *) NULL);
+  assert(cache_view->signature == MagickSignature);
+  assert(cache_view->image != (Image *) NULL);
+  if (cache_view->debug != MagickFalse)
     (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",
-      view_info->image->filename);
-  return(AcquireNexusIndexes(view_info->image->cache,view_info->id));
+      cache_view->image->filename);
+  return(AcquireNexusIndexes(cache_view->image->cache,cache_view->id));
 }
 
 /*
@@ -128,13 +172,13 @@ MagickExport const IndexPacket *AcquireCacheViewIndexes(
 %
 %  The format of the AcquireCacheViewPixels method is:
 %
-%      const PixelPacket *AcquireCacheViewPixels(const ViewInfo *view_info,
+%      const PixelPacket *AcquireCacheViewPixels(const ViewInfo *cache_view,
 %        const long x,const long y,const unsigned long columns,
 %        const unsigned long rows,ExceptionInfo *exception)
 %
 %  A description of each parameter follows:
 %
-%    o view_info: The address of a structure of type ViewInfo.
+%    o cache_view: the cache view.
 %
 %    o x,y,columns,rows:  These values define the perimeter of a region of
 %      pixels.
@@ -143,20 +187,20 @@ MagickExport const IndexPacket *AcquireCacheViewIndexes(
 %
 */
 MagickExport const PixelPacket *AcquireCacheViewPixels(
-  const ViewInfo *view_info,const long x,const long y,
+  const ViewInfo *cache_view,const long x,const long y,
   const unsigned long columns,const unsigned long rows,ExceptionInfo *exception)
 {
   const PixelPacket
     *pixels;
 
-  assert(view_info != (ViewInfo *) NULL);
-  assert(view_info->signature == MagickSignature);
-  assert(view_info->image != (Image *) NULL);
-  if (view_info->debug != MagickFalse)
+  assert(cache_view != (ViewInfo *) NULL);
+  assert(cache_view->signature == MagickSignature);
+  assert(cache_view->image != (Image *) NULL);
+  if (cache_view->debug != MagickFalse)
     (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",
-      view_info->image->filename);
-  pixels=AcquireCacheNexus(view_info->image,view_info->virtual_pixel_method,x,y,
-    columns,rows,view_info->id,exception);
+      cache_view->image->filename);
+  pixels=AcquireCacheNexus(cache_view->image,cache_view->virtual_pixel_method,
+    x,y,columns,rows,cache_view->id,exception);
   return(pixels);
 }
 
@@ -165,40 +209,143 @@ MagickExport const PixelPacket *AcquireCacheViewPixels(
 %                                                                             %
 %                                                                             %
 %                                                                             %
+%   A c q u i r e C a c h e V i e w T h r e a d S e t                         %
+%                                                                             %
+%                                                                             %
+%                                                                             %
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%
+%  AcquireCacheViewThreadSet() acquires a set of views, one for each possible
+%  thread.
+%
+%  The format of the AcquireCacheViewThreadSet method is:
+%
+%      ViewInfo **AcquireCacheViewThreadSet(const Image *image)
+%
+%  A description of each parameter follows:
+%
+%    o image: the image.
+%
+*/
+MagickExport ViewInfo **AcquireCacheViewThreadSet(const Image *image)
+{
+  register long
+    i;
+
+  ViewInfo
+    **cache_views;
+
+  assert(image != (Image *) NULL);
+  assert(image->signature == MagickSignature);
+  if (image->debug != MagickFalse)
+    (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",image->filename);
+  cache_views=(ViewInfo **) AcquireQuantumMemory(GetCacheViewMaximumThreads(),
+    sizeof(**cache_views));
+  if (cache_views == (ViewInfo **) NULL)
+    ThrowFatalException(ResourceLimitFatalError,"MemoryAllocationFailed");
+  for (i=0; i < (long) GetCacheViewMaximumThreads(); i++)
+    cache_views[i]=AcquireCacheView(image);
+  return(cache_views);
+}
+
+/*
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%                                                                             %
+%                                                                             %
+%                                                                             %
 %   A c q u i r e O n e C a c h e V i e w P i x e l                           %
 %                                                                             %
 %                                                                             %
 %                                                                             %
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
-%  AcquireCacheViewPixels() returns a single pixel at the specified (x,y) location.
-%  The image background color is returned if an error occurs.  If you plan to
-%  modify the pixel, use GetOneCacheViewPixel() instead.
+%  AcquireCacheViewPixels() returns a single pixel at the specified (x,y)
+%  location.  The image background color is returned if an error occurs.  If
+%  you plan to modify the pixel, use GetOneCacheViewPixel() instead.
 %
 %  The format of the AcquireOneCacheViewPixel method is:
 %
-%      PixelPacket AcquireOneCacheViewPixel(const ViewInfo *view_info,
+%      PixelPacket AcquireOneCacheViewPixel(const ViewInfo *cache_view,
 %        const long x,const long y,ExceptionInfo *exception)
 %
 %  A description of each parameter follows:
 %
-%    o view_info: The address of a structure of type ViewInfo.
+%    o cache_view: the cache view.
 %
 %    o x,y:  These values define the offset of the pixel.
 %
 %    o exception: Return any errors or warnings in this structure.
 %
 */
-MagickExport PixelPacket AcquireOneCacheViewPixel(const ViewInfo *view_info,
+MagickExport PixelPacket AcquireOneCacheViewPixel(const ViewInfo *cache_view,
   const long x,const long y,ExceptionInfo *exception)
 {
-  assert(view_info != (ViewInfo *) NULL);
-  assert(view_info->signature == MagickSignature);
-  assert(view_info->image != (Image *) NULL);
-  if (view_info->debug != MagickFalse)
+  const PixelPacket
+    *pixels;
+
+  assert(cache_view != (ViewInfo *) NULL);
+  assert(cache_view->signature == MagickSignature);
+  assert(cache_view->image != (Image *) NULL);
+  if (cache_view->debug != MagickFalse)
     (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",
-      view_info->image->filename);
-  return(AcquireOnePixel(view_info->image,x,y,exception));
+      cache_view->image->filename);
+  pixels=AcquireCacheNexus(cache_view->image,cache_view->virtual_pixel_method,
+    x,y,1,1,cache_view->id,exception);
+  if (pixels == (const PixelPacket *) NULL)
+    return(cache_view->image->background_color);
+  return(*pixels);
+}
+
+/*
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%                                                                             %
+%                                                                             %
+%                                                                             %
+%   A c q u i r e O n e C a c h e V i e w V i r t u a l P i x e l             %
+%                                                                             %
+%                                                                             %
+%                                                                             %
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%
+%  AcquireCacheViewPixels() returns a single pixel at the specified (x,y)
+%  location.  The image background color is returned if an error occurs.  If
+%  you plan to modify the pixel, use GetOneCacheViewPixel() instead.
+%
+%  The format of the AcquireOneCacheViewPixel method is:
+%
+%      PixelPacket AcquireOneCacheViewVirtualPixel(const ViewInfo *cache_view,
+%        const VirtualPixelMethod virtual_pixel_method,const long x,
+%        const long y,ExceptionInfo *exception)
+%
+%  A description of each parameter follows:
+%
+%    o cache_view: the cache view.
+%
+%    o virtual_pixel_method: the virtual pixel method.
+%
+%    o x,y:  These values define the offset of the pixel.
+%
+%    o exception: Return any errors or warnings in this structure.
+%
+*/
+MagickExport PixelPacket AcquireOneCacheViewVirtualPixel(
+  const ViewInfo *cache_view,const VirtualPixelMethod virtual_pixel_method,
+  const long x,const long y,ExceptionInfo *exception)
+{
+  const PixelPacket
+    *pixels;
+
+  assert(cache_view != (ViewInfo *) NULL);
+  assert(cache_view->signature == MagickSignature);
+  assert(cache_view->image != (Image *) NULL);
+  if (cache_view->debug != MagickFalse)
+    (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",
+      cache_view->image->filename);
+  pixels=AcquireCacheNexus(cache_view->image,virtual_pixel_method,x,y,1,1,
+    cache_view->id,exception);
+  if (pixels == (const PixelPacket *) NULL)
+    return(cache_view->image->background_color);
+  return(*pixels);
 }
 
 /*
@@ -216,31 +363,31 @@ MagickExport PixelPacket AcquireOneCacheViewPixel(const ViewInfo *view_info,
 %
 %  The format of the CloneCacheView method is:
 %
-%      ViewInfo *CloneCacheView(const ViewInfo *view_info)
+%      ViewInfo *CloneCacheView(const ViewInfo *cache_view)
 %
 %  A description of each parameter follows:
 %
-%    o view_info: The cache view.
+%    o cache_view: the cache view.
 %
 */
-MagickExport ViewInfo *CloneCacheView(const ViewInfo *view_info)
+MagickExport ViewInfo *CloneCacheView(const ViewInfo *cache_view)
 {
   ViewInfo
     *clone_view;
 
-  assert(view_info != (ViewInfo *) NULL);
-  assert(view_info->signature == MagickSignature);
-  if (view_info->debug != MagickFalse)
+  assert(cache_view != (ViewInfo *) NULL);
+  assert(cache_view->signature == MagickSignature);
+  if (cache_view->debug != MagickFalse)
     (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",
-      view_info->image->filename);
+      cache_view->image->filename);
   clone_view=(ViewInfo *) AcquireMagickMemory(sizeof(*clone_view));
   if (clone_view == (ViewInfo *) NULL)
     ThrowFatalException(ResourceLimitFatalError,"MemoryAllocationFailed");
   (void) ResetMagickMemory(clone_view,0,sizeof(*clone_view));
-  clone_view->image=ReferenceImage(view_info->image);
+  clone_view->image=ReferenceImage(cache_view->image);
   clone_view->id=GetNexus(clone_view->image->cache);
-  clone_view->virtual_pixel_method=view_info->virtual_pixel_method;
-  clone_view->debug=view_info->debug;
+  clone_view->virtual_pixel_method=cache_view->virtual_pixel_method;
+  clone_view->debug=cache_view->debug;
   clone_view->signature=MagickSignature;
   return(clone_view);
 }
@@ -250,38 +397,72 @@ MagickExport ViewInfo *CloneCacheView(const ViewInfo *view_info)
 %                                                                             %
 %                                                                             %
 %                                                                             %
-%   C l o s e C a c h e V i e w                                               %
+%   D e s t r o y C a c h e V i e w                                           %
 %                                                                             %
 %                                                                             %
 %                                                                             %
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
-%  CloseCacheView() closes the specified view returned by a previous call to
-%  OpenCacheView().
+%  DestroyCacheView() destroy the specified view returned by a previous call to
+%  AcquireCacheView().
 %
-%  The format of the CloseCacheView method is:
+%  The format of the DestroyCacheView method is:
 %
-%      ViewInfo *CloseCacheView(ViewInfo *view_info)
+%      ViewInfo *DestroyCacheView(ViewInfo *cache_view)
 %
 %  A description of each parameter follows:
 %
-%    o view_info: The address of a structure of type ViewInfo.
+%    o cache_view: the cache view.
 %
 */
-MagickExport ViewInfo *CloseCacheView(ViewInfo *view_info)
+MagickExport ViewInfo *DestroyCacheView(ViewInfo *cache_view)
 {
-  assert(view_info != (ViewInfo *) NULL);
-  assert(view_info->signature == MagickSignature);
-  assert(view_info->image != (Image *) NULL);
-  if (view_info->debug != MagickFalse)
+  assert(cache_view != (ViewInfo *) NULL);
+  assert(cache_view->signature == MagickSignature);
+  assert(cache_view->image != (Image *) NULL);
+  if (cache_view->debug != MagickFalse)
     (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",
-      view_info->image->filename);
-  if (view_info->id != 0)
-    DestroyCacheNexus(view_info->image->cache,view_info->id);
-  view_info->image=DestroyImage(view_info->image);
-  view_info->signature=(~MagickSignature);
-  view_info=(ViewInfo *) RelinquishMagickMemory(view_info);
-  return(view_info);
+      cache_view->image->filename);
+  if (cache_view->id != 0)
+    DestroyCacheNexus(cache_view->image->cache,cache_view->id);
+  cache_view->image=DestroyImage(cache_view->image);
+  cache_view->signature=(~MagickSignature);
+  cache_view=(ViewInfo *) RelinquishMagickMemory(cache_view);
+  return(cache_view);
+}
+
+/*
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%                                                                             %
+%                                                                             %
+%                                                                             %
+%   D e s t r o y C a c h e V i e w T h r e a d S e t                         %
+%                                                                             %
+%                                                                             %
+%                                                                             %
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%
+%  DestroyCacheViewThreadSet() destroys a set of cache views previously
+%  acquired from the AcquireCacheViewThreadSet() method.
+%
+%  The format of the DestoryCacheViewSet method is:
+%
+%      ViewInfo **DestroyCacheViewThreadSet(ViewInfo **cache_view)
+%
+%  A description of each parameter follows:
+%
+%    o cache_view: the cache views.
+%
+*/
+MagickExport ViewInfo **DestroyCacheViewThreadSet(ViewInfo **cache_views)
+{
+  register long
+    i;
+
+  assert(cache_views != (ViewInfo **) NULL);
+  for (i=0; i < (long) GetCacheViewMaximumThreads(); i++)
+    cache_views[i]=DestroyCacheView(cache_views[i]);
+  return((ViewInfo **) RelinquishMagickMemory(cache_views));
 }
 
 /*
@@ -300,22 +481,22 @@ MagickExport ViewInfo *CloseCacheView(ViewInfo *view_info)
 %
 %  The format of the GetCacheViewColorspace method is:
 %
-%      ColorspaceType GetCacheViewColorspace(const ViewInfo *view_info)
+%      ColorspaceType GetCacheViewColorspace(const ViewInfo *cache_view)
 %
 %  A description of each parameter follows:
 %
-%    o view_info: The address of a structure of type ViewInfo.
+%    o cache_view: the cache view.
 %
 */
-MagickExport ColorspaceType GetCacheViewColorspace(const ViewInfo *view_info)
+MagickExport ColorspaceType GetCacheViewColorspace(const ViewInfo *cache_view)
 {
-  assert(view_info != (ViewInfo *) NULL);
-  assert(view_info->signature == MagickSignature);
-  assert(view_info->image != (Image *) NULL);
-  if (view_info->debug != MagickFalse)
+  assert(cache_view != (ViewInfo *) NULL);
+  assert(cache_view->signature == MagickSignature);
+  assert(cache_view->image != (Image *) NULL);
+  if (cache_view->debug != MagickFalse)
     (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",
-      view_info->image->filename);
-  return(view_info->image->colorspace);
+      cache_view->image->filename);
+  return(cache_view->image->colorspace);
 }
 
 /*
@@ -334,22 +515,22 @@ MagickExport ColorspaceType GetCacheViewColorspace(const ViewInfo *view_info)
 %
 %  The format of the GetCacheViewException method is:
 %
-%      ExceptionInfo GetCacheViewException(const ViewInfo *view_info)
+%      ExceptionInfo GetCacheViewException(const ViewInfo *cache_view)
 %
 %  A description of each parameter follows:
 %
-%    o view_info: The address of a structure of type ViewInfo.
+%    o cache_view: the cache view.
 %
 */
-MagickExport ExceptionInfo *GetCacheViewException(const ViewInfo *view_info)
+MagickExport ExceptionInfo *GetCacheViewException(const ViewInfo *cache_view)
 {
-  assert(view_info != (ViewInfo *) NULL);
-  assert(view_info->signature == MagickSignature);
-  assert(view_info->image != (Image *) NULL);
-  if (view_info->debug != MagickFalse)
+  assert(cache_view != (ViewInfo *) NULL);
+  assert(cache_view->signature == MagickSignature);
+  assert(cache_view->image != (Image *) NULL);
+  if (cache_view->debug != MagickFalse)
     (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",
-      view_info->image->filename);
-  return(&view_info->image->exception);
+      cache_view->image->filename);
+  return(&cache_view->image->exception);
 }
 
 /*
@@ -368,22 +549,22 @@ MagickExport ExceptionInfo *GetCacheViewException(const ViewInfo *view_info)
 %
 %  The format of the GetCacheViewIndexes method is:
 %
-%      IndexPacket *GetCacheViewIndexes(const ViewInfo *view_info)
+%      IndexPacket *GetCacheViewIndexes(const ViewInfo *cache_view)
 %
 %  A description of each parameter follows:
 %
-%    o view_info: The address of a structure of type ViewInfo.
+%    o cache_view: the cache view.
 %
 */
-MagickExport IndexPacket *GetCacheViewIndexes(const ViewInfo *view_info)
+MagickExport IndexPacket *GetCacheViewIndexes(const ViewInfo *cache_view)
 {
-  assert(view_info != (ViewInfo *) NULL);
-  assert(view_info->signature == MagickSignature);
-  assert(view_info->image != (Image *) NULL);
-  if (view_info->debug != MagickFalse)
+  assert(cache_view != (ViewInfo *) NULL);
+  assert(cache_view->signature == MagickSignature);
+  assert(cache_view->image != (Image *) NULL);
+  if (cache_view->debug != MagickFalse)
     (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",
-      view_info->image->filename);
-  return(GetNexusIndexes(view_info->image->cache,view_info->id));
+      cache_view->image->filename);
+  return(GetNexusIndexes(cache_view->image->cache,cache_view->id));
 }
 
 /*
@@ -403,27 +584,27 @@ MagickExport IndexPacket *GetCacheViewIndexes(const ViewInfo *view_info)
 %
 %  The format of the GetCacheViewPixels method is:
 %
-%      PixelPacket *GetCacheViewPixels(ViewInfo *view_info,const long x,
+%      PixelPacket *GetCacheViewPixels(ViewInfo *cache_view,const long x,
 %        const long y,const unsigned long columns,const unsigned long rows)
 %
 %  A description of each parameter follows:
 %
-%    o view_info: The address of a structure of type ViewInfo.
+%    o cache_view: the cache view.
 %
 %    o x,y,columns,rows:  These values define the perimeter of a region of
 %      pixels.
 %
 */
-MagickExport PixelPacket *GetCacheViewPixels(ViewInfo *view_info,const long x,
+MagickExport PixelPacket *GetCacheViewPixels(ViewInfo *cache_view,const long x,
   const long y,const unsigned long columns,const unsigned long rows)
 {
-  assert(view_info != (ViewInfo *) NULL);
-  assert(view_info->signature == MagickSignature);
-  assert(view_info->image != (Image *) NULL);
-  if (view_info->debug != MagickFalse)
+  assert(cache_view != (ViewInfo *) NULL);
+  assert(cache_view->signature == MagickSignature);
+  assert(cache_view->image != (Image *) NULL);
+  if (cache_view->debug != MagickFalse)
     (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",
-      view_info->image->filename);
-  return(GetCacheNexus(view_info->image,x,y,columns,rows,view_info->id));
+      cache_view->image->filename);
+  return(GetCacheNexus(cache_view->image,x,y,columns,rows,cache_view->id));
 }
 
 /*
@@ -442,22 +623,22 @@ MagickExport PixelPacket *GetCacheViewPixels(ViewInfo *view_info,const long x,
 %
 %  The format of the GetCacheViewStorageClass method is:
 %
-%      ClassType GetCacheViewStorageClass(const ViewInfo *view_info)
+%      ClassType GetCacheViewStorageClass(const ViewInfo *cache_view)
 %
 %  A description of each parameter follows:
 %
-%    o view_info: The address of a structure of type ViewInfo.
+%    o cache_view: the cache view.
 %
 */
-MagickExport ClassType GetCacheViewStorageClass(const ViewInfo *view_info)
+MagickExport ClassType GetCacheViewStorageClass(const ViewInfo *cache_view)
 {
-  assert(view_info != (ViewInfo *) NULL);
-  assert(view_info->signature == MagickSignature);
-  assert(view_info->image != (Image *) NULL);
-  if (view_info->debug != MagickFalse)
+  assert(cache_view != (ViewInfo *) NULL);
+  assert(cache_view->signature == MagickSignature);
+  assert(cache_view->image != (Image *) NULL);
+  if (cache_view->debug != MagickFalse)
     (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",
-      view_info->image->filename);
-  return(view_info->image->storage_class);
+      cache_view->image->filename);
+  return(cache_view->image->storage_class);
 }
 
 /*
@@ -476,26 +657,26 @@ MagickExport ClassType GetCacheViewStorageClass(const ViewInfo *view_info)
 %
 %  The format of the GetOneCacheViewPixel method is:
 %
-%      PixelPacket GetOneCacheViewPixel(const ViewInfo *view_info,
+%      PixelPacket GetOneCacheViewPixel(const ViewInfo *cache_view,
 %        const long x,const long y)
 %
 %  A description of each parameter follows:
 %
-%    o view_info: The address of a structure of type ViewInfo.
+%    o cache_view: the cache view.
 %
 %    o x,y:  These values define the offset of the pixel.
 %
 */
-MagickExport PixelPacket GetOneCacheViewPixel(const ViewInfo *view_info,
+MagickExport PixelPacket GetOneCacheViewPixel(const ViewInfo *cache_view,
   const long x,const long y)
 {
-  assert(view_info != (ViewInfo *) NULL);
-  assert(view_info->signature == MagickSignature);
-  assert(view_info->image != (Image *) NULL);
-  if (view_info->debug != MagickFalse)
+  assert(cache_view != (ViewInfo *) NULL);
+  assert(cache_view->signature == MagickSignature);
+  assert(cache_view->image != (Image *) NULL);
+  if (cache_view->debug != MagickFalse)
     (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",
-      view_info->image->filename);
-  return(GetOnePixel(view_info->image,x,y));
+      cache_view->image->filename);
+  return(GetOnePixel(cache_view->image,x,y));
 }
 
 /*
@@ -503,83 +684,46 @@ MagickExport PixelPacket GetOneCacheViewPixel(const ViewInfo *view_info,
 %                                                                             %
 %                                                                             %
 %                                                                             %
-%   O p e n C a c h e V i e w                                                 %
+%   S e t C a c h e V i e w P i x e l s                                       %
 %                                                                             %
 %                                                                             %
 %                                                                             %
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
-%  OpenCacheView() opens a view into the pixel cache, using the
-%  VirtualPixelMethod that is defined within the given image itself.
-%
-%  The format of the OpenCacheView method is:
-%
-%      ViewInfo *OpenCacheView(const Image *image)
-%
-%  A description of each parameter follows:
-%
-%    o image: The image.
-%
-*/
-MagickExport ViewInfo *OpenCacheView(const Image *image)
-{
-  ViewInfo
-    *view_info;
-
-  assert(image != (Image *) NULL);
-  assert(image->signature == MagickSignature);
-  if (image->debug != MagickFalse)
-    (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",image->filename);
-  view_info=(ViewInfo *) AcquireMagickMemory(sizeof(*view_info));
-  if (view_info == (ViewInfo *) NULL)
-    ThrowFatalException(ResourceLimitFatalError,"MemoryAllocationFailed");
-  (void) ResetMagickMemory(view_info,0,sizeof(*view_info));
-  view_info->image=ReferenceImage((Image *) image);
-  view_info->id=GetNexus(view_info->image->cache);
-  view_info->virtual_pixel_method=GetImageVirtualPixelMethod(image);
-  view_info->debug=IsEventLogging();
-  view_info->signature=MagickSignature;
-  return(view_info);
-}
-
-/*
-%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
-%                                                                             %
-%                                                                             %
-%                                                                             %
-%   S e t C a c h e V i e w                                                   %
-%                                                                             %
-%                                                                             %
-%                                                                             %
-%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
-%
-%  SetCacheView() gets pixels from the in-memory or disk pixel cache as
+%  SetCacheViewPixels() gets pixels from the in-memory or disk pixel cache as
 %  defined by the geometry parameters.   A pointer to the pixels is returned
 %  if the pixels are transferred, otherwise a NULL is returned.
 %
 %  The format of the SetCacheView method is:
 %
-%      PixelPacket *SetCacheView(ViewInfo *view_info,const long x,const long y,
-%        const unsigned long columns,const unsigned long rows)
+%      PixelPacket *SetCacheViewPixels(ViewInfo *cache_view,const long x,
+%        const long y,const unsigned long columns,const unsigned long rows)
 %
 %  A description of each parameter follows:
 %
-%    o view_info: The address of a structure of type ViewInfo.
+%    o cache_view: the cache view.
 %
 %    o x,y,columns,rows:  These values define the perimeter of a region of
 %      pixels.
 %
 */
-MagickExport PixelPacket *SetCacheView(ViewInfo *view_info,const long x,
+
+MagickExport PixelPacket *SetCacheView(ViewInfo *cache_view,const long x,
   const long y,const unsigned long columns,const unsigned long rows)
 {
-  assert(view_info != (ViewInfo *) NULL);
-  assert(view_info->signature == MagickSignature);
-  assert(view_info->image != (Image *) NULL);
-  if (view_info->debug != MagickFalse)
+  return(SetCacheViewPixels(cache_view,x,y,columns,rows));
+}
+
+MagickExport PixelPacket *SetCacheViewPixels(ViewInfo *cache_view,const long x,
+  const long y,const unsigned long columns,const unsigned long rows)
+{
+  assert(cache_view != (ViewInfo *) NULL);
+  assert(cache_view->signature == MagickSignature);
+  assert(cache_view->image != (Image *) NULL);
+  if (cache_view->debug != MagickFalse)
     (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",
-      view_info->image->filename);
-  return(SetCacheNexus(view_info->image,x,y,columns,rows,view_info->id));
+      cache_view->image->filename);
+  return(SetCacheNexus(cache_view->image,x,y,columns,rows,cache_view->id));
 }
 
 /*
@@ -598,26 +742,26 @@ MagickExport PixelPacket *SetCacheView(ViewInfo *view_info,const long x,
 %
 %  The format of the SetCacheViewStorageClass method is:
 %
-%      MagickBooleanType SetCacheViewStorageClass(ViewInfo *view_info,
+%      MagickBooleanType SetCacheViewStorageClass(ViewInfo *cache_view,
 %        const ClassType storage_class)
 %
 %  A description of each parameter follows:
 %
-%    o view_info: The address of a structure of type ViewInfo.
+%    o cache_view: the cache view.
 %
-%    o storage_class: The image storage class: PseudoClass or DirectClass.
+%    o storage_class: the image storage class: PseudoClass or DirectClass.
 %
 */
-MagickExport MagickBooleanType SetCacheViewStorageClass(ViewInfo *view_info,
+MagickExport MagickBooleanType SetCacheViewStorageClass(ViewInfo *cache_view,
   const ClassType storage_class)
 {
-  assert(view_info != (ViewInfo *) NULL);
-  assert(view_info->signature == MagickSignature);
-  assert(view_info->image != (Image *) NULL);
-  if (view_info->debug != MagickFalse)
+  assert(cache_view != (ViewInfo *) NULL);
+  assert(cache_view->signature == MagickSignature);
+  assert(cache_view->image != (Image *) NULL);
+  if (cache_view->debug != MagickFalse)
     (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",
-      view_info->image->filename);
-  return(SetImageStorageClass(view_info->image,storage_class));
+      cache_view->image->filename);
+  return(SetImageStorageClass(cache_view->image,storage_class));
 }
 
 /*
@@ -636,26 +780,26 @@ MagickExport MagickBooleanType SetCacheViewStorageClass(ViewInfo *view_info,
 %
 %  The format of the SetCacheViewVirtualPixelMethod method is:
 %
-%      MagickBooleanType SetCacheViewVirtualPixelMethod(ViewInfo *view_info,
+%      MagickBooleanType SetCacheViewVirtualPixelMethod(ViewInfo *cache_view,
 %        const VirtualPixelMethod virtual_pixel_method)
 %
 %  A description of each parameter follows:
 %
-%    o view_info: The address of a structure of type ViewInfo.
+%    o cache_view: the cache view.
 %
-%    o virtual_pixel_method: The virtual pixel method.
+%    o virtual_pixel_method: the virtual pixel method.
 %
 */
 MagickExport MagickBooleanType SetCacheViewVirtualPixelMethod(
-  ViewInfo *view_info,const VirtualPixelMethod virtual_pixel_method)
+  ViewInfo *cache_view,const VirtualPixelMethod virtual_pixel_method)
 {
-  assert(view_info != (ViewInfo *) NULL);
-  assert(view_info->signature == MagickSignature);
-  assert(view_info->image != (Image *) NULL);
-  if (view_info->debug != MagickFalse)
+  assert(cache_view != (ViewInfo *) NULL);
+  assert(cache_view->signature == MagickSignature);
+  assert(cache_view->image != (Image *) NULL);
+  if (cache_view->debug != MagickFalse)
     (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",
-      view_info->image->filename);
-  view_info->virtual_pixel_method=virtual_pixel_method;
+      cache_view->image->filename);
+  cache_view->virtual_pixel_method=virtual_pixel_method;
   return(MagickTrue);
 }
 
@@ -670,26 +814,26 @@ MagickExport MagickBooleanType SetCacheViewVirtualPixelMethod(
 %                                                                             %
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
-%  SyncCacheView() saves the view_info pixels to the in-memory or disk cache.
+%  SyncCacheView() saves the cache_view pixels to the in-memory or disk cache.
 %  The method returns MagickTrue if the pixel region is synced, otherwise
 %  MagickFalse.
 %
 %  The format of the SyncCacheView method is:
 %
-%      MagickBooleanType SyncCacheView(ViewInfo *view_info)
+%      MagickBooleanType SyncCacheView(ViewInfo *cache_view)
 %
 %  A description of each parameter follows:
 %
-%    o view_info: The address of a structure of type ViewInfo.
+%    o cache_view: the cache view.
 %
 */
-MagickExport MagickBooleanType SyncCacheView(ViewInfo *view_info)
+MagickExport MagickBooleanType SyncCacheView(ViewInfo *cache_view)
 {
-  assert(view_info != (ViewInfo *) NULL);
-  assert(view_info->signature == MagickSignature);
-  assert(view_info->image != (Image *) NULL);
-  if (view_info->debug != MagickFalse)
+  assert(cache_view != (ViewInfo *) NULL);
+  assert(cache_view->signature == MagickSignature);
+  assert(cache_view->image != (Image *) NULL);
+  if (cache_view->debug != MagickFalse)
     (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",
-      view_info->image->filename);
-  return(SyncCacheNexus(view_info->image,view_info->id));
+      cache_view->image->filename);
+  return(SyncCacheNexus(cache_view->image,cache_view->id));
 }
