@@ -1,5 +1,5 @@
 /*
-  Copyright 1999-2007 ImageMagick Studio LLC, a non-profit organization
+  Copyright 1999-2008 ImageMagick Studio LLC, a non-profit organization
   dedicated to making software imaging solutions freely available.
   
   You may not use this file except in compliance with the License.
@@ -25,16 +25,18 @@ extern "C" {
 #include "magick/blob.h"
 
 extern MagickExport const PixelPacket
-  *AcquireCacheNexus(const Image *,const long,const long,const unsigned long,
-    const unsigned long,const unsigned long,ExceptionInfo *);
+  *AcquireCacheNexus(const Image *,const VirtualPixelMethod,const long,
+    const long,const unsigned long,const unsigned long,const unsigned long,
+    ExceptionInfo *);
 
 extern MagickExport MagickSizeType
-  GetPixelCacheArea(const Image *);
+  GetPixelCacheExtent(const Image *);
 
 extern MagickExport MagickBooleanType
   PersistCache(Image *,const char *,const MagickBooleanType,MagickOffsetType *,
     ExceptionInfo *),
-  SyncCacheNexus(Image *,const unsigned long);
+  SyncCacheNexus(Image *,const unsigned long),
+  SyncImagePixelCache(Image *);
 
 extern MagickExport PixelPacket
   *GetCacheNexus(Image *,const long,const long,const unsigned long,
@@ -43,8 +45,8 @@ extern MagickExport PixelPacket
     const unsigned long,const unsigned long);
 
 extern MagickExport VirtualPixelMethod
-  GetImageVirtualPixelMethod(const Image *),
-  SetImageVirtualPixelMethod(const Image *,const VirtualPixelMethod);
+  GetCacheVirtualPixelMethod(const Image *),
+  SetCacheVirtualPixelMethod(const Image *,const VirtualPixelMethod);
 
 extern MagickExport void
   DestroyCacheResources(void);
