@@ -42,6 +42,7 @@
 #include "magick/studio.h"
 #include "magick/property.h"
 #include "magick/cache.h"
+#include "magick/cache-view.h"
 #include "magick/color.h"
 #include "magick/color-private.h"
 #include "magick/colorspace.h"
@@ -152,9 +153,6 @@ MagickExport MagickBooleanType RGBTransformImage(Image *image,
   MagickBooleanType
     status;
 
-  MagickPixelPacket
-    pixel;
-
   PrimaryInfo
     primary_info,
     *x_map,
@@ -227,8 +225,11 @@ MagickExport MagickBooleanType RGBTransformImage(Image *image,
     }
     case CMYKColorspace:
     {
-      MagickPixelPacket
-        pixel;
+      MagickBooleanType
+        status;
+
+      ViewInfo
+        **image_view;
 
       /*
         Convert RGB to CMYK colorspace.
@@ -240,13 +241,35 @@ MagickExport MagickBooleanType RGBTransformImage(Image *image,
           if (SetImageStorageClass(image,DirectClass) == MagickFalse)
             return(MagickFalse);
         }
-      GetMagickPixelPacket(image,&pixel);
+      status=MagickTrue;
+      image_view=AcquireCacheViewThreadSet(image);
+      #pragma omp parallel for
       for (y=0; y < (long) image->rows; y++)
       {
-        q=GetImagePixels(image,0,y,image->columns,1);
+        MagickPixelPacket
+          pixel;
+
+        register IndexPacket
+          *indexes;
+
+        register long
+          id,
+          x;
+
+        register PixelPacket
+          *q;
+
+    if (status == MagickFalse)
+      continue;
+        id=GetCacheViewThreadId();
+        q=GetCacheViewPixels(image_view[id],0,y,image->columns,1);
         if (q == (PixelPacket *) NULL)
-          break;
-        indexes=GetIndexes(image);
+          {
+            status=MagickFalse;
+            continue;
+          }
+        indexes=GetCacheViewIndexes(image_view[id]);
+        GetMagickPixelPacket(image,&pixel);
         for (x=0; x < (long) image->columns; x++)
         {
           SetMagickPixelPacket(image,q,indexes+x,&pixel);
@@ -254,12 +277,13 @@ MagickExport MagickBooleanType RGBTransformImage(Image *image,
           SetPixelPacket(image,&pixel,q,indexes+x);
           q++;
         }
-        if (SyncImagePixels(image) == MagickFalse)
-          break;
+        if (SyncCacheView(image_view[id]) == MagickFalse)
+          status=MagickFalse;
       }
+      image_view=DestroyCacheViewThreadSet(image_view);
       image->type=image->matte == MagickFalse ? ColorSeparationType :
         ColorSeparationMatteType;
-      return(MagickTrue);
+      return(status);
     }
     case HSBColorspace:
     {
@@ -781,8 +805,8 @@ MagickExport MagickBooleanType RGBTransformImage(Image *image,
         x_map[i].x=0.299000*i;
         y_map[i].x=0.587000*i;
         z_map[i].x=0.114000*i;
-        y_map[i].y=(-0.331264)*i;
         x_map[i].y=(-0.168736)*i;
+        y_map[i].y=(-0.331264)*i;
         z_map[i].y=0.500000*i;
         x_map[i].z=0.500000*i;
         y_map[i].z=(-0.418688)*i;
@@ -829,6 +853,9 @@ MagickExport MagickBooleanType RGBTransformImage(Image *image,
     case DirectClass:
     default:
     {
+      MagickPixelPacket
+        pixel;
+
       /*
         Convert DirectClass image.
       */
@@ -868,6 +895,9 @@ MagickExport MagickBooleanType RGBTransformImage(Image *image,
     }
     case PseudoClass:
     {
+      MagickPixelPacket
+        pixel;
+
       /*
         Convert PseudoClass image.
       */
@@ -1718,9 +1748,14 @@ MagickExport MagickBooleanType TransformRGBImage(Image *image,
           {
             case YCCColorspace:
             {
-              pixel.red/=1.3584000f;
-              pixel.green/=1.3584000f;
-              pixel.blue/=1.3584000f;
+#if !defined(MAGICKCORE_HDRI_SUPPORT)
+              pixel.red=ScaleCharToQuantum(YCCMap[RoundToYCC(
+                255.0*QuantumScale*pixel.red)]);
+              pixel.green=ScaleCharToQuantum(YCCMap[RoundToYCC(
+                255.0*QuantumScale*pixel.green)]);
+              pixel.blue=ScaleCharToQuantum(YCCMap[RoundToYCC(
+                255.0*QuantumScale*pixel.blue)]);
+#endif
               break;
             }
             case sRGBColorspace:
@@ -1784,18 +1819,18 @@ MagickExport MagickBooleanType TransformRGBImage(Image *image,
           z_map[ScaleQuantumToMap(image->colormap[i].blue)].z;
         switch (colorspace)
         {
-#if !defined(MAGICKCORE_HDRI_SUPPORT)
           case YCCColorspace:
           {
+#if !defined(MAGICKCORE_HDRI_SUPPORT)
             image->colormap[i].red=ScaleCharToQuantum(YCCMap[RoundToYCC(
               255.0*QuantumScale*pixel.red)]);
             image->colormap[i].green=ScaleCharToQuantum(YCCMap[RoundToYCC(
               255.0*QuantumScale*pixel.green)]);
             image->colormap[i].blue=ScaleCharToQuantum(YCCMap[RoundToYCC(
               255.0*QuantumScale*pixel.blue)]);
+#endif
             break;
           }
-#endif
           case sRGBColorspace:
           {
             if ((QuantumScale*pixel.red) <= 0.0031308)
