@@ -124,36 +124,17 @@ MagickExport Image *CompareImageChannels(Image *image,
   long
     y;
 
+  MagickBooleanType
+    status;
+
   MagickPixelPacket
-    composite,
     highlight,
-    source,
     transparent;
 
-  MagickStatusType
-    difference;
-
-  register const IndexPacket
-    *indexes,
-    *reconstruct_indexes;
-
-  register const PixelPacket
-    *p,
-    *q;
-
-  register IndexPacket
-    *difference_indexes;
-
-  register long
-    x;
-
-  register PixelPacket
-    *r;
-
   ViewInfo
-    *difference_view,
-    *image_view,
-    *reconstruct_view;
+    **difference_view,
+    **image_view,
+    **reconstruct_view;
 
   assert(image != (Image *) NULL);
   assert(image->signature == MagickSignature);
@@ -191,23 +172,56 @@ MagickExport Image *CompareImageChannels(Image *image,
   /*
     Generate difference image.
   */
-  GetMagickPixelPacket(reconstruct_image,&source);
-  GetMagickPixelPacket(difference_image,&composite);
-  image_view=AcquireCacheView(image);
-  reconstruct_view=AcquireCacheView(reconstruct_image);
-  difference_view=AcquireCacheView(difference_image);
+  status=MagickTrue;
+  image_view=AcquireCacheViewThreadSet(image);
+  reconstruct_view=AcquireCacheViewThreadSet(reconstruct_image);
+  difference_view=AcquireCacheViewThreadSet(difference_image);
+  #pragma omp parallel for
   for (y=0; y < (long) image->rows; y++)
   {
-    p=AcquireCacheViewPixels(image_view,0,y,image->columns,1,exception);
-    q=AcquireCacheViewPixels(reconstruct_view,0,y,reconstruct_image->columns,1,
-      exception);
-    r=SetCacheViewPixels(difference_view,0,y,difference_image->columns,1);
+    MagickPixelPacket
+      composite,
+      source;
+
+    MagickStatusType
+      difference;
+
+    register const IndexPacket
+      *indexes,
+      *reconstruct_indexes;
+
+    register const PixelPacket
+      *p,
+      *q;
+
+    register IndexPacket
+      *difference_indexes;
+
+    register long
+      id,
+      x;
+
+    register PixelPacket
+      *r;
+
+    if (status == MagickFalse)
+      continue;
+    id=GetCacheViewThreadId();
+    p=AcquireCacheViewPixels(image_view[id],0,y,image->columns,1,exception);
+    q=AcquireCacheViewPixels(reconstruct_view[id],0,y,
+      reconstruct_image->columns,1,exception);
+    r=SetCacheViewPixels(difference_view[id],0,y,difference_image->columns,1);
     if ((p == (const PixelPacket *) NULL) ||
         (q == (const PixelPacket *) NULL) || (r == (PixelPacket *) NULL))
-      break;
-    indexes=AcquireCacheViewIndexes(image_view);
-    reconstruct_indexes=AcquireCacheViewIndexes(reconstruct_view);
-    difference_indexes=GetCacheViewIndexes(difference_view);
+      {
+        status=MagickFalse;
+        continue;
+      }
+    indexes=AcquireCacheViewIndexes(image_view[id]);
+    reconstruct_indexes=AcquireCacheViewIndexes(reconstruct_view[id]);
+    difference_indexes=GetCacheViewIndexes(difference_view[id]);
+    GetMagickPixelPacket(reconstruct_image,&source);
+    GetMagickPixelPacket(difference_image,&composite);
     for (x=0; x < (long) image->columns; x++)
     {
       difference=MagickFalse;
@@ -236,14 +250,16 @@ MagickExport Image *CompareImageChannels(Image *image,
       q++;
       r++;
     }
-    if (SyncCacheView(difference_view) == MagickFalse)
-      break;
+    if (SyncCacheView(difference_view[id]) == MagickFalse)
+      status=MagickFalse;
   }
-  difference_view=DestroyCacheView(difference_view);
-  reconstruct_view=DestroyCacheView(reconstruct_view);
-  image_view=DestroyCacheView(image_view);
+  difference_view=DestroyCacheViewThreadSet(difference_view);
+  reconstruct_view=DestroyCacheViewThreadSet(reconstruct_view);
+  image_view=DestroyCacheViewThreadSet(image_view);
   (void) GetImageChannelDistortion(image,reconstruct_image,channel,metric,
     distortion,exception);
+  if (status == MagickFalse)
+    difference_image=DestroyImage(difference_image);
   return(difference_image);
 }
 
@@ -363,38 +379,50 @@ static MagickRealType GetMeanAbsoluteError(const Image *image,
   long
     y;
 
+  MagickBooleanType
+    status;
+
   MagickRealType
     area,
     distortion;
 
-  register const IndexPacket
-    *indexes,
-    *reconstruct_indexes;
-
-  register const PixelPacket
-    *p,
-    *q;
-
-  register long
-    x;
-
   ViewInfo
-    *image_view,
-    *reconstruct_view;
+    **image_view,
+    **reconstruct_view;
 
+  status=MagickTrue;
   area=0.0;
   distortion=0.0;
-  image_view=AcquireCacheView(image);
-  reconstruct_view=AcquireCacheView(reconstruct_image);
+  image_view=AcquireCacheViewThreadSet(image);
+  reconstruct_view=AcquireCacheViewThreadSet(reconstruct_image);
+  #pragma omp parallel for reduction(+ : distortion, area)
   for (y=0; y < (long) image->rows; y++)
   {
-    p=AcquireCacheViewPixels(image_view,0,y,image->columns,1,exception);
-    q=AcquireCacheViewPixels(reconstruct_view,0,y,reconstruct_image->columns,1,
-      exception);
+    register const IndexPacket
+      *indexes,
+      *reconstruct_indexes;
+
+    register const PixelPacket
+      *p,
+      *q;
+
+    register long
+      id,
+      x;
+
+    if (status == MagickFalse)
+      continue;
+    id=GetCacheViewThreadId();
+    p=AcquireCacheViewPixels(image_view[id],0,y,image->columns,1,exception);
+    q=AcquireCacheViewPixels(reconstruct_view[id],0,y,
+      reconstruct_image->columns,1,exception);
     if ((p == (const PixelPacket *) NULL) || (q == (const PixelPacket *) NULL))
-      break;
-    indexes=AcquireCacheViewIndexes(image_view);
-    reconstruct_indexes=AcquireCacheViewIndexes(reconstruct_view);
+      {
+        status=MagickFalse;
+        continue;
+      }
+    indexes=AcquireCacheViewIndexes(image_view[id]);
+    reconstruct_indexes=AcquireCacheViewIndexes(reconstruct_view[id]);
     for (x=0; x < (long) image->columns; x++)
     {
       if ((channel & RedChannel) != 0)
@@ -427,8 +455,10 @@ static MagickRealType GetMeanAbsoluteError(const Image *image,
       q++;
     }
   }
-  reconstruct_view=DestroyCacheView(reconstruct_view);
-  image_view=DestroyCacheView(image_view);
+  reconstruct_view=DestroyCacheViewThreadSet(reconstruct_view);
+  image_view=DestroyCacheViewThreadSet(image_view);
+  if (status == MagickFalse)
+    return(-1.0);
   return(distortion/area);
 }
 
