@@ -59,6 +59,8 @@
 #include "magick/image-private.h"
 #include "magick/list.h"
 #include "magick/log.h"
+#include "magick/monitor.h"
+#include "magick/monitor-private.h"
 #include "magick/memory_.h"
 #include "magick/option.h"
 #include "magick/pixel-private.h"
@@ -550,7 +552,7 @@ static inline void CompositeLighten(const MagickPixelPacket *p,
 
 static inline MagickRealType LinearLight(const MagickRealType p,
   const MagickRealType alpha,const MagickRealType q,const MagickRealType beta)
-{ 
+{
   return((1.0-QuantumScale*beta)*q+2.0*(1.0-QuantumScale*alpha)*p-1.0);
 }
 
@@ -569,7 +571,7 @@ static inline void CompositeLinearLight(const MagickPixelPacket *p,
   composite->blue=gamma*LinearLight(p->blue,alpha,q->blue,beta);
   if (q->colorspace == CMYKColorspace)
     composite->index=gamma*LinearLight(p->index,alpha,q->index,beta);
-}   
+}
 
 static inline MagickRealType Minus(const MagickRealType p,
   const MagickRealType alpha,const MagickRealType q,const MagickRealType beta)
@@ -989,12 +991,11 @@ MagickExport MagickBooleanType CompositeImageChannel(Image *image,
   const ChannelType magick_unused(channel),const CompositeOperator compose,
   const Image *composite_image,const long x_offset,const long y_offset)
 {
+#define CompositeImageTag  "Composite/Image"
+
   const char
     *value;
 
-  const PixelPacket
-    *pixels;
-
   double
     brightness,
     hue,
@@ -1007,20 +1008,12 @@ MagickExport MagickBooleanType CompositeImageChannel(Image *image,
   Image
     *displace_image;
 
-  IndexPacket
-    *composite_indexes,
-    *indexes;
-
   long
     y;
 
   MagickBooleanType
-    modify_outside_overlay;
-
-  MagickPixelPacket
-    composite,
-    destination,
-    source;
+    modify_outside_overlay,
+    status;
 
   MagickRealType
     amount,
@@ -1035,18 +1028,9 @@ MagickExport MagickBooleanType CompositeImageChannel(Image *image,
   MagickStatusType
     flags;
 
-  register const PixelPacket
-    *p;
-
-  register long
-    x;
-
-  register PixelPacket
-    *q;
-
   ViewInfo
-    *composite_view,
-    *image_view;
+    **composite_view,
+    **image_view;
 
   /*
     Prepare composite image.
@@ -1094,7 +1078,7 @@ MagickExport MagickBooleanType CompositeImageChannel(Image *image,
         channel to exist, to add transparency.
       */
       if (image->matte == MagickFalse)
-        (void) SetImageOpacity(image,OpaqueOpacity);
+        (void) SetImageAlphaChannel(image,ResetAlphaChannel);
       modify_outside_overlay=MagickTrue;
       break;
     }
@@ -1154,6 +1138,15 @@ MagickExport MagickBooleanType CompositeImageChannel(Image *image,
       composite_view=AcquireCacheView(composite_image);
       for (y=0; y < (long) composite_image->rows; y++)
       {
+        register const PixelPacket
+          *p;
+
+        register long
+          x;
+
+        register PixelPacket
+          *q;
+
         if (((y+y_offset) < 0) || ((y+y_offset) >= (long) image->rows))
           continue;
         p=AcquireCacheViewPixels(composite_view,0,y,composite_image->columns,1,
@@ -1285,22 +1278,49 @@ MagickExport MagickBooleanType CompositeImageChannel(Image *image,
   /*
     Composite image.
   */
+  status=MagickTrue;
   hue=0.0;
   saturation=0.0;
   brightness=0.0;
   midpoint=((MagickRealType) QuantumRange+1.0)/2;
-  GetMagickPixelPacket(composite_image,&source);
-  GetMagickPixelPacket(image,&destination);
-  image_view=AcquireCacheView(image);
-  composite_view=AcquireCacheView(composite_image);
+  image_view=AcquireCacheViewThreadSet(image);
+  composite_view=AcquireCacheViewThreadSet(composite_image);
+  #pragma omp parallel for
   for (y=0; y < (long) image->rows; y++)
   {
+    const PixelPacket
+      *pixels;
+
+    MagickPixelPacket
+      composite,
+      destination,
+      source;
+
+    register const IndexPacket
+      *composite_indexes;
+
+    register const PixelPacket
+      *p;
+
+    register IndexPacket
+      *indexes;
+
+    register long
+      id,
+      x;
+
+    register PixelPacket
+      *q;
+
+    if (status == MagickFalse)
+      continue;
+    id=GetCacheViewThreadId();
     if (modify_outside_overlay == MagickFalse)
       {
         if (y < y_offset)
           continue;
         if ((y-y_offset) >= (long) composite_image->rows)
-          break;
+          continue;
       }
     /*
       If pixels is NULL, y is outside overlay region.
@@ -1309,19 +1329,27 @@ MagickExport MagickBooleanType CompositeImageChannel(Image *image,
     p=(PixelPacket *) NULL;
     if ((y >= y_offset) && ((y-y_offset) < (long) composite_image->rows))
       {
-        p=AcquireCacheViewPixels(composite_view,0,y-y_offset,composite_image->columns,
-          1,&image->exception);
+        p=AcquireCacheViewPixels(composite_view[id],0,y-y_offset,
+          composite_image->columns,1,&image->exception);
         if (p == (const PixelPacket *) NULL)
-          break;
+          {
+            status=MagickFalse;
+            continue;
+          }
         pixels=p;
         if (x_offset < 0)
           p-=x_offset;
       }
-    q=GetCacheViewPixels(image_view,0,y,image->columns,1);
+    q=GetCacheViewPixels(image_view[id],0,y,image->columns,1);
     if (q == (PixelPacket *) NULL)
-      break;
-    indexes=GetCacheViewIndexes(image_view);
-    composite_indexes=GetCacheViewIndexes(composite_view);
+      {
+        status=MagickFalse;
+        continue;
+      }
+    indexes=GetCacheViewIndexes(image_view[id]);
+    composite_indexes=AcquireCacheViewIndexes(composite_view[id]);
+    GetMagickPixelPacket(composite_image,&source);
+    GetMagickPixelPacket(image,&destination);
     for (x=0; x < (long) image->columns; x++)
     {
       if (modify_outside_overlay == MagickFalse)
@@ -1381,7 +1409,6 @@ MagickExport MagickBooleanType CompositeImageChannel(Image *image,
             }
             default:
               break;
-
           }
           if (image->colorspace == CMYKColorspace)
             {
@@ -1761,7 +1788,7 @@ MagickExport MagickBooleanType CompositeImageChannel(Image *image,
         case CopyBlackCompositeOp:
         {
           if (source.colorspace != CMYKColorspace)
-            ConvertRGBToCMYK(&source); 
+            ConvertRGBToCMYK(&source);
           composite.index=source.index;
           break;
         }
@@ -1787,12 +1814,14 @@ MagickExport MagickBooleanType CompositeImageChannel(Image *image,
         p=pixels;
       q++;
     }
-    if (SyncCacheView(image_view) == MagickFalse)
-      break;
+    if (SyncCacheView(image_view[id]) == MagickFalse)
+      status=MagickFalse;
+    if (SetImageProgress(image,CompositeImageTag,y,image->rows) == MagickFalse)
+      status=MagickFalse;
   }
-  composite_view=DestroyCacheView(composite_view);
-  image_view=DestroyCacheView(image_view);
+  composite_view=DestroyCacheViewThreadSet(composite_view);
+  image_view=DestroyCacheViewThreadSet(image_view);
   if (displace_image != (Image * ) NULL)
     displace_image=DestroyImage(displace_image);
-  return(MagickTrue);
+  return(status);
 }
