@@ -362,7 +362,7 @@ MagickExport void Ascii85Encode(Image *image,const unsigned char code)
 %
 %  A description of each parameter follows:
 %
-%    o image: The image.
+%    o image: the image.
 %
 */
 
@@ -673,9 +673,9 @@ MagickExport MagickBooleanType HuffmanDecodeImage(Image *image)
 %
 %  A description of each parameter follows:
 %
-%    o image_info: The image info..
+%    o image_info: the image info..
 %
-%    o image: The image.
+%    o image: the image.
 %
 */
 MagickExport MagickBooleanType HuffmanEncodeImage(const ImageInfo *image_info,
@@ -911,9 +911,9 @@ MagickExport MagickBooleanType HuffmanEncodeImage(const ImageInfo *image_info,
 %
 %  A description of each parameter follows:
 %
-%    o image_info: The image info..
+%    o image_info: the image info..
 %
-%    o image: The image.
+%    o image: the image.
 %
 */
 MagickExport MagickBooleanType Huffman2DEncodeImage(const ImageInfo *image_info,
@@ -1050,8 +1050,10 @@ MagickExport MagickBooleanType Huffman2DEncodeImage(const ImageInfo *image_info,
   assert(image->signature == MagickSignature);
   if (image->debug != MagickFalse)
     (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",image->filename);
-  ThrowBinaryException(MissingDelegateError,"TIFFLibraryIsNotAvailable",
+  (void) ThrowMagickException(&image->exception,GetMagickModule(),
+    MissingDelegateError,"DelegateLibrarySupportNotBuiltIn","`%s' (TIFF)",
     image->filename);
+  return(MagickFalse);
 }
 #endif
 
@@ -1076,11 +1078,11 @@ MagickExport MagickBooleanType Huffman2DEncodeImage(const ImageInfo *image_info,
 %
 %  A description of each parameter follows:
 %
-%    o image: The image.
+%    o image: the image.
 %
 %    o length:  A value that specifies the number of pixels to compress.
 %
-%    o pixels: The address of an unsigned array of characters containing the
+%    o pixels: the address of an unsigned array of characters containing the
 %      pixels to compress.
 %
 %
@@ -1239,11 +1241,11 @@ MagickExport MagickBooleanType LZWEncodeImage(Image *image,const size_t length,
 %
 %  A description of each parameter follows:
 %
-%    o image: The image.
+%    o image: the image.
 %
 %    o length:  A value that specifies the number of pixels to compress.
 %
-%    o pixels: The address of an unsigned array of characters containing the
+%    o pixels: the address of an unsigned array of characters containing the
 %      pixels to compress.
 %
 %
@@ -1376,12 +1378,12 @@ MagickExport MagickBooleanType PackbitsEncodeImage(Image *image,
 %
 %  A description of each parameter follows:
 %
-%    o file: The address of a structure of type FILE.  ZLIB encoded pixels
+%    o file: the address of a structure of type FILE.  ZLIB encoded pixels
 %      are written to this file.
 %
 %    o length:  A value that specifies the number of pixels to compress.
 %
-%    o pixels: The address of an unsigned array of characters containing the
+%    o pixels: the address of an unsigned array of characters containing the
 %      pixels to compress.
 %
 */
@@ -1447,7 +1449,9 @@ MagickExport MagickBooleanType ZLIBEncodeImage(Image *image,
   assert(image->signature == MagickSignature);
   if (image->debug != MagickFalse)
     (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",image->filename);
-  ThrowBinaryException(MissingDelegateError,"ZipLibraryIsNotAvailable",
+  (void) ThrowMagickException(&image->exception,GetMagickModule(),
+    MissingDelegateError,"DelegateLibrarySupportNotBuiltIn","`%s' (ZIP)",
     image->filename);
+  return(MagickFalse);
 }
 #endif
