@@ -90,7 +90,7 @@ static Image
 %                                                                             %
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
-%  ConstituteImage() returns an image from the the pixel data you supply.
+%  ConstituteImage() returns an image from the pixel data you supply.
 %  The pixel data must be in scanline order top-to-bottom.  The data can be
 %  char, short int, int, float, or double.  Float and double require the
 %  pixels to be normalized [0..1], otherwise [0..QuantumRange].  For example, to
