@@ -179,6 +179,8 @@ MagickExport MagickBooleanType ClutImageChannel(Image *image,
     register PixelPacket
       *q;
 
+    if (status == MagickFalse)
+      continue;
     id=GetCacheViewThreadId();
     q=GetCacheViewPixels(image_view[id],0,y,image->columns,1);
     if (q == (PixelPacket *) NULL)
@@ -260,7 +262,7 @@ MagickExport MagickBooleanType ClutImageChannel(Image *image,
     if (SyncCacheView(image_view[id]) == MagickFalse)
       status=MagickFalse;
     if (SetImageProgress(image,ClutImageTag,y,image->rows) == MagickFalse)
-      y=(long) image->rows;
+      status=MagickFalse;
   }
   image_view=DestroyCacheViewThreadSet(image_view);
   resample_filter=DestroyResampleFilterThreadSet(resample_filter);
@@ -375,6 +377,8 @@ MagickExport MagickBooleanType ContrastImage(Image *image,
     register PixelPacket
       *q;
 
+    if (status == MagickFalse)
+      continue;
     id=GetCacheViewThreadId();
     q=GetCacheViewPixels(image_view[id],0,y,image->columns,1);
     if (q == (PixelPacket *) NULL)
@@ -390,7 +394,7 @@ MagickExport MagickBooleanType ContrastImage(Image *image,
     if (SyncCacheView(image_view[id]) == MagickFalse)
       status=MagickFalse;
     if (SetImageProgress(image,ContrastImageTag,y,image->rows) == MagickFalse)
-      y=(long) image->rows;
+      status=MagickFalse;
   }
   image_view=DestroyCacheViewThreadSet(image_view);
   return(status);
@@ -520,6 +524,7 @@ MagickExport MagickBooleanType ContrastStretchImageChannel(Image *image,
   /*
     Form histogram.
   */
+  status=MagickTrue;
   (void) ResetMagickMemory(histogram,0,(MaxMap+1)*sizeof(*histogram));
   image_view=AcquireCacheViewThreadSet(image);
   #pragma omp parallel for
@@ -535,11 +540,16 @@ MagickExport MagickBooleanType ContrastStretchImageChannel(Image *image,
       id,
       x;
 
+    if (status == MagickFalse)
+      continue;
     id=GetCacheViewThreadId();
     p=AcquireCacheViewPixels(image_view[id],0,y,image->columns,1,
       &image->exception);
     if (p == (const PixelPacket *) NULL)
-      continue;
+      {
+        status=MagickFalse;
+        continue;
+      }
     indexes=GetCacheViewIndexes(image_view[id]);
     if (channel == DefaultChannels)
       #pragma omp parallel for
@@ -813,6 +823,8 @@ MagickExport MagickBooleanType ContrastStretchImageChannel(Image *image,
     register PixelPacket
       *q;
 
+    if (status == MagickFalse)
+      continue;
     id=GetCacheViewThreadId();
     q=GetCacheViewPixels(image_view[id],0,y,image->columns,1);
     if (q == (PixelPacket *) NULL)
@@ -860,7 +872,7 @@ MagickExport MagickBooleanType ContrastStretchImageChannel(Image *image,
       status=MagickFalse;
     progress=SetImageProgress(image,ContrastStretchImageTag,y,image->rows);
     if (progress == MagickFalse)
-      y=(long) image->rows;
+      status=MagickFalse;
   }
   image_view=DestroyCacheViewThreadSet(image_view);
   stretch_map=(MagickPixelPacket *) RelinquishMagickMemory(stretch_map);
@@ -981,6 +993,8 @@ MagickExport Image *EnhanceImage(const Image *image,ExceptionInfo *exception)
     /*
       Read another scan line.
     */
+    if (status == MagickFalse)
+      continue;
     id=GetCacheViewThreadId();
     p=AcquireCacheViewPixels(image_view[id],-2,y-2,image->columns+4,5,
       exception);
@@ -1035,7 +1049,7 @@ MagickExport Image *EnhanceImage(const Image *image,ExceptionInfo *exception)
     if (SyncCacheView(enhance_view[id]) == MagickFalse)
       status=MagickFalse;
     if (SetImageProgress(image,EnhanceImageTag,y,image->rows) == MagickFalse)
-      y=(long) image->rows;
+      status=MagickFalse;
   }
   enhance_view=DestroyCacheViewThreadSet(enhance_view);
   enhance_view=DestroyCacheViewThreadSet(image_view);
@@ -1079,9 +1093,6 @@ MagickExport MagickBooleanType EqualizeImageChannel(Image *image,
 {
 #define EqualizeImageTag  "Equalize/Image"
 
-  IndexPacket
-    *indexes;
-
   long
     y;
 
@@ -1096,15 +1107,11 @@ MagickExport MagickBooleanType EqualizeImageChannel(Image *image,
     *map,
     white;
 
-  register const PixelPacket
-    *p;
-
   register long
-    i,
-    x;
+    i;
 
-  register PixelPacket
-    *q;
+  ViewInfo
+    **image_view;
 
   /*
     Allocate and initialize histogram arrays.
@@ -1137,10 +1144,19 @@ MagickExport MagickBooleanType EqualizeImageChannel(Image *image,
   (void) ResetMagickMemory(histogram,0,(MaxMap+1)*sizeof(*histogram));
   for (y=0; y < (long) image->rows; y++)
   {
+    register const IndexPacket
+      *indexes;
+
+    register const PixelPacket
+      *p;
+
+    register long
+      x;
+
     p=AcquireImagePixels(image,0,y,image->columns,1,&image->exception);
     if (p == (const PixelPacket *) NULL)
       break;
-    indexes=(IndexPacket *) AcquireIndexes(image);
+    indexes=AcquireIndexes(image);
     for (x=0; x < (long) image->columns; x++)
     {
       if ((channel & RedChannel) != 0)
@@ -1179,6 +1195,7 @@ MagickExport MagickBooleanType EqualizeImageChannel(Image *image,
   black=map[0];
   white=map[(int) MaxMap];
   (void) ResetMagickMemory(equalize_map,0,(MaxMap+1)*sizeof(*equalize_map));
+  #pragma omp parallel for
   for (i=0; i <= (long) MaxMap; i++)
   {
     if (((channel & RedChannel) != 0) && (white.red != black.red))
@@ -1207,6 +1224,7 @@ MagickExport MagickBooleanType EqualizeImageChannel(Image *image,
       /*
         Equalize colormap.
       */
+      #pragma omp parallel for
       for (i=0; i < (long) image->colors; i++)
       {
         if (((channel & RedChannel) != 0) && (white.red != black.red))
@@ -1227,12 +1245,31 @@ MagickExport MagickBooleanType EqualizeImageChannel(Image *image,
   /*
     Equalize image.
   */
+  status=MagickTrue;
+  image_view=AcquireCacheViewThreadSet(image);
+  #pragma omp parallel for
   for (y=0; y < (long) image->rows; y++)
   {
-    q=GetImagePixels(image,0,y,image->columns,1);
+    register IndexPacket
+      *indexes;
+
+    register long
+      id,
+      x;
+
+    register PixelPacket
+      *q;
+
+    if (status == MagickFalse)
+      continue;
+    id=GetCacheViewThreadId();
+    q=GetCacheViewPixels(image_view[id],0,y,image->columns,1);
     if (q == (PixelPacket *) NULL)
-      break;
-    indexes=GetIndexes(image);
+      {
+        status=MagickFalse;
+        continue;
+      }
+    indexes=GetCacheViewIndexes(image_view[id]);
     for (x=0; x < (long) image->columns; x++)
     {
       if (((channel & RedChannel) != 0) && (white.red != black.red))
@@ -1252,19 +1289,14 @@ MagickExport MagickBooleanType EqualizeImageChannel(Image *image,
           indexes[x])].index);
       q++;
     }
-    if (SyncImagePixels(image) == MagickFalse)
-      break;
-    if ((image->progress_monitor != (MagickProgressMonitor) NULL) &&
-        (QuantumTick(y,image->rows) != MagickFalse))
-      {
-        status=image->progress_monitor(EqualizeImageTag,y,image->rows,
-          image->client_data);
-        if (status == MagickFalse)
-          break;
-      }
+    if (SyncCacheView(image_view[id]) == MagickFalse)
+      status=MagickFalse;
+    if (SetImageProgress(image,EqualizeImageTag,y,image->rows) == MagickFalse)
+      status=MagickFalse;
   }
+  image_view=DestroyCacheViewThreadSet(image_view);
   equalize_map=(MagickPixelPacket *) RelinquishMagickMemory(equalize_map);
-  return(MagickTrue);
+  return(status);
 }
 
 /*
@@ -1351,15 +1383,11 @@ MagickExport MagickBooleanType GammaImageChannel(Image *image,
   MagickRealType
     *gamma_map;
 
-  register IndexPacket
-    *indexes;
-
   register long
-    i,
-    x;
+    i;
 
-  register PixelPacket
-    *q;
+  ViewInfo
+    **image_view;
 
   /*
     Allocate and initialize gamma maps.
@@ -1377,6 +1405,7 @@ MagickExport MagickBooleanType GammaImageChannel(Image *image,
       image->filename);
   (void) ResetMagickMemory(gamma_map,0,(MaxMap+1)*sizeof(*gamma_map));
   if (gamma != 0.0)
+    #pragma omp parallel for
     for (i=0; i <= (long) MaxMap; i++)
       gamma_map[i]=(MagickRealType) ScaleMapToQuantum((MagickRealType)
         (MaxMap*pow((double) i/MaxMap,1.0/gamma)));
@@ -1385,6 +1414,7 @@ MagickExport MagickBooleanType GammaImageChannel(Image *image,
       /*
         Gamma-correct colormap.
       */
+      #pragma omp parallel for
       for (i=0; i < (long) image->colors; i++)
       {
         if ((channel & RedChannel) != 0)
@@ -1411,12 +1441,34 @@ MagickExport MagickBooleanType GammaImageChannel(Image *image,
   /*
     Gamma-correct image.
   */
+  status=MagickTrue;
+  image_view=AcquireCacheViewThreadSet(image);
+  #pragma omp parallel for
   for (y=0; y < (long) image->rows; y++)
   {
-    q=GetImagePixels(image,0,y,image->columns,1);
+    MagickBooleanType
+      progress;
+
+    register IndexPacket
+      *indexes;
+
+    register long
+      id,
+      x;
+
+    register PixelPacket
+      *q;
+
+    if (status == MagickFalse)
+      continue;
+    id=GetCacheViewThreadId();
+    q=GetCacheViewPixels(image_view[id],0,y,image->columns,1);
     if (q == (PixelPacket *) NULL)
-      break;
-    indexes=GetIndexes(image);
+      {
+        status=MagickFalse;
+        continue;
+      }
+    indexes=GetCacheViewIndexes(image_view[id]);
     for (x=0; x < (long) image->columns; x++)
     {
       if ((channel & RedChannel) != 0)
@@ -1439,20 +1491,16 @@ MagickExport MagickBooleanType GammaImageChannel(Image *image,
       q++;
     }
     if (SyncImagePixels(image) == MagickFalse)
-      break;
-    if ((image->progress_monitor != (MagickProgressMonitor) NULL) &&
-        (QuantumTick(y,image->rows) != MagickFalse))
-      {
-        status=image->progress_monitor(GammaCorrectImageTag,y,image->rows,
-          image->client_data);
-        if (status == MagickFalse)
-          break;
-      }
+      status=MagickFalse;
+    progress=SetImageProgress(image,GammaCorrectImageTag,y,image->rows);
+    if (progress == MagickFalse)
+      status=MagickFalse;
   }
+  image_view=DestroyCacheViewThreadSet(image_view);
   gamma_map=(MagickRealType *) RelinquishMagickMemory(gamma_map);
   if (image->gamma != 0.0)
     image->gamma*=gamma;
-  return(MagickTrue);
+  return(status);
 }
 
 /*
@@ -1527,17 +1575,6 @@ MagickExport MagickBooleanType LevelImage(Image *image,const char *levels)
   gamma=1.0;
   if ((flags & XiValue) != 0)
     gamma=geometry_info.xi;
-/* -- This does not seem to make any sense!
-  if ((fabs(white_point) <= 10.0) && (fabs(gamma) > 10.0))
-    {
-      double
-        swap;
-
-      swap=gamma;
-      gamma=white_point;
-      white_point=swap;
-    }
-*/
   if ((flags & PercentValue) != 0)
     {
       black_point*=(double) image->columns*image->rows/100.0;
@@ -1547,10 +1584,10 @@ MagickExport MagickBooleanType LevelImage(Image *image,const char *levels)
     white_point=(double) QuantumRange-black_point;
   if ((flags & AspectValue ) == 0)
     status=LevelImageChannel(image,DefaultChannels,black_point,white_point,
-         gamma);
+      gamma);
   else
     status=LevelizeImageChannel(image,DefaultChannels,black_point,white_point,
-         gamma);
+      gamma);
   return(status);
 }
 
@@ -1592,6 +1629,7 @@ MagickExport MagickBooleanType LevelImage(Image *image,const char *levels)
 %    o white_point: The level which is to be mapped to QuantiumRange (white)
 %
 %    o gamma: adjust gamma by this factor before mapping values.
+%
 */
 MagickExport MagickBooleanType LevelImageChannel(Image *image,
   const ChannelType channel,const double black_point,const double white_point,
@@ -1599,10 +1637,7 @@ MagickExport MagickBooleanType LevelImageChannel(Image *image,
 {
 #define LevelImageTag  "Level/Image"
 #define LevelValue(x) (RoundToQuantum((MagickRealType) QuantumRange* \
-       pow(((double) (x)-black_point)/(white_point-black_point),1.0/gamma)))
-
-  IndexPacket
-    *indexes;
+  pow(((double) (x)-black_point)/(white_point-black_point),1.0/gamma)))
 
   long
     y;
@@ -1611,11 +1646,10 @@ MagickExport MagickBooleanType LevelImageChannel(Image *image,
     status;
 
   register long
-    i,
-    x;
+    i;
 
-  register PixelPacket
-    *q;
+  ViewInfo
+    **image_view;
 
   /*
     Allocate and initialize levels map.
@@ -1625,6 +1659,7 @@ MagickExport MagickBooleanType LevelImageChannel(Image *image,
   if (image->debug != MagickFalse)
     (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",image->filename);
   if (image->storage_class == PseudoClass)
+    #pragma omp parallel for
     for (i=0; i < (long) image->colors; i++)
     {
       /*
@@ -1642,12 +1677,31 @@ MagickExport MagickBooleanType LevelImageChannel(Image *image,
   /*
     Level image.
   */
+  status=MagickTrue;
+  image_view=AcquireCacheViewThreadSet(image);
+  #pragma omp parallel for
   for (y=0; y < (long) image->rows; y++)
   {
-    q=GetImagePixels(image,0,y,image->columns,1);
+    register IndexPacket
+      *indexes;
+
+    register long
+      id,
+      x;
+
+    register PixelPacket
+      *q;
+
+    if (status == MagickFalse)
+      continue;
+    id=GetCacheViewThreadId();
+    q=GetCacheViewPixels(image_view[id],0,y,image->columns,1);
     if (q == (PixelPacket *) NULL)
-      break;
-    indexes=GetIndexes(image);
+      {
+        status=MagickFalse;
+        continue;
+      }
+    indexes=GetCacheViewIndexes(image_view[id]);
     for (x=0; x < (long) image->columns; x++)
     {
       if ((channel & RedChannel) != 0)
@@ -1663,18 +1717,13 @@ MagickExport MagickBooleanType LevelImageChannel(Image *image,
         indexes[x]=LevelValue(indexes[x]);
       q++;
     }
-    if (SyncImagePixels(image) == MagickFalse)
-      break;
-    if ((image->progress_monitor != (MagickProgressMonitor) NULL) &&
-        (QuantumTick(y,image->rows) != MagickFalse))
-      {
-        status=image->progress_monitor(LevelImageTag,y,image->rows,
-          image->client_data);
-        if (status == MagickFalse)
-          break;
-      }
+    if (SyncCacheView(image_view[id]) == MagickFalse)
+      status=MagickFalse;
+    if (SetImageProgress(image,LevelImageTag,y,image->rows) == MagickFalse)
+      status=MagickFalse;
   }
-  return(MagickTrue);
+  image_view=DestroyCacheViewThreadSet(image_view);
+  return(status);
 }
 
 /*
@@ -1689,7 +1738,7 @@ MagickExport MagickBooleanType LevelImageChannel(Image *image,
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
 %  LevelizeImageChannel() applies the reversed LevelImage() operation to just
-%  the Specific channels specified.  It will compress the full range of color
+%  the specific channels specified.  It compresses the full range of color
 %  values, so that they lie between the given black and white points. Gamma is
 %  applied before the values are mapped.
 %
@@ -1717,6 +1766,7 @@ MagickExport MagickBooleanType LevelImageChannel(Image *image,
 %    o white_point: The level to map QuantiumRange (white) to.
 %
 %    o gamma: adjust gamma by this factor before mapping values.
+%
 */
 
 MagickExport MagickBooleanType LevelizeImageChannel(Image *image,
@@ -1725,11 +1775,8 @@ MagickExport MagickBooleanType LevelizeImageChannel(Image *image,
 {
 #define LevelizeImageTag  "Levelize/Image"
 #define LevelizeValue(x) (RoundToQuantum(((MagickRealType) \
-                pow((double)(QuantumScale*(x)),1.0/gamma) \
-                     )*(white_point-black_point) + black_point))
-
-  IndexPacket
-    *indexes;
+  pow((double)(QuantumScale*(x)),1.0/gamma))*(white_point-black_point)+ \
+  black_point))
 
   long
     y;
@@ -1738,11 +1785,10 @@ MagickExport MagickBooleanType LevelizeImageChannel(Image *image,
     status;
 
   register long
-    i,
-    x;
+    i;
 
-  register PixelPacket
-    *q;
+  ViewInfo
+    **image_view;
 
   /*
     Allocate and initialize levels map.
@@ -1752,6 +1798,7 @@ MagickExport MagickBooleanType LevelizeImageChannel(Image *image,
   if (image->debug != MagickFalse)
     (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",image->filename);
   if (image->storage_class == PseudoClass)
+    #pragma omp parallel for
     for (i=0; i < (long) image->colors; i++)
     {
       /*
@@ -1765,16 +1812,35 @@ MagickExport MagickBooleanType LevelizeImageChannel(Image *image,
         image->colormap[i].blue=LevelizeValue(image->colormap[i].blue);
       if ((channel & OpacityChannel) != 0)
         image->colormap[i].opacity=LevelizeValue(image->colormap[i].opacity);
-      }
+    }
   /*
     Level image.
   */
+  status=MagickTrue;
+  image_view=AcquireCacheViewThreadSet(image);
+  #pragma omp parallel for
   for (y=0; y < (long) image->rows; y++)
   {
-    q=GetImagePixels(image,0,y,image->columns,1);
+    register IndexPacket
+      *indexes;
+
+    register long
+      id,
+      x;
+
+    register PixelPacket
+      *q;
+
+    if (status == MagickFalse)
+      continue;
+    id=GetCacheViewThreadId();
+    q=GetCacheViewPixels(image_view[id],0,y,image->columns,1);
     if (q == (PixelPacket *) NULL)
-      break;
-    indexes=GetIndexes(image);
+      {
+        status=MagickFalse;
+        continue;
+      }
+    indexes=GetCacheViewIndexes(image_view[id]);
     for (x=0; x < (long) image->columns; x++)
     {
       if ((channel & RedChannel) != 0)
@@ -1790,18 +1856,111 @@ MagickExport MagickBooleanType LevelizeImageChannel(Image *image,
         indexes[x]=LevelizeValue(indexes[x]);
       q++;
     }
-    if (SyncImagePixels(image) == MagickFalse)
-      break;
-    if ((image->progress_monitor != (MagickProgressMonitor) NULL) &&
-        (QuantumTick(y,image->rows) != MagickFalse))
-      {
-        status=image->progress_monitor(LevelizeImageTag,y,image->rows,
-          image->client_data);
-        if (status == MagickFalse)
-          break;
-      }
+    if (SyncCacheView(image_view[id]) == MagickFalse)
+      status=MagickFalse;
+    if (SetImageProgress(image,LevelizeImageTag,y,image->rows) == MagickFalse)
+      status=MagickFalse;
   }
-  return(MagickTrue);
+  return(status);
+}
+
+/*
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%                                                                             %
+%                                                                             %
+%                                                                             %
+%     L e v e l I m a g e C o l o r s                                         %
+%                                                                             %
+%                                                                             %
+%                                                                             %
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%
+%  LevelImageColor() will map the given color to "black" and "white"
+%  values, limearly spreading out the colors, and level values on a channel by
+%  channel bases, as per LevelImage().  The given colors allows you to specify
+%  different level ranges for each of the color channels seperatally.
+%
+%  If the boolean 'invert' is set true the image values will modifyed in the
+%  reverse direction. That is any existing "black" and "white" colors in the
+%  image will become the color values given, with all other values compressed
+%  appropriatally.  This effectivally maps a greyscale gradient into the given
+%  color gradient.
+%
+%  The format of the LevelImageColors method is:
+%
+%  MagickBooleanType LevelImageColors(Image *image,const ChannelType channel,
+%         const MagickPixelPacket *black_color,
+%         const MagickPixelPacket *white_color,
+%         const MagickBooleanType invert)
+%
+%  A description of each parameter follows:
+%
+%    o image: the image.
+%
+%    o channel: the channel.
+%
+%    o black_color: The color to map black to/from
+%
+%    o white_point: The color to map white to/from
+%
+%    o invert: if true map the colors (levelize), rather than from (level)
+%
+*/
+MagickBooleanType LevelImageColors(Image *image,const ChannelType channel,
+     const MagickPixelPacket *black_color, const MagickPixelPacket
+     *white_color, const MagickBooleanType invert)
+{
+#define LevelColorImageTag  "LevelColor/Image"
+
+  MagickBooleanType
+    status;
+
+  /*
+    Allocate and initialize levels map.
+  */
+  assert(image != (Image *) NULL);
+  assert(image->signature == MagickSignature);
+  if (image->debug != MagickFalse)
+    (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",image->filename);
+
+  status = MagickFalse;
+  if ( invert == MagickFalse ) {
+    if ((channel & RedChannel) != 0)
+      status |= LevelImageChannel(image,RedChannel,
+           black_color->red,white_color->red, (double)1.0);
+    if ((channel & GreenChannel) != 0)
+      status |= LevelImageChannel(image,GreenChannel,
+           black_color->green,white_color->green, (double)1.0);
+    if ((channel & BlueChannel) != 0)
+      status |= LevelImageChannel(image,BlueChannel,
+           black_color->blue,white_color->blue, (double)1.0);
+    if ((channel & OpacityChannel) != 0)
+      status |= LevelImageChannel(image,OpacityChannel,
+           black_color->opacity,white_color->opacity, (double)1.0);
+    if (((channel & IndexChannel) != 0) &&
+        (image->colorspace == CMYKColorspace))
+      status |= LevelImageChannel(image,IndexChannel,
+           black_color->index,white_color->index, (double)1.0);
+  }
+  else {
+    if ((channel & RedChannel) != 0)
+      status |= LevelizeImageChannel(image,RedChannel,
+           black_color->red,white_color->red, (double)1.0);
+    if ((channel & GreenChannel) != 0)
+      status |= LevelizeImageChannel(image,GreenChannel,
+           black_color->green,white_color->green, (double)1.0);
+    if ((channel & BlueChannel) != 0)
+      status |= LevelizeImageChannel(image,BlueChannel,
+           black_color->blue,white_color->blue, (double)1.0);
+    if ((channel & OpacityChannel) != 0)
+      status |= LevelizeImageChannel(image,OpacityChannel,
+           black_color->opacity,white_color->opacity, (double)1.0);
+    if (((channel & IndexChannel) != 0) &&
+        (image->colorspace == CMYKColorspace))
+      status |= LevelizeImageChannel(image,IndexChannel,
+           black_color->index,white_color->index, (double)1.0);
+  }
+  return(status);
 }
 
 /*
@@ -2035,11 +2194,10 @@ MagickExport MagickBooleanType ModulateImage(Image *image,const char *modulate)
     flags;
 
   register long
-    i,
-    x;
+    i;
 
-  register PixelPacket
-    *q;
+  ViewInfo
+    **image_view;
 
   /*
     Initialize gamma table.
@@ -2064,6 +2222,7 @@ MagickExport MagickBooleanType ModulateImage(Image *image,const char *modulate)
       /*
         Modulate colormap.
       */
+      #pragma omp parallel for
       for (i=0; i < (long) image->colors; i++)
         switch (image->colorspace)
         {
@@ -2094,11 +2253,27 @@ MagickExport MagickBooleanType ModulateImage(Image *image,const char *modulate)
   /*
     Modulate image.
   */
+  status=MagickTrue;
+  image_view=AcquireCacheViewThreadSet(image);
+  #pragma omp parallel for
   for (y=0; y < (long) image->rows; y++)
   {
-    q=GetImagePixels(image,0,y,image->columns,1);
+    register long
+      id,
+      x;
+
+    register PixelPacket
+      *q;
+
+    if (status == MagickFalse)
+      continue;
+    id=GetCacheViewThreadId();
+    q=GetCacheViewPixels(image_view[id],0,y,image->columns,1);
     if (q == (PixelPacket *) NULL)
-      break;
+      {
+        status=MagickFalse;
+        continue;
+      }
     for (x=0; x < (long) image->columns; x++)
     {
       switch (image->colorspace)
@@ -2125,18 +2300,13 @@ MagickExport MagickBooleanType ModulateImage(Image *image,const char *modulate)
       }
       q++;
     }
-    if (SyncImagePixels(image) == 0)
-      break;
-    if ((image->progress_monitor != (MagickProgressMonitor) NULL) &&
-        (QuantumTick(y,image->rows) != MagickFalse))
-      {
-        status=image->progress_monitor(ModulateImageTag,y,image->rows,
-          image->client_data);
-        if (status == MagickFalse)
-          break;
-      }
+    if (SyncCacheView(image_view[id]) == MagickFalse)
+      status=MagickFalse;
+    if (SetImageProgress(image,ModulateImageTag,y,image->rows) == MagickFalse)
+      status=MagickFalse;
   }
-  return(MagickTrue);
+  image_view=DestroyCacheViewThreadSet(image_view);
+  return(status);
 }
 
 /*
@@ -2244,6 +2414,8 @@ MagickExport MagickBooleanType NegateImageChannel(Image *image,
         register PixelPacket
           *q;
 
+    if (status == MagickFalse)
+      continue;
         id=GetCacheViewThreadId();
         q=GetCacheViewPixels(image_view[id],0,y,image->columns,1);
         if (q == (PixelPacket *) NULL)
@@ -2275,7 +2447,7 @@ MagickExport MagickBooleanType NegateImageChannel(Image *image,
         if (SyncCacheView(image_view[id]) == MagickFalse)
           status=MagickFalse;
         if (SetImageProgress(image,NegateImageTag,y,image->rows) == MagickFalse)
-          y=(long) image->rows;
+          status=MagickFalse;
       }
       image_view=DestroyCacheViewThreadSet(image_view);
       return(MagickTrue);
@@ -2296,6 +2468,8 @@ MagickExport MagickBooleanType NegateImageChannel(Image *image,
     register PixelPacket
       *q;
 
+    if (status == MagickFalse)
+      continue;
     id=GetCacheViewThreadId();
     q=GetCacheViewPixels(image_view[id],0,y,image->columns,1);
     if (q == (PixelPacket *) NULL)
@@ -2322,7 +2496,7 @@ MagickExport MagickBooleanType NegateImageChannel(Image *image,
     if (SyncCacheView(image_view[id]) == MagickFalse)
       status=MagickFalse;
     if (SetImageProgress(image,NegateImageTag,y,image->rows) == MagickFalse)
-      y=(long) image->rows;
+      status=MagickFalse;
   }
   image_view=DestroyCacheViewThreadSet(image_view);
   return(status);
@@ -2542,6 +2716,8 @@ MagickExport MagickBooleanType SigmoidalContrastImageChannel(Image *image,
     register PixelPacket
       *q;
 
+    if (status == MagickFalse)
+      continue;
     id=GetCacheViewThreadId();
     q=GetCacheViewPixels(image_view[id],0,y,image->columns,1);
     if (q == (PixelPacket *) NULL)
@@ -2570,7 +2746,7 @@ MagickExport MagickBooleanType SigmoidalContrastImageChannel(Image *image,
       status=MagickFalse;
     progress=SetImageProgress(image,SigmoidalContrastImageTag,y,image->rows);
     if (progress == MagickFalse)
-      y=(long) image->rows;
+      status=MagickFalse;
   }
   image_view=DestroyCacheViewThreadSet(image_view);
   sigmoidal_map=(MagickRealType *) RelinquishMagickMemory(sigmoidal_map);
