@@ -39,7 +39,8 @@ typedef enum
   SetEvaluateOperator,
   SubtractEvaluateOperator,
   XorEvaluateOperator,
-  PowEvaluateOperator
+  PowEvaluateOperator,
+  LogEvaluateOperator
 } MagickEvaluateOperator;
 
 extern MagickExport Image
