@@ -52,18 +52,6 @@ static inline double DegreesToRadians(const double degrees)
   return(MagickPI*degrees/180.0);
 }
 
-static inline MagickBooleanType QuantumTick(const MagickOffsetType offset,
-  const MagickSizeType span)
-{
-  if ((offset & (offset-1)) == 0)
-    return(MagickTrue);
-  if ((offset & 0x7f) == 0)
-    return(MagickTrue);
-  if (offset == (MagickOffsetType) (span-1))
-    return(MagickTrue);
-  return(MagickFalse);
-}
-
 static inline MagickRealType RadiansToDegrees(const MagickRealType radians)
 {
   return(180.0*radians/MagickPI);
