@@ -72,7 +72,7 @@
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
 %  ClearBounds() Clear the area specified by the bounds in an image to
-%  transparency.  This is typically used to handle Background Disposal
+%  transparency.  This typically used to handle Background Disposal
 %  for the previous frame in an animation sequence.
 %
 %  WARNING: no bounds checks are performed, except for the null or
@@ -85,7 +85,7 @@
 %
 %  A description of each parameter follows:
 %
-%    o image: The image to had the area cleared in
+%    o image: the image to had the area cleared in
 %
 %    o bounds: the area to be clear within the imag image
 %
@@ -103,7 +103,7 @@ static void ClearBounds(Image *image,RectangleInfo *bounds)
 
   if ( bounds->x < 0 ) return;
   if (image->matte == MagickFalse)
-    (void) SetImageOpacity(image,OpaqueOpacity);
+    (void) SetImageAlphaChannel(image,ResetAlphaChannel);
   for (y=0; y < (long) bounds->height; y++)
   {
     q=GetImagePixels(image,bounds->x,bounds->y+y,bounds->width,1);
@@ -131,7 +131,7 @@ static void ClearBounds(Image *image,RectangleInfo *bounds)
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
 %  IsBoundsCleared() tests whether any pixel in the bounds given, gets cleared
-%  when going from the first image to the second image.  This is typically used
+%  when going from the first image to the second image.  This typically used
 %  to check if a proposed disposal method will work successfully to generate
 %  the second frame image from the first disposed form of the previous frame.
 %
@@ -142,7 +142,7 @@ static void ClearBounds(Image *image,RectangleInfo *bounds)
 %
 %  A description of each parameter follows:
 %
-%    o image1, image 2: The images to check for cleared pixels
+%    o image1, image 2: the images to check for cleared pixels
 %
 %    o bounds: the area to be clear within the imag image
 %
@@ -214,7 +214,7 @@ static MagickBooleanType IsBoundsCleared(const Image *image1,
 %
 %  A description of each parameter follows:
 %
-%    o image: The image sequence.
+%    o image: the image sequence.
 %
 %    o exception: Return any errors or warnings in this structure.
 %
@@ -224,7 +224,7 @@ MagickExport Image *CoalesceImages(const Image *image,ExceptionInfo *exception)
   Image
     *coalesce_image,
     *dispose_image,
-    *prev;
+    *previous;
 
   register Image
     *next;
@@ -245,28 +245,31 @@ MagickExport Image *CoalesceImages(const Image *image,ExceptionInfo *exception)
   /* initialise first image */
   next=GetFirstImageInList(image);
   bounds=next->page;
-  if ( bounds.width == 0 ) {
-    bounds.width = next->columns;
-    if ( bounds.x > 0 )
-      bounds.width += bounds.x;
-  }
-  if ( bounds.height == 0 ) {
-    bounds.height = next->rows;
-    if ( bounds.y > 0 )
-      bounds.height += bounds.y;
-  }
+  if (bounds.width == 0)
+    {
+      bounds.width=next->columns;
+      if (bounds.x > 0)
+        bounds.width+=bounds.x;
+    }
+  if (bounds.height == 0)
+    {
+      bounds.height=next->rows;
+      if (bounds.y > 0)
+        bounds.height+=bounds.y;
+    }
   bounds.x=0;
   bounds.y=0;
   coalesce_image=CloneImage(next,bounds.width,bounds.height,MagickTrue,
-         exception);
+    exception);
   if (coalesce_image == (Image *) NULL)
     return((Image *) NULL);
   coalesce_image->page=bounds;
   coalesce_image->dispose=NoneDispose;
   coalesce_image->background_color.opacity=(Quantum) TransparentOpacity;
   (void) SetImageBackgroundColor(coalesce_image);
-
-  /* coalesce rest of the images */
+  /*
+    Coalesce rest of the images.
+  */
   dispose_image=CloneImage(coalesce_image,0,0,MagickTrue,exception);
   (void) CompositeImage(coalesce_image,CopyCompositeOp,next,next->page.x,
     next->page.y);
@@ -276,10 +279,10 @@ MagickExport Image *CoalesceImages(const Image *image,ExceptionInfo *exception)
     /*
       Determine the bounds that was overlaid in the previous image.
     */
-    prev=GetPreviousImageInList(next);
-    bounds=prev->page;
-    bounds.width=prev->columns;
-    bounds.height=prev->rows;
+    previous=GetPreviousImageInList(next);
+    bounds=previous->page;
+    bounds.width=previous->columns;
+    bounds.height=previous->rows;
     if (bounds.x < 0)
       {
         bounds.width+=bounds.x;
@@ -317,7 +320,7 @@ MagickExport Image *CoalesceImages(const Image *image,ExceptionInfo *exception)
     */
     coalesce_image->next=CloneImage(dispose_image,0,0,MagickTrue,exception);
     coalesce_image->next->previous=coalesce_image;
-    prev=coalesce_image;
+    previous=coalesce_image;
     coalesce_image=GetNextImageInList(coalesce_image);
     coalesce_image->matte=MagickTrue;
     (void) CompositeImage(coalesce_image,next->matte != MagickFalse ?
@@ -325,17 +328,15 @@ MagickExport Image *CoalesceImages(const Image *image,ExceptionInfo *exception)
     (void) CloneImageProfiles(coalesce_image,next);
     (void) CloneImageProperties(coalesce_image,next);
     (void) CloneImageArtifacts(coalesce_image,next);
-    coalesce_image->page=prev->page;
+    coalesce_image->page=previous->page;
     /*
-      Fix disposal setting of previous image, for correct animation.
       If a pixel goes opaque to transparent, use background dispose.
-      For both previous and current image.
     */
-    if (IsBoundsCleared(prev,coalesce_image,&bounds,exception) )
+    if (IsBoundsCleared(previous,coalesce_image,&bounds,exception))
       coalesce_image->dispose=BackgroundDispose;
     else
       coalesce_image->dispose=NoneDispose;
-    prev->dispose=coalesce_image->dispose;
+    previous->dispose=coalesce_image->dispose;
   }
   dispose_image=DestroyImage(dispose_image);
   return(GetFirstImageInList(coalesce_image));
@@ -362,7 +363,7 @@ MagickExport Image *CoalesceImages(const Image *image,ExceptionInfo *exception)
 %
 %  A description of each parameter follows:
 %
-%    o image: The image sequence.
+%    o image: the image sequence.
 %
 %    o exception: Return any errors or warnings in this structure.
 %
@@ -491,7 +492,7 @@ MagickExport Image *DisposeImages(const Image *image,ExceptionInfo *exception)
 %  ComparePixels() Compare the two pixels and return true if the pixels
 %  differ according to the given LayerType comparision method.
 %
-%  This is currently only used internally by CompareImageBounds(). It is
+%  This currently only used internally by CompareImageBounds(). It is
 %  doubtful that this sub-routine will be useful outside this module.
 %
 %  The format of the ComparePixels method is:
@@ -504,7 +505,7 @@ MagickExport Image *DisposeImages(const Image *image,ExceptionInfo *exception)
 %    o method: What differences to look for. Must be one of
 %              CompareAnyLayer, CompareClearLayer, CompareOverlayLayer.
 %
-%    o p, q: The pixels to test for appropriate differences.
+%    o p, q: the pixels to test for appropriate differences.
 %
 */
 
@@ -559,7 +560,7 @@ static MagickBooleanType ComparePixels(const ImageLayerMethod method,
 %  by which the two images differ, accourding to the given 'Compare...'
 %  layer method.
 %
-%  This is currently only used internally in this module, but may eventually
+%  This currently only used internally in this module, but may eventually
 %  be used by other modules.
 %
 %  The format of the CompareImageBounds method is:
@@ -572,7 +573,7 @@ static MagickBooleanType ComparePixels(const ImageLayerMethod method,
 %    o method: What differences to look for. Must be one of
 %              CompareAnyLayer, CompareClearLayer, CompareOverlayLayer.
 %
-%    o image1, image2: The two images to compare.
+%    o image1, image2: the two images to compare.
 %
 %    o exception: Return any errors or warnings in this structure.
 %
@@ -738,9 +739,9 @@ static RectangleInfo CompareImageBounds(const Image *image1,const Image *image2,
 %
 %  A description of each parameter follows:
 %
-%    o image: The image.
+%    o image: the image.
 %
-%    o method: The layers type to compare images with. Must be one of...
+%    o method: the layers type to compare images with. Must be one of...
 %              CompareAnyLayer, CompareClearLayer, CompareOverlayLayer.
 %
 %    o exception: Return any errors or warnings in this structure.
@@ -878,7 +879,7 @@ MagickExport Image *CompareImageLayers(const Image *image,
 %
 %  A description of each parameter follows:
 %
-%    o image: The image.
+%    o image: the image.
 %
 %    o exception: Return any errors or warnings in this structure.
 %
@@ -906,11 +907,11 @@ MagickExport Image *DeconstructImages(const Image *images,
 %  smallest cropped image to replace each frame, while preserving the results
 %  of the animation.
 %
-%  Note that this is not easy, and may require the expandsion of the bounds
+%  Note that this not easy, and may require the expandsion of the bounds
 %  of previous frame, to clear pixels for the next animation frame,
 %  using GIF Background Dispose method.
 %
-%  Currently this is only used internally, with external wrappers below.
+%  Currently this only used internally, with external wrappers below.
 %
 %  The format of the OptimizeLayerFrames method is:
 %
@@ -919,9 +920,9 @@ MagickExport Image *DeconstructImages(const Image *images,
 %
 %  A description of each parameter follows:
 %
-%    o image: The image.
+%    o image: the image.
 %
-%    o method: The layers type to optimize with. Must be one of...
+%    o method: the layers type to optimize with. Must be one of...
 %             OptimizeImageLayer, or  OptimizePlusLayer
 %
 %    o exception: Return any errors or warnings in this structure.
@@ -1145,7 +1146,7 @@ static Image *OptimizeLayerFrames(const Image *image,
             /*
               Straight background disposal failed to clear pixels needed!
               Lets try expanding the disposal area of the previous frame, to
-              include the pixels that are cleared.  This is guaranteed
+              include the pixels that are cleared.  This guaranteed
               to work, though may not be the most optimized solution.
             */
             try_bounds=CompareImageBounds(prev_image,next,CompareClearLayer,exception);
@@ -1319,7 +1320,7 @@ static Image *OptimizeLayerFrames(const Image *image,
 %
 %  A description of each parameter follows:
 %
-%    o image: The image.
+%    o image: the image.
 %
 %    o exception: Return any errors or warnings in this structure.
 %
@@ -1352,7 +1353,7 @@ MagickExport Image *OptimizeImageLayers(const Image *image,
 %
 %  A description of each parameter follows:
 %
-%    o image: The image.
+%    o image: the image.
 %
 %    o exception: Return any errors or warnings in this structure.
 %
@@ -1389,7 +1390,7 @@ MagickExport Image *OptimizePlusImageLayers(const Image *image,
 %
 %  A description of each parameter follows:
 %
-%    o image: The image sequence
+%    o image: the image sequence
 %
 %    o exception: Return any errors or warnings in this structure.
 %
@@ -1515,7 +1516,7 @@ MagickExport void OptimizeImageTransparency(const Image *image,
 %
 %  A description of each parameter follows:
 %
-%    o images: The image list
+%    o images: the image list
 %
 %    o exception: Return any errors or warnings in this structure.
 %
@@ -1579,7 +1580,7 @@ MagickExport void RemoveDuplicateLayers(Image **images,
 %  time delay of 3 or more centi-seconds (hundredths of a second).
 %
 %  However if all the frames have a zero time delay, then either the animation
-%  is as yet incomplete, or it is not a GIF animation.  This is a non-sensible
+%  is as yet incomplete, or it is not a GIF animation.  This a non-sensible
 %  situation, so no image will be removed and a 'Zero Time Animation' warning
 %  (exception) given.
 %
@@ -1596,7 +1597,7 @@ MagickExport void RemoveDuplicateLayers(Image **images,
 %
 %  A description of each parameter follows:
 %
-%    o images: The image list
+%    o images: the image list
 %
 %    o exception: Return any errors or warnings in this structure.
 %
@@ -1657,7 +1658,7 @@ MagickExport void RemoveZeroDelayLayers(Image **images,
 %  to the virtual canvas, and not the actual image.
 %
 %  No GIF disposal handling is performed, so GIF animations should be
-%  coalesced before use.  However this is not a requirement, and individual
+%  coalesced before use.  However this not a requirement, and individual
 %  layer images may have any size or offset, for special compositions.
 %
 %  Special case:- If one of the image sequences is just a single image that
@@ -1778,7 +1779,7 @@ MagickExport void CompositeLayers(Image *destination,
 %  image onward to produce a single image of the merged layers.
 %
 %  The inital canvas's size depends on the given ImageLayerMethod, and is
-%  initialized using the first images images background color.  The images
+%  initialized using the first images background color.  The images
 %  are then compositied onto that image in sequence using the given
 %  composition that has been assigned to each individual image.
 %
@@ -1789,9 +1790,9 @@ MagickExport void CompositeLayers(Image *destination,
 %
 %  A description of each parameter follows:
 %
-%    o image: The image list to be composited together
+%    o image: the image list to be composited together
 %
-%    o method: The method of selecting the size of the initial canvas.
+%    o method: the method of selecting the size of the initial canvas.
 %
 %        MergeLayer: Merge all layers onto a canvas just large enough
 %           to hold all the actual images. The virtual canvas of the
@@ -1855,11 +1856,11 @@ MagickExport Image *MergeImageLayers(const Image *image,
       next = GetNextImageInList(image);
       for ( ; next != (Image *) NULL;  next=GetNextImageInList(next)) {
         if ( page.x > next->page.x ) {
-             width += next->page.x-page.x;
+             width += page.x-next->page.x;
              page.x = next->page.x;
         }
         if ( page.y > next->page.y ) {
-             height += next->page.y-page.y;
+             height += page.y-next->page.y;
              page.y = next->page.y;
         }
         if ( width < (next->page.x + next->columns - page.x) )
@@ -1871,9 +1872,9 @@ MagickExport Image *MergeImageLayers(const Image *image,
     }
     case FlattenLayer:
     {
-      if ( page.width != 0 )
+      if ( page.width > 0 )
         width=page.width;
-      if ( page.height != 0 )
+      if ( page.height > 0 )
         height=page.height;
       page.x=0;
       page.y=0;
@@ -1887,7 +1888,7 @@ MagickExport Image *MergeImageLayers(const Image *image,
         height=page.height;
       for (next=image; next != (Image *) NULL; next=GetNextImageInList(next)) {
         if (method == MosaicLayer) {
-        page.x=next->page.x;
+          page.x=next->page.x;
           page.y=next->page.y;
           if ( width < (next->page.x + next->columns) )
              width = (unsigned long) next->page.x + next->columns;
