@@ -532,7 +532,7 @@ MagickExport Image *GetImageFromList(const Image *images,const long index)
     (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",images->filename);
   for (p=images; p->previous != (Image *) NULL; p=p->previous) ;
   length=GetImageListLength(images);
-  for (offset=index; offset < 0; offset+=length) ;
+  for (offset=index; offset < 0; offset+=(long) length) ;
   for (i=0; p != (Image *) NULL; p=p->next)
     if (i++ == (long) (offset % length))
       break;
