@@ -1169,7 +1169,7 @@ MagickExport struct dirent *readdir(DIR *entry)
 %  A description of each parameter follows:
 %
 %    o image:  Method ReadPICTImage returns a pointer to the image after
-%      reading.  A null image is returned if there is a a memory shortage or
+%      reading.  A null image is returned if there is a memory shortage or
 %      if the image cannot be read.
 %
 %    o image_info: the image info..
