@@ -17,7 +17,7 @@
 %                                 July 1998                                   %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2007 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2008 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -44,10 +44,11 @@
 %  written by Yoo C. Chung.
 %
 %  By default, ANSI memory methods are called (e.g. malloc).  Use the
-%  custom memory allocator by defining UseEmbeddableMagick.  The custom memory
-%  allocator has the advantage of using memory-mapped heap allocation which
-%  permits the virtual memory to be returned to the system in all cases, unlike
-%  the ANSI memory methods that typically only memory-map large allocations.
+%  custom memory allocator by defining MAGICKCORE_EMBEDDABLE_SUPPORT.  The
+%  custom memory allocator has the advantage of using memory-mapped heap
+%  allocation which permits the virtual memory to be returned to the system in
+%  all cases, unlike the ANSI memory methods that typically only memory-map
+%  large allocations.
 %
 */
 
@@ -119,11 +120,26 @@ typedef struct _MemoryInfo
     *segments[MaxSegments],
     segment_pool[MaxSegments];
 } MemoryInfo;
+
+typedef struct _MagickMemoryMethods
+{
+  AcquireMemoryHandler
+    acquire_memory_handler;
+
+  ResizeMemoryHandler
+    resize_memory_handler;
+
+  DestroyMemoryHandler
+    destroy_memory_handler;
+} MagickMemoryMethods;
 
 /*
   Global declarations.
 */
-#if defined(UseEmbeddableMagick)
+static MagickMemoryMethods
+  memory_methods = { malloc, realloc, free };
+
+#if defined(MAGICKCORE_EMBEDDABLE_SUPPORT)
 static MemoryInfo
   memory_info;
 
@@ -140,7 +156,7 @@ static MagickBooleanType
   ExpandHeap(size_t);
 #endif
 
-#if defined(UseEmbeddableMagick)
+#if defined(MAGICKCORE_EMBEDDABLE_SUPPORT)
 /*
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %                                                                             %
@@ -161,7 +177,7 @@ static MagickBooleanType
 %
 %  A description of each parameter follows:
 %
-%    o size: The size of the memory in bytes to allocate.
+%    o size: the size of the memory in bytes to allocate.
 %
 */
 
@@ -309,7 +325,7 @@ static void *AcquireBlock(size_t size)
 %
 %  A description of each parameter follows:
 %
-%    o size: The size of the memory in bytes to allocate.
+%    o size: the size of the memory in bytes to allocate.
 %
 */
 MagickExport void *AcquireMagickMemory(const size_t size)
@@ -317,8 +333,8 @@ MagickExport void *AcquireMagickMemory(const size_t size)
   register void
     *memory;
 
-#if !defined(UseEmbeddableMagick)
-  memory=malloc(size == 0 ? 1UL : size);
+#if !defined(MAGICKCORE_EMBEDDABLE_SUPPORT)
+  memory=memory_methods.acquire_memory_handler(size == 0 ? 1UL : size);
 #else
   if (free_segments == (DataSegmentInfo *) NULL)
     {
@@ -361,6 +377,45 @@ MagickExport void *AcquireMagickMemory(const size_t size)
 %                                                                             %
 %                                                                             %
 %                                                                             %
+%   A c q u i r e Q u a n t u m M e m o r y                                   %
+%                                                                             %
+%                                                                             %
+%                                                                             %
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%
+%  AcquireQuantumMemory() returns a pointer to a block of memory at least
+%  count * quantum bytes suitably aligned for any use.
+%
+%  The format of the AcquireQuantumMemory method is:
+%
+%      void *AcquireQuantumMemory(const size_t count,const size_t quantum)
+%
+%  A description of each parameter follows:
+%
+%    o count: the number of quantum elements to allocate.
+%
+%    o quantum: the number of bytes in each quantum.
+%
+*/
+MagickExport void *AcquireQuantumMemory(const size_t count,const size_t quantum)
+{
+  size_t
+    size;
+
+  size=count*quantum;
+  if ((count == 0) || (quantum != (size/count)))
+    {
+      errno=ENOMEM;
+      return((void *) NULL);
+    }
+  return(AcquireMagickMemory(size));
+}
+
+/*
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%                                                                             %
+%                                                                             %
+%                                                                             %
 %   C o p y M a g i c k M e m o r y                                           %
 %                                                                             %
 %                                                                             %
@@ -378,11 +433,11 @@ MagickExport void *AcquireMagickMemory(const size_t size)
 %
 %  A description of each parameter follows:
 %
-%    o destination: The destination.
+%    o destination: the destination.
 %
-%    o source: The source.
+%    o source: the source.
 %
-%    o size: The size of the memory in bytes to allocate.
+%    o size: the size of the memory in bytes to allocate.
 %
 */
 MagickExport void *CopyMagickMemory(void *destination,const void *source,
@@ -417,7 +472,7 @@ MagickExport void *CopyMagickMemory(void *destination,const void *source,
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
 %  DestroyMagickMemory() deallocates memory associated with the memory manager.
-%
+		%
 %  The format of the DestroyMagickMemory method is:
 %
 %      DestroyMagickMemory(void)
@@ -425,7 +480,7 @@ MagickExport void *CopyMagickMemory(void *destination,const void *source,
 */
 MagickExport void DestroyMagickMemory(void)
 {
-#if defined(UseEmbeddableMagick)
+#if defined(MAGICKCORE_EMBEDDABLE_SUPPORT)
   register long
     i;
 
@@ -433,17 +488,17 @@ MagickExport void DestroyMagickMemory(void)
   RelinquishSemaphoreInfo(memory_semaphore);
   for (i=0; i < (long) memory_info.number_segments; i++)
     if (memory_info.segments[i]->mapped == MagickFalse)
-      free(memory_info.segments[i]->allocation);
+      memory_methods.destroy_memory_handler(memory_info.segments[i]->allocation);
     else
       (void) UnmapBlob(memory_info.segments[i]->allocation,
         memory_info.segments[i]->length);
   free_segments=(DataSegmentInfo *) NULL;
   (void) ResetMagickMemory(&memory_info,0,sizeof(memory_info));
-  memory_semaphore=DestroySemaphoreInfo(memory_semaphore);
+  DestroySemaphoreInfo(&memory_semaphore);
 #endif
 }
 
-#if defined(UseEmbeddableMagick)
+#if defined(MAGICKCORE_EMBEDDABLE_SUPPORT)
 /*
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %                                                                             %
@@ -464,7 +519,7 @@ MagickExport void DestroyMagickMemory(void)
 %
 %  A description of each parameter follows:
 %
-%    o size: The size of the memory in bytes we require.
+%    o size: the size of the memory in bytes we require.
 %
 */
 static MagickBooleanType ExpandHeap(size_t size)
@@ -492,7 +547,7 @@ static MagickBooleanType ExpandHeap(size_t size)
   segment=MapBlob(-1,IOMode,0,blocksize);
   mapped=segment != (void *) NULL ? MagickTrue : MagickFalse;
   if (segment == (void *) NULL)
-    segment=(void *) malloc(blocksize);
+    segment=(void *) memory_methods.acquire_memory_handler(blocksize);
   if (segment == (void *) NULL)
     return(MagickFalse);
   segment_info=(DataSegmentInfo *) free_segments;
@@ -524,6 +579,48 @@ static MagickBooleanType ExpandHeap(size_t size)
 %                                                                             %
 %                                                                             %
 %                                                                             %
+%   G e t M a g i c k M e m o r y M e t h o d s                               %
+%                                                                             %
+%                                                                             %
+%                                                                             %
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%
+%  GetMagickMemoryMethods() gets the methods to acquire, resize, and destroy
+%  memory.
+%
+%  The format of the GetMagickMemoryMethods() method is:
+%
+%      void GetMagickMemoryMethods(AcquireMemoryHandler *acquire_memory_handler,
+%        ResizeMemoryHandler *resize_memory_handler,
+%        DestroyMemoryHandler *destroy_memory_handler)
+%
+%  A description of each parameter follows:
+%
+%    o acquire_memory_handler: method to acquire memory (e.g. malloc).
+%
+%    o resize_memory_handler: method to resize memory (e.g. realloc).
+%
+%    o destroy_memory_handler: method to destroy memory (e.g. free).
+%
+*/
+MagickExport void GetMagickMemoryMethods(
+  AcquireMemoryHandler *acquire_memory_handler,
+  ResizeMemoryHandler *resize_memory_handler,
+  DestroyMemoryHandler *destroy_memory_handler)
+{
+  assert(acquire_memory_handler != (AcquireMemoryHandler *) NULL);
+  assert(resize_memory_handler != (ResizeMemoryHandler *) NULL);
+  assert(destroy_memory_handler != (DestroyMemoryHandler *) NULL);
+  *acquire_memory_handler=memory_methods.acquire_memory_handler;
+  *resize_memory_handler=memory_methods.resize_memory_handler;
+  *destroy_memory_handler=memory_methods.destroy_memory_handler;
+}
+
+/*
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%                                                                             %
+%                                                                             %
+%                                                                             %
 %   R e l i n q u i s h M a g i c k M e m o r y                               %
 %                                                                             %
 %                                                                             %
@@ -546,8 +643,8 @@ MagickExport void *RelinquishMagickMemory(void *memory)
 {
   if (memory == (void *) NULL)
     return((void *) NULL);
-#if !defined(UseEmbeddableMagick)
-  free(memory);
+#if !defined(MAGICKCORE_EMBEDDABLE_SUPPORT)
+  memory_methods.destroy_memory_handler(memory);
 #else
   assert((SizeOfBlock(memory) % (4*sizeof(size_t))) == 0);
   assert((*BlockHeader(NextBlock(memory)) & PreviousBlockBit) != 0);
@@ -643,11 +740,11 @@ MagickExport void *ResetMagickMemory(void *memory,int byte,const size_t size)
 %
 %    o memory: A pointer to a memory allocation.
 %
-%    o size: The new size of the allocated memory.
+%    o size: the new size of the allocated memory.
 %
 */
 
-#if defined(UseEmbeddableMagick)
+#if defined(MAGICKCORE_EMBEDDABLE_SUPPORT)
 static inline void *ResizeBlock(void *block,size_t size)
 {
   register void
@@ -674,8 +771,8 @@ MagickExport void *ResizeMagickMemory(void *memory,const size_t size)
 
   if (memory == (void *) NULL)
     return(AcquireMagickMemory(size));
-#if !defined(UseEmbeddableMagick)
-  block=realloc(memory,size == 0 ? 1UL : size);
+#if !defined(MAGICKCORE_EMBEDDABLE_SUPPORT)
+  block=memory_methods.resize_memory_handler(memory,size == 0 ? 1UL : size);
   if (block == (void *) NULL)
     memory=RelinquishMagickMemory(memory);
 #else
@@ -687,8 +784,7 @@ MagickExport void *ResizeMagickMemory(void *memory,const size_t size)
         {
           RelinquishSemaphoreInfo(memory_semaphore);
           memory=RelinquishMagickMemory(memory);
-          ThrowMagickFatalException(ResourceLimitFatalError,
-            "MemoryAllocationFailed",GetExceptionMessage(errno));
+          ThrowFatalException(ResourceLimitFatalError,"MemoryAllocationFailed");
         }
       block=ResizeBlock(memory,size == 0 ? 1UL : size);
       assert(block != (void *) NULL);
@@ -698,3 +794,93 @@ MagickExport void *ResizeMagickMemory(void *memory,const size_t size)
 #endif
   return(block);
 }
+
+/*
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%                                                                             %
+%                                                                             %
+%                                                                             %
+%   R e s i z e Q u a n t u m M e m o r y                                     %
+%                                                                             %
+%                                                                             %
+%                                                                             %
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%
+%  ResizeQuantumMemory() changes the size of the memory and returns a pointer
+%  to the (possibly moved) block.  The contents will be unchanged up to the
+%  lesser of the new and old sizes.
+%
+%  The format of the ResizeQuantumMemory method is:
+%
+%      void *ResizeQuantumMemory(void *memory,const size_t count,
+%        const size_t quantum)
+%
+%  A description of each parameter follows:
+%
+%    o memory: A pointer to a memory allocation.
+%
+%    o count: the number of quantum elements to allocate.
+%
+%    o quantum: the number of bytes in each quantum.
+%
+*/
+MagickExport void *ResizeQuantumMemory(void *memory,const size_t count,
+  const size_t quantum)
+{
+  size_t
+    size;
+
+  size=count*quantum;
+  if ((count == 0) || (quantum != (size/count)))
+    {
+      memory=RelinquishMagickMemory(memory);
+      errno=ENOMEM;
+      return((void *) NULL);
+    }
+  return(ResizeMagickMemory(memory,size));
+}
+
+/*
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%                                                                             %
+%                                                                             %
+%                                                                             %
+%   S e t M a g i c k M e m o r y M e t h o d s                               %
+%                                                                             %
+%                                                                             %
+%                                                                             %
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%
+%  SetMagickMemoryMethods() sets the methods to acquire, resize, and destroy
+%  memory.
+%
+%  The format of the SetMagickMemoryMethods() method is:
+%
+%      SetMagickMemoryMethods(AcquireMemoryHandler acquire_memory_handler,
+%        ResizeMemoryHandler resize_memory_handler,
+%        DestroyMemoryHandler destroy_memory_handler)
+%
+%  A description of each parameter follows:
+%
+%    o acquire_memory_handler: method to acquire memory (e.g. malloc).
+%
+%    o resize_memory_handler: method to resize memory (e.g. realloc).
+%
+%    o destroy_memory_handler: method to destroy memory (e.g. free).
+%
+*/
+MagickExport void SetMagickMemoryMethods(
+  AcquireMemoryHandler acquire_memory_handler,
+  ResizeMemoryHandler resize_memory_handler,
+  DestroyMemoryHandler destroy_memory_handler)
+{
+  /*
+    Set memory methods.
+  */
+  if (acquire_memory_handler != (AcquireMemoryHandler) NULL)
+    memory_methods.acquire_memory_handler=acquire_memory_handler;
+  if (resize_memory_handler != (ResizeMemoryHandler) NULL)
+    memory_methods.resize_memory_handler=resize_memory_handler;
+  if (destroy_memory_handler != (DestroyMemoryHandler) NULL)
+    memory_methods.destroy_memory_handler=destroy_memory_handler;
+}
