@@ -17,7 +17,7 @@
 %                                 July 1992                                   %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2005 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2008 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -92,9 +92,9 @@
 %
 %  A description of each parameter follows:
 %
-%    o image_info: The image info.
+%    o image_info: the image info.
 %
-%    o montage_info: The montage info.
+%    o montage_info: the montage info.
 %
 */
 MagickExport MontageInfo *CloneMontageInfo(const ImageInfo *image_info,
@@ -105,8 +105,7 @@ MagickExport MontageInfo *CloneMontageInfo(const ImageInfo *image_info,
 
   clone_info=(MontageInfo *) AcquireMagickMemory(sizeof(*clone_info));
   if (clone_info == (MontageInfo *) NULL)
-    ThrowMagickFatalException(ResourceLimitFatalError,
-      "UnableToAllocateMontageInfo",image_info->filename);
+    ThrowFatalException(ResourceLimitFatalError,"MemoryAllocationFailed");
   GetMontageInfo(image_info,clone_info);
   if (montage_info == (MontageInfo *) NULL)
     return(clone_info);
@@ -229,7 +228,7 @@ MagickExport void GetMontageInfo(const ImageInfo *image_info,
   montage_info->gravity=CenterGravity;
   montage_info->pointsize=image_info->pointsize;
   montage_info->fill.opacity=OpaqueOpacity;
-  montage_info->stroke.opacity=TransparentOpacity;
+  montage_info->stroke.opacity=(Quantum) TransparentOpacity;
   montage_info->background_color=image_info->background_color;
   montage_info->border_color=image_info->border_color;
   montage_info->matte_color=image_info->matte_color;
@@ -259,7 +258,7 @@ MagickExport void GetMontageInfo(const ImageInfo *image_info,
 %
 %  A description of each parameter follows:
 %
-%    o image_info: The image info.
+%    o image_info: the image info.
 %
 %    o montage_info: Specifies a pointer to a MontageInfo structure.
 %
@@ -442,10 +441,7 @@ MagickExport Image *MontageImageList(const ImageInfo *image_info,
     progress_monitor=SetImageProgressMonitor(image,(MagickProgressMonitor) NULL,
       image->client_data);
     flags=ParseSizeGeometry(image,montage_info->geometry,&geometry);
-    if (image->filter == UndefinedFilter)
-      thumbnail=ThumbnailImage(image,geometry.width,geometry.height,exception);
-    else
-      thumbnail=ZoomImage(image,geometry.width,geometry.height,exception);
+    thumbnail=ThumbnailImage(image,geometry.width,geometry.height,exception);
     if (thumbnail == (Image *) NULL)
       break;
     image_list[i]=thumbnail;
@@ -575,7 +571,7 @@ MagickExport Image *MontageImageList(const ImageInfo *image_info,
   number_lines=0;
   for (i=0; i < (long) number_images; i++)
   {
-    value=GetImageProperty(image_list[i],"Label");
+    value=GetImageProperty(image_list[i],"label");
     if (value == (const char *) NULL)
       continue;
     if (MultilineCensus(value) > number_lines)
@@ -584,8 +580,8 @@ MagickExport Image *MontageImageList(const ImageInfo *image_info,
   /*
     Allocate next structure.
   */
-  tile_image=AllocateImage(NULL);
-  montage=AllocateImage(clone_info);
+  tile_image=AcquireImage(NULL);
+  montage=AcquireImage(clone_info);
   montage->scene=0;
   images_per_page=(number_images-1)/(tiles_per_row*tiles_per_column)+1;
   tiles=0;
@@ -656,7 +652,7 @@ MagickExport Image *MontageImageList(const ImageInfo *image_info,
       extent+=strlen(image_list[tile]->filename)+1;
       tile++;
     }
-    montage->directory=(char *) AcquireMagickMemory(extent*
+    montage->directory=(char *) AcquireQuantumMemory(extent,
       sizeof(*montage->directory));
     if ((montage->montage == (char *) NULL) ||
         (montage->directory == (char *) NULL))
@@ -786,7 +782,7 @@ MagickExport Image *MontageImageList(const ImageInfo *image_info,
           extract_info=frame_info;
           extract_info.width=width+2*frame_info.width;
           extract_info.height=height+2*frame_info.height;
-          value=GetImageProperty(image,"Label");
+          value=GetImageProperty(image,"label");
           if (value != (const char *) NULL)
             extract_info.height+=(unsigned long) ((metrics.ascent-
               metrics.descent+4)*MultilineCensus(value));
@@ -825,7 +821,7 @@ MagickExport Image *MontageImageList(const ImageInfo *image_info,
           }
           (void) CompositeImage(montage,OverCompositeOp,image,x_offset+x,
             y_offset+y);
-          value=GetImageProperty(image,"Label");
+          value=GetImageProperty(image,"label");
           if (value != (const char *) NULL)
             {
               char
@@ -873,7 +869,7 @@ MagickExport Image *MontageImageList(const ImageInfo *image_info,
         /*
           Allocate next image structure.
         */
-        AllocateNextImage(clone_info,montage);
+        AcquireNextImage(clone_info,montage);
         if (GetNextImageInList(montage) == (Image *) NULL)
           {
             montage=DestroyImageList(montage);
