@@ -1,5 +1,5 @@
 /*
-  Copyright 1999-2007 ImageMagick Studio LLC, a non-profit organization
+  Copyright 1999-2008 ImageMagick Studio LLC, a non-profit organization
   dedicated to making software imaging solutions freely available.
   
   You may not use this file except in compliance with the License.
@@ -24,31 +24,32 @@ extern "C" {
 
 typedef enum
 {
-  /* Options that are listed/parsed from tables in "options.c" */
   MagickUndefinedOptions = -1,
   MagickAlignOptions = 0,
+  MagickAlphaOptions,
   MagickBooleanOptions,
   MagickChannelOptions,
   MagickClassOptions,
   MagickClipPathOptions,
   MagickColorspaceOptions,
-  MagickCompositeOptions,
   MagickCommandOptions,
-  MagickCompressionOptions,
+  MagickComposeOptions,
+  MagickCompressOptions,
   MagickDataTypeOptions,
-  MagickDecorationOptions,
+  MagickDebugOptions,
+  MagickDecorateOptions,
   MagickDisposeOptions,
   MagickDistortOptions,
   MagickEndianOptions,
   MagickEvaluateOptions,
   MagickFillRuleOptions,
   MagickFilterOptions,
+  MagickFontsOptions,
   MagickGravityOptions,
-  MagickImageOptions,
   MagickIntentOptions,
   MagickInterlaceOptions,
   MagickInterpolateOptions,
-  MagickLayersOptions,
+  MagickLayerOptions,
   MagickLineCapOptions,
   MagickLineJoinOptions,
   MagickListOptions,
@@ -64,24 +65,26 @@ typedef enum
   MagickQuantumFormatOptions,
   MagickResolutionOptions,
   MagickResourceOptions,
+  MagickSparseColorOptions,
   MagickStorageOptions,
   MagickStretchOptions,
   MagickStyleOptions,
+  MagickTypeOptions,
   MagickVirtualPixelOptions,
-  /* Special Option Lists Indexed to a Specific List Function for that Option */
+
   MagickCoderOptions,
   MagickColorOptions,
   MagickConfigureOptions,
   MagickDelegateOptions,
+  MagickFontOptions,
   MagickFormatOptions,
   MagickMimeOptions,
   MagickLocaleOptions,
   MagickLogOptions,
   MagickMagicOptions,
   MagickModuleOptions,
-  /* MagickResourceOptions, -- duplicate Function context dependant */
-  MagickThresholdOptions,
-  MagickTypeOptions
+
+  MagickThresholdOptions
 } MagickOption;
 
 typedef struct _OptionInfo
@@ -91,6 +94,9 @@ typedef struct _OptionInfo
 
   long
     type;
+
+  MagickBooleanType
+    stealth;
 } OptionInfo;
 
 extern MagickExport char
@@ -111,7 +117,7 @@ extern MagickExport MagickBooleanType
   DefineImageOption(ImageInfo *,const char *),
   DeleteImageOption(ImageInfo *,const char *),
   IsMagickOption(const char *),
-  ListMagickOptionInfo(FILE *, const MagickOption, ExceptionInfo *),
+  ListMagickOptions(FILE *,const MagickOption,ExceptionInfo *),
   SetImageOption(ImageInfo *,const char *,const char *),
   SyncImageOptions(const ImageInfo *,Image *);
 
