@@ -177,7 +177,7 @@ MagickExport MagickBooleanType FloodfillPaintImage(Image *image,
   if (SetImageStorageClass(image,DirectClass) == MagickFalse)
     return(MagickFalse);
   if (image->matte == MagickFalse)
-    (void) SetImageOpacity(image,OpaqueOpacity);
+    (void) SetImageAlphaChannel(image,ResetAlphaChannel);
   /*
     Set floodfill state.
   */
@@ -185,7 +185,7 @@ MagickExport MagickBooleanType FloodfillPaintImage(Image *image,
     &image->exception);
   if (floodplane_image == (Image *) NULL)
     return(MagickFalse);
-  (void) SetImageOpacity(floodplane_image,OpaqueOpacity);
+  (void) SetImageAlphaChannel(floodplane_image,ResetAlphaChannel);
   segment_stack=(SegmentInfo *) AcquireQuantumMemory(MaxStacksize,
     sizeof(*segment_stack));
   if (segment_stack == (SegmentInfo *) NULL)
@@ -393,8 +393,8 @@ static unsigned long **AcquireHistogramThreadSet(const size_t count)
   unsigned long
     **histogram;
 
-  histogram=(unsigned long **) AcquireQuantumMemory(GetCacheViewMaximumThreads(),
-    sizeof(*histogram));
+  histogram=(unsigned long **) AcquireQuantumMemory(
+    GetCacheViewMaximumThreads(),sizeof(*histogram));
   if (histogram == (unsigned long **) NULL)
     return((unsigned long **) NULL);
   (void) ResetMagickMemory(histogram,0,GetCacheViewMaximumThreads()*
@@ -483,6 +483,8 @@ MagickExport Image *OilPaintImage(const Image *image,const double radius,
     register PixelPacket
       *q;
 
+    if (status == MagickFalse)
+      continue;
     id=GetCacheViewThreadId();
     p=AcquireCacheViewPixels(image_view[id],-((long) width/2L),y-(long)
       (width/2L),image->columns+width,width,exception);
@@ -537,11 +539,11 @@ MagickExport Image *OilPaintImage(const Image *image,const double radius,
     if (SyncCacheView(paint_view[id]) == MagickFalse)
       status=MagickFalse;
     if (SetImageProgress(image,OilPaintImageTag,y,image->rows) == MagickFalse)
-      y=(long) image->rows;
+      status=MagickFalse;
   }
   paint_view=DestroyCacheViewThreadSet(paint_view);
   image_view=DestroyCacheViewThreadSet(image_view);
-  histogram=(unsigned long **) DestroyHistogramThreadSet(histogram);
+  histogram=DestroyHistogramThreadSet(histogram);
   if (status == MagickFalse)
     paint_image=DestroyImage(paint_image);
   return(paint_image);
@@ -551,9 +553,11 @@ MagickExport Image *OilPaintImage(const Image *image,const double radius,
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %                                                                             %
 %                                                                             %
+%                                                                             %
 %     O p a q u e P a i n t I m a g e                                         %
 %                                                                             %
 %                                                                             %
+%                                                                             %
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
 %  OpaquePaintImage() changes any pixel that matches color with the color
@@ -642,6 +646,8 @@ MagickExport MagickBooleanType OpaquePaintImageChannel(Image *image,
     register PixelPacket
       *q;
 
+    if (status == MagickFalse)
+      continue;
     id=GetCacheViewThreadId();
     q=GetCacheViewPixels(image_view[id],0,y,image->columns,1);
     if (q == (PixelPacket *) NULL)
@@ -674,7 +680,7 @@ MagickExport MagickBooleanType OpaquePaintImageChannel(Image *image,
       status=MagickFalse;
     progress=SetImageProgress(image,OpaquePaintImageTag,y,image->rows);
     if (progress == MagickFalse)
-      y=(long) image->rows;
+      status=MagickFalse;
   }
   image_view=DestroyCacheViewThreadSet(image_view);
   return(status);
@@ -743,7 +749,7 @@ MagickExport MagickBooleanType TransparentPaintImage(Image *image,
   if (SetImageStorageClass(image,DirectClass) == MagickFalse)
     return(MagickFalse);
   if (image->matte == MagickFalse)
-    (void) SetImageOpacity(image,OpaqueOpacity);
+    (void) SetImageAlphaChannel(image,ResetAlphaChannel);
   status=MagickTrue;
   image_view=AcquireCacheViewThreadSet(image);
   #pragma omp parallel for
@@ -765,6 +771,8 @@ MagickExport MagickBooleanType TransparentPaintImage(Image *image,
     register PixelPacket
       *q;
 
+    if (status == MagickFalse)
+      continue;
     id=GetCacheViewThreadId();
     q=GetCacheViewPixels(image_view[id],0,y,image->columns,1);
     if (q == (PixelPacket *) NULL)
@@ -785,7 +793,7 @@ MagickExport MagickBooleanType TransparentPaintImage(Image *image,
       status=MagickFalse;
     progress=SetImageProgress(image,TransparentPaintImageTag,y,image->rows);
     if (progress == MagickFalse)
-      y=(long) image->rows;
+      status=MagickFalse;
   }
   image_view=AcquireCacheViewThreadSet(image);
   return(status);
