@@ -1,5 +1,5 @@
 /*
-  Copyright 1999-2007 ImageMagick Studio LLC, a non-profit organization
+  Copyright 1999-2008 ImageMagick Studio LLC, a non-profit organization
   dedicated to making software imaging solutions freely available.
   
   You may not use this file except in compliance with the License.
@@ -25,15 +25,18 @@ extern "C" {
 #include "magick/color.h"
 #include "magick/draw.h"
 
+extern MagickExport Image
+  *OilPaintImage(const Image *,const double,ExceptionInfo *);
+
 extern MagickExport MagickBooleanType
-  ColorFloodfillImage(Image *,const DrawInfo *,const PixelPacket,const long,
-    const long,const PaintMethod),
-  MatteFloodfillImage(Image *,const PixelPacket,const Quantum,const long,
-    const long,const PaintMethod),
-  PaintOpaqueImage(Image *,const MagickPixelPacket *,const MagickPixelPacket *),
-  PaintOpaqueImageChannel(Image *,const ChannelType,const MagickPixelPacket *,
-    const MagickPixelPacket *),
-  PaintTransparentImage(Image *,const MagickPixelPacket *,const Quantum);
+  FloodfillPaintImage(Image *,const ChannelType,const DrawInfo *,
+    const MagickPixelPacket *,const long,const long,const MagickBooleanType),
+  OpaquePaintImage(Image *,const MagickPixelPacket *,const MagickPixelPacket *,
+    const MagickBooleanType),
+  OpaquePaintImageChannel(Image *,const ChannelType,const MagickPixelPacket *,
+    const MagickPixelPacket *,const MagickBooleanType),
+  TransparentPaintImage(Image *,const MagickPixelPacket *,
+    const Quantum,const MagickBooleanType);
 
 #if defined(__cplusplus) || defined(c_plusplus)
 }
