@@ -967,11 +967,8 @@ MagickExport MagickBooleanType ProfileImage(Image *image,const char *name,
           (void) cmsCloseProfile(source_profile);
           (void) cmsCloseProfile(target_profile);
           if (transform == (cmsHTRANSFORM) NULL)
-            {
-              cmsDeleteTransform(transform);
-              ThrowBinaryException(ImageError,"UnableToCreateColorTransform",
-                name);
-            }
+            ThrowBinaryException(ImageError,"UnableToCreateColorTransform",
+              name);
           /*
             Transform image as dictated by the source and target image profiles.
           */
@@ -1456,7 +1453,7 @@ MagickExport MagickBooleanType SyncImageProfiles(Image *image)
   if (ReadProfileShort(endian,exif+2) != 0x002a)
     return(MagickFalse);
   /*
-    This is the offset to the first IFD.
+    This the offset to the first IFD.
   */
   offset=(ssize_t) ReadProfileLong(endian,exif+4);
   if ((size_t) offset >= length)
