@@ -1137,7 +1137,7 @@ static MagickBooleanType GetEXIFProperty(const Image *image,
   if (ReadPropertyShort(endian,exif+2) != 0x002a)
     return(MagickFalse);
   /*
-    This is the offset to the first IFD.
+    This the offset to the first IFD.
   */
   offset=(ssize_t) ReadPropertyLong(endian,exif+4);
   if ((size_t) offset >= length)
@@ -2678,6 +2678,11 @@ MagickExport char *InterpretImageProperties(const ImageInfo *image_info,
           MagickDisposeOptions,(long) image->dispose));
         break;
       }
+      case 'H':
+      {
+        q+=FormatMagickString(q,extent,"%+ld",image->page.height);
+        break;
+      }
       case 'O':
       {
         q+=FormatMagickString(q,extent,"%+ld%+ld",image->page.x,image->page.y);
@@ -2699,6 +2704,21 @@ MagickExport char *InterpretImageProperties(const ImageInfo *image_info,
         q+=FormatMagickString(q,extent,"%lu",image->delay);
         break;
       }
+      case 'W':
+      {
+        q+=FormatMagickString(q,extent,"%+ld",image->page.width);
+        break;
+      }
+      case 'X':
+      {
+        q+=FormatMagickString(q,extent,"%+ld",image->page.x);
+        break;
+      }
+      case 'Y':
+      {
+        q+=FormatMagickString(q,extent,"%+ld",image->page.y);
+        break;
+      }
       case '[':
       {
         char
