@@ -614,54 +614,29 @@ MagickExport size_t ExportQuantumPixels(Image *image,
           for (x=((long) number_pixels-7); x > 0; x-=8)
           {
             *q='\0';
-            if (IsGrayPixel(p) != MagickFalse)
-              *q|=(p->red <= (Quantum) (QuantumRange/2) ? black : white) << 7;
-            else
-              *q|=(PixelIntensity(p) > (1.0*QuantumRange/2.0) ? black :
-                white) << 7;
+            *q|=(PixelIntensityToQuantum(p) < (QuantumRange/2) ? black :
+              white) << 7;
             p++;
-            if (IsGrayPixel(p) != MagickFalse)
-              *q|=(p->red <= (Quantum) (QuantumRange/2) ? black : white) << 6;
-            else
-              *q|=(PixelIntensity(p) > (1.0*QuantumRange/2.0) ? black :
-                white) << 6;
+            *q|=(PixelIntensityToQuantum(p) < (QuantumRange/2) ? black :
+              white) << 6;
             p++;
-            if (IsGrayPixel(p) != MagickFalse)
-              *q|=(p->red <= (Quantum) (QuantumRange/2) ? black : white) << 5;
-            else
-              *q|=(PixelIntensity(p) > (1.0*QuantumRange/2.0) ? black :
-                white) << 5;
+            *q|=(PixelIntensityToQuantum(p) < (QuantumRange/2) ? black :
+              white) << 5;
             p++;
-            if (IsGrayPixel(p) != MagickFalse)
-              *q|=(p->red <= (Quantum) (QuantumRange/2) ? black : white) << 4;
-            else
-              *q|=(PixelIntensity(p) > (1.0*QuantumRange/2.0) ? black :
-                white) << 4;
+            *q|=(PixelIntensityToQuantum(p) < (QuantumRange/2) ? black :
+              white) << 4;
             p++;
-            if (IsGrayPixel(p) != MagickFalse)
-              *q|=(p->red <= (Quantum) (QuantumRange/2) ? black : white) << 3;
-            else
-              *q|=(PixelIntensity(p) > (1.0*QuantumRange/2.0) ? black :
-                white) << 3;
+            *q|=(PixelIntensityToQuantum(p) < (QuantumRange/2) ? black :
+              white) << 3;
             p++;
-            if (IsGrayPixel(p) != MagickFalse)
-              *q|=(p->red <= (Quantum) (QuantumRange/2) ? black : white) << 2;
-            else
-              *q|=(PixelIntensity(p) > (1.0*QuantumRange/2.0) ? black :
-                white) << 2;
+            *q|=(PixelIntensityToQuantum(p) < (QuantumRange/2) ? black :
+              white) << 2;
             p++;
-            if (IsGrayPixel(p) != MagickFalse)
-              *q|=(p->red <= (Quantum) (QuantumRange/2) ? black :
-                white) << 1;
-            else
-              *q|=(PixelIntensity(p) > (1.0*QuantumRange/2.0) ? black :
-                white) << 1;
+            *q|=(PixelIntensityToQuantum(p) < (QuantumRange/2) ? black :
+              white) << 1;
             p++;
-            if (IsGrayPixel(p) != MagickFalse)
-              *q|=(p->red <= (Quantum) (QuantumRange/2) ? black : white) << 0;
-            else
-              *q|=(PixelIntensity(p) > (1.0*QuantumRange/2.0) ? black :
-                white) << 0;
+            *q|=(PixelIntensityToQuantum(p) < (QuantumRange/2) ? black :
+              white) << 0;
             p++;
             q++;
           }
@@ -670,12 +645,8 @@ MagickExport size_t ExportQuantumPixels(Image *image,
               *q='\0';
               for (bit=7; bit >= (long) (8-(number_pixels % 8)); bit--)
               {
-                if (IsGrayPixel(p) != MagickFalse)
-                  *q|=(p->red <= (Quantum) (QuantumRange/2) ? black : white)
-                     << bit;
-                else
-                  *q|=(PixelIntensity(p) > (1.0*QuantumRange/2.0) ? black :
-                    white) << bit;
+                *q|=(PixelIntensityToQuantum(p) < (QuantumRange/2) ? black :
+                  white) << bit;
                 p++;
               }
               q++;
@@ -689,10 +660,7 @@ MagickExport size_t ExportQuantumPixels(Image *image,
 
           for (x=0; x < (long) (number_pixels-1) ; x+=2)
           {
-            if (IsGrayPixel(p) != MagickFalse)
-              pixel=ScaleQuantumToChar(p->red);
-            else
-              pixel=ScaleQuantumToChar(PixelIntensityToQuantum(p));
+            pixel=ScaleQuantumToChar(PixelIntensityToQuantum(p));
             *q=(((pixel >> 4) & 0xf) << 4);
             p++;
             pixel=ScaleQuantumToChar(PixelIntensityToQuantum(p));
@@ -702,10 +670,7 @@ MagickExport size_t ExportQuantumPixels(Image *image,
           }
           if ((number_pixels % 2) != 0)
             {
-              if (IsGrayPixel(p) != MagickFalse)
-                pixel=ScaleQuantumToChar(p->red);
-              else
-                pixel=ScaleQuantumToChar(PixelIntensityToQuantum(p));
+              pixel=ScaleQuantumToChar(PixelIntensityToQuantum(p));
               *q=(((pixel >> 4) & 0xf) << 4);
               p++;
               q++;
@@ -719,10 +684,7 @@ MagickExport size_t ExportQuantumPixels(Image *image,
 
           for (x=0; x < (long) number_pixels; x++)
           {
-            if (IsGrayPixel(p) != MagickFalse)
-              pixel=ScaleQuantumToChar(p->red);
-            else
-              pixel=ScaleQuantumToChar(PixelIntensityToQuantum(p));
+            pixel=ScaleQuantumToChar(PixelIntensityToQuantum(p));
             q=PopCharPixel(pixel,q);
             p++;
             q+=quantum_info->pad;
@@ -739,10 +701,7 @@ MagickExport size_t ExportQuantumPixels(Image *image,
             {
               for (x=0; x < (long) number_pixels; x++)
               {
-                if (IsGrayPixel(p) != MagickFalse)
-                  pixel=ScaleQuantumToShort(p->red);
-                else
-                  pixel=ScaleQuantumToShort(PixelIntensityToQuantum(p));
+                pixel=ScaleQuantumToShort(PixelIntensityToQuantum(p));
                 q=PopShortPixel(endian,(unsigned short) ScaleQuantumToAny(
                   (Quantum) pixel,image->depth,scale),q);
                 p++;
@@ -752,12 +711,8 @@ MagickExport size_t ExportQuantumPixels(Image *image,
             }
           for (x=0; x < (long) number_pixels; x++)
           {
-            if (IsGrayPixel(p) != MagickFalse)
-              q=PopQuantumPixel(&quantum_state,image->depth,ScaleQuantumToAny(
-                p->red,image->depth,scale),q);
-            else
-              q=PopQuantumPixel(&quantum_state,image->depth,ScaleQuantumToAny(
-                PixelIntensityToQuantum(p),image->depth,scale),q);
+            q=PopQuantumPixel(&quantum_state,image->depth,ScaleQuantumToAny(
+              PixelIntensityToQuantum(p),image->depth,scale),q);
             p++;
             q+=quantum_info->pad;
           }
@@ -773,10 +728,7 @@ MagickExport size_t ExportQuantumPixels(Image *image,
             {
               for (x=0; x < (long) number_pixels; x++)
               {
-                if (IsGrayPixel(p) != MagickFalse)
-                  pixel=ScaleQuantumToShort(p->red);
-                else
-                  pixel=ScaleQuantumToShort(PixelIntensityToQuantum(p));
+                pixel=ScaleQuantumToShort(PixelIntensityToQuantum(p));
                 q=PopShortPixel(endian,(unsigned short) (pixel >> 4),q);
                 p++;
                 q+=quantum_info->pad;
@@ -785,12 +737,8 @@ MagickExport size_t ExportQuantumPixels(Image *image,
             }
           for (x=0; x < (long) number_pixels; x++)
           {
-            if (IsGrayPixel(p) != MagickFalse)
-              q=PopQuantumPixel(&quantum_state,image->depth,ScaleQuantumToAny(
-                p->red,image->depth,scale),q);
-            else
-              q=PopQuantumPixel(&quantum_state,image->depth,ScaleQuantumToAny(
-                PixelIntensityToQuantum(p),image->depth,scale),q);
+            q=PopQuantumPixel(&quantum_state,image->depth,ScaleQuantumToAny(
+              PixelIntensityToQuantum(p),image->depth,scale),q);
             p++;
             q+=quantum_info->pad;
           }
@@ -803,10 +751,7 @@ MagickExport size_t ExportQuantumPixels(Image *image,
 
           for (x=0; x < (long) number_pixels; x++)
           {
-            if (IsGrayPixel(p) != MagickFalse)
-              pixel=ScaleQuantumToShort(p->red);
-            else
-              pixel=ScaleQuantumToShort(PixelIntensityToQuantum(p));
+            pixel=ScaleQuantumToShort(PixelIntensityToQuantum(p));
             q=PopShortPixel(endian,pixel,q);
             p++;
             q+=quantum_info->pad;
@@ -825,10 +770,7 @@ MagickExport size_t ExportQuantumPixels(Image *image,
                 float
                   pixel;
 
-                if (IsGrayPixel(p) != MagickFalse)
-                  pixel=(float) p->red;
-                else
-                  pixel=(float) PixelIntensityToQuantum(p);
+                pixel=(float) PixelIntensityToQuantum(p);
                 q=PopFloatPixel(&quantum_state,pixel,q);
                 p++;
                 q+=quantum_info->pad;
@@ -837,10 +779,7 @@ MagickExport size_t ExportQuantumPixels(Image *image,
             }
           for (x=0; x < (long) number_pixels; x++)
           {
-            if (IsGrayPixel(p) != MagickFalse)
-              pixel=ScaleQuantumToLong(p->red);
-            else
-              pixel=ScaleQuantumToLong(PixelIntensityToQuantum(p));
+            pixel=ScaleQuantumToLong(PixelIntensityToQuantum(p));
             q=PopLongPixel(endian,pixel,q);
             p++;
             q+=quantum_info->pad;
@@ -869,12 +808,8 @@ MagickExport size_t ExportQuantumPixels(Image *image,
           scale=GetQuantumScale(image->depth);
           for (x=0; x < (long) number_pixels; x++)
           {
-            if (IsGrayPixel(p) != MagickFalse)
-              q=PopQuantumPixel(&quantum_state,image->depth,ScaleQuantumToAny(
-                p->red,image->depth,scale),q);
-            else
-              q=PopQuantumPixel(&quantum_state,image->depth,ScaleQuantumToAny(
-                PixelIntensityToQuantum(p),image->depth,scale),q);
+            q=PopQuantumPixel(&quantum_state,image->depth,ScaleQuantumToAny(
+              PixelIntensityToQuantum(p),image->depth,scale),q);
             p++;
             q+=quantum_info->pad;
           }
@@ -894,34 +829,22 @@ MagickExport size_t ExportQuantumPixels(Image *image,
 
           for (x=((long) number_pixels-3); x > 0; x-=4)
           {
-            if (IsGrayPixel(p) != MagickFalse)
-              pixel=ScaleQuantumToChar(p->red);
-            else
-              pixel=ScaleQuantumToChar(PixelIntensityToQuantum(p));
+            pixel=ScaleQuantumToChar(PixelIntensityToQuantum(p));
             *q=(unsigned char) (((int) pixel != 0 ? 0x00 : 0x01) << 7);
             pixel=(unsigned char) (p->opacity == OpaqueOpacity ? 0x00 : 0x01);
             *q|=(((int) pixel != 0 ? 0x00 : 0x01) << 6);
             p++;
-            if (IsGrayPixel(p) != MagickFalse)
-              pixel=ScaleQuantumToChar(p->red);
-            else
-              pixel=ScaleQuantumToChar(PixelIntensityToQuantum(p));
+            pixel=ScaleQuantumToChar(PixelIntensityToQuantum(p));
             *q|=(((int) pixel != 0 ? 0x00 : 0x01) << 5);
             pixel=(unsigned char) (p->opacity == OpaqueOpacity ? 0x00 : 0x01);
             *q|=(((int) pixel != 0 ? 0x00 : 0x01) << 4);
             p++;
-            if (IsGrayPixel(p) != MagickFalse)
-              pixel=ScaleQuantumToChar(p->red);
-            else
-              pixel=ScaleQuantumToChar(PixelIntensityToQuantum(p));
+            pixel=ScaleQuantumToChar(PixelIntensityToQuantum(p));
             *q|=(((int) pixel != 0 ? 0x00 : 0x01) << 3);
             pixel=(unsigned char) (p->opacity == OpaqueOpacity ? 0x00 : 0x01);
             *q|=(((int) pixel != 0 ? 0x00 : 0x01) << 2);
             p++;
-            if (IsGrayPixel(p) != MagickFalse)
-              pixel=ScaleQuantumToChar(p->red);
-            else
-              pixel=ScaleQuantumToChar(PixelIntensityToQuantum(p));
+            pixel=ScaleQuantumToChar(PixelIntensityToQuantum(p));
             *q|=(((int) pixel != 0 ? 0x00 : 0x01) << 1);
             pixel=(unsigned char) (p->opacity == OpaqueOpacity ? 0x00 : 0x01);
             *q|=(((int) pixel != 0 ? 0x00 : 0x01) << 0);
@@ -933,10 +856,7 @@ MagickExport size_t ExportQuantumPixels(Image *image,
               *q='\0';
               for (bit=3; bit >= (long) (4-(number_pixels % 4)); bit-=2)
               {
-                if (IsGrayPixel(p) != MagickFalse)
-                  pixel=ScaleQuantumToChar(p->red);
-                else
-                  pixel=ScaleQuantumToChar(PixelIntensityToQuantum(p));
+                pixel=ScaleQuantumToChar(PixelIntensityToQuantum(p));
                 *q|=(((int) pixel != 0 ? 0x00 : 0x01) << (unsigned char) bit);
                 pixel=(unsigned char) (p->opacity == OpaqueOpacity ?
                   0x00 : 0x01);
@@ -955,10 +875,7 @@ MagickExport size_t ExportQuantumPixels(Image *image,
 
           for (x=0; x < (long) number_pixels ; x++)
           {
-            if (IsGrayPixel(p) != MagickFalse)
-              pixel=ScaleQuantumToChar(p->red);
-            else
-              pixel=ScaleQuantumToChar(PixelIntensityToQuantum(p));
+            pixel=ScaleQuantumToChar(PixelIntensityToQuantum(p));
             *q=(((pixel >> 4) & 0xf) << 4);
             pixel=(unsigned char) (16*QuantumScale*((Quantum) (QuantumRange-
               p->opacity))+0.5);
@@ -975,10 +892,7 @@ MagickExport size_t ExportQuantumPixels(Image *image,
 
           for (x=0; x < (long) number_pixels; x++)
           {
-            if (IsGrayPixel(p) != MagickFalse)
-              pixel=ScaleQuantumToChar(p->red);
-            else
-              pixel=ScaleQuantumToChar(PixelIntensityToQuantum(p));
+            pixel=ScaleQuantumToChar(PixelIntensityToQuantum(p));
             q=PopCharPixel(pixel,q);
             pixel=ScaleQuantumToChar((Quantum) (QuantumRange-p->opacity));
             q=PopCharPixel(pixel,q);
@@ -994,10 +908,7 @@ MagickExport size_t ExportQuantumPixels(Image *image,
 
           for (x=0; x < (long) number_pixels; x++)
           {
-            if (IsGrayPixel(p) != MagickFalse)
-              pixel=ScaleQuantumToShort(p->red);
-            else
-              pixel=ScaleQuantumToShort(PixelIntensityToQuantum(p));
+            pixel=ScaleQuantumToShort(PixelIntensityToQuantum(p));
             q=PopShortPixel(endian,pixel,q);
             pixel=ScaleQuantumToShort((Quantum) (QuantumRange-p->opacity));
             q=PopShortPixel(endian,pixel,q);
@@ -1018,10 +929,7 @@ MagickExport size_t ExportQuantumPixels(Image *image,
                 float
                   pixel;
 
-                if (IsGrayPixel(p) != MagickFalse)
-                  pixel=(float) p->red;
-                else
-                  pixel=(float) PixelIntensityToQuantum(p);
+                pixel=(float) PixelIntensityToQuantum(p);
                 q=PopFloatPixel(&quantum_state,pixel,q);
                 pixel=(float) (QuantumRange-p->opacity);
                 q=PopFloatPixel(&quantum_state,pixel,q);
@@ -1032,10 +940,7 @@ MagickExport size_t ExportQuantumPixels(Image *image,
             }
           for (x=0; x < (long) number_pixels; x++)
           {
-            if (IsGrayPixel(p) != MagickFalse)
-              pixel=ScaleQuantumToShort(p->red);
-            else
-              pixel=ScaleQuantumToLong(PixelIntensityToQuantum(p));
+            pixel=ScaleQuantumToLong(PixelIntensityToQuantum(p));
             q=PopLongPixel(endian,pixel,q);
             pixel=ScaleQuantumToLong((Quantum) (QuantumRange-p->opacity));
             q=PopLongPixel(endian,pixel,q);
@@ -1053,10 +958,7 @@ MagickExport size_t ExportQuantumPixels(Image *image,
                 double
                   pixel;
 
-                if (IsGrayPixel(p) != MagickFalse)
-                  pixel=(double) p->red;
-                else
-                  pixel=(double) PixelIntensityToQuantum(p);
+                pixel=(double) PixelIntensityToQuantum(p);
                 q=PopDoublePixel(&quantum_state,pixel,q);
                 pixel=(double) (QuantumRange-p->opacity);
                 q=PopDoublePixel(&quantum_state,pixel,q);
@@ -1071,12 +973,8 @@ MagickExport size_t ExportQuantumPixels(Image *image,
           scale=GetQuantumScale(image->depth);
           for (x=0; x < (long) number_pixels; x++)
           {
-            if (IsGrayPixel(p) != MagickFalse)
-              q=PopQuantumPixel(&quantum_state,image->depth,ScaleQuantumToAny(
-                p->red,image->depth,scale),q);
-            else
-              q=PopQuantumPixel(&quantum_state,image->depth,ScaleQuantumToAny(
-                PixelIntensityToQuantum(p),image->depth,scale),q);
+            q=PopQuantumPixel(&quantum_state,image->depth,ScaleQuantumToAny(
+              PixelIntensityToQuantum(p),image->depth,scale),q);
             q=PopQuantumPixel(&quantum_state,image->depth,ScaleQuantumToAny(
               (Quantum) (QuantumRange-p->opacity),image->depth,scale),q);
             p++;
