@@ -885,7 +885,7 @@ MagickExport MagickPixelPacket ResamplePixelColor(
     case TileVirtualPixelMethod:
     case MirrorVirtualPixelMethod:
     case RandomVirtualPixelMethod:
-      /* resampling of area always needed - no VP limits */
+      /* resampling of arealways needed - no VP limits */
       break;
   }
   if ( hit ) {
@@ -1068,7 +1068,7 @@ MagickExport MagickPixelPacket ResamplePixelColor(
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
 %  ScaleResampleFilter() does all the calculations needed to resample an image
-%  at a specific scale, defined by two scaling vectors.  This is not using
+%  at a specific scale, defined by two scaling vectors.  This not using
 %  a orthogonal scaling, but two distorted scaling vectors.
 %
 %  The input vectors are produced by either finding the derivitives of
@@ -1097,7 +1097,7 @@ MagickExport MagickPixelPacket ResamplePixelColor(
 %         for the X direction:  du/dx, dv/dx
 %         and the Y direction:  du/dy, dv/dy
 %         This defines the size and angle of the elliptical resampling area
-%         The order is the the order you generally would figure out the
+%         The order is the order you generally would figure out the
 %         deritives from the distortion equations.
 %
 */
@@ -1133,7 +1133,7 @@ MagickExport void ScaleResampleFilter(ResampleFilter *resample_filter,
   F *= F;
 #define F_UNITY 1.0
 #else
-  /* This is Paul Heckbert's recomended "Higher Quality EWA" formula, from page
+  /* This Paul Heckbert's recomended "Higher Quality EWA" formula, from page
      60 in his thesis, which adds a unit circle to the elliptical area so are
      to do both Reconstruction and Prefiltering of the pixels in the
      resampling.  It also means it is likely to have at least 4 pixels within
@@ -1189,7 +1189,7 @@ MagickExport void ScaleResampleFilter(ResampleFilter *resample_filter,
     Ellipse_Area = MagickPI*Major*Minor
     ellipse_angle =  arctan2(B, A-C);
 
-    This is actually used as part of parallelogram bounds
+    This actually used as part of parallelogram bounds
     max_horizontal_cross_section =  2*sqrt(F/A) = sqrt(C-B*B/A);
     max_vertical_cross_section   =  2*sqrt(F/C) = sqrt(A-B*B/C);
     */
@@ -1293,7 +1293,7 @@ static void SetResampleFilter(ResampleFilter *resample_filter,
 
   switch ( filter ) {
   case PointFilter:
-    /* This is equivelent to turning off the EWA algroithm.
+    /* This equivelent to turning off the EWA algroithm.
        Only Interpolated lookup will be used.  */
     break;
   default:
