@@ -479,7 +479,7 @@ MagickExport void DestroyMagickResources(void)
 %                                                                             %
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
-%  GetMagickResource() returns the the specified resource.
+%  GetMagickResource() returns the specified resource.
 %
 %  The format of the GetMagickResource() method is:
 %
@@ -542,7 +542,7 @@ MagickExport MagickSizeType GetMagickResource(const ResourceType type)
 %                                                                             %
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
-%  GetMagickResource() returns the the specified resource limit.
+%  GetMagickResource() returns the specified resource limit.
 %
 %  The format of the GetMagickResourceLimit() method is:
 %
