@@ -121,6 +121,9 @@ MagickExport RectangleInfo GetImageBoundingBox(const Image *image,
   long
     y;
 
+  MagickBooleanType
+    status;
+
   MagickPixelPacket
     target[3],
     pixel;
@@ -131,11 +134,8 @@ MagickExport RectangleInfo GetImageBoundingBox(const Image *image,
   register const PixelPacket
     *p;
 
-  register IndexPacket
-    *indexes;
-
-  register long
-    x;
+  ViewInfo
+    *image_view;
 
   assert(image != (Image *) NULL);
   assert(image->signature == MagickSignature);
@@ -146,23 +146,37 @@ MagickExport RectangleInfo GetImageBoundingBox(const Image *image,
   bounds.x=(long) image->columns;
   bounds.y=(long) image->rows;
   GetMagickPixelPacket(image,&target[0]);
-  p=AcquireImagePixels(image,0,0,1,1,exception);
+  image_view=AcquireCacheView(image);
+  p=AcquireCacheViewPixels(image_view,0,0,1,1,exception);
   if (p == (const PixelPacket *) NULL)
-    return(bounds);
+    {
+      image_view=DestroyCacheView(image_view);
+      return(bounds);
+    }
   SetMagickPixelPacket(image,p,GetIndexes(image),&target[0]);
   GetMagickPixelPacket(image,&target[1]);
-  p=AcquireImagePixels(image,(long) image->columns-1,0,1,1,exception);
+  p=AcquireCacheViewPixels(image_view,(long) image->columns-1,0,1,1,exception);
   SetMagickPixelPacket(image,p,GetIndexes(image),&target[1]);
   GetMagickPixelPacket(image,&target[2]);
-  p=AcquireImagePixels(image,0,(long) image->rows-1,1,1,exception);
+  p=AcquireCacheViewPixels(image_view,0,(long) image->rows-1,1,1,exception);
   SetMagickPixelPacket(image,p,GetIndexes(image),&target[2]);
-  GetMagickPixelPacket(image,&pixel);
+  status=MagickTrue;
   for (y=0; y < (long) image->rows; y++)
   {
-    p=AcquireImagePixels(image,0,y,image->columns,1,exception);
+    register const PixelPacket
+      *p;
+
+    register IndexPacket
+      *indexes;
+
+    register long
+      x;
+
+    p=AcquireCacheViewPixels(image_view,0,y,image->columns,1,exception);
     if (p == (const PixelPacket *) NULL)
       break;
-    indexes=GetIndexes(image);
+    indexes=GetCacheViewIndexes(image_view);
+    GetMagickPixelPacket(image,&pixel);
     for (x=0; x < (long) image->columns; x++)
     {
       SetMagickPixelPacket(image,p,indexes+x,&pixel);
@@ -181,6 +195,7 @@ MagickExport RectangleInfo GetImageBoundingBox(const Image *image,
       p++;
     }
   }
+  image_view=DestroyCacheView(image_view);
   if ((bounds.width == 0) || (bounds.height == 0))
     (void) ThrowMagickException(exception,GetMagickModule(),OptionWarning,
       "GeometryDoesNotContainImage","`%s'",image->filename);
@@ -189,6 +204,7 @@ MagickExport RectangleInfo GetImageBoundingBox(const Image *image,
       bounds.width-=(bounds.x-1);
       bounds.height-=(bounds.y-1);
     }
+/* printf("%lux%lu%+ld%+ld\n",bounds.width,bounds.height,bounds.x,bounds.y); */
   return(bounds);
 }
 
@@ -233,6 +249,9 @@ MagickExport unsigned long GetImageChannelDepth(const Image *image,
   long
     y;
 
+  MagickBooleanType
+    status;
+
   register long
     id;
 
@@ -254,6 +273,7 @@ MagickExport unsigned long GetImageChannelDepth(const Image *image,
     GetCacheViewMaximumThreads(),sizeof(*current_depth));
   if (current_depth == (unsigned long *) NULL)
     ThrowFatalException(ResourceLimitFatalError,"MemoryAllocationFailed");
+  status=MagickTrue;
   for (id=0; id < (long) GetCacheViewMaximumThreads(); id++)
     current_depth[id]=1;
   if ((image->storage_class == PseudoClass) && (image->matte == MagickFalse))
@@ -268,6 +288,8 @@ MagickExport unsigned long GetImageChannelDepth(const Image *image,
       #pragma omp parallel for
       for (i=0; i < (long) image->colors; i++)
       {  
+        if (status == MagickFalse)
+          continue;
         id=GetCacheViewThreadId();
         while (current_depth[id] < MAGICKCORE_QUANTUM_DEPTH)
         {
@@ -315,6 +337,8 @@ MagickExport unsigned long GetImageChannelDepth(const Image *image,
       id,
       x;
 
+    if (status == MagickFalse)
+      continue;
     id=GetCacheViewThreadId();
     p=AcquireCacheViewPixels(image_view[id],0,y,image->columns,1,exception);
     if (p == (const PixelPacket *) NULL)
@@ -355,7 +379,7 @@ MagickExport unsigned long GetImageChannelDepth(const Image *image,
       p++;
     }
     if (current_depth[id] == MAGICKCORE_QUANTUM_DEPTH)
-      y=(long) image->rows;
+      status=MagickFalse;
   }
   image_view=DestroyCacheViewThreadSet(image_view);
   depth=current_depth[0];
@@ -680,7 +704,7 @@ MagickExport MagickBooleanType GetImageChannelRange(const Image *image,
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
 %  GetImageChannelStatistics() returns statistics for each channel in the
-%  image.  The statistics incude the channel depth, its minima and
+%  image.  The statistics incude the channel depth, its minimand
 %  maxima, the mean, and the standard deviation.  You can access the red
 %  channel mean, for example, like this:
 %
@@ -1038,6 +1062,8 @@ MagickExport MagickBooleanType SetImageChannelDepth(Image *image,
     register PixelPacket
       *q;
 
+    if (status == MagickFalse)
+      continue;
     id=GetCacheViewThreadId();
     q=GetCacheViewPixels(image_view[id],0,y,image->columns,1);
     if (q == (PixelPacket *) NULL)
