@@ -1013,14 +1013,11 @@ MagickExport long FormatMagickSize(const MagickSizeType size,char *format)
   static const char
     *units[] = { "b", "kb", "mb", "gb", "tb", "pb", "eb", (char *) NULL };
 
-  length=(double) ((MagickOffsetType) (size/2))*2.0;
+  length=1.0*size;
   for (i=0; (length >= 1024.0) && (units[i+1] != (const char *) NULL); i++)
     length/=1024.0;
-  if (i == 0)
-    count=FormatMagickString(format,MaxTextExtent,"%g%s",length,units[i]);
-  else
-    count=FormatMagickString(format,MaxTextExtent,"%.*g%s",(int) (i+1),length,
-      units[i]);
+  count=FormatMagickString(format,MaxTextExtent,"%.*g%s",(int) (i+2),length,
+    units[i]);
   return(count);
 }
 
