@@ -271,6 +271,16 @@ MagickExport Image *AdaptiveThresholdImage(const Image *image,
 %  BilevelImage() changes the value of individual pixels based on the
 %  intensity of each pixel channel.  The result is a high-contrast image.
 %
+%  More precisely each channel value of the image is 'thresholded' so that if
+%  it is equal to or less than the given value it is set to zero, while any
+%  value greater than that give is set to it maximum or QuantumRange.
+%
+%  This function is what is used to implement the "-threshold" operator for
+%  the command line API.
+%
+%  If the default channel setting is given the image is thresholded using just
+%  the gray 'intensity' of the image, rather than the individual channels.
+%
 %  The format of the BilevelImageChannel method is:
 %
 %      MagickBooleanType BilevelImage(Image *image,const double threshold)
@@ -285,6 +295,10 @@ MagickExport Image *AdaptiveThresholdImage(const Image *image,
 %
 %    o threshold: define the threshold values.
 %
+% Aside: You can get the same results as operator using LevelImageChannels()
+% using the 'threshold' value for both the black_point and the white_point,
+% though it may be slightly slower.
+%
 */
 
 MagickExport MagickBooleanType BilevelImage(Image *image,const double threshold)
@@ -683,7 +697,7 @@ MagickExport ThresholdMap *GetThresholdMapFile(const char *xml,
     return(map);
   }
 
-  /* Allocate the theshold levels array */
+  /* Allocate theshold levels array */
   content = GetXMLTreeContent(levels);
   if ( content == (char *)NULL ) {
     (void) ThrowMagickException(exception,GetMagickModule(),OptionError,
@@ -1125,7 +1139,7 @@ MagickExport MagickBooleanType OrderedPosterizeImageChannel(Image *image,
   }
 #else
   /* Parse level values as a geometry */
-  /* This is difficult!
+  /* This difficult!
    * How to map   GeometryInfo structure elements into
    * LongPixelPacket structure elements, but according to channel?
    * Note the channels list may skip elements!!!!
