@@ -81,7 +81,7 @@
 %
 %  A description of each parameter follows:
 %
-%    o image: The image.
+%    o image: the image.
 %
 %    o chop_info: Define the region of the image to chop.
 %
@@ -228,6 +228,7 @@ MagickExport Image *ChopImage(const Image *image,const RectangleInfo *chop_info,
           break;
       }
   }
+  chop_image->type=image->type;
   return(chop_image);
 }
 
@@ -251,7 +252,7 @@ MagickExport Image *ChopImage(const Image *image,const RectangleInfo *chop_info,
 %
 %  A description of each parameter follows:
 %
-%    o image: The image sequence.
+%    o image: the image sequence.
 %
 %    o exception: Return any errors or warnings in this structure.
 %
@@ -396,7 +397,7 @@ MagickExport Image *ConsolidateCMYKImages(const Image *images,
 %
 %  A description of each parameter follows:
 %
-%    o image: The image.
+%    o image: the image.
 %
 %    o geometry: Define the region of the image to crop with members
 %      x, y, width, and height.
@@ -465,9 +466,7 @@ MagickExport Image *CropImage(const Image *image,const RectangleInfo *geometry,
       ((page.y-bounding_box.y) > (long) image->rows))
     {
       /*
-        Crop missed the image on the virtual canvas
-        Give warnign and return a 'missed image'
-        Special case, for 'background' disposed GIF animation frames.
+        Crop is not within virtual canvas, return 1 pixel transparent image.
       */
       (void) ThrowMagickException(exception,GetMagickModule(),OptionWarning,
         "GeometryDoesNotContainImage","`%s'",image->filename);
@@ -538,13 +537,13 @@ MagickExport Image *CropImage(const Image *image,const RectangleInfo *geometry,
     }
   crop_image->page.x=bounding_box.x;
   crop_image->page.y=bounding_box.y;
-  image_view=OpenCacheView(image);
-  crop_view=OpenCacheView(crop_image);
+  image_view=AcquireCacheView(image);
+  crop_view=AcquireCacheView(crop_image);
   for (y=0; y < (long) crop_image->rows; y++)
   {
     p=AcquireCacheViewPixels(image_view,page.x,page.y+y,crop_image->columns,1,
       exception);
-    q=SetCacheView(crop_view,0,y,crop_image->columns,1);
+    q=SetCacheViewPixels(crop_view,0,y,crop_image->columns,1);
     if ((p == (const PixelPacket *) NULL) || (q == (PixelPacket *) NULL))
       break;
     (void) CopyMagickMemory(q,p,(size_t) crop_image->columns*sizeof(*q));
@@ -565,8 +564,9 @@ MagickExport Image *CropImage(const Image *image,const RectangleInfo *geometry,
           break;
       }
   }
-  crop_view=CloseCacheView(crop_view);
-  image_view=CloseCacheView(image_view);
+  crop_view=DestroyCacheView(crop_view);
+  image_view=DestroyCacheView(image_view);
+  crop_image->type=image->type;
   return(crop_image);
 }
 
@@ -590,7 +590,7 @@ MagickExport Image *CropImage(const Image *image,const RectangleInfo *geometry,
 %
 %  A description of each parameter follows:
 %
-%    o image: The image.
+%    o image: the image.
 %
 %    o geometry: Define the region of the image to extend with members
 %      x, y, width, and height.
@@ -689,7 +689,7 @@ MagickExport Image *ExcerptImage(const Image *image,
 %
 %  A description of each parameter follows:
 %
-%    o image: The image.
+%    o image: the image.
 %
 %    o geometry: Define the region of the image to extend with members
 %      x, y, width, and height.
@@ -751,7 +751,7 @@ MagickExport Image *ExtentImage(const Image *image,
 %
 %  A description of each parameter follows:
 %
-%    o image: The image.
+%    o image: the image.
 %
 %    o exception: Return any errors or warnings in this structure.
 %
@@ -819,6 +819,7 @@ MagickExport Image *FlipImage(const Image *image,ExceptionInfo *exception)
           break;
       }
   }
+  flip_image->type=image->type;
   return(flip_image);
 }
 
@@ -842,7 +843,7 @@ MagickExport Image *FlipImage(const Image *image,ExceptionInfo *exception)
 %
 %  A description of each parameter follows:
 %
-%    o image: The image.
+%    o image: the image.
 %
 %    o exception: Return any errors or warnings in this structure.
 %
@@ -917,6 +918,7 @@ MagickExport Image *FlopImage(const Image *image,ExceptionInfo *exception)
           break;
       }
   }
+  flop_image->type=image->type;
   return(flop_image);
 }
 
@@ -940,11 +942,11 @@ MagickExport Image *FlopImage(const Image *image,ExceptionInfo *exception)
 %
 %  A description of each parameter follows:
 %
-%    o image: The image.
+%    o image: the image.
 %
-%    o x_offset: The number of columns to roll in the horizontal direction.
+%    o x_offset: the number of columns to roll in the horizontal direction.
 %
-%    o y_offset: The number of rows to roll in the vertical direction.
+%    o y_offset: the number of rows to roll in the vertical direction.
 %
 %    o exception: Return any errors or warnings in this structure.
 %
@@ -1037,6 +1039,7 @@ MagickExport Image *RollImage(const Image *image,const long x_offset,
           break;
       }
   }
+  roll_image->type=image->type;
   return(roll_image);
 }
 
@@ -1066,7 +1069,7 @@ MagickExport Image *RollImage(const Image *image,const long x_offset,
 %      image.  A null image is returned if there is a memory shortage or
 %      if the image width or height is zero.
 %
-%    o image: The image.
+%    o image: the image.
 %
 %    o shave_info: Specifies a pointer to a RectangleInfo which defines the
 %      region of the image to crop.
@@ -1126,7 +1129,7 @@ MagickExport Image *ShaveImage(const Image *image,
 %
 %  A description of each parameter follows:
 %
-%    o image: The image.
+%    o image: the image.
 %
 %    o geometry: Define the region of the image to splice with members
 %      x, y, width, and height.
@@ -1370,7 +1373,7 @@ MagickExport Image *SpliceImage(const Image *image,
 %
 %  A description of each parameter follows:
 %
-%    o image: The image The transformed image is returned as this parameter.
+%    o image: the image The transformed image is returned as this parameter.
 %
 %    o crop_geometry: A crop geometry string.  This geometry defines a
 %      subregion of the image to crop.
@@ -1515,7 +1518,7 @@ MagickExport MagickBooleanType TransformImage(Image **image,
 %
 %  A description of each parameter follows:
 %
-%    o image: The image The transformed image is returned as this parameter.
+%    o image: the image The transformed image is returned as this parameter.
 %
 %    o crop_geometry: A crop geometry string.  This geometry defines a
 %      subregion of the image to crop.
@@ -1554,6 +1557,7 @@ MagickExport MagickBooleanType TransformImages(Image **images,
     AppendImageToList(&transform_images,image);
   }
   *images=transform_images;
+  image_list=(Image **) RelinquishMagickMemory(image_list);
   return(status != 0 ? MagickTrue : MagickFalse);
 }
 
@@ -1577,7 +1581,7 @@ MagickExport MagickBooleanType TransformImages(Image **images,
 %
 %  A description of each parameter follows:
 %
-%    o image: The image.
+%    o image: the image.
 %
 %    o exception: Return any errors or warnings in this structure.
 %
@@ -1676,7 +1680,7 @@ MagickExport Image *TransposeImage(const Image *image,ExceptionInfo *exception)
 %
 %  A description of each parameter follows:
 %
-%    o image: The image.
+%    o image: the image.
 %
 %    o exception: Return any errors or warnings in this structure.
 %
@@ -1780,7 +1784,7 @@ MagickExport Image *TransverseImage(const Image *image,ExceptionInfo *exception)
 %
 %  A description of each parameter follows:
 %
-%    o image: The image.
+%    o image: the image.
 %
 %    o exception: Return any errors or warnings in this structure.
 %
