@@ -252,7 +252,7 @@ MagickExport MagickBooleanType AcquireUniqueSymbolicLink(const char *source,
 %
 %  A description of each parameter follows.
 %
-%   o  format:  Specifies a pointer to an array of characters.  This is the
+%   o  format:  Specifies a pointer to an array of characters.  This the
 %      format of the image.
 %
 %   o  filename:  Specifies a pointer to an array of characters.  The unique
@@ -1252,7 +1252,7 @@ static int IsDirectory(const char *path)
 */
 MagickExport MagickBooleanType IsMagickTrue(const char *value)
 {
-  if (value == (char *) NULL)
+  if (value == (const char *) NULL)
     return(MagickFalse);
   if (LocaleCompare(value,"true") == 0)
     return(MagickTrue);
