@@ -239,7 +239,7 @@ int main ( int argc, char **argv )
       goto program_exit;
     }
 
-   original =DestroyImage( original );
+   original =DestroyImageList( original );
   original = (Image*)NULL;
 
   /*
@@ -329,13 +329,13 @@ int main ( int argc, char **argv )
  program_exit:
   (void) fflush(stdout);
   if (original)
-     original =DestroyImage( original );
+     original =DestroyImageList( original );
   original = 0;
   if (final)
     {
       if (getenv("SHOW_RESULT") != 0)
 			  DisplayImages( imageInfo, final );
-       final =DestroyImage( final );
+       final =DestroyImageList( final );
     }
   final = 0;
   if (pixels)
