@@ -96,15 +96,15 @@ int main(int argc,char **argv)
   }
   image_info=AcquireImageInfo();
   status=CompositeImageCommand(image_info,argc,argv,(char **) NULL,exception);
-  if ((status == MagickFalse) || (exception->severity != UndefinedException))
+  if (exception->severity != UndefinedException)
     {
-      if ((exception->severity < ErrorException) &&
-          (regard_warnings == MagickFalse))
+      if ((exception->severity > ErrorException) ||
+          (regard_warnings != MagickFalse))
         status=MagickTrue;
       CatchException(exception);
     }
   image_info=DestroyImageInfo(image_info);
   exception=DestroyExceptionInfo(exception);
   MagickCoreTerminus();
-  return(status == MagickFalse ? 1 : 0);
+  return(status == MagickFalse ? 0 : 1);
 }
