@@ -76,9 +76,9 @@
 %
 %  A description of each parameter follows:
 %
-%    o image_info: The image info.
+%    o image_info: the image info.
 %
-%    o argc: The number of elements in the argument vector.
+%    o argc: the number of elements in the argument vector.
 %
 %    o argv: A text array containing the command line arguments.
 %
@@ -125,11 +125,13 @@ static void AnimateUsage(void)
     *settings[]=
     {
       "-alpha option        activate, deactivate, reset, or set the alpha channel",
-      "-authenticate value  decrypt image with this password",
+      "-authenticate password",
+      "                     decipher image with this password",
       "-backdrop            display image centered on a backdrop",
       "-channel type        apply option to select image channels",
       "-colormap type       Shared or Private",
       "-colorspace type     alternate image colorspace",
+      "-decipher filename   convert cipher pixels to plain pixels",
       "-define format:option",
       "                     define one or more image format options",
       "-delay value         display the next image after pausing",
@@ -156,6 +158,7 @@ static void AnimateUsage(void)
       "-quiet               suppress all warning messages",
       "-regard-warnings     pay attention to warning messages",
       "-remote command      execute a command in an remote display process",
+      "-respect-parenthesis settings remain in effect until parenthesis boundary",
       "-sampling-factor geometry",
       "                     horizontal and vertical sampling factor",
       "-scenes range        image scene range",
@@ -230,8 +233,7 @@ WandExport MagickBooleanType AnimateImageCommand(ImageInfo *image_info,
       display=(Display *) NULL; \
     } \
   XDestroyResourceInfo(&resource_info); \
-  for ( ; k >= 0; k--) \
-    image_stack[k]=DestroyImageList(image_stack[k]); \
+  DestroyImageStack(); \
   for (i=0; i < (long) argc; i++) \
     argv[i]=DestroyString(argv[i]); \
   argv=(char **) RelinquishMagickMemory(argv); \
@@ -262,7 +264,10 @@ WandExport MagickBooleanType AnimateImageCommand(ImageInfo *image_info,
     *display;
 
   Image
-    *image_stack[MaxImageStackDepth+1];
+    *image;
+
+  ImageStack
+    image_stack[MaxImageStackDepth+1];
 
   long
     first_scene,
@@ -307,7 +312,7 @@ WandExport MagickBooleanType AnimateImageCommand(ImageInfo *image_info,
           (void) fprintf(stdout,"Version: %s\n",
             GetMagickVersion((unsigned long *) NULL));
           (void) fprintf(stdout,"Copyright: %s\n\n",GetMagickCopyright());
-          return(MagickTrue);
+          return(MagickFalse);
         }
     }
   status=MagickTrue;
@@ -316,8 +321,8 @@ WandExport MagickBooleanType AnimateImageCommand(ImageInfo *image_info,
   first_scene=0;
   j=1;
   k=0;
-  image_stack[k]=NewImageList();
   last_scene=0;
+  NewImageStack();
   option=(char *) NULL;
   pend=MagickFalse;
   resource_database=(XrmDatabase) NULL;
@@ -363,8 +368,8 @@ WandExport MagickBooleanType AnimateImageCommand(ImageInfo *image_info,
       XDisplayName(server_name));
   (void) XSetErrorHandler(XError);
   resource_database=XGetResourceDatabase(display,GetClientName());
-  XGetResourceInfo(resource_database,GetClientName(),&resource_info);
-  image_info=resource_info.image_info;
+  XGetResourceInfo(image_info,resource_database,GetClientName(),
+    &resource_info);
   quantize_info=resource_info.quantize_info;
   image_info->density=XGetResourceInstance(resource_database,GetClientName(),
     "density",(char *) NULL);
@@ -388,7 +393,7 @@ WandExport MagickBooleanType AnimateImageCommand(ImageInfo *image_info,
     if (i < (long) argc)
       option=argv[i];
     else
-      if (image_stack[k] != (Image *) NULL)
+      if (image != (Image *) NULL)
         break;
       else
         if (isatty(STDIN_FILENO) != MagickFalse)
@@ -409,40 +414,35 @@ WandExport MagickBooleanType AnimateImageCommand(ImageInfo *image_info,
           }
     if (LocaleCompare(option,"(") == 0)
       {
+        FireImageStack(MagickFalse,MagickTrue,pend);
         if (k == MaxImageStackDepth)
           ThrowAnimateException(OptionError,"ParenthesisNestedTooDeeply",
             option);
-        MogrifyImageStack(image_stack[k],MagickTrue,pend);
-        k++;
-        image_stack[k]=NewImageList();
+        PushImageStack();
         continue;
       }
     if (LocaleCompare(option,")") == 0)
       {
+        FireImageStack(MagickFalse,MagickTrue,MagickTrue);
         if (k == 0)
           ThrowAnimateException(OptionError,"UnableToParseExpression",option);
-        if (image_stack[k] != (Image *) NULL)
-          {
-            MogrifyImageStack(image_stack[k],MagickTrue,MagickTrue);
-            AppendImageToList(&image_stack[k-1],image_stack[k]);
-          }
-        k--;
+        PopImageStack();
         continue;
       }
     if (IsMagickOption(option) == MagickFalse)
       {
-        Image
-          *image;
-
         /*
           Option is a file name.
         */
-        MogrifyImageStack(image_stack[k],MagickTrue,pend);
+        FireImageStack(MagickFalse,MagickTrue,pend);
         for (scene=first_scene; scene <= last_scene ; scene++)
         {
           const char
             *filename;
 
+          Image
+            *images;
+
           /*
             Read image.
           */
@@ -469,17 +469,17 @@ WandExport MagickBooleanType AnimateImageCommand(ImageInfo *image_info,
               (void) CopyMagickString(image_info->filename,filename,
                 MaxTextExtent);
             }
-          image=ReadImage(image_info,exception);
-          status&=(image != (Image *) NULL) &&
+          images=ReadImage(image_info,exception);
+          status&=(images != (Image *) NULL) &&
             (exception->severity < ErrorException);
-          if (image == (Image *) NULL)
+          if (images == (Image *) NULL)
             continue;
-          AppendImageToList(&image_stack[k],image);
-          MogrifyImageStack(image_stack[k],MagickFalse,MagickTrue);
+          AppendImageStack(images);
+          FireImageStack(MagickFalse,MagickFalse,MagickTrue);
         }
         continue;
       }
-    pend=image_stack[k] != (Image *) NULL ? MagickTrue : MagickFalse;
+    pend=image != (Image *) NULL ? MagickTrue : MagickFalse;
     switch (*(option+1))
     {
       case 'a':
@@ -585,9 +585,9 @@ WandExport MagickBooleanType AnimateImageCommand(ImageInfo *image_info,
             Image
               *clone_images;
 
-            clone_images=image_stack[k];
+            clone_images=image;
             if (k != 0)
-              clone_images=image_stack[k-1];
+              clone_images=image_stack[k-1].image;
             if (clone_images == (Image *) NULL)
               ThrowAnimateException(ImageError,"ImageSequenceRequired",option);
             if (*option == '+')
@@ -603,8 +603,8 @@ WandExport MagickBooleanType AnimateImageCommand(ImageInfo *image_info,
               }
             if (clone_images == (Image *) NULL)
               ThrowAnimateException(OptionError,"NoSuchImage",option);
-            MogrifyImageStack(image_stack[k],MagickTrue,MagickTrue);
-            AppendImageToList(&image_stack[k],clone_images);
+            FireImageStack(MagickFalse,MagickTrue,MagickTrue);
+            AppendImageStack(clone_images);
             break;
           }
         if (LocaleCompare("coalesce",option+1) == 0)
@@ -689,6 +689,15 @@ WandExport MagickBooleanType AnimateImageCommand(ImageInfo *image_info,
             (void) SetLogEventMask(argv[i]);
             break;
           }
+        if (LocaleCompare("decipher",option+1) == 0)
+          {
+            if (*option == '+')
+              break;
+            i++;
+            if (i == (long) (argc-1))
+              ThrowAnimateException(OptionError,"MissingArgument",option);
+            break;
+          }
         if (LocaleCompare("define",option+1) == 0)
           {
             i++;
@@ -1042,7 +1051,7 @@ WandExport MagickBooleanType AnimateImageCommand(ImageInfo *image_info,
             i++;
             if (i == (long) argc)
               ThrowAnimateException(OptionError,"MissingArgument",option);
-            resource_info.name=argv[i];
+            resource_info.name=ConstantString(argv[i]);
             break;
           }
         if (LocaleCompare("noop",option+1) == 0)
@@ -1152,6 +1161,11 @@ WandExport MagickBooleanType AnimateImageCommand(ImageInfo *image_info,
               ThrowAnimateInvalidArgumentException(option,argv[i]);
             break;
           }
+        if (LocaleCompare("respect-parenthesis",option+1) == 0)
+          {
+            respect_parenthesis=(*option == '-') ? MagickTrue : MagickFalse;
+            break;
+          }
         if (LocaleCompare("rotate",option+1) == 0)
           {
             i++;
@@ -1184,7 +1198,7 @@ WandExport MagickBooleanType AnimateImageCommand(ImageInfo *image_info,
             if (*option == '+')
               {
                 seed=(unsigned long) time((time_t *) NULL);
-                SeedRandomReservoir(seed);
+                SeedPseudoRandomGenerator(seed);
                 break;
               }
             i++;
@@ -1193,7 +1207,7 @@ WandExport MagickBooleanType AnimateImageCommand(ImageInfo *image_info,
             if (IsGeometry(argv[i]) == MagickFalse)
               ThrowAnimateInvalidArgumentException(option,argv[i]);
             seed=(unsigned long) atol(argv[i]);
-            SeedRandomReservoir(seed);
+            SeedPseudoRandomGenerator(seed);
             break;
           }
         if (LocaleCompare("scenes",option+1) == 0)
@@ -1374,19 +1388,19 @@ WandExport MagickBooleanType AnimateImageCommand(ImageInfo *image_info,
       default:
         ThrowAnimateException(OptionError,"UnrecognizedOption",option);
     }
-    fire=(MagickBooleanType) ParseMagickOption(MagickMogrifyOptions,
-      MagickFalse,option+1);
-    if (fire == MagickTrue)
-      MogrifyImageStack(image_stack[k],MagickTrue,MagickTrue);
+    fire=ParseMagickOption(MagickMogrifyOptions,MagickFalse,option+1) < 0 ? 
+      MagickFalse : MagickTrue;
+    if (fire != MagickFalse)
+      FireImageStack(MagickFalse,MagickTrue,MagickTrue);
   }
   i--;
   if (k != 0)
     ThrowAnimateException(OptionError,"UnbalancedParenthesis",argv[i]);
-  if (image_stack[k] == (Image *) NULL)
+  if (image == (Image *) NULL)
     ThrowAnimateException(OptionError,"MissingAnImageFilename",argv[argc-1])
-  MogrifyImageStack(image_stack[k],MagickTrue,MagickTrue);
+  FireImageStack(MagickFalse,MagickTrue,MagickTrue);
   if (resource_info.window_id != (char *) NULL)
-    XAnimateBackgroundImage(display,&resource_info,image_stack[k]);
+    XAnimateBackgroundImage(display,&resource_info,image);
   else
     {
       Image
@@ -1396,19 +1410,19 @@ WandExport MagickBooleanType AnimateImageCommand(ImageInfo *image_info,
         Animate image to X server.
       */
       animate_image=XAnimateImages(display,&resource_info,argv,argc,
-        image_stack[k]);
+        image);
       while (animate_image != (Image *) NULL)
       {
-        image_stack[k]=animate_image;
+        image=animate_image;
         animate_image=XAnimateImages(display,&resource_info,argv,argc,
-          image_stack[k]);
+          image);
       }
     }
   DestroyAnimate();
   return(status != 0 ? MagickTrue : MagickFalse);
 #else
   (void) ThrowMagickException(exception,GetMagickModule(),MissingDelegateError,
-    "XWindowLibraryIsNotAvailable","`%s'",image_info->filename);
+    "DelegateLibrarySupportNotBuiltIn","`%s' (X11)",image_info->filename);
   AnimateUsage();
   return(MagickFalse);
 #endif
