@@ -17,7 +17,7 @@
 %                                 July 1992                                   %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2007 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2008 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -95,9 +95,9 @@ typedef struct _CompositeOptions
 %
 %  A description of each parameter follows:
 %
-%    o image_info: The image info.
+%    o image_info: the image info.
 %
-%    o argc: The number of elements in the argument vector.
+%    o argc: the number of elements in the argument vector.
 %
 %    o argv: A text array containing the command line arguments.
 %
@@ -182,8 +182,8 @@ static MagickBooleanType CompositeImageList(ImageInfo *image_info,Image **image,
               /*
                 Tile the composite image.
               */
-              (void) SetImageProperty(composite_image,
-                "[modify-outside-overlay]","false");
+              (void) SetImageArtifact(composite_image,"modify-outside-overlay",
+                "false");
               columns=composite_image->columns;
               for (y=0; y < (long) (*image)->rows; y+=composite_image->rows)
                 for (x=0; x < (long) (*image)->columns; x+=columns)
@@ -226,15 +226,27 @@ static void CompositeUsage(void)
     **p;
 
   static const char
+    *miscellaneous[]=
+    {
+      "-debug events        display copious debugging information",
+      "-help                print program options",
+      "-list type           print a list of supported option arguments",
+      "-log format          format of debugging information",
+      "-version             print version information",
+      (char *) NULL
+    },
     *operators[]=
     {
       "-blend geometry      blend images",
+      "-border geometry     surround image with a border of color",
+      "-bordercolor color   border color",
       "-colors value        preferred number of colors in the image",
+      "-decipher filename    convert cipher pixels to plain pixels",
       "-displace geometry   shift image pixels defined by a displacement map",
       "-dissolve value      dissolve the two images a given percent",
+      "-encipher filename   convert plain pixels to cipher pixels",
       "-extract geometry    extract area from image",
       "-geometry geometry   location of the composite image",
-      "-help                print program options",
       "-identify            identify the format and characteristics of the image",
       "-monochrome          transform image to black and white",
       "-negate              replace every pixel with its complementary color ",
@@ -244,6 +256,7 @@ static void CompositeUsage(void)
       "-rotate degrees      apply Paeth rotation to the image",
       "-resize geometry     resize the image",
       "-sharpen geometry    sharpen the image",
+      "-shave geometry      shave pixels from the image edges",
       "-stegano offset      hide watermark within an image",
       "-stereo              combine two image to create a stereo anaglyph",
       "-strip               strip image of all profiles and comments",
@@ -251,7 +264,6 @@ static void CompositeUsage(void)
       "-transform           affine transform image",
       "-type type           image type",
       "-unsharp geometry    sharpen the image",
-      "-version             print version information",
       "-watermark geometry  percent brightness and saturation of a watermark",
       "-write filename      write images to this file",
       (char *) NULL
@@ -259,20 +271,21 @@ static void CompositeUsage(void)
     *settings[]=
     {
       "-affine matrix       affine transform matrix",
-      "-authenticate value  decrypt image with this password",
+      "-alpha option        activate, deactivate, reset, or set the alpha channel",
+      "-authenticate password",
+      "                     decipher image with this password",
       "-blue-primary point  chromaticity blue primary point",
       "-channel type        apply option to select image channels",
       "-colorspace type     alternate image colorspace",
       "-comment string      annotate image with comment",
       "-compose operator    composite operator",
       "-compress type       type of pixel compression when writing the image",
-      "-debug events        display copious debugging information",
       "-define format:option",
       "                     define one or more image format options",
       "-depth value         image depth",
       "-density geometry    horizontal and vertical density of the image",
       "-display server      get image or font from this X server",
-      "-dispose method      GIF disposal method",
+      "-dispose method      layer disposal method",
       "-dither              apply Floyd/Steinberg error diffusion to image",
       "-encoding type       text encoding type",
       "-endian type         endianness (MSB or LSB) of the image",
@@ -285,20 +298,18 @@ static void CompositeUsage(void)
       "-interpolate method  pixel color interpolation method",
       "-label string        assign a label to an image",
       "-limit type value    pixel cache resource limit",
-      "-log format          format of debugging information",
-      "-matte               store matte channel if the image has one",
       "-monitor             monitor progress",
       "-page geometry       size and location of an image canvas (setting)",
       "-quality value       JPEG/MIFF/PNG compression level",
       "-quiet               suppress all warning messages",
       "-red-primary point   chromaticity red primary point",
       "-regard-warnings     pay attention to warning messages",
+      "-respect-parenthesis settings remain in effect until parenthesis boundary",
       "-sampling-factor geometry",
       "                     horizontal and vertical sampling factor",
       "-scene value         image scene number",
       "-seed value          seed a new sequence of pseudo-random numbers",
       "-size geometry       width and height of image",
-      "-support factor      resize support: > 1.0 is blurry, < 1.0 is sharp",
       "-transparent-color color",
       "                     transparent color",
       "-treedepth value     color tree depth",
@@ -309,8 +320,14 @@ static void CompositeUsage(void)
       "                     virtual pixel access method",
       "-white-point point   chromaticity white point",
       (char *) NULL
+    },
+    *stack_operators[]=
+    {
+      "-swap indexes        swap two images in the image sequence",
+      (char *) NULL
     };
 
+
   (void) printf("Version: %s\n",GetMagickVersion((unsigned long *) NULL));
   (void) printf("Copyright: %s\n\n",GetMagickCopyright());
   (void) printf("Usage: %s [options ...] image [options ...] composite\n"
@@ -322,6 +339,12 @@ static void CompositeUsage(void)
   (void) printf("\nImage Operators:\n");
   for (p=operators; *p != (char *) NULL; p++)
     (void) printf("  %s\n",*p);
+  (void) printf("\nImage Stack Operators:\n");
+  for (p=stack_operators; *p != (char *) NULL; p++)
+    (void) printf("  %s\n",*p);
+  (void) printf("\nMiscellaneous Options:\n");
+  for (p=miscellaneous; *p != (char *) NULL; p++)
+    (void) printf("  %s\n",*p);
   (void) printf(
     "\nBy default, the image format of `file' is determined by its magic\n");
   (void) printf(
@@ -370,8 +393,7 @@ WandExport MagickBooleanType CompositeImageCommand(ImageInfo *image_info,
 #define DestroyComposite() \
 { \
   RelinquishCompositeOptions(&composite_options); \
-  for ( ; k >= 0; k--) \
-    image_stack[k]=DestroyImageList(image_stack[k]); \
+  DestroyImageStack(); \
   for (i=0; i < (long) argc; i++) \
     argv[i]=DestroyString(argv[i]); \
   argv=(char **) RelinquishMagickMemory(argv); \
@@ -379,7 +401,7 @@ WandExport MagickBooleanType CompositeImageCommand(ImageInfo *image_info,
 #define ThrowCompositeException(asperity,tag,option) \
 { \
   (void) ThrowMagickException(exception,GetMagickModule(),asperity,tag,"`%s'", \
-    option); \
+     option == (char *) NULL ? strerror(errno) : option); \
   DestroyComposite(); \
   return(MagickFalse); \
 }
@@ -404,9 +426,12 @@ WandExport MagickBooleanType CompositeImageCommand(ImageInfo *image_info,
   Image
     *composite_image,
     *image,
-    *image_stack[MaxImageStackDepth+1],
+    *images,
     *mask_image;
 
+  ImageStack
+    image_stack[MaxImageStackDepth+1];
+
   MagickBooleanType
     fire,
     pend;
@@ -438,7 +463,7 @@ WandExport MagickBooleanType CompositeImageCommand(ImageInfo *image_info,
           (void) fprintf(stdout,"Version: %s\n",
             GetMagickVersion((unsigned long *) NULL));
           (void) fprintf(stdout,"Copyright: %s\n\n",GetMagickCopyright());
-          return(MagickTrue);
+          return(MagickFalse);
         }
     }
   if (argc < 4)
@@ -448,7 +473,7 @@ WandExport MagickBooleanType CompositeImageCommand(ImageInfo *image_info,
   format="%w,%h,%m";
   j=1;
   k=0;
-  image_stack[k]=NewImageList();
+  NewImageStack();
   option=(char *) NULL;
   pend=MagickFalse;
   status=MagickTrue;
@@ -461,62 +486,50 @@ WandExport MagickBooleanType CompositeImageCommand(ImageInfo *image_info,
   ReadCommandlLine(argc,&argv);
   status=ExpandFilenames(&argc,&argv);
   if (status == MagickFalse)
-    {
-      char
-        *message;
-
-      message=GetExceptionMessage(errno);
-      ThrowCompositeException(ResourceLimitError,"MemoryAllocationFailed",
-        message);
-      message=DestroyString(message);
-    }
+    ThrowCompositeException(ResourceLimitError,"MemoryAllocationFailed",
+      strerror(errno));
   for (i=1; i < (long) (argc-1); i++)
   {
     option=argv[i];
     if (LocaleCompare(option,"(") == 0)
       {
+        FireImageStack(MagickFalse,MagickTrue,pend);
         if (k == MaxImageStackDepth)
           ThrowCompositeException(OptionError,"ParenthesisNestedTooDeeply",
             option);
-        MogrifyImageStack(image_stack[k],MagickTrue,pend);
-        k++;
-        image_stack[k]=NewImageList();
+        PushImageStack();
         continue;
       }
     if (LocaleCompare(option,")") == 0)
       {
+        FireImageStack(MagickFalse,MagickTrue,MagickTrue);
         if (k == 0)
           ThrowCompositeException(OptionError,"UnableToParseExpression",option);
-        if (image_stack[k] != (Image *) NULL)
-          {
-            MogrifyImageStack(image_stack[k],MagickTrue,MagickTrue);
-            AppendImageToList(&image_stack[k-1],image_stack[k]);
-          }
-        k--;
+        PopImageStack();
         continue;
       }
     if (IsMagickOption(option) == MagickFalse)
       {
         Image
-          *image;
+          *images;
 
         /*
           Read input image.
         */
-        MogrifyImageStack(image_stack[k],MagickTrue,pend);
+        FireImageStack(MagickFalse,MagickTrue,pend);
         filename=argv[i];
         if ((LocaleCompare(filename,"--") == 0) && (i < (argc-1)))
           filename=argv[++i];
         (void) CopyMagickString(image_info->filename,filename,MaxTextExtent);
-        image=ReadImage(image_info,exception);
-        status&=(image != (Image *) NULL) &&
+        images=ReadImage(image_info,exception);
+        status&=(images != (Image *) NULL) &&
           (exception->severity < ErrorException);
-        if (image == (Image *) NULL)
+        if (images == (Image *) NULL)
           continue;
-        AppendImageToList(&image_stack[k],image);
+        AppendImageStack(images);
         continue;
       }
-    pend=image_stack[k] != (Image *) NULL ? MagickTrue : MagickFalse;
+    pend=image != (Image *) NULL ? MagickTrue : MagickFalse;
     switch (*(option+1))
     {
       case 'a':
@@ -532,6 +545,22 @@ WandExport MagickBooleanType CompositeImageCommand(ImageInfo *image_info,
               ThrowCompositeInvalidArgumentException(option,argv[i]);
             break;
           }
+        if (LocaleCompare("alpha",option+1) == 0)
+          {
+            long
+              type;
+
+            if (*option == '+')
+              break;
+            i++;
+            if (i == (long) argc)
+              ThrowCompositeException(OptionError,"MissingArgument",option);
+            type=ParseMagickOption(MagickAlphaOptions,MagickFalse,argv[i]);
+            if (type < 0)
+              ThrowCompositeException(OptionError,
+                "UnrecognizedAlphaChannelType",argv[i]);
+            break;
+          }
         if (LocaleCompare("authenticate",option+1) == 0)
           {
             if (*option == '+')
@@ -579,6 +608,26 @@ WandExport MagickBooleanType CompositeImageCommand(ImageInfo *image_info,
               ThrowCompositeInvalidArgumentException(option,argv[i]);
             break;
           }
+        if (LocaleCompare("border",option+1) == 0)
+          {
+            if (*option == '+')
+              break;
+            i++;
+            if (i == (long) (argc-1))
+              ThrowCompositeException(OptionError,"MissingArgument",option);
+            if (IsGeometry(argv[i]) == MagickFalse)
+              ThrowCompositeInvalidArgumentException(option,argv[i]);
+            break;
+          }
+        if (LocaleCompare("bordercolor",option+1) == 0)
+          {
+            if (*option == '+')
+              break;
+            i++;
+            if (i == (long) (argc-1))
+              ThrowCompositeException(OptionError,"MissingArgument",option);
+            break;
+          }
         ThrowCompositeException(OptionError,"UnrecognizedOption",option)
       }
       case 'c':
@@ -662,27 +711,27 @@ WandExport MagickBooleanType CompositeImageCommand(ImageInfo *image_info,
             i++;
             if (i == (long) argc)
               ThrowCompositeException(OptionError,"MissingArgument",option);
-            compose=ParseMagickOption(MagickCompositeOptions,MagickFalse,
+            compose=ParseMagickOption(MagickComposeOptions,MagickFalse,
               argv[i]);
             if (compose < 0)
-              ThrowCompositeException(OptionError,
-                "UnrecognizedComposeOperator",argv[i]);
+              ThrowCompositeException(OptionError,"UnrecognizedComposeOperator",
+                argv[i]);
             composite_options.compose=(CompositeOperator) compose;
             break;
           }
         if (LocaleCompare("compress",option+1) == 0)
           {
             long
-              compression;
+              compress;
 
             if (*option == '+')
               break;
             i++;
             if (i == (long) argc)
               ThrowCompositeException(OptionError,"MissingArgument",option);
-            compression=ParseMagickOption(MagickCompressionOptions,
-              MagickFalse,argv[i]);
-            if (compression < 0)
+            compress=ParseMagickOption(MagickCompressOptions,MagickFalse,
+              argv[i]);
+            if (compress < 0)
               ThrowCompositeException(OptionError,
                 "UnrecognizedImageCompression",argv[i]);
             break;
@@ -708,6 +757,15 @@ WandExport MagickBooleanType CompositeImageCommand(ImageInfo *image_info,
             (void) SetLogEventMask(argv[i]);
             break;
           }
+        if (LocaleCompare("decipher",option+1) == 0)
+          {
+            if (*option == '+')
+              break;
+            i++;
+            if (i == (long) (argc-1))
+              ThrowCompositeException(OptionError,"MissingArgument",option);
+            break;
+          }
         if (LocaleCompare("define",option+1) == 0)
           {
             i++;
@@ -808,6 +866,15 @@ WandExport MagickBooleanType CompositeImageCommand(ImageInfo *image_info,
       }
       case 'e':
       {
+        if (LocaleCompare("encipher",option+1) == 0)
+          {
+            if (*option == '+')
+              break;
+            i++;
+            if (i == (long) (argc-1))
+              ThrowCompositeException(OptionError,"MissingArgument",option);
+            break;
+          }
         if (LocaleCompare("encoding",option+1) == 0)
           {
             if (*option == '+')
@@ -859,8 +926,7 @@ WandExport MagickBooleanType CompositeImageCommand(ImageInfo *image_info,
             i++;
             if (i == (long) argc)
               ThrowCompositeException(OptionError,"MissingArgument",option);
-            filter=ParseMagickOption(MagickFilterOptions,MagickFalse,
-              argv[i]);
+            filter=ParseMagickOption(MagickFilterOptions,MagickFalse,argv[i]);
             if (filter < 0)
               ThrowCompositeException(OptionError,"UnrecognizedImageFilter",
                 argv[i]);
@@ -994,6 +1060,9 @@ WandExport MagickBooleanType CompositeImageCommand(ImageInfo *image_info,
           }
         if (LocaleCompare("limit",option+1) == 0)
           {
+            char
+              *p;
+
             long
               resource;
 
@@ -1010,8 +1079,8 @@ WandExport MagickBooleanType CompositeImageCommand(ImageInfo *image_info,
             i++;
             if (i == (long) argc)
               ThrowCompositeException(OptionError,"MissingArgument",option);
-            if ((LocaleCompare("unlimited",argv[i]) != 0) &&
-                (IsGeometry(argv[i]) == MagickFalse))
+            (void) strtod(argv[i],&p);
+            if ((p == argv[i]) && (LocaleCompare("unlimited",argv[i]) != 0))
               ThrowCompositeInvalidArgumentException(option,argv[i]);
             break;
           }
@@ -1135,6 +1204,11 @@ WandExport MagickBooleanType CompositeImageCommand(ImageInfo *image_info,
               ThrowCompositeInvalidArgumentException(option,argv[i]);
             break;
           }
+        if (LocaleCompare("respect-parenthesis",option+1) == 0)
+          {
+            respect_parenthesis=(*option == '-') ? MagickTrue : MagickFalse;
+            break;
+          }
         if (LocaleCompare("resize",option+1) == 0)
           {
             if (*option == '+')
@@ -1189,7 +1263,7 @@ WandExport MagickBooleanType CompositeImageCommand(ImageInfo *image_info,
             if (*option == '+')
               {
                 seed=(unsigned long) time((time_t *) NULL);
-                SeedRandomReservoir(seed);
+                SeedPseudoRandomGenerator(seed);
                 break;
               }
             i++;
@@ -1198,7 +1272,7 @@ WandExport MagickBooleanType CompositeImageCommand(ImageInfo *image_info,
             if (IsGeometry(argv[i]) == MagickFalse)
               ThrowCompositeInvalidArgumentException(option,argv[i]);
             seed=(unsigned long) atol(argv[i]);
-            SeedRandomReservoir(seed);
+            SeedPseudoRandomGenerator(seed);
             break;
           }
         if (LocaleCompare("sharpen",option+1) == 0)
@@ -1210,6 +1284,17 @@ WandExport MagickBooleanType CompositeImageCommand(ImageInfo *image_info,
               ThrowCompositeInvalidArgumentException(option,argv[i]);
             break;
           }
+        if (LocaleCompare("shave",option+1) == 0)
+          {
+            if (*option == '+')
+              break;
+            i++;
+            if (i == (long) (argc-1))
+              ThrowCompositeException(OptionError,"MissingArgument",option);
+            if (IsGeometry(argv[i]) == MagickFalse)
+              ThrowCompositeInvalidArgumentException(option,argv[i]);
+            break;
+          }
         if (LocaleCompare("size",option+1) == 0)
           {
             if (*option == '+')
@@ -1243,11 +1328,16 @@ WandExport MagickBooleanType CompositeImageCommand(ImageInfo *image_info,
         if (LocaleCompare("strip",option+1) == 0)
           break;
         if (LocaleCompare("support",option+1) == 0)
+          {
+            i++;  /* deprecated */
+            break;
+          }
+        if (LocaleCompare("swap",option+1) == 0)
           {
             if (*option == '+')
               break;
             i++;
-            if (i == (long) argc)
+            if (i == (long) (argc-1))
               ThrowCompositeException(OptionError,"MissingArgument",option);
             if (IsGeometry(argv[i]) == MagickFalse)
               ThrowCompositeInvalidArgumentException(option,argv[i]);
@@ -1306,7 +1396,7 @@ WandExport MagickBooleanType CompositeImageCommand(ImageInfo *image_info,
             i++;
             if (i == (long) argc)
               ThrowCompositeException(OptionError,"MissingArgument",option);
-            type=ParseMagickOption(MagickImageOptions,MagickFalse,argv[i]);
+            type=ParseMagickOption(MagickTypeOptions,MagickFalse,argv[i]);
             if (type < 0)
               ThrowCompositeException(OptionError,"UnrecognizedImageType",
                 argv[i]);
@@ -1423,60 +1513,53 @@ WandExport MagickBooleanType CompositeImageCommand(ImageInfo *image_info,
       default:
         ThrowCompositeException(OptionError,"UnrecognizedOption",option)
     }
-    fire=(MagickBooleanType) ParseMagickOption(MagickMogrifyOptions,
-      MagickFalse,option+1);
-    if (fire == MagickTrue)
-      MogrifyImageStack(image_stack[k],MagickTrue,MagickTrue);
+    fire=ParseMagickOption(MagickMogrifyOptions,MagickFalse,option+1) < 0 ?
+      MagickFalse : MagickTrue;
+    if (fire != MagickFalse)
+      FireImageStack(MagickFalse,MagickTrue,MagickTrue);
   }
   if (k != 0)
     ThrowCompositeException(OptionError,"UnbalancedParenthesis",argv[i]);
   if (i-- != (long) (argc-1))
     ThrowCompositeException(OptionError,"MissingAnImageFilename",argv[i]);
-  if ((image_stack[k] == (Image *) NULL) ||
-      (GetImageListLength(image_stack[k]) < 2))
+  if ((image == (Image *) NULL) ||
+      (GetImageListLength(image) < 2))
     ThrowCompositeException(OptionError,"MissingAnImageFilename",argv[argc-1]);
-  MogrifyImageStack(image_stack[k],MagickTrue,MagickTrue);
+  FireImageStack(MagickFalse,MagickTrue,MagickTrue);
   /*
     Composite images.
   */
-  composite_image=RemoveFirstImageFromList(image_stack+k);
-  image=RemoveFirstImageFromList(image_stack+k);
+  RemoveImageStack(composite_image);
+  RemoveImageStack(images);
   (void) TransformImage(&composite_image,(char *) NULL,
     composite_image->geometry);
-  mask_image=RemoveFirstImageFromList(image_stack+k);
+  RemoveImageStack(mask_image);
   if (mask_image != (Image *) NULL)
     {
-      image->mask=mask_image;
-      (void) NegateImage(image->mask,MagickFalse);
+      images->mask=mask_image;
+      (void) NegateImage(images->mask,MagickFalse);
     }
-  status&=CompositeImageList(image_info,&image,composite_image,
+  status&=CompositeImageList(image_info,&images,composite_image,
     &composite_options,exception);
   composite_image=DestroyImage(composite_image);
   /*
     Write composite images.
   */
-  status&=WriteImages(image_info,image,argv[argc-1],exception);
+  status&=WriteImages(image_info,images,argv[argc-1],exception);
   if (metadata != (char **) NULL)
     {
       char
         *text;
 
-      text=InterpretImageProperties(image_info,image,format);
+      text=InterpretImageProperties(image_info,images,format);
       if (text == (char *) NULL)
-        {
-          char
-            *message;
-
-          message=GetExceptionMessage(errno);
-          ThrowCompositeException(ResourceLimitError,"MemoryAllocationFailed",
-            message);
-          message=DestroyString(message);
-        }
+        ThrowCompositeException(ResourceLimitError,"MemoryAllocationFailed",
+          strerror(errno));
       (void) ConcatenateString(&(*metadata),text);
       (void) ConcatenateString(&(*metadata),"\n");
       text=DestroyString(text);
     }
-  image=DestroyImage(image);
+  images=DestroyImage(images);
   RelinquishCompositeOptions(&composite_options);
   DestroyComposite();
   return(status != 0 ? MagickTrue : MagickFalse);
