@@ -149,7 +149,7 @@ static void ConvertUsage(void)
       "-adaptive-blur geometry",
       "                     adaptively blur pixels; decrease effect near edges",
       "-adaptive-resize geometry",
-      "                     adaptively resize image with data dependent triangulation",
+      "                     adaptively resize image using 'mesh' interpolation",
       "-adaptive-sharpen geometry",
       "                     adaptively sharpen pixels; increase effect near edges",
       "-alpha option        activate, deactivate, reset, or set the alpha channel",
@@ -175,9 +175,10 @@ static void ConvertUsage(void)
       "                     apply a convolution kernel to the image",
       "-cycle amount        cycle the image colormap",
       "-decipher filename   convert cipher pixels to plain pixels",
+      "-deskew threshold    straighten an image",
       "-despeckle           reduce the speckles within an image",
-      "-distort type coefficients",
-      "                     distort the image",
+      "-distort method args",
+      "                     distort images according to given method ad args",
       "-draw string         annotate the image with a graphic primitive",
       "-edge radius         apply a filter to detect edges in the image",
       "-encipher filename   convert plain pixels to cipher pixels",
@@ -203,6 +204,8 @@ static void ConvertUsage(void)
       "-lat geometry        local adaptive thresholding",
       "-layers method       optimize, merge,  or compare image layers",
       "-level value         adjust the level of image contrast",
+      "-level-colors color,color",
+      "                     level image using given colors",
       "-linear-stretch geometry",
       "                     improve contrast by `stretching with saturation'",
       "-liquid-rescale geometry",
@@ -252,6 +255,8 @@ static void ConvertUsage(void)
       "                     increase the contrast without saturating highlights or shadows",
       "-sketch geometry     simulate a pencil sketch",
       "-solarize threshold  negate all pixels above the threshold level",
+      "-sparse-color method args",
+      "                     fill in a image based on a few color points",
       "-splice geometry     splice the background color into the image",
       "-spread radius       displace image pixels by a random amount",
       "-strip               strip image of all profiles and comments",
@@ -1084,6 +1089,17 @@ WandExport MagickBooleanType ConvertImageCommand(ImageInfo *image_info,
               ThrowConvertInvalidArgumentException(option,argv[i]);
             break;
           }
+        if (LocaleCompare("deskew",option+1) == 0)
+          {
+            if (*option == '+')
+              break;
+            i++;
+            if (i == (long) (argc-1))
+              ThrowConvertException(OptionError,"MissingArgument",option);
+            if (IsGeometry(argv[i]) == MagickFalse)
+              ThrowConvertInvalidArgumentException(option,argv[i]);
+            break;
+          }
         if (LocaleCompare("despeckle",option+1) == 0)
           break;
         if (LocaleCompare("display",option+1) == 0)
@@ -1558,6 +1574,13 @@ WandExport MagickBooleanType ConvertImageCommand(ImageInfo *image_info,
               ThrowConvertInvalidArgumentException(option,argv[i]);
             break;
           }
+        if (LocaleCompare("level-colors",option+1) == 0)
+          {
+            i++;
+            if (i == (long) (argc-1))
+              ThrowConvertException(OptionError,"MissingArgument",option);
+            break;
+          }
         if (LocaleCompare("linewidth",option+1) == 0)
           {
             if (*option == '+')
@@ -2262,6 +2285,29 @@ WandExport MagickBooleanType ConvertImageCommand(ImageInfo *image_info,
               ThrowConvertInvalidArgumentException(option,argv[i]);
             break;
           }
+        if (LocaleCompare("sparse-color",option+1) == 0)
+          {
+            char
+              *p;
+
+            long
+              op;
+
+            i++;
+            if (i == (long) argc)
+              ThrowConvertException(OptionError,"MissingArgument",option);
+            op=ParseMagickOption(MagickSparseColorOptions,MagickFalse,argv[i]);
+            if (op < 0)
+              ThrowConvertException(OptionError,"UnrecognizedSparseColorType",
+                argv[i]);
+            i++;
+            if (i == (long) (argc-1))
+              ThrowConvertException(OptionError,"MissingArgument",option);
+            (void) strtod(argv[i],&p);
+            if (p == argv[i])
+              ThrowConvertInvalidArgumentException(option,argv[i]);
+            break;
+          }
         if (LocaleCompare("splice",option+1) == 0)
           {
             if (*option == '+')
