@@ -120,6 +120,7 @@ static void DisplayUsage(void)
       "-contrast            enhance or reduce the image contrast",
       "-crop geometry       preferred size and location of the cropped image",
       "-decipher filename   convert cipher pixels to plain pixels",
+      "-deskew threshold    straighten an image",
       "-despeckle           reduce the speckles within an image",
       "-edge factor         apply a filter to detect edges in the image",
       "-enhance             apply a digital filter to enhance a noisy image",
@@ -139,6 +140,7 @@ static void DisplayUsage(void)
       "-segment value       segment an image",
       "-sharpen geometry    sharpen the image",
       "-strip               strip image of all profiles and comments",
+      "-threshold value     threshold the image",
       "-trim                trim image edges",
       (char *) NULL
     },
@@ -972,6 +974,17 @@ WandExport MagickBooleanType DisplayImageCommand(ImageInfo *image_info,
               ThrowDisplayInvalidArgumentException(option,argv[i]);
             break;
           }
+        if (LocaleCompare("deskew",option+1) == 0)
+          {
+            if (*option == '+')
+              break;
+            i++;
+            if (i == (long) (argc-1))
+              ThrowDisplayException(OptionError,"MissingArgument",option);
+            if (IsGeometry(argv[i]) == MagickFalse)
+              ThrowDisplayInvalidArgumentException(option,argv[i]);
+            break;
+          }
         if (LocaleCompare("despeckle",option+1) == 0)
           break;
         if (LocaleCompare("display",option+1) == 0)
@@ -1633,6 +1646,17 @@ WandExport MagickBooleanType DisplayImageCommand(ImageInfo *image_info,
               ThrowDisplayException(OptionError,"MissingArgument",option);
             break;
           }
+        if (LocaleCompare("threshold",option+1) == 0)
+          {
+            if (*option == '+')
+              break;
+            i++;
+            if (i == (long) argc)
+              ThrowDisplayException(OptionError,"MissingArgument",option);
+            if (IsGeometry(argv[i]) == MagickFalse)
+              ThrowDisplayInvalidArgumentException(option,argv[i]);
+            break;
+          }
         if (LocaleCompare("thumbnail",option+1) == 0)
           {
             if (*option == '+')
