@@ -83,9 +83,9 @@
 %
 %  A description of each parameter follows:
 %
-%    o image_info: The image info.
+%    o image_info: the image info.
 %
-%    o argc: The number of elements in the argument vector.
+%    o argc: the number of elements in the argument vector.
 %
 %    o argv: A text array containing the command line arguments.
 %
@@ -117,6 +117,7 @@ static void ImportUsage(void)
       "-border              include image borders in the output image",
       "-colors value        preferred number of colors in the image",
       "-crop geometry       preferred size and location of the cropped image",
+      "-encipher filename   convert plain pixels to cipher pixels",
       "-geometry geometry   perferred size or location of the image",
       "-help                print program options",
       "-monochrome          transform image to black and white",
@@ -148,6 +149,7 @@ static void ImportUsage(void)
       "-dispose method      layer disposal method",
       "-dither              apply Floyd/Steinberg error diffusion to image",
       "-delay value         display the next image after pausing",
+      "-encipher filename   convert plain pixels to cipher pixels",
       "-endian type         endianness (MSB or LSB) of the image",
       "-encoding type       text encoding type",
       "-filter type         use this filter when resizing an image",
@@ -166,6 +168,7 @@ static void ImportUsage(void)
       "-quality value       JPEG/MIFF/PNG compression level",
       "-quiet               suppress all warning messages",
       "-regard-warnings     pay attention to warning messages",
+      "-respect-parenthesis settings remain in effect until parenthesis boundary",
       "-sampling-factor geometry",
       "                     horizontal and vertical sampling factor",
       "-scene value         image scene number",
@@ -228,8 +231,7 @@ WandExport MagickBooleanType ImportImageCommand(ImageInfo *image_info,
       XCloseDisplay(display); \
       display=(Display *) NULL; \
     } \
-  for ( ; k >= 0; k--) \
-    image_stack[k]=DestroyImageList(image_stack[k]); \
+  DestroyImageStack(); \
   for (i=0; i < (long) argc; i++) \
     argv[i]=DestroyString(argv[i]); \
   argv=(char **) RelinquishMagickMemory(argv); \
@@ -237,7 +239,7 @@ WandExport MagickBooleanType ImportImageCommand(ImageInfo *image_info,
 #define ThrowImportException(asperity,tag,option) \
 { \
   (void) ThrowMagickException(exception,GetMagickModule(),asperity,tag,"`%s'", \
-    option); \
+     option); \
   DestroyImport(); \
   return(MagickFalse); \
 }
@@ -260,7 +262,10 @@ WandExport MagickBooleanType ImportImageCommand(ImageInfo *image_info,
     *display;
 
   Image
-    *image_stack[MaxImageStackDepth+1];
+    *image;
+
+  ImageStack
+    image_stack[MaxImageStackDepth+1];
 
   long
     j,
@@ -306,13 +311,13 @@ WandExport MagickBooleanType ImportImageCommand(ImageInfo *image_info,
           (void) fprintf(stdout,"Version: %s\n",
             GetMagickVersion((unsigned long *) NULL));
           (void) fprintf(stdout,"Copyright: %s\n\n",GetMagickCopyright());
-          return(MagickTrue);
+          return(MagickFalse);
         }
     }
   display=(Display *) NULL;
   j=1;
   k=0;
-  image_stack[k]=NewImageList();
+  NewImageStack();
   option=(char *) NULL;
   pend=MagickFalse;
   resource_database=(XrmDatabase) NULL;
@@ -326,15 +331,8 @@ WandExport MagickBooleanType ImportImageCommand(ImageInfo *image_info,
   ReadCommandlLine(argc,&argv);
   status=ExpandFilenames(&argc,&argv);
   if (status == MagickFalse)
-    {
-      char
-        *message;
-
-      message=GetExceptionMessage(errno);
-      ThrowImportException(ResourceLimitError,"MemoryAllocationFailed",
-        message);
-      message=DestroyString(message);
-    }
+    ThrowImportException(ResourceLimitError,"MemoryAllocationFailed",
+      strerror(errno));
   for (i=1; i < (long) argc; i++)
   {
     /*
@@ -367,8 +365,8 @@ WandExport MagickBooleanType ImportImageCommand(ImageInfo *image_info,
   (void) XSetErrorHandler(XError);
   resource_database=XGetResourceDatabase(display,GetClientName());
   XGetImportInfo(&ximage_info);
-  XGetResourceInfo(resource_database,GetClientName(),&resource_info);
-  image_info=resource_info.image_info;
+  XGetResourceInfo(image_info,resource_database,GetClientName(),
+    &resource_info);
   quantize_info=resource_info.quantize_info;
   resource_value=XGetResourceInstance(resource_database,GetClientName(),
     "border","False");
@@ -430,30 +428,25 @@ WandExport MagickBooleanType ImportImageCommand(ImageInfo *image_info,
     option=argv[i];
     if (LocaleCompare(option,"(") == 0)
       {
+        FireImageStack(MagickFalse,MagickTrue,pend);
         if (k == MaxImageStackDepth)
           ThrowImportException(OptionError,"ParenthesisNestedTooDeeply",
             option);
-        MogrifyImageStack(image_stack[k],MagickTrue,pend);
-        k++;
-        image_stack[k]=NewImageList();
+        PushImageStack();
         continue;
       }
     if (LocaleCompare(option,")") == 0)
       {
+        FireImageStack(MagickFalse,MagickTrue,MagickTrue);
         if (k == 0)
           ThrowImportException(OptionError,"UnableToParseExpression",option);
-        if (image_stack[k] != (Image *) NULL)
-          {
-            MogrifyImageStack(image_stack[k],MagickTrue,MagickTrue);
-            AppendImageToList(&image_stack[k-1],image_stack[k]);
-          }
-        k--;
+        PopImageStack();
         continue;
       }
     if (IsMagickOption(option) == MagickFalse)
       {
         Image
-          *image;
+          *images;
 
         unsigned long
           scene;
@@ -461,7 +454,7 @@ WandExport MagickBooleanType ImportImageCommand(ImageInfo *image_info,
         /*
           Read image from X server.
         */
-        MogrifyImageStack(image_stack[k],MagickFalse,pend);
+        FireImageStack(MagickFalse,MagickFalse,pend);
         filename=argv[i];
         if (target_window != (char *) NULL)
           (void) CopyMagickString(image_info->filename,target_window,
@@ -469,20 +462,20 @@ WandExport MagickBooleanType ImportImageCommand(ImageInfo *image_info,
         for (scene=0; scene < (unsigned long) MagickMax(snapshots,1); scene++)
         {
           (void) sleep(resource_info.pause);
-          image=XImportImage(image_info,&ximage_info);
-          status&=(image != (Image *) NULL) &&
+          images=XImportImage(image_info,&ximage_info);
+          status&=(images != (Image *) NULL) &&
             (exception->severity < ErrorException);
-          if (image == (Image *) NULL)
+          if (images == (Image *) NULL)
             continue;
-          (void) CopyMagickString(image->filename,filename,MaxTextExtent);
-          (void) CopyMagickString(image->magick,"PS",MaxTextExtent);
-          image->scene=scene;
-          AppendImageToList(&image_stack[k],image);
-          MogrifyImageStack(image_stack[k],MagickFalse,MagickTrue);
+          (void) CopyMagickString(images->filename,filename,MaxTextExtent);
+          (void) CopyMagickString(images->magick,"PS",MaxTextExtent);
+          images->scene=scene;
+          AppendImageStack(images);
+          FireImageStack(MagickFalse,MagickFalse,MagickTrue);
         }
         continue;
       }
-    pend=image_stack[k] != (Image *) NULL ? MagickTrue : MagickFalse;
+    pend=image != (Image *) NULL ? MagickTrue : MagickFalse;
     switch(*(option+1))
     {
       case 'a':
@@ -735,6 +728,15 @@ WandExport MagickBooleanType ImportImageCommand(ImageInfo *image_info,
       }
       case 'e':
       {
+        if (LocaleCompare("encipher",option+1) == 0)
+          {
+            if (*option == '+')
+              break;
+            i++;
+            if (i == (long) (argc-1))
+              ThrowImportException(OptionError,"MissingArgument",option);
+            break;
+          }
         if (LocaleCompare("encoding",option+1) == 0)
           {
             if (*option == '+')
@@ -1048,6 +1050,11 @@ WandExport MagickBooleanType ImportImageCommand(ImageInfo *image_info,
               ThrowImportInvalidArgumentException(option,argv[i]);
             break;
           }
+        if (LocaleCompare("respect-parenthesis",option+1) == 0)
+          {
+            respect_parenthesis=(*option == '-') ? MagickTrue : MagickFalse;
+            break;
+          }
         if (LocaleCompare("rotate",option+1) == 0)
           {
             i++;
@@ -1108,7 +1115,7 @@ WandExport MagickBooleanType ImportImageCommand(ImageInfo *image_info,
             if (*option == '+')
               {
                 seed=(unsigned long) time((time_t *) NULL);
-                SeedRandomReservoir(seed);
+                SeedPseudoRandomGenerator(seed);
                 break;
               }
             i++;
@@ -1117,7 +1124,7 @@ WandExport MagickBooleanType ImportImageCommand(ImageInfo *image_info,
             if (IsGeometry(argv[i]) == MagickFalse)
               ThrowImportInvalidArgumentException(option,argv[i]);
             seed=(unsigned long) atol(argv[i]);
-            SeedRandomReservoir(seed);
+            SeedPseudoRandomGenerator(seed);
             break;
           }
         if (LocaleCompare("silent",option+1) == 0)
@@ -1235,25 +1242,25 @@ WandExport MagickBooleanType ImportImageCommand(ImageInfo *image_info,
       default:
         ThrowImportException(OptionError,"UnrecognizedOption",option);
     }
-    fire=(MagickBooleanType) ParseMagickOption(MagickMogrifyOptions,
-      MagickFalse,option+1);
-    if (fire == MagickTrue)
-      MogrifyImageStack(image_stack[k],MagickTrue,MagickTrue);
+    fire=ParseMagickOption(MagickMogrifyOptions,MagickFalse,option+1) < 0 ? 
+      MagickFalse : MagickTrue;
+    if (fire != MagickFalse)
+      FireImageStack(MagickFalse,MagickTrue,MagickTrue);
   }
   if (k != 0)
     ThrowImportException(OptionError,"UnbalancedParenthesis",argv[i]);
   if (i != argc)
     ThrowImportException(OptionError,"MissingAnImageFilename",argv[i]);
-  if (image_stack[k] == (Image *) NULL)
+  if (image == (Image *) NULL)
     ThrowImportException(OptionError,"MissingAnImageFilename",argv[argc-1]);
-  MogrifyImageStack(image_stack[k],MagickTrue,MagickTrue)
-  GetImageException(image_stack[k],exception);
-  status&=WriteImages(image_info,image_stack[k],filename,exception);
+  FireImageStack(MagickFalse,MagickTrue,MagickTrue)
+  GetImageException(image,exception);
+  status&=WriteImages(image_info,image,filename,exception);
   DestroyImport();
   return(status != 0 ? MagickTrue : MagickFalse);
 #else
   (void) ThrowMagickException(exception,GetMagickModule(),MissingDelegateError,
-    "XWindowLibraryIsNotAvailable","`%s'",image_info->filename);
+    "DelegateLibrarySupportNotBuiltIn","`%s' (X11)",image_info->filename);
   ImportUsage();
   return(MagickFalse);
 #endif
