@@ -65,6 +65,12 @@ extern "C" {
 # else
 #  include "magick-config.h"
 # endif
+#if defined(_magickcore_const) && !defined(const)
+# define const _magickcore_const
+#endif
+#if defined(_magickcore_inline) && !defined(inline)
+# define inline _magickcore_inline
+#endif
 # if defined(__cplusplus) || defined(c_plusplus)
 #  undef inline
 # endif
@@ -174,6 +180,16 @@ extern "C" {
 #include <signal.h>
 #include <assert.h>
 
+#if defined(MAGICKCORE_HAVE_PTHREAD )
+# include <pthread.h>
+#endif
+#if defined(MAGICKCORE_HAVE_SYS_SYSLIMITS_H)
+# include <sys/syslimits.h>
+#endif
+#if defined(MAGICKCORE_HAVE_ARM_LIMITS_H)
+# include <arm/limits.h>
+#endif
+
 #if defined(MAGICKCORE_HAVE_PREAD) && defined(MAGICKCORE_HAVE_DECL_PREAD) && !MAGICKCORE_HAVE_DECL_PREAD
 ssize_t pread(int,void *,size_t,off_t);
 #endif
