@@ -427,7 +427,22 @@ int main(int argc,char **argv)
       exit(1);
     }
   (void) fprintf(stdout,"Reading images...\n");
-  status=MagickReadImage(magick_wand,"sequence.miff");
+  {
+    char
+      *p,
+      path[MaxTextExtent];
+
+    path[0]=0;
+    p=getenv("SRCDIR");
+    if (p != (char *) NULL)
+      {
+        (void) strcpy(path,p);
+        if (path[strlen(path)-1] != '/')
+          (void) strcat(path,"/");
+      }
+    (void) strcat(path,"sequence.miff");
+    status=MagickReadImage(magick_wand,path);
+  }
   if (status == MagickFalse)
     ThrowAPIException(magick_wand);
   if (MagickGetNumberImages(magick_wand) != 5)
@@ -559,8 +574,8 @@ int main(int argc,char **argv)
   }
   (void) PixelSyncIterator(iterator);
   iterator=DestroyPixelIterator(iterator);
-  (void) fprintf(stdout,"Write to image.miff...\n");
-  status=MagickWriteImages(magick_wand,"image.miff",MagickTrue);
+  (void) fprintf(stdout,"Write to wandtest_out.miff...\n");
+  status=MagickWriteImages(magick_wand,"wandtest_out.miff",MagickTrue);
   if (status == MagickFalse)
     ThrowAPIException(magick_wand);
   (void) fprintf(stdout,"Change image format from \"MIFF\" to \"GIF\"...\n");
@@ -578,8 +593,8 @@ int main(int argc,char **argv)
       (void) fprintf( stderr,"Get delay does not match set delay\n");
       exit(1);
     }
-  (void) fprintf(stdout,"Write to image_0.gif...\n");
-  status=MagickWriteImages(magick_wand,"image.gif",MagickTrue);
+  (void) fprintf(stdout,"Write to wandtest_out_0.gif...\n");
+  status=MagickWriteImages(magick_wand,"wandtest_out.gif",MagickTrue);
   if (status == MagickFalse)
     ThrowAPIException(magick_wand);
   (void) fprintf(stdout,"Set, list, get, and delete wand option...\n");
